/*     */ package com.google.zxing.aztec.decoder;
/*     */ 
/*     */ import com.google.zxing.FormatException;
/*     */ import com.google.zxing.aztec.AztecDetectorResult;
/*     */ import com.google.zxing.common.BitMatrix;
/*     */ import com.google.zxing.common.DecoderResult;
/*     */ import com.google.zxing.common.reedsolomon.GenericGF;
/*     */ import com.google.zxing.common.reedsolomon.ReedSolomonDecoder;
/*     */ import com.google.zxing.common.reedsolomon.ReedSolomonException;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public final class Decoder
/*     */ {
/*     */   private enum Table
/*     */   {
/*  36 */     UPPER,
/*  37 */     LOWER,
/*  38 */     MIXED,
/*  39 */     DIGIT,
/*  40 */     PUNCT,
/*  41 */     BINARY;
/*     */   }
/*     */   
/*  44 */   private static final int[] NB_BITS_COMPACT = new int[] { 0, 104, 240, 408, 608 };
/*     */ 
/*     */ 
/*     */   
/*  48 */   private static final int[] NB_BITS = new int[] { 0, 128, 288, 480, 704, 960, 1248, 1568, 1920, 2304, 2720, 3168, 3648, 4160, 4704, 5280, 5888, 6528, 7200, 7904, 8640, 9408, 10208, 11040, 11904, 12800, 13728, 14688, 15680, 16704, 17760, 18848, 19968 };
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  53 */   private static final int[] NB_DATABLOCK_COMPACT = new int[] { 0, 17, 40, 51, 76 };
/*     */ 
/*     */ 
/*     */   
/*  57 */   private static final int[] NB_DATABLOCK = new int[] { 0, 21, 48, 60, 88, 120, 156, 196, 240, 230, 272, 316, 364, 416, 470, 528, 588, 652, 720, 790, 864, 940, 1020, 920, 992, 1066, 1144, 1224, 1306, 1392, 1480, 1570, 1664 };
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  62 */   private static final String[] UPPER_TABLE = new String[] { "CTRL_PS", " ", "A", "B", "C", "D", "E", "F", "G", "H", "I", "J", "K", "L", "M", "N", "O", "P", "Q", "R", "S", "T", "U", "V", "W", "X", "Y", "Z", "CTRL_LL", "CTRL_ML", "CTRL_DL", "CTRL_BS" };
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  67 */   private static final String[] LOWER_TABLE = new String[] { "CTRL_PS", " ", "a", "b", "c", "d", "e", "f", "g", "h", "i", "j", "k", "l", "m", "n", "o", "p", "q", "r", "s", "t", "u", "v", "w", "x", "y", "z", "CTRL_US", "CTRL_ML", "CTRL_DL", "CTRL_BS" };
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  72 */   private static final String[] MIXED_TABLE = new String[] { "CTRL_PS", " ", "\001", "\002", "\003", "\004", "\005", "\006", "\007", "\b", "\t", "\n", "\013", "\f", "\r", "\033", "\034", "\035", "\036", "\037", "@", "\\", "^", "_", "`", "|", "~", "", "CTRL_LL", "CTRL_UL", "CTRL_PL", "CTRL_BS" };
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  78 */   private static final String[] PUNCT_TABLE = new String[] { "", "\r", "\r\n", ". ", ", ", ": ", "!", "\"", "#", "$", "%", "&", "'", "(", ")", "*", "+", ",", "-", ".", "/", ":", ";", "<", "=", ">", "?", "[", "]", "{", "}", "CTRL_UL" };
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  83 */   private static final String[] DIGIT_TABLE = new String[] { "CTRL_PS", " ", "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", ",", ".", "CTRL_UL", "CTRL_US" };
/*     */   
/*     */   private int numCodewords;
/*     */   
/*     */   private int codewordSize;
/*     */   
/*     */   private AztecDetectorResult ddata;
/*     */   private int invertedBitCount;
/*     */   
/*     */   public DecoderResult decode(AztecDetectorResult detectorResult) throws FormatException {
/*  93 */     this.ddata = detectorResult;
/*  94 */     BitMatrix matrix = detectorResult.getBits();
/*     */     
/*  96 */     if (!this.ddata.isCompact()) {
/*  97 */       matrix = removeDashedLines(this.ddata.getBits());
/*     */     }
/*     */     
/* 100 */     boolean[] rawbits = extractBits(matrix);
/*     */     
/* 102 */     boolean[] correctedBits = correctBits(rawbits);
/*     */     
/* 104 */     String result = getEncodedData(correctedBits);
/*     */     
/* 106 */     return new DecoderResult(null, result, null, null);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private String getEncodedData(boolean[] correctedBits) throws FormatException {
/* 117 */     int endIndex = this.codewordSize * this.ddata.getNbDatablocks() - this.invertedBitCount;
/* 118 */     if (endIndex > correctedBits.length) {
/* 119 */       throw FormatException.getFormatInstance();
/*     */     }
/*     */     
/* 122 */     Table lastTable = Table.UPPER;
/* 123 */     Table table = Table.UPPER;
/* 124 */     int startIndex = 0;
/* 125 */     StringBuilder result = new StringBuilder(20);
/* 126 */     boolean end = false;
/* 127 */     boolean shift = false;
/* 128 */     boolean switchShift = false;
/* 129 */     boolean binaryShift = false;
/*     */     
/* 131 */     while (!end) {
/*     */       
/* 133 */       if (shift) {
/*     */         
/* 135 */         switchShift = true;
/*     */       } else {
/*     */         
/* 138 */         lastTable = table;
/*     */       } 
/*     */ 
/*     */       
/* 142 */       if (binaryShift) {
/* 143 */         if (endIndex - startIndex < 5) {
/*     */           break;
/*     */         }
/*     */         
/* 147 */         int length = readCode(correctedBits, startIndex, 5);
/* 148 */         startIndex += 5;
/* 149 */         if (length == 0) {
/* 150 */           if (endIndex - startIndex < 11) {
/*     */             break;
/*     */           }
/*     */           
/* 154 */           length = readCode(correctedBits, startIndex, 11) + 31;
/* 155 */           startIndex += 11;
/*     */         } 
/* 157 */         for (int charCount = 0; charCount < length; charCount++) {
/* 158 */           if (endIndex - startIndex < 8) {
/* 159 */             end = true;
/*     */             
/*     */             break;
/*     */           } 
/* 163 */           int code = readCode(correctedBits, startIndex, 8);
/* 164 */           result.append((char)code);
/* 165 */           startIndex += 8;
/*     */         } 
/* 167 */         binaryShift = false;
/*     */       }
/* 169 */       else if (table == Table.BINARY) {
/* 170 */         if (endIndex - startIndex < 8) {
/*     */           break;
/*     */         }
/* 173 */         int code = readCode(correctedBits, startIndex, 8);
/* 174 */         startIndex += 8;
/*     */         
/* 176 */         result.append((char)code);
/*     */       } else {
/*     */         
/* 179 */         int size = 5;
/*     */         
/* 181 */         if (table == Table.DIGIT) {
/* 182 */           size = 4;
/*     */         }
/*     */         
/* 185 */         if (endIndex - startIndex < size) {
/*     */           break;
/*     */         }
/*     */         
/* 189 */         int code = readCode(correctedBits, startIndex, size);
/* 190 */         startIndex += size;
/*     */         
/* 192 */         String str = getCharacter(table, code);
/* 193 */         if (str.startsWith("CTRL_")) {
/*     */           
/* 195 */           table = getTable(str.charAt(5));
/*     */           
/* 197 */           if (str.charAt(6) == 'S') {
/* 198 */             shift = true;
/* 199 */             if (str.charAt(5) == 'B') {
/* 200 */               binaryShift = true;
/*     */             }
/*     */           } 
/*     */         } else {
/* 204 */           result.append(str);
/*     */         } 
/*     */       } 
/*     */ 
/*     */ 
/*     */ 
/*     */       
/* 211 */       if (switchShift) {
/* 212 */         table = lastTable;
/* 213 */         shift = false;
/* 214 */         switchShift = false;
/*     */       } 
/*     */     } 
/*     */     
/* 218 */     return result.toString();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static Table getTable(char t) {
/* 226 */     switch (t) {
/*     */       case 'L':
/* 228 */         return Table.LOWER;
/*     */       case 'P':
/* 230 */         return Table.PUNCT;
/*     */       case 'M':
/* 232 */         return Table.MIXED;
/*     */       case 'D':
/* 234 */         return Table.DIGIT;
/*     */       case 'B':
/* 236 */         return Table.BINARY;
/*     */     } 
/*     */     
/* 239 */     return Table.UPPER;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static String getCharacter(Table table, int code) {
/* 250 */     switch (table) {
/*     */       case UPPER:
/* 252 */         return UPPER_TABLE[code];
/*     */       case LOWER:
/* 254 */         return LOWER_TABLE[code];
/*     */       case MIXED:
/* 256 */         return MIXED_TABLE[code];
/*     */       case PUNCT:
/* 258 */         return PUNCT_TABLE[code];
/*     */       case DIGIT:
/* 260 */         return DIGIT_TABLE[code];
/*     */     } 
/* 262 */     return "";
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private boolean[] correctBits(boolean[] rawbits) throws FormatException {
/*     */     GenericGF gf;
/*     */     int numECCodewords;
/* 275 */     if (this.ddata.getNbLayers() <= 2) {
/* 276 */       this.codewordSize = 6;
/* 277 */       gf = GenericGF.AZTEC_DATA_6;
/* 278 */     } else if (this.ddata.getNbLayers() <= 8) {
/* 279 */       this.codewordSize = 8;
/* 280 */       gf = GenericGF.AZTEC_DATA_8;
/* 281 */     } else if (this.ddata.getNbLayers() <= 22) {
/* 282 */       this.codewordSize = 10;
/* 283 */       gf = GenericGF.AZTEC_DATA_10;
/*     */     } else {
/* 285 */       this.codewordSize = 12;
/* 286 */       gf = GenericGF.AZTEC_DATA_12;
/*     */     } 
/*     */     
/* 289 */     int numDataCodewords = this.ddata.getNbDatablocks();
/*     */ 
/*     */ 
/*     */     
/* 293 */     if (this.ddata.isCompact()) {
/* 294 */       offset = NB_BITS_COMPACT[this.ddata.getNbLayers()] - this.numCodewords * this.codewordSize;
/* 295 */       numECCodewords = NB_DATABLOCK_COMPACT[this.ddata.getNbLayers()] - numDataCodewords;
/*     */     } else {
/* 297 */       offset = NB_BITS[this.ddata.getNbLayers()] - this.numCodewords * this.codewordSize;
/* 298 */       numECCodewords = NB_DATABLOCK[this.ddata.getNbLayers()] - numDataCodewords;
/*     */     } 
/*     */     
/* 301 */     int[] dataWords = new int[this.numCodewords];
/* 302 */     for (int i = 0; i < this.numCodewords; i++) {
/* 303 */       int flag = 1;
/* 304 */       for (int k = 1; k <= this.codewordSize; k++) {
/* 305 */         if (rawbits[this.codewordSize * i + this.codewordSize - k + offset]) {
/* 306 */           dataWords[i] = dataWords[i] + flag;
/*     */         }
/* 308 */         flag <<= 1;
/*     */       } 
/*     */     } 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     try {
/* 317 */       ReedSolomonDecoder rsDecoder = new ReedSolomonDecoder(gf);
/* 318 */       rsDecoder.decode(dataWords, numECCodewords);
/* 319 */     } catch (ReedSolomonException ignored) {
/* 320 */       throw FormatException.getFormatInstance();
/*     */     } 
/*     */     
/* 323 */     int offset = 0;
/* 324 */     this.invertedBitCount = 0;
/*     */     
/* 326 */     boolean[] correctedBits = new boolean[numDataCodewords * this.codewordSize];
/* 327 */     for (int j = 0; j < numDataCodewords; j++) {
/*     */       
/* 329 */       boolean seriesColor = false;
/* 330 */       int seriesCount = 0;
/* 331 */       int flag = 1 << this.codewordSize - 1;
/*     */       
/* 333 */       for (int k = 0; k < this.codewordSize; k++) {
/*     */         
/* 335 */         boolean color = ((dataWords[j] & flag) == flag);
/*     */         
/* 337 */         if (seriesCount == this.codewordSize - 1) {
/*     */           
/* 339 */           if (color == seriesColor)
/*     */           {
/* 341 */             throw FormatException.getFormatInstance();
/*     */           }
/*     */           
/* 344 */           seriesColor = false;
/* 345 */           seriesCount = 0;
/* 346 */           offset++;
/* 347 */           this.invertedBitCount++;
/*     */         } else {
/*     */           
/* 350 */           if (seriesColor == color) {
/* 351 */             seriesCount++;
/*     */           } else {
/* 353 */             seriesCount = 1;
/* 354 */             seriesColor = color;
/*     */           } 
/*     */           
/* 357 */           correctedBits[j * this.codewordSize + k - offset] = color;
/*     */         } 
/*     */ 
/*     */         
/* 361 */         flag >>>= 1;
/*     */       } 
/*     */     } 
/*     */     
/* 365 */     return correctedBits;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private boolean[] extractBits(BitMatrix matrix) throws FormatException {
/*     */     boolean[] rawbits;
/* 377 */     if (this.ddata.isCompact()) {
/* 378 */       if (this.ddata.getNbLayers() > NB_BITS_COMPACT.length) {
/* 379 */         throw FormatException.getFormatInstance();
/*     */       }
/* 381 */       rawbits = new boolean[NB_BITS_COMPACT[this.ddata.getNbLayers()]];
/* 382 */       this.numCodewords = NB_DATABLOCK_COMPACT[this.ddata.getNbLayers()];
/*     */     } else {
/* 384 */       if (this.ddata.getNbLayers() > NB_BITS.length) {
/* 385 */         throw FormatException.getFormatInstance();
/*     */       }
/* 387 */       rawbits = new boolean[NB_BITS[this.ddata.getNbLayers()]];
/* 388 */       this.numCodewords = NB_DATABLOCK[this.ddata.getNbLayers()];
/*     */     } 
/*     */     
/* 391 */     int layer = this.ddata.getNbLayers();
/* 392 */     int size = matrix.getHeight();
/* 393 */     int rawbitsOffset = 0;
/* 394 */     int matrixOffset = 0;
/*     */     
/* 396 */     while (layer != 0) {
/*     */       
/* 398 */       int flip = 0; int i;
/* 399 */       for (i = 0; i < 2 * size - 4; i++) {
/* 400 */         rawbits[rawbitsOffset + i] = matrix.get(matrixOffset + flip, matrixOffset + i / 2);
/* 401 */         rawbits[rawbitsOffset + 2 * size - 4 + i] = matrix.get(matrixOffset + i / 2, matrixOffset + size - 1 - flip);
/* 402 */         flip = (flip + 1) % 2;
/*     */       } 
/*     */       
/* 405 */       flip = 0;
/* 406 */       for (i = 2 * size + 1; i > 5; i--) {
/* 407 */         rawbits[rawbitsOffset + 4 * size - 8 + 2 * size - i + 1] = matrix.get(matrixOffset + size - 1 - flip, matrixOffset + i / 2 - 1);
/*     */         
/* 409 */         rawbits[rawbitsOffset + 6 * size - 12 + 2 * size - i + 1] = matrix.get(matrixOffset + i / 2 - 1, matrixOffset + flip);
/*     */         
/* 411 */         flip = (flip + 1) % 2;
/*     */       } 
/*     */       
/* 414 */       matrixOffset += 2;
/* 415 */       rawbitsOffset += 8 * size - 16;
/* 416 */       layer--;
/* 417 */       size -= 4;
/*     */     } 
/*     */     
/* 420 */     return rawbits;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static BitMatrix removeDashedLines(BitMatrix matrix) {
/* 427 */     int nbDashed = 1 + 2 * (matrix.getWidth() - 1) / 2 / 16;
/* 428 */     BitMatrix newMatrix = new BitMatrix(matrix.getWidth() - nbDashed, matrix.getHeight() - nbDashed);
/*     */     
/* 430 */     int nx = 0;
/*     */     
/* 432 */     for (int x = 0; x < matrix.getWidth(); x++) {
/*     */       
/* 434 */       if ((matrix.getWidth() / 2 - x) % 16 != 0) {
/*     */ 
/*     */ 
/*     */         
/* 438 */         int ny = 0;
/* 439 */         for (int y = 0; y < matrix.getHeight(); y++) {
/*     */           
/* 441 */           if ((matrix.getWidth() / 2 - y) % 16 != 0) {
/*     */ 
/*     */ 
/*     */             
/* 445 */             if (matrix.get(x, y)) {
/* 446 */               newMatrix.set(nx, ny);
/*     */             }
/* 448 */             ny++;
/*     */           } 
/* 450 */         }  nx++;
/*     */       } 
/*     */     } 
/* 453 */     return newMatrix;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static int readCode(boolean[] rawbits, int startIndex, int length) {
/* 460 */     int res = 0;
/*     */     
/* 462 */     for (int i = startIndex; i < startIndex + length; i++) {
/* 463 */       res <<= 1;
/* 464 */       if (rawbits[i]) {
/* 465 */         res++;
/*     */       }
/*     */     } 
/*     */     
/* 469 */     return res;
/*     */   }
/*     */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\com\google\zxing\aztec\decoder\Decoder.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       1.1.3
 */