/*     */ package com.google.zxing.aztec.detector;
/*     */ 
/*     */ import com.google.zxing.NotFoundException;
/*     */ import com.google.zxing.ResultPoint;
/*     */ import com.google.zxing.aztec.AztecDetectorResult;
/*     */ import com.google.zxing.common.BitMatrix;
/*     */ import com.google.zxing.common.GridSampler;
/*     */ import com.google.zxing.common.detector.MathUtils;
/*     */ import com.google.zxing.common.detector.WhiteRectangleDetector;
/*     */ import com.google.zxing.common.reedsolomon.GenericGF;
/*     */ import com.google.zxing.common.reedsolomon.ReedSolomonDecoder;
/*     */ import com.google.zxing.common.reedsolomon.ReedSolomonException;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public final class Detector
/*     */ {
/*     */   private final BitMatrix image;
/*     */   private boolean compact;
/*     */   private int nbLayers;
/*     */   private int nbDataBlocks;
/*     */   private int nbCenterLayers;
/*     */   private int shift;
/*     */   
/*     */   public Detector(BitMatrix image) {
/*  47 */     this.image = image;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public AztecDetectorResult detect() throws NotFoundException {
/*  59 */     Point pCenter = getMatrixCenter();
/*     */ 
/*     */     
/*  62 */     Point[] bullEyeCornerPoints = getBullEyeCornerPoints(pCenter);
/*     */ 
/*     */     
/*  65 */     extractParameters(bullEyeCornerPoints);
/*     */ 
/*     */     
/*  68 */     ResultPoint[] corners = getMatrixCornerPoints(bullEyeCornerPoints);
/*     */ 
/*     */     
/*  71 */     BitMatrix bits = sampleGrid(this.image, corners[this.shift % 4], corners[(this.shift + 3) % 4], corners[(this.shift + 2) % 4], corners[(this.shift + 1) % 4]);
/*     */     
/*  73 */     return new AztecDetectorResult(bits, corners, this.compact, this.nbDataBlocks, this.nbLayers);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private void extractParameters(Point[] bullEyeCornerPoints) throws NotFoundException {
/*     */     boolean[] parameterData;
/*  84 */     int twoCenterLayers = 2 * this.nbCenterLayers;
/*     */ 
/*     */     
/*  87 */     boolean[] resab = sampleLine(bullEyeCornerPoints[0], bullEyeCornerPoints[1], twoCenterLayers + 1);
/*  88 */     boolean[] resbc = sampleLine(bullEyeCornerPoints[1], bullEyeCornerPoints[2], twoCenterLayers + 1);
/*  89 */     boolean[] rescd = sampleLine(bullEyeCornerPoints[2], bullEyeCornerPoints[3], twoCenterLayers + 1);
/*  90 */     boolean[] resda = sampleLine(bullEyeCornerPoints[3], bullEyeCornerPoints[0], twoCenterLayers + 1);
/*     */ 
/*     */     
/*  93 */     if (resab[0] && resab[twoCenterLayers]) {
/*  94 */       this.shift = 0;
/*  95 */     } else if (resbc[0] && resbc[twoCenterLayers]) {
/*  96 */       this.shift = 1;
/*  97 */     } else if (rescd[0] && rescd[twoCenterLayers]) {
/*  98 */       this.shift = 2;
/*  99 */     } else if (resda[0] && resda[twoCenterLayers]) {
/* 100 */       this.shift = 3;
/*     */     } else {
/* 102 */       throw NotFoundException.getNotFoundInstance();
/*     */     } 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 112 */     if (this.compact) {
/* 113 */       boolean[] shiftedParameterData = new boolean[28]; int i;
/* 114 */       for (i = 0; i < 7; i++) {
/* 115 */         shiftedParameterData[i] = resab[2 + i];
/* 116 */         shiftedParameterData[i + 7] = resbc[2 + i];
/* 117 */         shiftedParameterData[i + 14] = rescd[2 + i];
/* 118 */         shiftedParameterData[i + 21] = resda[2 + i];
/*     */       } 
/*     */       
/* 121 */       parameterData = new boolean[28];
/* 122 */       for (i = 0; i < 28; i++) {
/* 123 */         parameterData[i] = shiftedParameterData[(i + this.shift * 7) % 28];
/*     */       }
/*     */     } else {
/* 126 */       boolean[] shiftedParameterData = new boolean[40]; int i;
/* 127 */       for (i = 0; i < 11; i++) {
/* 128 */         if (i < 5) {
/* 129 */           shiftedParameterData[i] = resab[2 + i];
/* 130 */           shiftedParameterData[i + 10] = resbc[2 + i];
/* 131 */           shiftedParameterData[i + 20] = rescd[2 + i];
/* 132 */           shiftedParameterData[i + 30] = resda[2 + i];
/*     */         } 
/* 134 */         if (i > 5) {
/* 135 */           shiftedParameterData[i - 1] = resab[2 + i];
/* 136 */           shiftedParameterData[i + 9] = resbc[2 + i];
/* 137 */           shiftedParameterData[i + 19] = rescd[2 + i];
/* 138 */           shiftedParameterData[i + 29] = resda[2 + i];
/*     */         } 
/*     */       } 
/*     */       
/* 142 */       parameterData = new boolean[40];
/* 143 */       for (i = 0; i < 40; i++) {
/* 144 */         parameterData[i] = shiftedParameterData[(i + this.shift * 10) % 40];
/*     */       }
/*     */     } 
/*     */ 
/*     */     
/* 149 */     correctParameterData(parameterData, this.compact);
/*     */ 
/*     */     
/* 152 */     getParameters(parameterData);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private ResultPoint[] getMatrixCornerPoints(Point[] bullEyeCornerPoints) throws NotFoundException {
/* 164 */     float ratio = (2 * this.nbLayers + ((this.nbLayers > 4) ? 1 : 0) + (this.nbLayers - 4) / 8) / 2.0F * this.nbCenterLayers;
/*     */ 
/*     */     
/* 167 */     int dx = bullEyeCornerPoints[0].getX() - bullEyeCornerPoints[2].getX();
/* 168 */     dx += (dx > 0) ? 1 : -1;
/* 169 */     int dy = bullEyeCornerPoints[0].getY() - bullEyeCornerPoints[2].getY();
/* 170 */     dy += (dy > 0) ? 1 : -1;
/*     */     
/* 172 */     int targetcx = MathUtils.round(bullEyeCornerPoints[2].getX() - ratio * dx);
/* 173 */     int targetcy = MathUtils.round(bullEyeCornerPoints[2].getY() - ratio * dy);
/*     */     
/* 175 */     int targetax = MathUtils.round(bullEyeCornerPoints[0].getX() + ratio * dx);
/* 176 */     int targetay = MathUtils.round(bullEyeCornerPoints[0].getY() + ratio * dy);
/*     */     
/* 178 */     dx = bullEyeCornerPoints[1].getX() - bullEyeCornerPoints[3].getX();
/* 179 */     dx += (dx > 0) ? 1 : -1;
/* 180 */     dy = bullEyeCornerPoints[1].getY() - bullEyeCornerPoints[3].getY();
/* 181 */     dy += (dy > 0) ? 1 : -1;
/*     */     
/* 183 */     int targetdx = MathUtils.round(bullEyeCornerPoints[3].getX() - ratio * dx);
/* 184 */     int targetdy = MathUtils.round(bullEyeCornerPoints[3].getY() - ratio * dy);
/* 185 */     int targetbx = MathUtils.round(bullEyeCornerPoints[1].getX() + ratio * dx);
/* 186 */     int targetby = MathUtils.round(bullEyeCornerPoints[1].getY() + ratio * dy);
/*     */     
/* 188 */     if (!isValid(targetax, targetay) || !isValid(targetbx, targetby) || !isValid(targetcx, targetcy) || !isValid(targetdx, targetdy))
/*     */     {
/*     */ 
/*     */       
/* 192 */       throw NotFoundException.getNotFoundInstance();
/*     */     }
/*     */     
/* 195 */     return new ResultPoint[] { new ResultPoint(targetax, targetay), new ResultPoint(targetbx, targetby), new ResultPoint(targetcx, targetcy), new ResultPoint(targetdx, targetdy) };
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static void correctParameterData(boolean[] parameterData, boolean compact) throws NotFoundException {
/*     */     int numCodewords, numDataCodewords;
/* 215 */     if (compact) {
/* 216 */       numCodewords = 7;
/* 217 */       numDataCodewords = 2;
/*     */     } else {
/* 219 */       numCodewords = 10;
/* 220 */       numDataCodewords = 4;
/*     */     } 
/*     */     
/* 223 */     int numECCodewords = numCodewords - numDataCodewords;
/* 224 */     int[] parameterWords = new int[numCodewords];
/*     */     
/* 226 */     int codewordSize = 4; int i;
/* 227 */     for (i = 0; i < numCodewords; i++) {
/* 228 */       int flag = 1;
/* 229 */       for (int j = 1; j <= codewordSize; j++) {
/* 230 */         if (parameterData[codewordSize * i + codewordSize - j]) {
/* 231 */           parameterWords[i] = parameterWords[i] + flag;
/*     */         }
/* 233 */         flag <<= 1;
/*     */       } 
/*     */     } 
/*     */     
/*     */     try {
/* 238 */       ReedSolomonDecoder rsDecoder = new ReedSolomonDecoder(GenericGF.AZTEC_PARAM);
/* 239 */       rsDecoder.decode(parameterWords, numECCodewords);
/* 240 */     } catch (ReedSolomonException ignored) {
/* 241 */       throw NotFoundException.getNotFoundInstance();
/*     */     } 
/*     */     
/* 244 */     for (i = 0; i < numDataCodewords; i++) {
/* 245 */       int flag = 1;
/* 246 */       for (int j = 1; j <= codewordSize; j++) {
/* 247 */         parameterData[i * codewordSize + codewordSize - j] = ((parameterWords[i] & flag) == flag);
/* 248 */         flag <<= 1;
/*     */       } 
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private Point[] getBullEyeCornerPoints(Point pCenter) throws NotFoundException {
/* 262 */     Point pina = pCenter;
/* 263 */     Point pinb = pCenter;
/* 264 */     Point pinc = pCenter;
/* 265 */     Point pind = pCenter;
/*     */     
/* 267 */     boolean color = true;
/*     */     
/* 269 */     for (this.nbCenterLayers = 1; this.nbCenterLayers < 9; this.nbCenterLayers++) {
/* 270 */       Point pouta = getFirstDifferent(pina, color, 1, -1);
/* 271 */       Point poutb = getFirstDifferent(pinb, color, 1, 1);
/* 272 */       Point poutc = getFirstDifferent(pinc, color, -1, 1);
/* 273 */       Point poutd = getFirstDifferent(pind, color, -1, -1);
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */       
/* 279 */       if (this.nbCenterLayers > 2) {
/* 280 */         float q = distance(poutd, pouta) * this.nbCenterLayers / distance(pind, pina) * (this.nbCenterLayers + 2);
/* 281 */         if (q < 0.75D || q > 1.25D || !isWhiteOrBlackRectangle(pouta, poutb, poutc, poutd)) {
/*     */           break;
/*     */         }
/*     */       } 
/*     */       
/* 286 */       pina = pouta;
/* 287 */       pinb = poutb;
/* 288 */       pinc = poutc;
/* 289 */       pind = poutd;
/*     */       
/* 291 */       color = !color;
/*     */     } 
/*     */     
/* 294 */     if (this.nbCenterLayers != 5 && this.nbCenterLayers != 7) {
/* 295 */       throw NotFoundException.getNotFoundInstance();
/*     */     }
/*     */     
/* 298 */     this.compact = (this.nbCenterLayers == 5);
/*     */     
/* 300 */     float ratio = 1.5F / (2 * this.nbCenterLayers - 3);
/*     */     
/* 302 */     int dx = pina.getX() - pinc.getX();
/* 303 */     int dy = pina.getY() - pinc.getY();
/* 304 */     int targetcx = MathUtils.round(pinc.getX() - ratio * dx);
/* 305 */     int targetcy = MathUtils.round(pinc.getY() - ratio * dy);
/* 306 */     int targetax = MathUtils.round(pina.getX() + ratio * dx);
/* 307 */     int targetay = MathUtils.round(pina.getY() + ratio * dy);
/*     */     
/* 309 */     dx = pinb.getX() - pind.getX();
/* 310 */     dy = pinb.getY() - pind.getY();
/*     */     
/* 312 */     int targetdx = MathUtils.round(pind.getX() - ratio * dx);
/* 313 */     int targetdy = MathUtils.round(pind.getY() - ratio * dy);
/* 314 */     int targetbx = MathUtils.round(pinb.getX() + ratio * dx);
/* 315 */     int targetby = MathUtils.round(pinb.getY() + ratio * dy);
/*     */     
/* 317 */     if (!isValid(targetax, targetay) || !isValid(targetbx, targetby) || !isValid(targetcx, targetcy) || !isValid(targetdx, targetdy))
/*     */     {
/*     */ 
/*     */       
/* 321 */       throw NotFoundException.getNotFoundInstance();
/*     */     }
/*     */     
/* 324 */     return new Point[] { new Point(targetax, targetay), new Point(targetbx, targetby), new Point(targetcx, targetcy), new Point(targetdx, targetdy) };
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private Point getMatrixCenter() {
/*     */     ResultPoint resultPoint1, resultPoint2, resultPoint3, resultPoint4;
/*     */     try {
/* 347 */       ResultPoint[] cornerPoints = (new WhiteRectangleDetector(this.image)).detect();
/* 348 */       resultPoint1 = cornerPoints[0];
/* 349 */       resultPoint2 = cornerPoints[1];
/* 350 */       resultPoint3 = cornerPoints[2];
/* 351 */       resultPoint4 = cornerPoints[3];
/*     */     }
/* 353 */     catch (NotFoundException e) {
/*     */ 
/*     */ 
/*     */       
/* 357 */       int i = this.image.getWidth() / 2;
/* 358 */       int j = this.image.getHeight() / 2;
/* 359 */       resultPoint1 = getFirstDifferent(new Point(i + 7, j - 7), false, 1, -1).toResultPoint();
/* 360 */       resultPoint2 = getFirstDifferent(new Point(i + 7, j + 7), false, 1, 1).toResultPoint();
/* 361 */       resultPoint3 = getFirstDifferent(new Point(i - 7, j + 7), false, -1, 1).toResultPoint();
/* 362 */       resultPoint4 = getFirstDifferent(new Point(i - 7, j - 7), false, -1, -1).toResultPoint();
/*     */     } 
/*     */ 
/*     */ 
/*     */     
/* 367 */     int cx = MathUtils.round((resultPoint1.getX() + resultPoint4.getX() + resultPoint2.getX() + resultPoint3.getX()) / 4.0F);
/* 368 */     int cy = MathUtils.round((resultPoint1.getY() + resultPoint4.getY() + resultPoint2.getY() + resultPoint3.getY()) / 4.0F);
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     try {
/* 374 */       ResultPoint[] cornerPoints = (new WhiteRectangleDetector(this.image, 15, cx, cy)).detect();
/* 375 */       resultPoint1 = cornerPoints[0];
/* 376 */       resultPoint2 = cornerPoints[1];
/* 377 */       resultPoint3 = cornerPoints[2];
/* 378 */       resultPoint4 = cornerPoints[3];
/* 379 */     } catch (NotFoundException e) {
/*     */ 
/*     */ 
/*     */       
/* 383 */       resultPoint1 = getFirstDifferent(new Point(cx + 7, cy - 7), false, 1, -1).toResultPoint();
/* 384 */       resultPoint2 = getFirstDifferent(new Point(cx + 7, cy + 7), false, 1, 1).toResultPoint();
/* 385 */       resultPoint3 = getFirstDifferent(new Point(cx - 7, cy + 7), false, -1, 1).toResultPoint();
/* 386 */       resultPoint4 = getFirstDifferent(new Point(cx - 7, cy - 7), false, -1, -1).toResultPoint();
/*     */     } 
/*     */ 
/*     */ 
/*     */     
/* 391 */     cx = MathUtils.round((resultPoint1.getX() + resultPoint4.getX() + resultPoint2.getX() + resultPoint3.getX()) / 4.0F);
/* 392 */     cy = MathUtils.round((resultPoint1.getY() + resultPoint4.getY() + resultPoint2.getY() + resultPoint3.getY()) / 4.0F);
/*     */     
/* 394 */     return new Point(cx, cy);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private BitMatrix sampleGrid(BitMatrix image, ResultPoint topLeft, ResultPoint bottomLeft, ResultPoint bottomRight, ResultPoint topRight) throws NotFoundException {
/*     */     int dimension;
/* 407 */     if (this.compact) {
/* 408 */       dimension = 4 * this.nbLayers + 11;
/*     */     }
/* 410 */     else if (this.nbLayers <= 4) {
/* 411 */       dimension = 4 * this.nbLayers + 15;
/*     */     } else {
/* 413 */       dimension = 4 * this.nbLayers + 2 * ((this.nbLayers - 4) / 8 + 1) + 15;
/*     */     } 
/*     */ 
/*     */     
/* 417 */     GridSampler sampler = GridSampler.getInstance();
/*     */     
/* 419 */     return sampler.sampleGrid(image, dimension, dimension, 0.5F, 0.5F, dimension - 0.5F, 0.5F, dimension - 0.5F, dimension - 0.5F, 0.5F, dimension - 0.5F, topLeft.getX(), topLeft.getY(), topRight.getX(), topRight.getY(), bottomRight.getX(), bottomRight.getY(), bottomLeft.getX(), bottomLeft.getY());
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private void getParameters(boolean[] parameterData) {
/*     */     int nbBitsForNbLayers, nbBitsForNbDatablocks;
/* 448 */     if (this.compact) {
/* 449 */       nbBitsForNbLayers = 2;
/* 450 */       nbBitsForNbDatablocks = 6;
/*     */     } else {
/* 452 */       nbBitsForNbLayers = 5;
/* 453 */       nbBitsForNbDatablocks = 11;
/*     */     } 
/*     */     int i;
/* 456 */     for (i = 0; i < nbBitsForNbLayers; i++) {
/* 457 */       this.nbLayers <<= 1;
/* 458 */       if (parameterData[i]) {
/* 459 */         this.nbLayers++;
/*     */       }
/*     */     } 
/*     */     
/* 463 */     for (i = nbBitsForNbLayers; i < nbBitsForNbLayers + nbBitsForNbDatablocks; i++) {
/* 464 */       this.nbDataBlocks <<= 1;
/* 465 */       if (parameterData[i]) {
/* 466 */         this.nbDataBlocks++;
/*     */       }
/*     */     } 
/*     */     
/* 470 */     this.nbLayers++;
/* 471 */     this.nbDataBlocks++;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private boolean[] sampleLine(Point p1, Point p2, int size) {
/* 484 */     boolean[] res = new boolean[size];
/* 485 */     float d = distance(p1, p2);
/* 486 */     float moduleSize = d / (size - 1);
/* 487 */     float dx = moduleSize * (p2.getX() - p1.getX()) / d;
/* 488 */     float dy = moduleSize * (p2.getY() - p1.getY()) / d;
/*     */     
/* 490 */     float px = p1.getX();
/* 491 */     float py = p1.getY();
/*     */     
/* 493 */     for (int i = 0; i < size; i++) {
/* 494 */       res[i] = this.image.get(MathUtils.round(px), MathUtils.round(py));
/* 495 */       px += dx;
/* 496 */       py += dy;
/*     */     } 
/*     */     
/* 499 */     return res;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private boolean isWhiteOrBlackRectangle(Point p1, Point p2, Point p3, Point p4) {
/* 511 */     int corr = 3;
/*     */     
/* 513 */     p1 = new Point(p1.getX() - corr, p1.getY() + corr);
/* 514 */     p2 = new Point(p2.getX() - corr, p2.getY() - corr);
/* 515 */     p3 = new Point(p3.getX() + corr, p3.getY() - corr);
/* 516 */     p4 = new Point(p4.getX() + corr, p4.getY() + corr);
/*     */     
/* 518 */     int cInit = getColor(p4, p1);
/*     */     
/* 520 */     if (cInit == 0) {
/* 521 */       return false;
/*     */     }
/*     */     
/* 524 */     int c = getColor(p1, p2);
/*     */     
/* 526 */     if (c != cInit) {
/* 527 */       return false;
/*     */     }
/*     */     
/* 530 */     c = getColor(p2, p3);
/*     */     
/* 532 */     if (c != cInit) {
/* 533 */       return false;
/*     */     }
/*     */     
/* 536 */     c = getColor(p3, p4);
/*     */     
/* 538 */     return (c == cInit);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private int getColor(Point p1, Point p2) {
/* 548 */     float d = distance(p1, p2);
/* 549 */     float dx = (p2.getX() - p1.getX()) / d;
/* 550 */     float dy = (p2.getY() - p1.getY()) / d;
/* 551 */     int error = 0;
/*     */     
/* 553 */     float px = p1.getX();
/* 554 */     float py = p1.getY();
/*     */     
/* 556 */     boolean colorModel = this.image.get(p1.getX(), p1.getY());
/*     */     
/* 558 */     for (int i = 0; i < d; i++) {
/* 559 */       px += dx;
/* 560 */       py += dy;
/* 561 */       if (this.image.get(MathUtils.round(px), MathUtils.round(py)) != colorModel) {
/* 562 */         error++;
/*     */       }
/*     */     } 
/*     */     
/* 566 */     float errRatio = error / d;
/*     */     
/* 568 */     if (errRatio > 0.1F && errRatio < 0.9F) {
/* 569 */       return 0;
/*     */     }
/*     */     
/* 572 */     return (((errRatio <= 0.1F)) == colorModel) ? 1 : -1;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private Point getFirstDifferent(Point init, boolean color, int dx, int dy) {
/* 579 */     int x = init.getX() + dx;
/* 580 */     int y = init.getY() + dy;
/*     */     
/* 582 */     while (isValid(x, y) && this.image.get(x, y) == color) {
/* 583 */       x += dx;
/* 584 */       y += dy;
/*     */     } 
/*     */     
/* 587 */     x -= dx;
/* 588 */     y -= dy;
/*     */     
/* 590 */     while (isValid(x, y) && this.image.get(x, y) == color) {
/* 591 */       x += dx;
/*     */     }
/* 593 */     x -= dx;
/*     */     
/* 595 */     while (isValid(x, y) && this.image.get(x, y) == color) {
/* 596 */       y += dy;
/*     */     }
/* 598 */     y -= dy;
/*     */     
/* 600 */     return new Point(x, y);
/*     */   }
/*     */   
/*     */   private boolean isValid(int x, int y) {
/* 604 */     return (x >= 0 && x < this.image.getWidth() && y > 0 && y < this.image.getHeight());
/*     */   }
/*     */   
/*     */   private static float distance(Point a, Point b) {
/* 608 */     return MathUtils.distance(a.getX(), a.getY(), b.getX(), b.getY());
/*     */   }
/*     */   
/*     */   static final class Point {
/*     */     private final int x;
/*     */     private final int y;
/*     */     
/*     */     ResultPoint toResultPoint() {
/* 616 */       return new ResultPoint(getX(), getY());
/*     */     }
/*     */     
/*     */     Point(int x, int y) {
/* 620 */       this.x = x;
/* 621 */       this.y = y;
/*     */     }
/*     */     
/*     */     int getX() {
/* 625 */       return this.x;
/*     */     }
/*     */     
/*     */     int getY() {
/* 629 */       return this.y;
/*     */     }
/*     */   }
/*     */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\com\google\zxing\aztec\detector\Detector.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       1.1.3
 */