/*     */ package com.google.zxing.aztec.encoder;
/*     */ 
/*     */ import com.google.zxing.common.BitArray;
/*     */ import com.google.zxing.common.BitMatrix;
/*     */ import com.google.zxing.common.reedsolomon.GenericGF;
/*     */ import com.google.zxing.common.reedsolomon.ReedSolomonEncoder;
/*     */ import java.util.Arrays;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public final class Encoder
/*     */ {
/*     */   public static final int DEFAULT_EC_PERCENT = 33;
/*     */   private static final int TABLE_UPPER = 0;
/*     */   private static final int TABLE_LOWER = 1;
/*     */   private static final int TABLE_DIGIT = 2;
/*     */   private static final int TABLE_MIXED = 3;
/*     */   private static final int TABLE_PUNCT = 4;
/*     */   private static final int TABLE_BINARY = 5;
/*  42 */   private static final int[][] CHAR_MAP = new int[5][256];
/*  43 */   private static final int[][] SHIFT_TABLE = new int[6][6];
/*  44 */   private static final int[][] LATCH_TABLE = new int[6][6];
/*     */   
/*     */   private static final int[] NB_BITS;
/*     */   
/*     */   static {
/*  49 */     CHAR_MAP[0][32] = 1; int c;
/*  50 */     for (c = 65; c <= 90; c++) {
/*  51 */       CHAR_MAP[0][c] = c - 65 + 2;
/*     */     }
/*  53 */     CHAR_MAP[1][32] = 1;
/*  54 */     for (c = 97; c <= 122; c++) {
/*  55 */       CHAR_MAP[1][c] = c - 97 + 2;
/*     */     }
/*  57 */     CHAR_MAP[2][32] = 1;
/*  58 */     for (c = 48; c <= 57; c++) {
/*  59 */       CHAR_MAP[2][c] = c - 48 + 2;
/*     */     }
/*  61 */     CHAR_MAP[2][44] = 12;
/*  62 */     CHAR_MAP[2][46] = 13;
/*  63 */     int[] mixedTable = { 0, 32, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 27, 28, 29, 30, 31, 64, 92, 94, 95, 96, 124, 126, 127 };
/*     */ 
/*     */ 
/*     */     
/*  67 */     for (int i = 0; i < mixedTable.length; i++) {
/*  68 */       CHAR_MAP[3][mixedTable[i]] = i;
/*     */     }
/*  70 */     int[] punctTable = { 0, 13, 0, 0, 0, 0, 33, 39, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 58, 59, 60, 61, 62, 63, 91, 93, 123, 125 };
/*     */     
/*     */     int j;
/*     */     
/*  74 */     for (j = 0; j < punctTable.length; j++) {
/*  75 */       if (punctTable[j] > 0) {
/*  76 */         CHAR_MAP[4][punctTable[j]] = j;
/*     */       }
/*     */     } 
/*  79 */     for (int[] table : SHIFT_TABLE) {
/*  80 */       Arrays.fill(table, -1);
/*     */     }
/*  82 */     for (int[] table : LATCH_TABLE) {
/*  83 */       Arrays.fill(table, -1);
/*     */     }
/*  85 */     SHIFT_TABLE[0][4] = 0;
/*  86 */     LATCH_TABLE[0][1] = 28;
/*  87 */     LATCH_TABLE[0][3] = 29;
/*  88 */     LATCH_TABLE[0][2] = 30;
/*  89 */     SHIFT_TABLE[0][5] = 31;
/*  90 */     SHIFT_TABLE[1][4] = 0;
/*  91 */     SHIFT_TABLE[1][0] = 28;
/*  92 */     LATCH_TABLE[1][3] = 29;
/*  93 */     LATCH_TABLE[1][2] = 30;
/*  94 */     SHIFT_TABLE[1][5] = 31;
/*  95 */     SHIFT_TABLE[3][4] = 0;
/*  96 */     LATCH_TABLE[3][1] = 28;
/*  97 */     LATCH_TABLE[3][0] = 29;
/*  98 */     LATCH_TABLE[3][4] = 30;
/*  99 */     SHIFT_TABLE[3][5] = 31;
/* 100 */     LATCH_TABLE[4][0] = 31;
/* 101 */     SHIFT_TABLE[2][4] = 0;
/* 102 */     LATCH_TABLE[2][0] = 30;
/* 103 */     SHIFT_TABLE[2][0] = 31;
/* 104 */   } private static final int[] NB_BITS_COMPACT = new int[5]; static {
/* 105 */     for (j = 1; j < NB_BITS_COMPACT.length; j++) {
/* 106 */       NB_BITS_COMPACT[j] = (88 + 16 * j) * j;
/*     */     }
/* 108 */     NB_BITS = new int[33];
/* 109 */     for (j = 1; j < NB_BITS.length; j++) {
/* 110 */       NB_BITS[j] = (112 + 16 * j) * j;
/*     */     }
/*     */ 
/*     */     
/* 114 */     WORD_SIZE = new int[] { 4, 6, 6, 8, 8, 8, 8, 8, 8, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12 };
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static final int[] WORD_SIZE;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static AztecCode encode(byte[] data) {
/* 129 */     return encode(data, 33);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static AztecCode encode(byte[] data, int minECCPercent) {
/*     */     int matrixSize;
/* 143 */     BitArray bits = highLevelEncode(data);
/*     */ 
/*     */     
/* 146 */     int eccBits = bits.getSize() * minECCPercent / 100 + 11;
/* 147 */     int totalSizeBits = bits.getSize() + eccBits;
/*     */     
/* 149 */     int wordSize = 0;
/* 150 */     int totalSymbolBits = 0;
/* 151 */     BitArray stuffedBits = null; int layers;
/* 152 */     for (layers = 1; layers < NB_BITS_COMPACT.length; layers++) {
/* 153 */       if (NB_BITS_COMPACT[layers] >= totalSizeBits) {
/* 154 */         if (wordSize != WORD_SIZE[layers]) {
/* 155 */           wordSize = WORD_SIZE[layers];
/* 156 */           stuffedBits = stuffBits(bits, wordSize);
/*     */         } 
/* 158 */         totalSymbolBits = NB_BITS_COMPACT[layers];
/* 159 */         if (stuffedBits.getSize() + eccBits <= NB_BITS_COMPACT[layers]) {
/*     */           break;
/*     */         }
/*     */       } 
/*     */     } 
/* 164 */     boolean compact = true;
/* 165 */     if (layers == NB_BITS_COMPACT.length) {
/* 166 */       compact = false;
/* 167 */       for (layers = 1; layers < NB_BITS.length; layers++) {
/* 168 */         if (NB_BITS[layers] >= totalSizeBits) {
/* 169 */           if (wordSize != WORD_SIZE[layers]) {
/* 170 */             wordSize = WORD_SIZE[layers];
/* 171 */             stuffedBits = stuffBits(bits, wordSize);
/*     */           } 
/* 173 */           totalSymbolBits = NB_BITS[layers];
/* 174 */           if (stuffedBits.getSize() + eccBits <= NB_BITS[layers]) {
/*     */             break;
/*     */           }
/*     */         } 
/*     */       } 
/*     */     } 
/* 180 */     if (layers == NB_BITS.length) {
/* 181 */       throw new IllegalArgumentException("Data too large for an Aztec code");
/*     */     }
/*     */ 
/*     */     
/* 185 */     int messageSizeInWords = (stuffedBits.getSize() + wordSize - 1) / wordSize;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 194 */     ReedSolomonEncoder rs = new ReedSolomonEncoder(getGF(wordSize));
/* 195 */     int totalSizeInFullWords = totalSymbolBits / wordSize;
/* 196 */     int[] messageWords = bitsToWords(stuffedBits, wordSize, totalSizeInFullWords);
/* 197 */     rs.encode(messageWords, totalSizeInFullWords - messageSizeInWords);
/*     */ 
/*     */     
/* 200 */     int startPad = totalSymbolBits % wordSize;
/* 201 */     BitArray messageBits = new BitArray();
/* 202 */     messageBits.appendBits(0, startPad);
/* 203 */     for (int messageWord : messageWords) {
/* 204 */       messageBits.appendBits(messageWord, wordSize);
/*     */     }
/*     */ 
/*     */     
/* 208 */     BitArray modeMessage = generateModeMessage(compact, layers, messageSizeInWords);
/*     */ 
/*     */     
/* 211 */     int baseMatrixSize = compact ? (11 + layers * 4) : (14 + layers * 4);
/* 212 */     int[] alignmentMap = new int[baseMatrixSize];
/*     */     
/* 214 */     if (compact) {
/*     */       
/* 216 */       matrixSize = baseMatrixSize;
/* 217 */       for (int j = 0; j < alignmentMap.length; j++) {
/* 218 */         alignmentMap[j] = j;
/*     */       }
/*     */     } else {
/* 221 */       matrixSize = baseMatrixSize + 1 + 2 * (baseMatrixSize / 2 - 1) / 15;
/* 222 */       int origCenter = baseMatrixSize / 2;
/* 223 */       int center = matrixSize / 2;
/* 224 */       for (int j = 0; j < origCenter; j++) {
/* 225 */         int newOffset = j + j / 15;
/* 226 */         alignmentMap[origCenter - j - 1] = center - newOffset - 1;
/* 227 */         alignmentMap[origCenter + j] = center + newOffset + 1;
/*     */       } 
/*     */     } 
/* 230 */     BitMatrix matrix = new BitMatrix(matrixSize);
/*     */     
/*     */     int i, rowOffset;
/* 233 */     for (i = 0, rowOffset = 0; i < layers; i++) {
/* 234 */       int rowSize = compact ? ((layers - i) * 4 + 9) : ((layers - i) * 4 + 12);
/* 235 */       for (int j = 0; j < rowSize; j++) {
/* 236 */         int columnOffset = j * 2;
/* 237 */         for (int k = 0; k < 2; k++) {
/* 238 */           if (messageBits.get(rowOffset + columnOffset + k)) {
/* 239 */             matrix.set(alignmentMap[i * 2 + k], alignmentMap[i * 2 + j]);
/*     */           }
/* 241 */           if (messageBits.get(rowOffset + rowSize * 2 + columnOffset + k)) {
/* 242 */             matrix.set(alignmentMap[i * 2 + j], alignmentMap[baseMatrixSize - 1 - i * 2 - k]);
/*     */           }
/* 244 */           if (messageBits.get(rowOffset + rowSize * 4 + columnOffset + k)) {
/* 245 */             matrix.set(alignmentMap[baseMatrixSize - 1 - i * 2 - k], alignmentMap[baseMatrixSize - 1 - i * 2 - j]);
/*     */           }
/* 247 */           if (messageBits.get(rowOffset + rowSize * 6 + columnOffset + k)) {
/* 248 */             matrix.set(alignmentMap[baseMatrixSize - 1 - i * 2 - j], alignmentMap[i * 2 + k]);
/*     */           }
/*     */         } 
/*     */       } 
/* 252 */       rowOffset += rowSize * 8;
/*     */     } 
/* 254 */     drawModeMessage(matrix, compact, matrixSize, modeMessage);
/*     */ 
/*     */     
/* 257 */     if (compact) {
/* 258 */       drawBullsEye(matrix, matrixSize / 2, 5);
/*     */     } else {
/* 260 */       drawBullsEye(matrix, matrixSize / 2, 7); int j;
/* 261 */       for (i = 0, j = 0; i < baseMatrixSize / 2 - 1; i += 15, j += 16) {
/* 262 */         for (int k = matrixSize / 2 & 0x1; k < matrixSize; k += 2) {
/* 263 */           matrix.set(matrixSize / 2 - j, k);
/* 264 */           matrix.set(matrixSize / 2 + j, k);
/* 265 */           matrix.set(k, matrixSize / 2 - j);
/* 266 */           matrix.set(k, matrixSize / 2 + j);
/*     */         } 
/*     */       } 
/*     */     } 
/*     */     
/* 271 */     AztecCode aztec = new AztecCode();
/* 272 */     aztec.setCompact(compact);
/* 273 */     aztec.setSize(matrixSize);
/* 274 */     aztec.setLayers(layers);
/* 275 */     aztec.setCodeWords(messageSizeInWords);
/* 276 */     aztec.setMatrix(matrix);
/* 277 */     return aztec;
/*     */   }
/*     */   
/*     */   static void drawBullsEye(BitMatrix matrix, int center, int size) {
/* 281 */     for (int i = 0; i < size; i += 2) {
/* 282 */       for (int j = center - i; j <= center + i; j++) {
/* 283 */         matrix.set(j, center - i);
/* 284 */         matrix.set(j, center + i);
/* 285 */         matrix.set(center - i, j);
/* 286 */         matrix.set(center + i, j);
/*     */       } 
/*     */     } 
/* 289 */     matrix.set(center - size, center - size);
/* 290 */     matrix.set(center - size + 1, center - size);
/* 291 */     matrix.set(center - size, center - size + 1);
/* 292 */     matrix.set(center + size, center - size);
/* 293 */     matrix.set(center + size, center - size + 1);
/* 294 */     matrix.set(center + size, center + size - 1);
/*     */   }
/*     */   
/*     */   static BitArray generateModeMessage(boolean compact, int layers, int messageSizeInWords) {
/* 298 */     BitArray modeMessage = new BitArray();
/* 299 */     if (compact) {
/* 300 */       modeMessage.appendBits(layers - 1, 2);
/* 301 */       modeMessage.appendBits(messageSizeInWords - 1, 6);
/* 302 */       modeMessage = generateCheckWords(modeMessage, 28, 4);
/*     */     } else {
/* 304 */       modeMessage.appendBits(layers - 1, 5);
/* 305 */       modeMessage.appendBits(messageSizeInWords - 1, 11);
/* 306 */       modeMessage = generateCheckWords(modeMessage, 40, 4);
/*     */     } 
/* 308 */     return modeMessage;
/*     */   }
/*     */   
/*     */   static void drawModeMessage(BitMatrix matrix, boolean compact, int matrixSize, BitArray modeMessage) {
/* 312 */     if (compact) {
/* 313 */       for (int i = 0; i < 7; i++) {
/* 314 */         if (modeMessage.get(i)) {
/* 315 */           matrix.set(matrixSize / 2 - 3 + i, matrixSize / 2 - 5);
/*     */         }
/* 317 */         if (modeMessage.get(i + 7)) {
/* 318 */           matrix.set(matrixSize / 2 + 5, matrixSize / 2 - 3 + i);
/*     */         }
/* 320 */         if (modeMessage.get(20 - i)) {
/* 321 */           matrix.set(matrixSize / 2 - 3 + i, matrixSize / 2 + 5);
/*     */         }
/* 323 */         if (modeMessage.get(27 - i)) {
/* 324 */           matrix.set(matrixSize / 2 - 5, matrixSize / 2 - 3 + i);
/*     */         }
/*     */       } 
/*     */     } else {
/* 328 */       for (int i = 0; i < 10; i++) {
/* 329 */         if (modeMessage.get(i)) {
/* 330 */           matrix.set(matrixSize / 2 - 5 + i + i / 5, matrixSize / 2 - 7);
/*     */         }
/* 332 */         if (modeMessage.get(i + 10)) {
/* 333 */           matrix.set(matrixSize / 2 + 7, matrixSize / 2 - 5 + i + i / 5);
/*     */         }
/* 335 */         if (modeMessage.get(29 - i)) {
/* 336 */           matrix.set(matrixSize / 2 - 5 + i + i / 5, matrixSize / 2 + 7);
/*     */         }
/* 338 */         if (modeMessage.get(39 - i)) {
/* 339 */           matrix.set(matrixSize / 2 - 7, matrixSize / 2 - 5 + i + i / 5);
/*     */         }
/*     */       } 
/*     */     } 
/*     */   }
/*     */   
/*     */   static BitArray generateCheckWords(BitArray stuffedBits, int totalSymbolBits, int wordSize) {
/* 346 */     int messageSizeInWords = (stuffedBits.getSize() + wordSize - 1) / wordSize;
/* 347 */     for (int i = messageSizeInWords * wordSize - stuffedBits.getSize(); i > 0; i--) {
/* 348 */       stuffedBits.appendBit(true);
/*     */     }
/* 350 */     ReedSolomonEncoder rs = new ReedSolomonEncoder(getGF(wordSize));
/* 351 */     int totalSizeInFullWords = totalSymbolBits / wordSize;
/* 352 */     int[] messageWords = bitsToWords(stuffedBits, wordSize, totalSizeInFullWords);
/* 353 */     rs.encode(messageWords, totalSizeInFullWords - messageSizeInWords);
/* 354 */     int startPad = totalSymbolBits % wordSize;
/* 355 */     BitArray messageBits = new BitArray();
/* 356 */     messageBits.appendBits(0, startPad);
/* 357 */     for (int messageWord : messageWords) {
/* 358 */       messageBits.appendBits(messageWord, wordSize);
/*     */     }
/* 360 */     return messageBits;
/*     */   }
/*     */   
/*     */   static int[] bitsToWords(BitArray stuffedBits, int wordSize, int totalWords) {
/* 364 */     int[] message = new int[totalWords];
/*     */ 
/*     */     
/* 367 */     for (int i = 0, n = stuffedBits.getSize() / wordSize; i < n; i++) {
/* 368 */       int value = 0;
/* 369 */       for (int j = 0; j < wordSize; j++) {
/* 370 */         value |= stuffedBits.get(i * wordSize + j) ? (1 << wordSize - j - 1) : 0;
/*     */       }
/* 372 */       message[i] = value;
/*     */     } 
/* 374 */     return message;
/*     */   }
/*     */   
/*     */   static GenericGF getGF(int wordSize) {
/* 378 */     switch (wordSize) {
/*     */       case 4:
/* 380 */         return GenericGF.AZTEC_PARAM;
/*     */       case 6:
/* 382 */         return GenericGF.AZTEC_DATA_6;
/*     */       case 8:
/* 384 */         return GenericGF.AZTEC_DATA_8;
/*     */       case 10:
/* 386 */         return GenericGF.AZTEC_DATA_10;
/*     */       case 12:
/* 388 */         return GenericGF.AZTEC_DATA_12;
/*     */     } 
/* 390 */     return null;
/*     */   }
/*     */ 
/*     */   
/*     */   static BitArray stuffBits(BitArray bits, int wordSize) {
/* 395 */     BitArray out = new BitArray();
/*     */ 
/*     */     
/* 398 */     int n = bits.getSize();
/* 399 */     int mask = (1 << wordSize) - 2; int i;
/* 400 */     for (i = 0; i < n; i += wordSize) {
/* 401 */       int word = 0;
/* 402 */       for (int j = 0; j < wordSize; j++) {
/* 403 */         if (i + j >= n || bits.get(i + j)) {
/* 404 */           word |= 1 << wordSize - 1 - j;
/*     */         }
/*     */       } 
/* 407 */       if ((word & mask) == mask) {
/* 408 */         out.appendBits(word & mask, wordSize);
/* 409 */         i--;
/* 410 */       } else if ((word & mask) == 0) {
/* 411 */         out.appendBits(word | 0x1, wordSize);
/* 412 */         i--;
/*     */       } else {
/* 414 */         out.appendBits(word, wordSize);
/*     */       } 
/*     */     } 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 436 */     return out;
/*     */   }
/*     */   
/*     */   static BitArray highLevelEncode(byte[] data) {
/* 440 */     BitArray bits = new BitArray();
/* 441 */     int mode = 0;
/* 442 */     int[] idx = new int[5];
/* 443 */     int[] idxnext = new int[5];
/* 444 */     for (int i = 0; i < data.length; i++) {
/* 445 */       int c = data[i] & 0xFF;
/* 446 */       int next = (i < data.length - 1) ? (data[i + 1] & 0xFF) : 0;
/* 447 */       int punctWord = 0;
/*     */       
/* 449 */       if (c == 13 && next == 10) {
/* 450 */         punctWord = 2;
/* 451 */       } else if (c == 46 && next == 32) {
/* 452 */         punctWord = 3;
/* 453 */       } else if (c == 44 && next == 32) {
/* 454 */         punctWord = 4;
/* 455 */       } else if (c == 58 && next == 32) {
/* 456 */         punctWord = 5;
/*     */       } 
/* 458 */       if (punctWord > 0) {
/* 459 */         if (mode == 4) {
/* 460 */           outputWord(bits, 4, punctWord);
/* 461 */           i++; continue;
/*     */         } 
/* 463 */         if (SHIFT_TABLE[mode][4] >= 0) {
/* 464 */           outputWord(bits, mode, SHIFT_TABLE[mode][4]);
/* 465 */           outputWord(bits, 4, punctWord);
/* 466 */           i++; continue;
/*     */         } 
/* 468 */         if (LATCH_TABLE[mode][4] >= 0) {
/* 469 */           outputWord(bits, mode, LATCH_TABLE[mode][4]);
/* 470 */           outputWord(bits, 4, punctWord);
/* 471 */           mode = 4;
/* 472 */           i++;
/*     */           
/*     */           continue;
/*     */         } 
/*     */       } 
/* 477 */       int firstMatch = -1;
/* 478 */       int shiftMode = -1;
/* 479 */       int latchMode = -1;
/*     */       int j;
/* 481 */       for (j = 0; j < 5; j++) {
/* 482 */         idx[j] = CHAR_MAP[j][c];
/* 483 */         if (idx[j] > 0 && firstMatch < 0) {
/* 484 */           firstMatch = j;
/*     */         }
/* 486 */         if (shiftMode < 0 && idx[j] > 0 && SHIFT_TABLE[mode][j] >= 0) {
/* 487 */           shiftMode = j;
/*     */         }
/* 489 */         idxnext[j] = CHAR_MAP[j][next];
/* 490 */         if (latchMode < 0 && idx[j] > 0 && (next == 0 || idxnext[j] > 0) && LATCH_TABLE[mode][j] >= 0) {
/* 491 */           latchMode = j;
/*     */         }
/*     */       } 
/* 494 */       if (shiftMode < 0 && latchMode < 0) {
/* 495 */         for (j = 0; j < 5; j++) {
/* 496 */           if (idx[j] > 0 && LATCH_TABLE[mode][j] >= 0) {
/* 497 */             latchMode = j;
/*     */             break;
/*     */           } 
/*     */         } 
/*     */       }
/* 502 */       if (idx[mode] > 0) {
/*     */         
/* 504 */         outputWord(bits, mode, idx[mode]); continue;
/*     */       } 
/* 506 */       if (latchMode >= 0) {
/*     */         
/* 508 */         outputWord(bits, mode, LATCH_TABLE[mode][latchMode]);
/* 509 */         outputWord(bits, latchMode, idx[latchMode]);
/* 510 */         mode = latchMode; continue;
/* 511 */       }  if (shiftMode >= 0) {
/*     */         
/* 513 */         outputWord(bits, mode, SHIFT_TABLE[mode][shiftMode]);
/* 514 */         outputWord(bits, shiftMode, idx[shiftMode]); continue;
/*     */       } 
/* 516 */       if (firstMatch >= 0) {
/*     */         
/* 518 */         if (mode == 4) {
/* 519 */           outputWord(bits, 4, LATCH_TABLE[4][0]);
/* 520 */           mode = 0;
/* 521 */           i--; continue;
/*     */         } 
/* 523 */         if (mode == 2) {
/* 524 */           outputWord(bits, 2, LATCH_TABLE[2][0]);
/* 525 */           mode = 0;
/* 526 */           i--;
/*     */           
/*     */           continue;
/*     */         } 
/*     */       } 
/*     */       
/*     */       int k, lookahead;
/*     */       
/* 534 */       for (k = i + 1, lookahead = 0; k < data.length; k++) {
/* 535 */         next = data[k] & 0xFF;
/* 536 */         boolean binary = true;
/* 537 */         for (j = 0; j < 5; j++) {
/* 538 */           if (CHAR_MAP[j][next] > 0) {
/* 539 */             binary = false;
/*     */             break;
/*     */           } 
/*     */         } 
/* 543 */         if (binary) {
/* 544 */           lookahead = 0;
/*     */         } else {
/*     */           
/* 547 */           if (lookahead >= 1) {
/* 548 */             k -= lookahead;
/*     */             break;
/*     */           } 
/* 551 */           lookahead++;
/*     */         } 
/*     */       } 
/* 554 */       k -= i;
/*     */       
/* 556 */       switch (mode) {
/*     */         case 0:
/*     */         case 1:
/*     */         case 3:
/* 560 */           outputWord(bits, mode, SHIFT_TABLE[mode][5]);
/*     */           break;
/*     */         case 2:
/* 563 */           outputWord(bits, mode, LATCH_TABLE[mode][0]);
/* 564 */           mode = 0;
/* 565 */           outputWord(bits, mode, SHIFT_TABLE[mode][5]);
/*     */           break;
/*     */         case 4:
/* 568 */           outputWord(bits, mode, LATCH_TABLE[mode][0]);
/* 569 */           mode = 0;
/* 570 */           outputWord(bits, mode, SHIFT_TABLE[mode][5]);
/*     */           break;
/*     */       } 
/* 573 */       if (k >= 32 && k < 63) {
/* 574 */         k = 31;
/*     */       }
/* 576 */       if (k > 542) {
/* 577 */         k = 542;
/*     */       }
/* 579 */       if (k < 32) {
/* 580 */         bits.appendBits(k, 5);
/*     */       } else {
/* 582 */         bits.appendBits(k - 31, 16);
/*     */       } 
/* 584 */       for (; k > 0; k--, i++) {
/* 585 */         bits.appendBits(data[i], 8);
/*     */       }
/* 587 */       i--;
/*     */       
/*     */       continue;
/*     */     } 
/* 591 */     return bits;
/*     */   }
/*     */   
/*     */   static void outputWord(BitArray bits, int mode, int value) {
/* 595 */     if (mode == 2) {
/* 596 */       bits.appendBits(value, 4);
/* 597 */     } else if (mode < 5) {
/* 598 */       bits.appendBits(value, 5);
/*     */     } else {
/* 600 */       bits.appendBits(value, 8);
/*     */     } 
/*     */   }
/*     */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\com\google\zxing\aztec\encoder\Encoder.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       1.1.3
 */