/*     */ package com.google.zxing.client.result;
/*     */ 
/*     */ import java.text.DateFormat;
/*     */ import java.text.ParseException;
/*     */ import java.text.SimpleDateFormat;
/*     */ import java.util.Calendar;
/*     */ import java.util.Date;
/*     */ import java.util.GregorianCalendar;
/*     */ import java.util.Locale;
/*     */ import java.util.TimeZone;
/*     */ import java.util.regex.Matcher;
/*     */ import java.util.regex.Pattern;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public final class CalendarParsedResult
/*     */   extends ParsedResult
/*     */ {
/*  35 */   private static final Pattern RFC2445_DURATION = Pattern.compile("P(?:(\\d+)W)?(?:(\\d+)D)?(?:T(?:(\\d+)H)?(?:(\\d+)M)?(?:(\\d+)S)?)?");
/*     */   
/*  37 */   private static final long[] RFC2445_DURATION_FIELD_UNITS = new long[] { 604800000L, 86400000L, 3600000L, 60000L, 1000L };
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  45 */   private static final Pattern DATE_TIME = Pattern.compile("[0-9]{8}(T[0-9]{6}Z?)?");
/*     */   
/*  47 */   private static final DateFormat DATE_FORMAT = new SimpleDateFormat("yyyyMMdd", Locale.ENGLISH);
/*     */ 
/*     */ 
/*     */   
/*     */   static {
/*  52 */     DATE_FORMAT.setTimeZone(TimeZone.getTimeZone("GMT"));
/*     */   }
/*  54 */   private static final DateFormat DATE_TIME_FORMAT = new SimpleDateFormat("yyyyMMdd'T'HHmmss", Locale.ENGLISH);
/*     */   
/*     */   private final String summary;
/*     */   
/*     */   private final Date start;
/*     */   
/*     */   private final boolean startAllDay;
/*     */   
/*     */   private final Date end;
/*     */   
/*     */   private final boolean endAllDay;
/*     */   
/*     */   private final String location;
/*     */   
/*     */   private final String organizer;
/*     */   
/*     */   private final String[] attendees;
/*     */   
/*     */   private final String description;
/*     */   
/*     */   private final double latitude;
/*     */   private final double longitude;
/*     */   
/*     */   public CalendarParsedResult(String summary, String startString, String endString, String durationString, String location, String organizer, String[] attendees, String description, double latitude, double longitude) {
/*  78 */     super(ParsedResultType.CALENDAR);
/*  79 */     this.summary = summary;
/*     */     
/*     */     try {
/*  82 */       this.start = parseDate(startString);
/*  83 */     } catch (ParseException pe) {
/*  84 */       throw new IllegalArgumentException(pe.toString());
/*     */     } 
/*     */     
/*  87 */     if (endString == null) {
/*  88 */       long durationMS = parseDurationMS(durationString);
/*  89 */       this.end = (durationMS < 0L) ? null : new Date(this.start.getTime() + durationMS);
/*     */     } else {
/*     */       try {
/*  92 */         this.end = parseDate(endString);
/*  93 */       } catch (ParseException pe) {
/*  94 */         throw new IllegalArgumentException(pe.toString());
/*     */       } 
/*     */     } 
/*     */     
/*  98 */     this.startAllDay = (startString.length() == 8);
/*  99 */     this.endAllDay = (endString != null && endString.length() == 8);
/*     */     
/* 101 */     this.location = location;
/* 102 */     this.organizer = organizer;
/* 103 */     this.attendees = attendees;
/* 104 */     this.description = description;
/* 105 */     this.latitude = latitude;
/* 106 */     this.longitude = longitude;
/*     */   }
/*     */   
/*     */   public String getSummary() {
/* 110 */     return this.summary;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Date getStart() {
/* 117 */     return this.start;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public boolean isStartAllDay() {
/* 124 */     return this.startAllDay;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Date getEnd() {
/* 132 */     return this.end;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public boolean isEndAllDay() {
/* 139 */     return this.endAllDay;
/*     */   }
/*     */   
/*     */   public String getLocation() {
/* 143 */     return this.location;
/*     */   }
/*     */   
/*     */   public String getOrganizer() {
/* 147 */     return this.organizer;
/*     */   }
/*     */   
/*     */   public String[] getAttendees() {
/* 151 */     return this.attendees;
/*     */   }
/*     */   
/*     */   public String getDescription() {
/* 155 */     return this.description;
/*     */   }
/*     */   
/*     */   public double getLatitude() {
/* 159 */     return this.latitude;
/*     */   }
/*     */   
/*     */   public double getLongitude() {
/* 163 */     return this.longitude;
/*     */   }
/*     */ 
/*     */   
/*     */   public String getDisplayResult() {
/* 168 */     StringBuilder result = new StringBuilder(100);
/* 169 */     maybeAppend(this.summary, result);
/* 170 */     maybeAppend(format(this.startAllDay, this.start), result);
/* 171 */     maybeAppend(format(this.endAllDay, this.end), result);
/* 172 */     maybeAppend(this.location, result);
/* 173 */     maybeAppend(this.organizer, result);
/* 174 */     maybeAppend(this.attendees, result);
/* 175 */     maybeAppend(this.description, result);
/* 176 */     return result.toString();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static Date parseDate(String when) throws ParseException {
/*     */     Date date;
/* 187 */     if (!DATE_TIME.matcher(when).matches()) {
/* 188 */       throw new ParseException(when, 0);
/*     */     }
/* 190 */     if (when.length() == 8)
/*     */     {
/* 192 */       return DATE_FORMAT.parse(when);
/*     */     }
/*     */ 
/*     */     
/* 196 */     if (when.length() == 16 && when.charAt(15) == 'Z') {
/* 197 */       date = DATE_TIME_FORMAT.parse(when.substring(0, 15));
/* 198 */       Calendar calendar = new GregorianCalendar();
/* 199 */       long milliseconds = date.getTime();
/*     */       
/* 201 */       milliseconds += calendar.get(15);
/*     */ 
/*     */       
/* 204 */       calendar.setTime(new Date(milliseconds));
/* 205 */       milliseconds += calendar.get(16);
/* 206 */       date = new Date(milliseconds);
/*     */     } else {
/* 208 */       date = DATE_TIME_FORMAT.parse(when);
/*     */     } 
/* 210 */     return date;
/*     */   }
/*     */ 
/*     */   
/*     */   private static String format(boolean allDay, Date date) {
/* 215 */     if (date == null) {
/* 216 */       return null;
/*     */     }
/* 218 */     DateFormat format = allDay ? DateFormat.getDateInstance(2) : DateFormat.getDateTimeInstance(2, 2);
/*     */ 
/*     */     
/* 221 */     return format.format(date);
/*     */   }
/*     */   
/*     */   private static long parseDurationMS(CharSequence durationString) {
/* 225 */     if (durationString == null) {
/* 226 */       return -1L;
/*     */     }
/* 228 */     Matcher m = RFC2445_DURATION.matcher(durationString);
/* 229 */     if (!m.matches()) {
/* 230 */       return -1L;
/*     */     }
/* 232 */     long durationMS = 0L;
/* 233 */     for (int i = 0; i < RFC2445_DURATION_FIELD_UNITS.length; i++) {
/* 234 */       String fieldValue = m.group(i + 1);
/* 235 */       if (fieldValue != null) {
/* 236 */         durationMS += RFC2445_DURATION_FIELD_UNITS[i] * Integer.parseInt(fieldValue);
/*     */       }
/*     */     } 
/* 239 */     return durationMS;
/*     */   }
/*     */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\com\google\zxing\client\result\CalendarParsedResult.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       1.1.3
 */