/*     */ package com.google.zxing.client.result;
/*     */ 
/*     */ import com.google.zxing.Result;
/*     */ import java.io.UnsupportedEncodingException;
/*     */ import java.net.URLDecoder;
/*     */ import java.util.ArrayList;
/*     */ import java.util.HashMap;
/*     */ import java.util.List;
/*     */ import java.util.Map;
/*     */ import java.util.regex.Pattern;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public abstract class ResultParser
/*     */ {
/*  42 */   private static final ResultParser[] PARSERS = new ResultParser[] { new BookmarkDoCoMoResultParser(), new AddressBookDoCoMoResultParser(), new EmailDoCoMoResultParser(), new AddressBookAUResultParser(), new VCardResultParser(), new BizcardResultParser(), new VEventResultParser(), new EmailAddressResultParser(), new SMTPResultParser(), new TelResultParser(), new SMSMMSResultParser(), new SMSTOMMSTOResultParser(), new GeoResultParser(), new WifiResultParser(), new URLTOResultParser(), new URIResultParser(), new ISBNResultParser(), new ProductResultParser(), new ExpandedProductResultParser() };
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  64 */   private static final Pattern DIGITS = Pattern.compile("\\d*");
/*  65 */   private static final Pattern ALPHANUM = Pattern.compile("[a-zA-Z0-9]*");
/*  66 */   private static final Pattern AMPERSAND = Pattern.compile("&");
/*  67 */   private static final Pattern EQUALS = Pattern.compile("=");
/*     */ 
/*     */   
/*     */   private static final String BYTE_ORDER_MARK = "﻿";
/*     */ 
/*     */ 
/*     */   
/*     */   public abstract ParsedResult parse(Result paramResult);
/*     */ 
/*     */   
/*     */   protected static String getMassagedText(Result result) {
/*  78 */     String text = result.getText();
/*  79 */     if (text.startsWith("﻿")) {
/*  80 */       text = text.substring(1);
/*     */     }
/*  82 */     return text;
/*     */   }
/*     */   
/*     */   public static ParsedResult parseResult(Result theResult) {
/*  86 */     for (ResultParser parser : PARSERS) {
/*  87 */       ParsedResult result = parser.parse(theResult);
/*  88 */       if (result != null) {
/*  89 */         return result;
/*     */       }
/*     */     } 
/*  92 */     return new TextParsedResult(theResult.getText(), null);
/*     */   }
/*     */   
/*     */   protected static void maybeAppend(String value, StringBuilder result) {
/*  96 */     if (value != null) {
/*  97 */       result.append('\n');
/*  98 */       result.append(value);
/*     */     } 
/*     */   }
/*     */   
/*     */   protected static void maybeAppend(String[] value, StringBuilder result) {
/* 103 */     if (value != null) {
/* 104 */       for (String s : value) {
/* 105 */         result.append('\n');
/* 106 */         result.append(s);
/*     */       } 
/*     */     }
/*     */   }
/*     */   
/*     */   protected static String[] maybeWrap(String value) {
/* 112 */     (new String[1])[0] = value; return (value == null) ? null : new String[1];
/*     */   }
/*     */   
/*     */   protected static String unescapeBackslash(String escaped) {
/* 116 */     int backslash = escaped.indexOf('\\');
/* 117 */     if (backslash < 0) {
/* 118 */       return escaped;
/*     */     }
/* 120 */     int max = escaped.length();
/* 121 */     StringBuilder unescaped = new StringBuilder(max - 1);
/* 122 */     unescaped.append(escaped.toCharArray(), 0, backslash);
/* 123 */     boolean nextIsEscaped = false;
/* 124 */     for (int i = backslash; i < max; i++) {
/* 125 */       char c = escaped.charAt(i);
/* 126 */       if (nextIsEscaped || c != '\\') {
/* 127 */         unescaped.append(c);
/* 128 */         nextIsEscaped = false;
/*     */       } else {
/* 130 */         nextIsEscaped = true;
/*     */       } 
/*     */     } 
/* 133 */     return unescaped.toString();
/*     */   }
/*     */   
/*     */   protected static int parseHexDigit(char c) {
/* 137 */     if (c >= '0' && c <= '9') {
/* 138 */       return c - 48;
/*     */     }
/* 140 */     if (c >= 'a' && c <= 'f') {
/* 141 */       return 10 + c - 97;
/*     */     }
/* 143 */     if (c >= 'A' && c <= 'F') {
/* 144 */       return 10 + c - 65;
/*     */     }
/* 146 */     return -1;
/*     */   }
/*     */   
/*     */   protected static boolean isStringOfDigits(CharSequence value, int length) {
/* 150 */     return (value != null && length == value.length() && DIGITS.matcher(value).matches());
/*     */   }
/*     */   
/*     */   protected static boolean isSubstringOfDigits(CharSequence value, int offset, int length) {
/* 154 */     if (value == null) {
/* 155 */       return false;
/*     */     }
/* 157 */     int max = offset + length;
/* 158 */     return (value.length() >= max && DIGITS.matcher(value.subSequence(offset, max)).matches());
/*     */   }
/*     */   
/*     */   protected static boolean isSubstringOfAlphaNumeric(CharSequence value, int offset, int length) {
/* 162 */     if (value == null) {
/* 163 */       return false;
/*     */     }
/* 165 */     int max = offset + length;
/* 166 */     return (value.length() >= max && ALPHANUM.matcher(value.subSequence(offset, max)).matches());
/*     */   }
/*     */   
/*     */   static Map<String, String> parseNameValuePairs(String uri) {
/* 170 */     int paramStart = uri.indexOf('?');
/* 171 */     if (paramStart < 0) {
/* 172 */       return null;
/*     */     }
/* 174 */     Map<String, String> result = new HashMap<String, String>(3);
/* 175 */     for (String keyValue : AMPERSAND.split(uri.substring(paramStart + 1))) {
/* 176 */       appendKeyValue(keyValue, result);
/*     */     }
/* 178 */     return result;
/*     */   }
/*     */   
/*     */   private static void appendKeyValue(CharSequence keyValue, Map<String, String> result) {
/* 182 */     String[] keyValueTokens = EQUALS.split(keyValue, 2);
/* 183 */     if (keyValueTokens.length == 2) {
/* 184 */       String key = keyValueTokens[0];
/* 185 */       String value = keyValueTokens[1];
/*     */       try {
/* 187 */         value = urlDecode(value);
/* 188 */         result.put(key, value);
/* 189 */       } catch (IllegalArgumentException iae) {}
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   static String urlDecode(String encoded) {
/*     */     try {
/* 197 */       return URLDecoder.decode(encoded, "UTF-8");
/* 198 */     } catch (UnsupportedEncodingException uee) {
/* 199 */       throw new IllegalStateException(uee);
/*     */     } 
/*     */   }
/*     */   
/*     */   static String[] matchPrefixedField(String prefix, String rawText, char endChar, boolean trim) {
/* 204 */     List<String> matches = null;
/* 205 */     int i = 0;
/* 206 */     int max = rawText.length();
/* 207 */     while (i < max) {
/* 208 */       i = rawText.indexOf(prefix, i);
/* 209 */       if (i < 0) {
/*     */         break;
/*     */       }
/* 212 */       i += prefix.length();
/* 213 */       int start = i;
/* 214 */       boolean more = true;
/* 215 */       while (more) {
/* 216 */         i = rawText.indexOf(endChar, i);
/* 217 */         if (i < 0) {
/*     */           
/* 219 */           i = rawText.length();
/* 220 */           more = false; continue;
/* 221 */         }  if (rawText.charAt(i - 1) == '\\') {
/*     */           
/* 223 */           i++;
/*     */           continue;
/*     */         } 
/* 226 */         if (matches == null) {
/* 227 */           matches = new ArrayList<String>(3);
/*     */         }
/* 229 */         String element = unescapeBackslash(rawText.substring(start, i));
/* 230 */         if (trim) {
/* 231 */           element = element.trim();
/*     */         }
/* 233 */         if (element.length() > 0) {
/* 234 */           matches.add(element);
/*     */         }
/* 236 */         i++;
/* 237 */         more = false;
/*     */       } 
/*     */     } 
/*     */     
/* 241 */     if (matches == null || matches.isEmpty()) {
/* 242 */       return null;
/*     */     }
/* 244 */     return matches.<String>toArray(new String[matches.size()]);
/*     */   }
/*     */   
/*     */   static String matchSinglePrefixedField(String prefix, String rawText, char endChar, boolean trim) {
/* 248 */     String[] matches = matchPrefixedField(prefix, rawText, endChar, trim);
/* 249 */     return (matches == null) ? null : matches[0];
/*     */   }
/*     */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\com\google\zxing\client\result\ResultParser.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       1.1.3
 */