/*     */ package com.google.zxing.client.result;
/*     */ 
/*     */ import com.google.zxing.Result;
/*     */ import java.io.ByteArrayOutputStream;
/*     */ import java.io.UnsupportedEncodingException;
/*     */ import java.util.ArrayList;
/*     */ import java.util.Collection;
/*     */ import java.util.List;
/*     */ import java.util.regex.Matcher;
/*     */ import java.util.regex.Pattern;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public final class VCardResultParser
/*     */   extends ResultParser
/*     */ {
/*  37 */   private static final Pattern BEGIN_VCARD = Pattern.compile("BEGIN:VCARD", 2);
/*  38 */   private static final Pattern VCARD_LIKE_DATE = Pattern.compile("\\d{4}-?\\d{2}-?\\d{2}");
/*  39 */   private static final Pattern CR_LF_SPACE_TAB = Pattern.compile("\r\n[ \t]");
/*  40 */   private static final Pattern NEWLINE_ESCAPE = Pattern.compile("\\\\[nN]");
/*  41 */   private static final Pattern VCARD_ESCAPES = Pattern.compile("\\\\([,;\\\\])");
/*  42 */   private static final Pattern EQUALS = Pattern.compile("=");
/*  43 */   private static final Pattern SEMICOLON = Pattern.compile(";");
/*  44 */   private static final Pattern UNESCAPED_SEMICOLONS = Pattern.compile("(?<!\\\\);+");
/*  45 */   private static final Pattern COMMA = Pattern.compile(",");
/*  46 */   private static final Pattern SEMICOLON_OR_COMMA = Pattern.compile("[;,]");
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public AddressBookParsedResult parse(Result result) {
/*  53 */     String rawText = getMassagedText(result);
/*  54 */     Matcher m = BEGIN_VCARD.matcher(rawText);
/*  55 */     if (!m.find() || m.start() != 0) {
/*  56 */       return null;
/*     */     }
/*  58 */     List<List<String>> names = matchVCardPrefixedField("FN", rawText, true, false);
/*  59 */     if (names == null) {
/*     */       
/*  61 */       names = matchVCardPrefixedField("N", rawText, true, false);
/*  62 */       formatNames(names);
/*     */     } 
/*  64 */     List<String> nicknameString = matchSingleVCardPrefixedField("NICKNAME", rawText, true, false);
/*  65 */     String[] nicknames = (nicknameString == null) ? null : COMMA.split(nicknameString.get(0));
/*  66 */     List<List<String>> phoneNumbers = matchVCardPrefixedField("TEL", rawText, true, false);
/*  67 */     List<List<String>> emails = matchVCardPrefixedField("EMAIL", rawText, true, false);
/*  68 */     List<String> note = matchSingleVCardPrefixedField("NOTE", rawText, false, false);
/*  69 */     List<List<String>> addresses = matchVCardPrefixedField("ADR", rawText, true, true);
/*  70 */     List<String> org = matchSingleVCardPrefixedField("ORG", rawText, true, true);
/*  71 */     List<String> birthday = matchSingleVCardPrefixedField("BDAY", rawText, true, false);
/*  72 */     if (birthday != null && !isLikeVCardDate(birthday.get(0))) {
/*  73 */       birthday = null;
/*     */     }
/*  75 */     List<String> title = matchSingleVCardPrefixedField("TITLE", rawText, true, false);
/*  76 */     List<List<String>> urls = matchVCardPrefixedField("URL", rawText, true, false);
/*  77 */     List<String> instantMessenger = matchSingleVCardPrefixedField("IMPP", rawText, true, false);
/*  78 */     List<String> geoString = matchSingleVCardPrefixedField("GEO", rawText, true, false);
/*  79 */     String[] geo = (geoString == null) ? null : SEMICOLON_OR_COMMA.split(geoString.get(0));
/*  80 */     if (geo != null && geo.length != 2) {
/*  81 */       geo = null;
/*     */     }
/*  83 */     return new AddressBookParsedResult(toPrimaryValues(names), nicknames, null, toPrimaryValues(phoneNumbers), toTypes(phoneNumbers), toPrimaryValues(emails), toTypes(emails), toPrimaryValue(instantMessenger), toPrimaryValue(note), toPrimaryValues(addresses), toTypes(addresses), toPrimaryValue(org), toPrimaryValue(birthday), toPrimaryValue(title), toPrimaryValues(urls), geo);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   static List<List<String>> matchVCardPrefixedField(CharSequence prefix, String rawText, boolean trim, boolean parseFieldDivider) {
/* 105 */     List<List<String>> matches = null;
/* 106 */     int i = 0;
/* 107 */     int max = rawText.length();
/*     */     
/* 109 */     while (i < max) {
/*     */ 
/*     */ 
/*     */       
/* 113 */       Matcher matcher = Pattern.compile("(?:^|\n)" + prefix + "(?:;([^:]*))?:", 2).matcher(rawText);
/*     */       
/* 115 */       if (i > 0) {
/* 116 */         i--;
/*     */       }
/* 118 */       if (!matcher.find(i)) {
/*     */         break;
/*     */       }
/* 121 */       i = matcher.end(0);
/*     */       
/* 123 */       String metadataString = matcher.group(1);
/* 124 */       List<String> metadata = null;
/* 125 */       boolean quotedPrintable = false;
/* 126 */       String quotedPrintableCharset = null;
/* 127 */       if (metadataString != null) {
/* 128 */         for (String metadatum : SEMICOLON.split(metadataString)) {
/* 129 */           if (metadata == null) {
/* 130 */             metadata = new ArrayList<String>(1);
/*     */           }
/* 132 */           metadata.add(metadatum);
/* 133 */           String[] metadatumTokens = EQUALS.split(metadatum, 2);
/* 134 */           if (metadatumTokens.length > 1) {
/* 135 */             String key = metadatumTokens[0];
/* 136 */             String value = metadatumTokens[1];
/* 137 */             if ("ENCODING".equalsIgnoreCase(key) && "QUOTED-PRINTABLE".equalsIgnoreCase(value)) {
/* 138 */               quotedPrintable = true;
/* 139 */             } else if ("CHARSET".equalsIgnoreCase(key)) {
/* 140 */               quotedPrintableCharset = value;
/*     */             } 
/*     */           } 
/*     */         } 
/*     */       }
/*     */       
/* 146 */       int matchStart = i;
/*     */       
/* 148 */       while ((i = rawText.indexOf('\n', i)) >= 0) {
/* 149 */         if (i < rawText.length() - 1 && (rawText.charAt(i + 1) == ' ' || rawText.charAt(i + 1) == '\t')) {
/*     */ 
/*     */           
/* 152 */           i += 2; continue;
/* 153 */         }  if (quotedPrintable && ((i >= 1 && rawText.charAt(i - 1) == '=') || (i >= 2 && rawText.charAt(i - 2) == '=')))
/*     */         {
/*     */           
/* 156 */           i++;
/*     */         }
/*     */       } 
/*     */ 
/*     */ 
/*     */       
/* 162 */       if (i < 0) {
/*     */         
/* 164 */         i = max; continue;
/* 165 */       }  if (i > matchStart) {
/*     */         
/* 167 */         if (matches == null) {
/* 168 */           matches = new ArrayList<List<String>>(1);
/*     */         }
/* 170 */         if (i >= 1 && rawText.charAt(i - 1) == '\r') {
/* 171 */           i--;
/*     */         }
/* 173 */         String element = rawText.substring(matchStart, i);
/* 174 */         if (trim) {
/* 175 */           element = element.trim();
/*     */         }
/* 177 */         if (quotedPrintable) {
/* 178 */           element = decodeQuotedPrintable(element, quotedPrintableCharset);
/* 179 */           if (parseFieldDivider) {
/* 180 */             element = UNESCAPED_SEMICOLONS.matcher(element).replaceAll("\n").trim();
/*     */           }
/*     */         } else {
/* 183 */           if (parseFieldDivider) {
/* 184 */             element = UNESCAPED_SEMICOLONS.matcher(element).replaceAll("\n").trim();
/*     */           }
/* 186 */           element = CR_LF_SPACE_TAB.matcher(element).replaceAll("");
/* 187 */           element = NEWLINE_ESCAPE.matcher(element).replaceAll("\n");
/* 188 */           element = VCARD_ESCAPES.matcher(element).replaceAll("$1");
/*     */         } 
/* 190 */         if (metadata == null) {
/* 191 */           List<String> match = new ArrayList<String>(1);
/* 192 */           match.add(element);
/* 193 */           matches.add(match);
/*     */         } else {
/* 195 */           metadata.add(0, element);
/* 196 */           matches.add(metadata);
/*     */         } 
/* 198 */         i++; continue;
/*     */       } 
/* 200 */       i++;
/*     */     } 
/*     */ 
/*     */ 
/*     */     
/* 205 */     return matches;
/*     */   }
/*     */   
/*     */   private static String decodeQuotedPrintable(CharSequence value, String charset) {
/* 209 */     int length = value.length();
/* 210 */     StringBuilder result = new StringBuilder(length);
/* 211 */     ByteArrayOutputStream fragmentBuffer = new ByteArrayOutputStream();
/* 212 */     for (int i = 0; i < length; i++) {
/* 213 */       char c = value.charAt(i);
/* 214 */       switch (c) {
/*     */         case '\n':
/*     */         case '\r':
/*     */           break;
/*     */         case '=':
/* 219 */           if (i < length - 2) {
/* 220 */             char nextChar = value.charAt(i + 1);
/* 221 */             if (nextChar != '\r' && nextChar != '\n') {
/* 222 */               char nextNextChar = value.charAt(i + 2);
/* 223 */               int firstDigit = parseHexDigit(nextChar);
/* 224 */               int secondDigit = parseHexDigit(nextNextChar);
/* 225 */               if (firstDigit >= 0 && secondDigit >= 0) {
/* 226 */                 fragmentBuffer.write((firstDigit << 4) + secondDigit);
/*     */               }
/* 228 */               i += 2;
/*     */             } 
/*     */           } 
/*     */           break;
/*     */         default:
/* 233 */           maybeAppendFragment(fragmentBuffer, charset, result);
/* 234 */           result.append(c); break;
/*     */       } 
/*     */     } 
/* 237 */     maybeAppendFragment(fragmentBuffer, charset, result);
/* 238 */     return result.toString();
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   private static void maybeAppendFragment(ByteArrayOutputStream fragmentBuffer, String charset, StringBuilder result) {
/* 244 */     if (fragmentBuffer.size() > 0) {
/* 245 */       String str; byte[] fragmentBytes = fragmentBuffer.toByteArray();
/*     */       
/* 247 */       if (charset == null) {
/* 248 */         str = new String(fragmentBytes);
/*     */       } else {
/*     */         try {
/* 251 */           str = new String(fragmentBytes, charset);
/* 252 */         } catch (UnsupportedEncodingException e) {
/*     */           
/* 254 */           str = new String(fragmentBytes);
/*     */         } 
/*     */       } 
/* 257 */       fragmentBuffer.reset();
/* 258 */       result.append(str);
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   static List<String> matchSingleVCardPrefixedField(CharSequence prefix, String rawText, boolean trim, boolean parseFieldDivider) {
/* 266 */     List<List<String>> values = matchVCardPrefixedField(prefix, rawText, trim, parseFieldDivider);
/* 267 */     return (values == null || values.isEmpty()) ? null : values.get(0);
/*     */   }
/*     */   
/*     */   private static String toPrimaryValue(List<String> list) {
/* 271 */     return (list == null || list.isEmpty()) ? null : list.get(0);
/*     */   }
/*     */   
/*     */   private static String[] toPrimaryValues(Collection<List<String>> lists) {
/* 275 */     if (lists == null || lists.isEmpty()) {
/* 276 */       return null;
/*     */     }
/* 278 */     List<String> result = new ArrayList<String>(lists.size());
/* 279 */     for (List<String> list : lists) {
/* 280 */       String value = list.get(0);
/* 281 */       if (value != null && value.length() > 0) {
/* 282 */         result.add(value);
/*     */       }
/*     */     } 
/* 285 */     return result.<String>toArray(new String[lists.size()]);
/*     */   }
/*     */   
/*     */   private static String[] toTypes(Collection<List<String>> lists) {
/* 289 */     if (lists == null || lists.isEmpty()) {
/* 290 */       return null;
/*     */     }
/* 292 */     List<String> result = new ArrayList<String>(lists.size());
/* 293 */     for (List<String> list : lists) {
/* 294 */       String type = null;
/* 295 */       for (int i = 1; i < list.size(); i++) {
/* 296 */         String metadatum = list.get(i);
/* 297 */         int equals = metadatum.indexOf('=');
/* 298 */         if (equals < 0) {
/*     */           
/* 300 */           type = metadatum;
/*     */           break;
/*     */         } 
/* 303 */         if ("TYPE".equalsIgnoreCase(metadatum.substring(0, equals))) {
/* 304 */           type = metadatum.substring(equals + 1);
/*     */           break;
/*     */         } 
/*     */       } 
/* 308 */       result.add(type);
/*     */     } 
/* 310 */     return result.<String>toArray(new String[lists.size()]);
/*     */   }
/*     */   
/*     */   private static boolean isLikeVCardDate(CharSequence value) {
/* 314 */     return (value == null || VCARD_LIKE_DATE.matcher(value).matches());
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static void formatNames(Iterable<List<String>> names) {
/* 324 */     if (names != null) {
/* 325 */       for (List<String> list : names) {
/* 326 */         String name = list.get(0);
/* 327 */         String[] components = new String[5];
/* 328 */         int start = 0;
/*     */         
/* 330 */         int componentIndex = 0; int end;
/* 331 */         while (componentIndex < components.length - 1 && (end = name.indexOf(';', start)) > 0) {
/* 332 */           components[componentIndex] = name.substring(start, end);
/* 333 */           componentIndex++;
/* 334 */           start = end + 1;
/*     */         } 
/* 336 */         components[componentIndex] = name.substring(start);
/* 337 */         StringBuilder newName = new StringBuilder(100);
/* 338 */         maybeAppendComponent(components, 3, newName);
/* 339 */         maybeAppendComponent(components, 1, newName);
/* 340 */         maybeAppendComponent(components, 2, newName);
/* 341 */         maybeAppendComponent(components, 0, newName);
/* 342 */         maybeAppendComponent(components, 4, newName);
/* 343 */         list.set(0, newName.toString().trim());
/*     */       } 
/*     */     }
/*     */   }
/*     */   
/*     */   private static void maybeAppendComponent(String[] components, int i, StringBuilder newName) {
/* 349 */     if (components[i] != null) {
/* 350 */       newName.append(' ');
/* 351 */       newName.append(components[i]);
/*     */     } 
/*     */   }
/*     */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\com\google\zxing\client\result\VCardResultParser.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       1.1.3
 */