/*     */ package com.google.zxing.common;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public final class BitArray
/*     */ {
/*     */   private int[] bits;
/*     */   private int size;
/*     */   
/*     */   public BitArray() {
/*  30 */     this.size = 0;
/*  31 */     this.bits = new int[1];
/*     */   }
/*     */   
/*     */   public BitArray(int size) {
/*  35 */     this.size = size;
/*  36 */     this.bits = makeArray(size);
/*     */   }
/*     */   
/*     */   public int getSize() {
/*  40 */     return this.size;
/*     */   }
/*     */   
/*     */   public int getSizeInBytes() {
/*  44 */     return this.size + 7 >> 3;
/*     */   }
/*     */   
/*     */   private void ensureCapacity(int size) {
/*  48 */     if (size > this.bits.length << 5) {
/*  49 */       int[] newBits = makeArray(size);
/*  50 */       System.arraycopy(this.bits, 0, newBits, 0, this.bits.length);
/*  51 */       this.bits = newBits;
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public boolean get(int i) {
/*  60 */     return ((this.bits[i >> 5] & 1 << (i & 0x1F)) != 0);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void set(int i) {
/*  69 */     this.bits[i >> 5] = this.bits[i >> 5] | 1 << (i & 0x1F);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void flip(int i) {
/*  78 */     this.bits[i >> 5] = this.bits[i >> 5] ^ 1 << (i & 0x1F);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public int getNextSet(int from) {
/*  88 */     if (from >= this.size) {
/*  89 */       return this.size;
/*     */     }
/*  91 */     int bitsOffset = from >> 5;
/*  92 */     int currentBits = this.bits[bitsOffset];
/*     */     
/*  94 */     currentBits &= (1 << (from & 0x1F)) - 1 ^ 0xFFFFFFFF;
/*  95 */     while (currentBits == 0) {
/*  96 */       if (++bitsOffset == this.bits.length) {
/*  97 */         return this.size;
/*     */       }
/*  99 */       currentBits = this.bits[bitsOffset];
/*     */     } 
/* 101 */     int result = (bitsOffset << 5) + Integer.numberOfTrailingZeros(currentBits);
/* 102 */     return (result > this.size) ? this.size : result;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public int getNextUnset(int from) {
/* 109 */     if (from >= this.size) {
/* 110 */       return this.size;
/*     */     }
/* 112 */     int bitsOffset = from >> 5;
/* 113 */     int currentBits = this.bits[bitsOffset] ^ 0xFFFFFFFF;
/*     */     
/* 115 */     currentBits &= (1 << (from & 0x1F)) - 1 ^ 0xFFFFFFFF;
/* 116 */     while (currentBits == 0) {
/* 117 */       if (++bitsOffset == this.bits.length) {
/* 118 */         return this.size;
/*     */       }
/* 120 */       currentBits = this.bits[bitsOffset] ^ 0xFFFFFFFF;
/*     */     } 
/* 122 */     int result = (bitsOffset << 5) + Integer.numberOfTrailingZeros(currentBits);
/* 123 */     return (result > this.size) ? this.size : result;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void setBulk(int i, int newBits) {
/* 134 */     this.bits[i >> 5] = newBits;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void setRange(int start, int end) {
/* 144 */     if (end < start) {
/* 145 */       throw new IllegalArgumentException();
/*     */     }
/* 147 */     if (end == start) {
/*     */       return;
/*     */     }
/* 150 */     end--;
/* 151 */     int firstInt = start >> 5;
/* 152 */     int lastInt = end >> 5;
/* 153 */     for (int i = firstInt; i <= lastInt; i++) {
/* 154 */       int mask, firstBit = (i > firstInt) ? 0 : (start & 0x1F);
/* 155 */       int lastBit = (i < lastInt) ? 31 : (end & 0x1F);
/*     */       
/* 157 */       if (firstBit == 0 && lastBit == 31) {
/* 158 */         mask = -1;
/*     */       } else {
/* 160 */         mask = 0;
/* 161 */         for (int j = firstBit; j <= lastBit; j++) {
/* 162 */           mask |= 1 << j;
/*     */         }
/*     */       } 
/* 165 */       this.bits[i] = this.bits[i] | mask;
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void clear() {
/* 173 */     int max = this.bits.length;
/* 174 */     for (int i = 0; i < max; i++) {
/* 175 */       this.bits[i] = 0;
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public boolean isRange(int start, int end, boolean value) {
/* 189 */     if (end < start) {
/* 190 */       throw new IllegalArgumentException();
/*     */     }
/* 192 */     if (end == start) {
/* 193 */       return true;
/*     */     }
/* 195 */     end--;
/* 196 */     int firstInt = start >> 5;
/* 197 */     int lastInt = end >> 5;
/* 198 */     for (int i = firstInt; i <= lastInt; i++) {
/* 199 */       int mask, firstBit = (i > firstInt) ? 0 : (start & 0x1F);
/* 200 */       int lastBit = (i < lastInt) ? 31 : (end & 0x1F);
/*     */       
/* 202 */       if (firstBit == 0 && lastBit == 31) {
/* 203 */         mask = -1;
/*     */       } else {
/* 205 */         mask = 0;
/* 206 */         for (int j = firstBit; j <= lastBit; j++) {
/* 207 */           mask |= 1 << j;
/*     */         }
/*     */       } 
/*     */ 
/*     */ 
/*     */       
/* 213 */       if ((this.bits[i] & mask) != (value ? mask : 0)) {
/* 214 */         return false;
/*     */       }
/*     */     } 
/* 217 */     return true;
/*     */   }
/*     */   
/*     */   public void appendBit(boolean bit) {
/* 221 */     ensureCapacity(this.size + 1);
/* 222 */     if (bit) {
/* 223 */       this.bits[this.size >> 5] = this.bits[this.size >> 5] | 1 << (this.size & 0x1F);
/*     */     }
/* 225 */     this.size++;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void appendBits(int value, int numBits) {
/* 234 */     if (numBits < 0 || numBits > 32) {
/* 235 */       throw new IllegalArgumentException("Num bits must be between 0 and 32");
/*     */     }
/* 237 */     ensureCapacity(this.size + numBits);
/* 238 */     for (int numBitsLeft = numBits; numBitsLeft > 0; numBitsLeft--) {
/* 239 */       appendBit(((value >> numBitsLeft - 1 & 0x1) == 1));
/*     */     }
/*     */   }
/*     */   
/*     */   public void appendBitArray(BitArray other) {
/* 244 */     int otherSize = other.size;
/* 245 */     ensureCapacity(this.size + otherSize);
/* 246 */     for (int i = 0; i < otherSize; i++) {
/* 247 */       appendBit(other.get(i));
/*     */     }
/*     */   }
/*     */   
/*     */   public void xor(BitArray other) {
/* 252 */     if (this.bits.length != other.bits.length) {
/* 253 */       throw new IllegalArgumentException("Sizes don't match");
/*     */     }
/* 255 */     for (int i = 0; i < this.bits.length; i++)
/*     */     {
/*     */       
/* 258 */       this.bits[i] = this.bits[i] ^ other.bits[i];
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void toBytes(int bitOffset, byte[] array, int offset, int numBytes) {
/* 271 */     for (int i = 0; i < numBytes; i++) {
/* 272 */       int theByte = 0;
/* 273 */       for (int j = 0; j < 8; j++) {
/* 274 */         if (get(bitOffset)) {
/* 275 */           theByte |= 1 << 7 - j;
/*     */         }
/* 277 */         bitOffset++;
/*     */       } 
/* 279 */       array[offset + i] = (byte)theByte;
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public int[] getBitArray() {
/* 288 */     return this.bits;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void reverse() {
/* 295 */     int[] newBits = new int[this.bits.length];
/* 296 */     int size = this.size;
/* 297 */     for (int i = 0; i < size; i++) {
/* 298 */       if (get(size - i - 1)) {
/* 299 */         newBits[i >> 5] = newBits[i >> 5] | 1 << (i & 0x1F);
/*     */       }
/*     */     } 
/* 302 */     this.bits = newBits;
/*     */   }
/*     */   
/*     */   private static int[] makeArray(int size) {
/* 306 */     return new int[size + 31 >> 5];
/*     */   }
/*     */ 
/*     */   
/*     */   public String toString() {
/* 311 */     StringBuilder result = new StringBuilder(this.size);
/* 312 */     for (int i = 0; i < this.size; i++) {
/* 313 */       if ((i & 0x7) == 0) {
/* 314 */         result.append(' ');
/*     */       }
/* 316 */       result.append(get(i) ? 88 : 46);
/*     */     } 
/* 318 */     return result.toString();
/*     */   }
/*     */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\com\google\zxing\common\BitArray.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       1.1.3
 */