/*     */ package com.google.zxing.common;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public final class BitMatrix
/*     */ {
/*     */   private final int width;
/*     */   private final int height;
/*     */   private final int rowSize;
/*     */   private final int[] bits;
/*     */   
/*     */   public BitMatrix(int dimension) {
/*  43 */     this(dimension, dimension);
/*     */   }
/*     */   
/*     */   public BitMatrix(int width, int height) {
/*  47 */     if (width < 1 || height < 1) {
/*  48 */       throw new IllegalArgumentException("Both dimensions must be greater than 0");
/*     */     }
/*  50 */     this.width = width;
/*  51 */     this.height = height;
/*  52 */     this.rowSize = width + 31 >> 5;
/*  53 */     this.bits = new int[this.rowSize * height];
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public boolean get(int x, int y) {
/*  64 */     int offset = y * this.rowSize + (x >> 5);
/*  65 */     return ((this.bits[offset] >>> (x & 0x1F) & 0x1) != 0);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void set(int x, int y) {
/*  75 */     int offset = y * this.rowSize + (x >> 5);
/*  76 */     this.bits[offset] = this.bits[offset] | 1 << (x & 0x1F);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void flip(int x, int y) {
/*  86 */     int offset = y * this.rowSize + (x >> 5);
/*  87 */     this.bits[offset] = this.bits[offset] ^ 1 << (x & 0x1F);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void clear() {
/*  94 */     int max = this.bits.length;
/*  95 */     for (int i = 0; i < max; i++) {
/*  96 */       this.bits[i] = 0;
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void setRegion(int left, int top, int width, int height) {
/* 109 */     if (top < 0 || left < 0) {
/* 110 */       throw new IllegalArgumentException("Left and top must be nonnegative");
/*     */     }
/* 112 */     if (height < 1 || width < 1) {
/* 113 */       throw new IllegalArgumentException("Height and width must be at least 1");
/*     */     }
/* 115 */     int right = left + width;
/* 116 */     int bottom = top + height;
/* 117 */     if (bottom > this.height || right > this.width) {
/* 118 */       throw new IllegalArgumentException("The region must fit inside the matrix");
/*     */     }
/* 120 */     for (int y = top; y < bottom; y++) {
/* 121 */       int offset = y * this.rowSize;
/* 122 */       for (int x = left; x < right; x++) {
/* 123 */         this.bits[offset + (x >> 5)] = this.bits[offset + (x >> 5)] | 1 << (x & 0x1F);
/*     */       }
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public BitArray getRow(int y, BitArray row) {
/* 137 */     if (row == null || row.getSize() < this.width) {
/* 138 */       row = new BitArray(this.width);
/*     */     }
/* 140 */     int offset = y * this.rowSize;
/* 141 */     for (int x = 0; x < this.rowSize; x++) {
/* 142 */       row.setBulk(x << 5, this.bits[offset + x]);
/*     */     }
/* 144 */     return row;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void setRow(int y, BitArray row) {
/* 152 */     System.arraycopy(row.getBitArray(), 0, this.bits, y * this.rowSize, this.rowSize);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public int[] getEnclosingRectangle() {
/* 161 */     int left = this.width;
/* 162 */     int top = this.height;
/* 163 */     int right = -1;
/* 164 */     int bottom = -1;
/*     */     
/* 166 */     for (int y = 0; y < this.height; y++) {
/* 167 */       for (int x32 = 0; x32 < this.rowSize; x32++) {
/* 168 */         int theBits = this.bits[y * this.rowSize + x32];
/* 169 */         if (theBits != 0) {
/* 170 */           if (y < top) {
/* 171 */             top = y;
/*     */           }
/* 173 */           if (y > bottom) {
/* 174 */             bottom = y;
/*     */           }
/* 176 */           if (x32 * 32 < left) {
/* 177 */             int bit = 0;
/* 178 */             while (theBits << 31 - bit == 0) {
/* 179 */               bit++;
/*     */             }
/* 181 */             if (x32 * 32 + bit < left) {
/* 182 */               left = x32 * 32 + bit;
/*     */             }
/*     */           } 
/* 185 */           if (x32 * 32 + 31 > right) {
/* 186 */             int bit = 31;
/* 187 */             while (theBits >>> bit == 0) {
/* 188 */               bit--;
/*     */             }
/* 190 */             if (x32 * 32 + bit > right) {
/* 191 */               right = x32 * 32 + bit;
/*     */             }
/*     */           } 
/*     */         } 
/*     */       } 
/*     */     } 
/*     */     
/* 198 */     int width = right - left;
/* 199 */     int height = bottom - top;
/*     */     
/* 201 */     if (width < 0 || height < 0) {
/* 202 */       return null;
/*     */     }
/*     */     
/* 205 */     return new int[] { left, top, width, height };
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public int[] getTopLeftOnBit() {
/* 214 */     int bitsOffset = 0;
/* 215 */     while (bitsOffset < this.bits.length && this.bits[bitsOffset] == 0) {
/* 216 */       bitsOffset++;
/*     */     }
/* 218 */     if (bitsOffset == this.bits.length) {
/* 219 */       return null;
/*     */     }
/* 221 */     int y = bitsOffset / this.rowSize;
/* 222 */     int x = bitsOffset % this.rowSize << 5;
/*     */     
/* 224 */     int theBits = this.bits[bitsOffset];
/* 225 */     int bit = 0;
/* 226 */     while (theBits << 31 - bit == 0) {
/* 227 */       bit++;
/*     */     }
/* 229 */     x += bit;
/* 230 */     return new int[] { x, y };
/*     */   }
/*     */   
/*     */   public int[] getBottomRightOnBit() {
/* 234 */     int bitsOffset = this.bits.length - 1;
/* 235 */     while (bitsOffset >= 0 && this.bits[bitsOffset] == 0) {
/* 236 */       bitsOffset--;
/*     */     }
/* 238 */     if (bitsOffset < 0) {
/* 239 */       return null;
/*     */     }
/*     */     
/* 242 */     int y = bitsOffset / this.rowSize;
/* 243 */     int x = bitsOffset % this.rowSize << 5;
/*     */     
/* 245 */     int theBits = this.bits[bitsOffset];
/* 246 */     int bit = 31;
/* 247 */     while (theBits >>> bit == 0) {
/* 248 */       bit--;
/*     */     }
/* 250 */     x += bit;
/*     */     
/* 252 */     return new int[] { x, y };
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public int getWidth() {
/* 259 */     return this.width;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public int getHeight() {
/* 266 */     return this.height;
/*     */   }
/*     */ 
/*     */   
/*     */   public boolean equals(Object o) {
/* 271 */     if (!(o instanceof BitMatrix)) {
/* 272 */       return false;
/*     */     }
/* 274 */     BitMatrix other = (BitMatrix)o;
/* 275 */     if (this.width != other.width || this.height != other.height || this.rowSize != other.rowSize || this.bits.length != other.bits.length)
/*     */     {
/* 277 */       return false;
/*     */     }
/* 279 */     for (int i = 0; i < this.bits.length; i++) {
/* 280 */       if (this.bits[i] != other.bits[i]) {
/* 281 */         return false;
/*     */       }
/*     */     } 
/* 284 */     return true;
/*     */   }
/*     */ 
/*     */   
/*     */   public int hashCode() {
/* 289 */     int hash = this.width;
/* 290 */     hash = 31 * hash + this.width;
/* 291 */     hash = 31 * hash + this.height;
/* 292 */     hash = 31 * hash + this.rowSize;
/* 293 */     for (int bit : this.bits) {
/* 294 */       hash = 31 * hash + bit;
/*     */     }
/* 296 */     return hash;
/*     */   }
/*     */ 
/*     */   
/*     */   public String toString() {
/* 301 */     StringBuilder result = new StringBuilder(this.height * (this.width + 1));
/* 302 */     for (int y = 0; y < this.height; y++) {
/* 303 */       for (int x = 0; x < this.width; x++) {
/* 304 */         result.append(get(x, y) ? "X " : "  ");
/*     */       }
/* 306 */       result.append('\n');
/*     */     } 
/* 308 */     return result.toString();
/*     */   }
/*     */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\com\google\zxing\common\BitMatrix.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       1.1.3
 */