/*     */ package com.google.zxing.common.detector;
/*     */ 
/*     */ import com.google.zxing.NotFoundException;
/*     */ import com.google.zxing.ResultPoint;
/*     */ import com.google.zxing.common.BitMatrix;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public final class WhiteRectangleDetector
/*     */ {
/*     */   private static final int INIT_SIZE = 30;
/*     */   private static final int CORR = 1;
/*     */   private final BitMatrix image;
/*     */   private final int height;
/*     */   private final int width;
/*     */   private final int leftInit;
/*     */   private final int rightInit;
/*     */   private final int downInit;
/*     */   private final int upInit;
/*     */   
/*     */   public WhiteRectangleDetector(BitMatrix image) throws NotFoundException {
/*  50 */     this.image = image;
/*  51 */     this.height = image.getHeight();
/*  52 */     this.width = image.getWidth();
/*  53 */     this.leftInit = this.width - 30 >> 1;
/*  54 */     this.rightInit = this.width + 30 >> 1;
/*  55 */     this.upInit = this.height - 30 >> 1;
/*  56 */     this.downInit = this.height + 30 >> 1;
/*  57 */     if (this.upInit < 0 || this.leftInit < 0 || this.downInit >= this.height || this.rightInit >= this.width) {
/*  58 */       throw NotFoundException.getNotFoundInstance();
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public WhiteRectangleDetector(BitMatrix image, int initSize, int x, int y) throws NotFoundException {
/*  66 */     this.image = image;
/*  67 */     this.height = image.getHeight();
/*  68 */     this.width = image.getWidth();
/*  69 */     int halfsize = initSize >> 1;
/*  70 */     this.leftInit = x - halfsize;
/*  71 */     this.rightInit = x + halfsize;
/*  72 */     this.upInit = y - halfsize;
/*  73 */     this.downInit = y + halfsize;
/*  74 */     if (this.upInit < 0 || this.leftInit < 0 || this.downInit >= this.height || this.rightInit >= this.width) {
/*  75 */       throw NotFoundException.getNotFoundInstance();
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public ResultPoint[] detect() throws NotFoundException {
/*  95 */     int left = this.leftInit;
/*  96 */     int right = this.rightInit;
/*  97 */     int up = this.upInit;
/*  98 */     int down = this.downInit;
/*  99 */     boolean sizeExceeded = false;
/* 100 */     boolean aBlackPointFoundOnBorder = true;
/* 101 */     boolean atLeastOneBlackPointFoundOnBorder = false;
/*     */     
/* 103 */     while (aBlackPointFoundOnBorder) {
/*     */       
/* 105 */       aBlackPointFoundOnBorder = false;
/*     */ 
/*     */ 
/*     */ 
/*     */       
/* 110 */       boolean rightBorderNotWhite = true;
/* 111 */       while (rightBorderNotWhite && right < this.width) {
/* 112 */         rightBorderNotWhite = containsBlackPoint(up, down, right, false);
/* 113 */         if (rightBorderNotWhite) {
/* 114 */           right++;
/* 115 */           aBlackPointFoundOnBorder = true;
/*     */         } 
/*     */       } 
/*     */       
/* 119 */       if (right >= this.width) {
/* 120 */         sizeExceeded = true;
/*     */ 
/*     */         
/*     */         break;
/*     */       } 
/*     */ 
/*     */       
/* 127 */       boolean bottomBorderNotWhite = true;
/* 128 */       while (bottomBorderNotWhite && down < this.height) {
/* 129 */         bottomBorderNotWhite = containsBlackPoint(left, right, down, true);
/* 130 */         if (bottomBorderNotWhite) {
/* 131 */           down++;
/* 132 */           aBlackPointFoundOnBorder = true;
/*     */         } 
/*     */       } 
/*     */       
/* 136 */       if (down >= this.height) {
/* 137 */         sizeExceeded = true;
/*     */ 
/*     */         
/*     */         break;
/*     */       } 
/*     */ 
/*     */       
/* 144 */       boolean leftBorderNotWhite = true;
/* 145 */       while (leftBorderNotWhite && left >= 0) {
/* 146 */         leftBorderNotWhite = containsBlackPoint(up, down, left, false);
/* 147 */         if (leftBorderNotWhite) {
/* 148 */           left--;
/* 149 */           aBlackPointFoundOnBorder = true;
/*     */         } 
/*     */       } 
/*     */       
/* 153 */       if (left < 0) {
/* 154 */         sizeExceeded = true;
/*     */ 
/*     */         
/*     */         break;
/*     */       } 
/*     */ 
/*     */       
/* 161 */       boolean topBorderNotWhite = true;
/* 162 */       while (topBorderNotWhite && up >= 0) {
/* 163 */         topBorderNotWhite = containsBlackPoint(left, right, up, true);
/* 164 */         if (topBorderNotWhite) {
/* 165 */           up--;
/* 166 */           aBlackPointFoundOnBorder = true;
/*     */         } 
/*     */       } 
/*     */       
/* 170 */       if (up < 0) {
/* 171 */         sizeExceeded = true;
/*     */         
/*     */         break;
/*     */       } 
/* 175 */       if (aBlackPointFoundOnBorder) {
/* 176 */         atLeastOneBlackPointFoundOnBorder = true;
/*     */       }
/*     */     } 
/*     */ 
/*     */     
/* 181 */     if (!sizeExceeded && atLeastOneBlackPointFoundOnBorder) {
/*     */       
/* 183 */       int maxSize = right - left;
/*     */       
/* 185 */       ResultPoint z = null;
/* 186 */       for (int i = 1; i < maxSize; i++) {
/* 187 */         z = getBlackPointOnSegment(left, (down - i), (left + i), down);
/* 188 */         if (z != null) {
/*     */           break;
/*     */         }
/*     */       } 
/*     */       
/* 193 */       if (z == null) {
/* 194 */         throw NotFoundException.getNotFoundInstance();
/*     */       }
/*     */       
/* 197 */       ResultPoint t = null;
/*     */       
/* 199 */       for (int j = 1; j < maxSize; j++) {
/* 200 */         t = getBlackPointOnSegment(left, (up + j), (left + j), up);
/* 201 */         if (t != null) {
/*     */           break;
/*     */         }
/*     */       } 
/*     */       
/* 206 */       if (t == null) {
/* 207 */         throw NotFoundException.getNotFoundInstance();
/*     */       }
/*     */       
/* 210 */       ResultPoint x = null;
/*     */       
/* 212 */       for (int k = 1; k < maxSize; k++) {
/* 213 */         x = getBlackPointOnSegment(right, (up + k), (right - k), up);
/* 214 */         if (x != null) {
/*     */           break;
/*     */         }
/*     */       } 
/*     */       
/* 219 */       if (x == null) {
/* 220 */         throw NotFoundException.getNotFoundInstance();
/*     */       }
/*     */       
/* 223 */       ResultPoint y = null;
/*     */       
/* 225 */       for (int m = 1; m < maxSize; m++) {
/* 226 */         y = getBlackPointOnSegment(right, (down - m), (right - m), down);
/* 227 */         if (y != null) {
/*     */           break;
/*     */         }
/*     */       } 
/*     */       
/* 232 */       if (y == null) {
/* 233 */         throw NotFoundException.getNotFoundInstance();
/*     */       }
/*     */       
/* 236 */       return centerEdges(y, z, x, t);
/*     */     } 
/*     */     
/* 239 */     throw NotFoundException.getNotFoundInstance();
/*     */   }
/*     */ 
/*     */   
/*     */   private ResultPoint getBlackPointOnSegment(float aX, float aY, float bX, float bY) {
/* 244 */     int dist = MathUtils.round(MathUtils.distance(aX, aY, bX, bY));
/* 245 */     float xStep = (bX - aX) / dist;
/* 246 */     float yStep = (bY - aY) / dist;
/*     */     
/* 248 */     for (int i = 0; i < dist; i++) {
/* 249 */       int x = MathUtils.round(aX + i * xStep);
/* 250 */       int y = MathUtils.round(aY + i * yStep);
/* 251 */       if (this.image.get(x, y)) {
/* 252 */         return new ResultPoint(x, y);
/*     */       }
/*     */     } 
/* 255 */     return null;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private ResultPoint[] centerEdges(ResultPoint y, ResultPoint z, ResultPoint x, ResultPoint t) {
/* 281 */     float yi = y.getX();
/* 282 */     float yj = y.getY();
/* 283 */     float zi = z.getX();
/* 284 */     float zj = z.getY();
/* 285 */     float xi = x.getX();
/* 286 */     float xj = x.getY();
/* 287 */     float ti = t.getX();
/* 288 */     float tj = t.getY();
/*     */     
/* 290 */     if (yi < this.width / 2.0F) {
/* 291 */       return new ResultPoint[] { new ResultPoint(ti - 1.0F, tj + 1.0F), new ResultPoint(zi + 1.0F, zj + 1.0F), new ResultPoint(xi - 1.0F, xj - 1.0F), new ResultPoint(yi + 1.0F, yj - 1.0F) };
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 297 */     return new ResultPoint[] { new ResultPoint(ti + 1.0F, tj + 1.0F), new ResultPoint(zi + 1.0F, zj - 1.0F), new ResultPoint(xi - 1.0F, xj + 1.0F), new ResultPoint(yi - 1.0F, yj - 1.0F) };
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private boolean containsBlackPoint(int a, int b, int fixed, boolean horizontal) {
/* 316 */     if (horizontal) {
/* 317 */       for (int x = a; x <= b; x++) {
/* 318 */         if (this.image.get(x, fixed)) {
/* 319 */           return true;
/*     */         }
/*     */       } 
/*     */     } else {
/* 323 */       for (int y = a; y <= b; y++) {
/* 324 */         if (this.image.get(fixed, y)) {
/* 325 */           return true;
/*     */         }
/*     */       } 
/*     */     } 
/*     */     
/* 330 */     return false;
/*     */   }
/*     */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\com\google\zxing\common\detector\WhiteRectangleDetector.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       1.1.3
 */