/*     */ package com.google.zxing.datamatrix;
/*     */ 
/*     */ import com.google.zxing.BarcodeFormat;
/*     */ import com.google.zxing.Dimension;
/*     */ import com.google.zxing.EncodeHintType;
/*     */ import com.google.zxing.Writer;
/*     */ import com.google.zxing.common.BitMatrix;
/*     */ import com.google.zxing.datamatrix.encoder.DefaultPlacement;
/*     */ import com.google.zxing.datamatrix.encoder.ErrorCorrection;
/*     */ import com.google.zxing.datamatrix.encoder.HighLevelEncoder;
/*     */ import com.google.zxing.datamatrix.encoder.SymbolInfo;
/*     */ import com.google.zxing.datamatrix.encoder.SymbolShapeHint;
/*     */ import com.google.zxing.qrcode.encoder.ByteMatrix;
/*     */ import java.util.Map;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public final class DataMatrixWriter
/*     */   implements Writer
/*     */ {
/*     */   public BitMatrix encode(String contents, BarcodeFormat format, int width, int height) {
/*  43 */     return encode(contents, format, width, height, null);
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   public BitMatrix encode(String contents, BarcodeFormat format, int width, int height, Map<EncodeHintType, ?> hints) {
/*  49 */     if (contents.length() == 0) {
/*  50 */       throw new IllegalArgumentException("Found empty contents");
/*     */     }
/*     */     
/*  53 */     if (format != BarcodeFormat.DATA_MATRIX) {
/*  54 */       throw new IllegalArgumentException("Can only encode DATA_MATRIX, but got " + format);
/*     */     }
/*     */     
/*  57 */     if (width < 0 || height < 0) {
/*  58 */       throw new IllegalArgumentException("Requested dimensions are too small: " + width + 'x' + height);
/*     */     }
/*     */ 
/*     */     
/*  62 */     SymbolShapeHint shape = SymbolShapeHint.FORCE_NONE;
/*  63 */     Dimension minSize = null;
/*  64 */     Dimension maxSize = null;
/*  65 */     if (hints != null) {
/*  66 */       SymbolShapeHint requestedShape = (SymbolShapeHint)hints.get(EncodeHintType.DATA_MATRIX_SHAPE);
/*  67 */       if (requestedShape != null) {
/*  68 */         shape = requestedShape;
/*     */       }
/*  70 */       Dimension requestedMinSize = (Dimension)hints.get(EncodeHintType.MIN_SIZE);
/*  71 */       if (requestedMinSize != null) {
/*  72 */         minSize = requestedMinSize;
/*     */       }
/*  74 */       Dimension requestedMaxSize = (Dimension)hints.get(EncodeHintType.MAX_SIZE);
/*  75 */       if (requestedMaxSize != null) {
/*  76 */         maxSize = requestedMaxSize;
/*     */       }
/*     */     } 
/*     */ 
/*     */ 
/*     */     
/*  82 */     String encoded = HighLevelEncoder.encodeHighLevel(contents, shape, minSize, maxSize);
/*     */     
/*  84 */     SymbolInfo symbolInfo = SymbolInfo.lookup(encoded.length(), shape, minSize, maxSize, true);
/*     */ 
/*     */     
/*  87 */     String codewords = ErrorCorrection.encodeECC200(encoded, symbolInfo);
/*     */ 
/*     */     
/*  90 */     DefaultPlacement placement = new DefaultPlacement(codewords, symbolInfo.getSymbolDataWidth(), symbolInfo.getSymbolDataHeight());
/*     */     
/*  92 */     placement.place();
/*     */ 
/*     */     
/*  95 */     return encodeLowLevel(placement, symbolInfo);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static BitMatrix encodeLowLevel(DefaultPlacement placement, SymbolInfo symbolInfo) {
/* 106 */     int symbolWidth = symbolInfo.getSymbolDataWidth();
/* 107 */     int symbolHeight = symbolInfo.getSymbolDataHeight();
/*     */     
/* 109 */     ByteMatrix matrix = new ByteMatrix(symbolInfo.getSymbolWidth(), symbolInfo.getSymbolHeight());
/*     */     
/* 111 */     int matrixY = 0;
/*     */     
/* 113 */     for (int y = 0; y < symbolHeight; y++) {
/*     */ 
/*     */       
/* 116 */       if (y % symbolInfo.matrixHeight == 0) {
/* 117 */         int i = 0;
/* 118 */         for (int j = 0; j < symbolInfo.getSymbolWidth(); j++) {
/* 119 */           matrix.set(i, matrixY, (j % 2 == 0));
/* 120 */           i++;
/*     */         } 
/* 122 */         matrixY++;
/*     */       } 
/* 124 */       int matrixX = 0; int x;
/* 125 */       for (x = 0; x < symbolWidth; x++) {
/*     */         
/* 127 */         if (x % symbolInfo.matrixWidth == 0) {
/* 128 */           matrix.set(matrixX, matrixY, true);
/* 129 */           matrixX++;
/*     */         } 
/* 131 */         matrix.set(matrixX, matrixY, placement.getBit(x, y));
/* 132 */         matrixX++;
/*     */         
/* 134 */         if (x % symbolInfo.matrixWidth == symbolInfo.matrixWidth - 1) {
/* 135 */           matrix.set(matrixX, matrixY, (y % 2 == 0));
/* 136 */           matrixX++;
/*     */         } 
/*     */       } 
/* 139 */       matrixY++;
/*     */       
/* 141 */       if (y % symbolInfo.matrixHeight == symbolInfo.matrixHeight - 1) {
/* 142 */         matrixX = 0;
/* 143 */         for (x = 0; x < symbolInfo.getSymbolWidth(); x++) {
/* 144 */           matrix.set(matrixX, matrixY, true);
/* 145 */           matrixX++;
/*     */         } 
/* 147 */         matrixY++;
/*     */       } 
/*     */     } 
/*     */     
/* 151 */     return convertByteMatrixToBitMatrix(matrix);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static BitMatrix convertByteMatrixToBitMatrix(ByteMatrix matrix) {
/* 161 */     int matrixWidgth = matrix.getWidth();
/* 162 */     int matrixHeight = matrix.getHeight();
/*     */     
/* 164 */     BitMatrix output = new BitMatrix(matrixWidgth, matrixHeight);
/* 165 */     output.clear();
/* 166 */     for (int i = 0; i < matrixWidgth; i++) {
/* 167 */       for (int j = 0; j < matrixHeight; j++) {
/*     */         
/* 169 */         if (matrix.get(i, j) == 1) {
/* 170 */           output.set(i, j);
/*     */         }
/*     */       } 
/*     */     } 
/*     */     
/* 175 */     return output;
/*     */   }
/*     */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\com\google\zxing\datamatrix\DataMatrixWriter.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       1.1.3
 */