/*     */ package com.google.zxing.datamatrix.decoder;
/*     */ 
/*     */ import com.google.zxing.FormatException;
/*     */ import com.google.zxing.common.BitSource;
/*     */ import com.google.zxing.common.DecoderResult;
/*     */ import java.io.UnsupportedEncodingException;
/*     */ import java.util.ArrayList;
/*     */ import java.util.Collection;
/*     */ import java.util.List;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ final class DecodedBitStreamParser
/*     */ {
/*     */   private enum Mode
/*     */   {
/*  40 */     PAD_ENCODE,
/*  41 */     ASCII_ENCODE,
/*  42 */     C40_ENCODE,
/*  43 */     TEXT_ENCODE,
/*  44 */     ANSIX12_ENCODE,
/*  45 */     EDIFACT_ENCODE,
/*  46 */     BASE256_ENCODE;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  53 */   private static final char[] C40_BASIC_SET_CHARS = new char[] { '*', '*', '*', ' ', '0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I', 'J', 'K', 'L', 'M', 'N', 'O', 'P', 'Q', 'R', 'S', 'T', 'U', 'V', 'W', 'X', 'Y', 'Z' };
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  59 */   private static final char[] C40_SHIFT2_SET_CHARS = new char[] { '!', '"', '#', '$', '%', '&', '\'', '(', ')', '*', '+', ',', '-', '.', '/', ':', ';', '<', '=', '>', '?', '@', '[', '\\', ']', '^', '_' };
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  68 */   private static final char[] TEXT_BASIC_SET_CHARS = new char[] { '*', '*', '*', ' ', '0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i', 'j', 'k', 'l', 'm', 'n', 'o', 'p', 'q', 'r', 's', 't', 'u', 'v', 'w', 'x', 'y', 'z' };
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  74 */   private static final char[] TEXT_SHIFT3_SET_CHARS = new char[] { '\'', 'A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I', 'J', 'K', 'L', 'M', 'N', 'O', 'P', 'Q', 'R', 'S', 'T', 'U', 'V', 'W', 'X', 'Y', 'Z', '{', '|', '}', '~', '' };
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   static DecoderResult decode(byte[] bytes) throws FormatException {
/*  83 */     BitSource bits = new BitSource(bytes);
/*  84 */     StringBuilder result = new StringBuilder(100);
/*  85 */     StringBuilder resultTrailer = new StringBuilder(0);
/*  86 */     List<byte[]> byteSegments = (List)new ArrayList<byte>(1);
/*  87 */     Mode mode = Mode.ASCII_ENCODE;
/*     */     do {
/*  89 */       if (mode == Mode.ASCII_ENCODE) {
/*  90 */         mode = decodeAsciiSegment(bits, result, resultTrailer);
/*     */       } else {
/*  92 */         switch (mode) {
/*     */           case C40_ENCODE:
/*  94 */             decodeC40Segment(bits, result);
/*     */             break;
/*     */           case TEXT_ENCODE:
/*  97 */             decodeTextSegment(bits, result);
/*     */             break;
/*     */           case ANSIX12_ENCODE:
/* 100 */             decodeAnsiX12Segment(bits, result);
/*     */             break;
/*     */           case EDIFACT_ENCODE:
/* 103 */             decodeEdifactSegment(bits, result);
/*     */             break;
/*     */           case BASE256_ENCODE:
/* 106 */             decodeBase256Segment(bits, result, (Collection<byte[]>)byteSegments);
/*     */             break;
/*     */           default:
/* 109 */             throw FormatException.getFormatInstance();
/*     */         } 
/* 111 */         mode = Mode.ASCII_ENCODE;
/*     */       } 
/* 113 */     } while (mode != Mode.PAD_ENCODE && bits.available() > 0);
/* 114 */     if (resultTrailer.length() > 0) {
/* 115 */       result.append(resultTrailer.toString());
/*     */     }
/* 117 */     return new DecoderResult(bytes, result.toString(), byteSegments.isEmpty() ? null : byteSegments, null);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static Mode decodeAsciiSegment(BitSource bits, StringBuilder result, StringBuilder resultTrailer) throws FormatException {
/* 126 */     boolean upperShift = false;
/*     */     while (true) {
/* 128 */       int oneByte = bits.readBits(8);
/* 129 */       if (oneByte == 0)
/* 130 */         throw FormatException.getFormatInstance(); 
/* 131 */       if (oneByte <= 128) {
/* 132 */         if (upperShift) {
/* 133 */           oneByte += 128;
/*     */         }
/*     */         
/* 136 */         result.append((char)(oneByte - 1));
/* 137 */         return Mode.ASCII_ENCODE;
/* 138 */       }  if (oneByte == 129)
/* 139 */         return Mode.PAD_ENCODE; 
/* 140 */       if (oneByte <= 229)
/* 141 */       { int value = oneByte - 130;
/* 142 */         if (value < 10) {
/* 143 */           result.append('0');
/*     */         }
/* 145 */         result.append(value); }
/* 146 */       else { if (oneByte == 230)
/* 147 */           return Mode.C40_ENCODE; 
/* 148 */         if (oneByte == 231)
/* 149 */           return Mode.BASE256_ENCODE; 
/* 150 */         if (oneByte == 232) {
/*     */           
/* 152 */           result.append('\035');
/* 153 */         } else if (oneByte != 233 && oneByte != 234) {
/*     */ 
/*     */ 
/*     */           
/* 157 */           if (oneByte == 235)
/* 158 */           { upperShift = true; }
/* 159 */           else if (oneByte == 236)
/* 160 */           { result.append("[)>\03605\035");
/* 161 */             resultTrailer.insert(0, "\036\004"); }
/* 162 */           else if (oneByte == 237)
/* 163 */           { result.append("[)>\03606\035");
/* 164 */             resultTrailer.insert(0, "\036\004"); }
/* 165 */           else { if (oneByte == 238)
/* 166 */               return Mode.ANSIX12_ENCODE; 
/* 167 */             if (oneByte == 239)
/* 168 */               return Mode.TEXT_ENCODE; 
/* 169 */             if (oneByte == 240)
/* 170 */               return Mode.EDIFACT_ENCODE; 
/* 171 */             if (oneByte != 241)
/*     */             {
/*     */ 
/*     */               
/* 175 */               if (oneByte >= 242)
/*     */               {
/* 177 */                 if (oneByte != 254 || bits.available() != 0)
/* 178 */                   throw FormatException.getFormatInstance();  }  }  }
/*     */         
/*     */         }  }
/* 181 */        if (bits.available() <= 0) {
/* 182 */         return Mode.ASCII_ENCODE;
/*     */       }
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static void decodeC40Segment(BitSource bits, StringBuilder result) throws FormatException {
/* 192 */     boolean upperShift = false;
/*     */     
/* 194 */     int[] cValues = new int[3];
/* 195 */     int shift = 0;
/*     */ 
/*     */     
/*     */     do {
/* 199 */       if (bits.available() == 8) {
/*     */         return;
/*     */       }
/* 202 */       int firstByte = bits.readBits(8);
/* 203 */       if (firstByte == 254) {
/*     */         return;
/*     */       }
/*     */       
/* 207 */       parseTwoBytes(firstByte, bits.readBits(8), cValues);
/*     */       
/* 209 */       for (int i = 0; i < 3; i++) {
/* 210 */         int cValue = cValues[i];
/* 211 */         switch (shift) {
/*     */           case 0:
/* 213 */             if (cValue < 3) {
/* 214 */               shift = cValue + 1; break;
/* 215 */             }  if (cValue < C40_BASIC_SET_CHARS.length) {
/* 216 */               char c40char = C40_BASIC_SET_CHARS[cValue];
/* 217 */               if (upperShift) {
/* 218 */                 result.append((char)(c40char + 128));
/* 219 */                 upperShift = false; break;
/*     */               } 
/* 221 */               result.append(c40char);
/*     */               break;
/*     */             } 
/* 224 */             throw FormatException.getFormatInstance();
/*     */ 
/*     */           
/*     */           case 1:
/* 228 */             if (upperShift) {
/* 229 */               result.append((char)(cValue + 128));
/* 230 */               upperShift = false;
/*     */             } else {
/* 232 */               result.append((char)cValue);
/*     */             } 
/* 234 */             shift = 0;
/*     */             break;
/*     */           case 2:
/* 237 */             if (cValue < C40_SHIFT2_SET_CHARS.length) {
/* 238 */               char c40char = C40_SHIFT2_SET_CHARS[cValue];
/* 239 */               if (upperShift) {
/* 240 */                 result.append((char)(c40char + 128));
/* 241 */                 upperShift = false;
/*     */               } else {
/* 243 */                 result.append(c40char);
/*     */               } 
/* 245 */             } else if (cValue == 27) {
/* 246 */               result.append('\035');
/* 247 */             } else if (cValue == 30) {
/* 248 */               upperShift = true;
/*     */             } else {
/* 250 */               throw FormatException.getFormatInstance();
/*     */             } 
/* 252 */             shift = 0;
/*     */             break;
/*     */           case 3:
/* 255 */             if (upperShift) {
/* 256 */               result.append((char)(cValue + 224));
/* 257 */               upperShift = false;
/*     */             } else {
/* 259 */               result.append((char)(cValue + 96));
/*     */             } 
/* 261 */             shift = 0;
/*     */             break;
/*     */           default:
/* 264 */             throw FormatException.getFormatInstance();
/*     */         } 
/*     */       } 
/* 267 */     } while (bits.available() > 0);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static void decodeTextSegment(BitSource bits, StringBuilder result) throws FormatException {
/* 277 */     boolean upperShift = false;
/*     */     
/* 279 */     int[] cValues = new int[3];
/* 280 */     int shift = 0;
/*     */     
/*     */     do {
/* 283 */       if (bits.available() == 8) {
/*     */         return;
/*     */       }
/* 286 */       int firstByte = bits.readBits(8);
/* 287 */       if (firstByte == 254) {
/*     */         return;
/*     */       }
/*     */       
/* 291 */       parseTwoBytes(firstByte, bits.readBits(8), cValues);
/*     */       
/* 293 */       for (int i = 0; i < 3; i++) {
/* 294 */         int cValue = cValues[i];
/* 295 */         switch (shift) {
/*     */           case 0:
/* 297 */             if (cValue < 3) {
/* 298 */               shift = cValue + 1; break;
/* 299 */             }  if (cValue < TEXT_BASIC_SET_CHARS.length) {
/* 300 */               char textChar = TEXT_BASIC_SET_CHARS[cValue];
/* 301 */               if (upperShift) {
/* 302 */                 result.append((char)(textChar + 128));
/* 303 */                 upperShift = false; break;
/*     */               } 
/* 305 */               result.append(textChar);
/*     */               break;
/*     */             } 
/* 308 */             throw FormatException.getFormatInstance();
/*     */ 
/*     */           
/*     */           case 1:
/* 312 */             if (upperShift) {
/* 313 */               result.append((char)(cValue + 128));
/* 314 */               upperShift = false;
/*     */             } else {
/* 316 */               result.append((char)cValue);
/*     */             } 
/* 318 */             shift = 0;
/*     */             break;
/*     */           
/*     */           case 2:
/* 322 */             if (cValue < C40_SHIFT2_SET_CHARS.length) {
/* 323 */               char c40char = C40_SHIFT2_SET_CHARS[cValue];
/* 324 */               if (upperShift) {
/* 325 */                 result.append((char)(c40char + 128));
/* 326 */                 upperShift = false;
/*     */               } else {
/* 328 */                 result.append(c40char);
/*     */               } 
/* 330 */             } else if (cValue == 27) {
/* 331 */               result.append('\035');
/* 332 */             } else if (cValue == 30) {
/* 333 */               upperShift = true;
/*     */             } else {
/* 335 */               throw FormatException.getFormatInstance();
/*     */             } 
/* 337 */             shift = 0;
/*     */             break;
/*     */           case 3:
/* 340 */             if (cValue < TEXT_SHIFT3_SET_CHARS.length) {
/* 341 */               char textChar = TEXT_SHIFT3_SET_CHARS[cValue];
/* 342 */               if (upperShift) {
/* 343 */                 result.append((char)(textChar + 128));
/* 344 */                 upperShift = false;
/*     */               } else {
/* 346 */                 result.append(textChar);
/*     */               } 
/* 348 */               shift = 0; break;
/*     */             } 
/* 350 */             throw FormatException.getFormatInstance();
/*     */ 
/*     */           
/*     */           default:
/* 354 */             throw FormatException.getFormatInstance();
/*     */         } 
/*     */       } 
/* 357 */     } while (bits.available() > 0);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static void decodeAnsiX12Segment(BitSource bits, StringBuilder result) throws FormatException {
/* 368 */     int[] cValues = new int[3];
/*     */     
/*     */     do {
/* 371 */       if (bits.available() == 8) {
/*     */         return;
/*     */       }
/* 374 */       int firstByte = bits.readBits(8);
/* 375 */       if (firstByte == 254) {
/*     */         return;
/*     */       }
/*     */       
/* 379 */       parseTwoBytes(firstByte, bits.readBits(8), cValues);
/*     */       
/* 381 */       for (int i = 0; i < 3; i++) {
/* 382 */         int cValue = cValues[i];
/* 383 */         if (cValue == 0) {
/* 384 */           result.append('\r');
/* 385 */         } else if (cValue == 1) {
/* 386 */           result.append('*');
/* 387 */         } else if (cValue == 2) {
/* 388 */           result.append('>');
/* 389 */         } else if (cValue == 3) {
/* 390 */           result.append(' ');
/* 391 */         } else if (cValue < 14) {
/* 392 */           result.append((char)(cValue + 44));
/* 393 */         } else if (cValue < 40) {
/* 394 */           result.append((char)(cValue + 51));
/*     */         } else {
/* 396 */           throw FormatException.getFormatInstance();
/*     */         } 
/*     */       } 
/* 399 */     } while (bits.available() > 0);
/*     */   }
/*     */   
/*     */   private static void parseTwoBytes(int firstByte, int secondByte, int[] result) {
/* 403 */     int fullBitValue = (firstByte << 8) + secondByte - 1;
/* 404 */     int temp = fullBitValue / 1600;
/* 405 */     result[0] = temp;
/* 406 */     fullBitValue -= temp * 1600;
/* 407 */     temp = fullBitValue / 40;
/* 408 */     result[1] = temp;
/* 409 */     result[2] = fullBitValue - temp * 40;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static void decodeEdifactSegment(BitSource bits, StringBuilder result) {
/*     */     do {
/* 418 */       if (bits.available() <= 16) {
/*     */         return;
/*     */       }
/*     */       
/* 422 */       for (int i = 0; i < 4; i++) {
/* 423 */         int edifactValue = bits.readBits(6);
/*     */ 
/*     */         
/* 426 */         if (edifactValue == 31) {
/*     */           
/* 428 */           int bitsLeft = 8 - bits.getBitOffset();
/* 429 */           if (bitsLeft != 8) {
/* 430 */             bits.readBits(bitsLeft);
/*     */           }
/*     */           
/*     */           return;
/*     */         } 
/* 435 */         if ((edifactValue & 0x20) == 0) {
/* 436 */           edifactValue |= 0x40;
/*     */         }
/* 438 */         result.append((char)edifactValue);
/*     */       } 
/* 440 */     } while (bits.available() > 0);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static void decodeBase256Segment(BitSource bits, StringBuilder result, Collection<byte[]> byteSegments) throws FormatException {
/* 451 */     int count, codewordPosition = 1 + bits.getByteOffset();
/* 452 */     int d1 = unrandomize255State(bits.readBits(8), codewordPosition++);
/*     */     
/* 454 */     if (d1 == 0) {
/* 455 */       count = bits.available() / 8;
/* 456 */     } else if (d1 < 250) {
/* 457 */       count = d1;
/*     */     } else {
/* 459 */       count = 250 * (d1 - 249) + unrandomize255State(bits.readBits(8), codewordPosition++);
/*     */     } 
/*     */ 
/*     */     
/* 463 */     if (count < 0) {
/* 464 */       throw FormatException.getFormatInstance();
/*     */     }
/*     */     
/* 467 */     byte[] bytes = new byte[count];
/* 468 */     for (int i = 0; i < count; i++) {
/*     */ 
/*     */       
/* 471 */       if (bits.available() < 8) {
/* 472 */         throw FormatException.getFormatInstance();
/*     */       }
/* 474 */       bytes[i] = (byte)unrandomize255State(bits.readBits(8), codewordPosition++);
/*     */     } 
/* 476 */     byteSegments.add(bytes);
/*     */     try {
/* 478 */       result.append(new String(bytes, "ISO8859_1"));
/* 479 */     } catch (UnsupportedEncodingException uee) {
/* 480 */       throw new IllegalStateException("Platform does not support required encoding: " + uee);
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static int unrandomize255State(int randomizedBase256Codeword, int base256CodewordPosition) {
/* 489 */     int pseudoRandomNumber = 149 * base256CodewordPosition % 255 + 1;
/* 490 */     int tempVariable = randomizedBase256Codeword - pseudoRandomNumber;
/* 491 */     return (tempVariable >= 0) ? tempVariable : (tempVariable + 256);
/*     */   }
/*     */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\com\google\zxing\datamatrix\decoder\DecodedBitStreamParser.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       1.1.3
 */