/*     */ package com.google.zxing.datamatrix.encoder;
/*     */ 
/*     */ import com.google.zxing.Dimension;
/*     */ import java.nio.charset.Charset;
/*     */ import java.util.Arrays;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public final class HighLevelEncoder
/*     */ {
/*     */   private static final char PAD = '';
/*     */   static final char LATCH_TO_C40 = 'æ';
/*     */   static final char LATCH_TO_BASE256 = 'ç';
/*     */   static final char UPPER_SHIFT = 'ë';
/*     */   private static final char MACRO_05 = 'ì';
/*     */   private static final char MACRO_06 = 'í';
/*     */   static final char LATCH_TO_ANSIX12 = 'î';
/*     */   static final char LATCH_TO_TEXT = 'ï';
/*     */   static final char LATCH_TO_EDIFACT = 'ð';
/*     */   static final char C40_UNLATCH = 'þ';
/*     */   static final char X12_UNLATCH = 'þ';
/*     */   private static final String MACRO_05_HEADER = "[)>\03605\035";
/*     */   private static final String MACRO_06_HEADER = "[)>\03606\035";
/*     */   private static final String MACRO_TRAILER = "\036\004";
/*     */   static final int ASCII_ENCODATION = 0;
/*     */   static final int C40_ENCODATION = 1;
/*     */   static final int TEXT_ENCODATION = 2;
/*     */   static final int X12_ENCODATION = 3;
/*     */   static final int EDIFACT_ENCODATION = 4;
/*     */   static final int BASE256_ENCODATION = 5;
/*     */   
/*     */   public static byte[] getBytesForMessage(String msg) {
/* 123 */     return msg.getBytes(Charset.forName("cp437"));
/*     */   }
/*     */   
/*     */   private static char randomize253State(char ch, int codewordPosition) {
/* 127 */     int pseudoRandom = 149 * codewordPosition % 253 + 1;
/* 128 */     int tempVariable = ch + pseudoRandom;
/* 129 */     return (tempVariable <= 254) ? (char)tempVariable : (char)(tempVariable - 254);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static String encodeHighLevel(String msg) {
/* 140 */     return encodeHighLevel(msg, SymbolShapeHint.FORCE_NONE, null, null);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static String encodeHighLevel(String msg, SymbolShapeHint shape, Dimension minSize, Dimension maxSize) {
/* 159 */     Encoder[] encoders = { new ASCIIEncoder(), new C40Encoder(), new TextEncoder(), new X12Encoder(), new EdifactEncoder(), new Base256Encoder() };
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 164 */     EncoderContext context = new EncoderContext(msg);
/* 165 */     context.setSymbolShape(shape);
/* 166 */     context.setSizeConstraints(minSize, maxSize);
/*     */     
/* 168 */     if (msg.startsWith("[)>\03605\035") && msg.endsWith("\036\004")) {
/* 169 */       context.writeCodeword('ì');
/* 170 */       context.setSkipAtEnd(2);
/* 171 */       context.pos += "[)>\03605\035".length();
/* 172 */     } else if (msg.startsWith("[)>\03606\035") && msg.endsWith("\036\004")) {
/* 173 */       context.writeCodeword('í');
/* 174 */       context.setSkipAtEnd(2);
/* 175 */       context.pos += "[)>\03606\035".length();
/*     */     } 
/*     */     
/* 178 */     int encodingMode = 0;
/* 179 */     while (context.hasMoreCharacters()) {
/* 180 */       encoders[encodingMode].encode(context);
/* 181 */       if (context.newEncoding >= 0) {
/* 182 */         encodingMode = context.newEncoding;
/* 183 */         context.resetEncoderSignal();
/*     */       } 
/*     */     } 
/* 186 */     int len = context.codewords.length();
/* 187 */     context.updateSymbolInfo();
/* 188 */     int capacity = context.symbolInfo.dataCapacity;
/* 189 */     if (len < capacity && 
/* 190 */       encodingMode != 0 && encodingMode != 5) {
/* 191 */       context.writeCodeword('þ');
/*     */     }
/*     */ 
/*     */     
/* 195 */     StringBuilder codewords = context.codewords;
/* 196 */     if (codewords.length() < capacity) {
/* 197 */       codewords.append('');
/*     */     }
/* 199 */     while (codewords.length() < capacity) {
/* 200 */       codewords.append(randomize253State('', codewords.length() + 1));
/*     */     }
/*     */     
/* 203 */     return context.codewords.toString();
/*     */   }
/*     */   static int lookAheadTest(CharSequence msg, int startpos, int currentMode) {
/*     */     float[] charCounts;
/* 207 */     if (startpos >= msg.length()) {
/* 208 */       return currentMode;
/*     */     }
/*     */ 
/*     */     
/* 212 */     if (currentMode == 0) {
/* 213 */       charCounts = new float[] { 0.0F, 1.0F, 1.0F, 1.0F, 1.0F, 1.25F };
/*     */     } else {
/* 215 */       charCounts = new float[] { 1.0F, 2.0F, 2.0F, 2.0F, 2.0F, 2.25F };
/* 216 */       charCounts[currentMode] = 0.0F;
/*     */     } 
/*     */     
/* 219 */     int charsProcessed = 0;
/*     */     
/*     */     while (true) {
/* 222 */       if (startpos + charsProcessed == msg.length()) {
/* 223 */         int min = Integer.MAX_VALUE;
/* 224 */         byte[] mins = new byte[6];
/* 225 */         int[] intCharCounts = new int[6];
/* 226 */         min = findMinimums(charCounts, intCharCounts, min, mins);
/* 227 */         int minCount = getMinimumCount(mins);
/*     */         
/* 229 */         if (intCharCounts[0] == min) {
/* 230 */           return 0;
/*     */         }
/* 232 */         if (minCount == 1 && mins[5] > 0) {
/* 233 */           return 5;
/*     */         }
/* 235 */         if (minCount == 1 && mins[4] > 0) {
/* 236 */           return 4;
/*     */         }
/* 238 */         if (minCount == 1 && mins[2] > 0) {
/* 239 */           return 2;
/*     */         }
/* 241 */         if (minCount == 1 && mins[3] > 0) {
/* 242 */           return 3;
/*     */         }
/* 244 */         return 1;
/*     */       } 
/*     */       
/* 247 */       char c = msg.charAt(startpos + charsProcessed);
/* 248 */       charsProcessed++;
/*     */ 
/*     */       
/* 251 */       if (isDigit(c)) {
/* 252 */         charCounts[0] = (float)(charCounts[0] + 0.5D);
/* 253 */       } else if (isExtendedASCII(c)) {
/* 254 */         charCounts[0] = (int)Math.ceil(charCounts[0]);
/* 255 */         charCounts[0] = charCounts[0] + 2.0F;
/*     */       } else {
/* 257 */         charCounts[0] = (int)Math.ceil(charCounts[0]);
/* 258 */         charCounts[0] = charCounts[0] + 1.0F;
/*     */       } 
/*     */ 
/*     */       
/* 262 */       if (isNativeC40(c)) {
/* 263 */         charCounts[1] = charCounts[1] + 0.6666667F;
/* 264 */       } else if (isExtendedASCII(c)) {
/* 265 */         charCounts[1] = charCounts[1] + 2.6666667F;
/*     */       } else {
/* 267 */         charCounts[1] = charCounts[1] + 1.3333334F;
/*     */       } 
/*     */ 
/*     */       
/* 271 */       if (isNativeText(c)) {
/* 272 */         charCounts[2] = charCounts[2] + 0.6666667F;
/* 273 */       } else if (isExtendedASCII(c)) {
/* 274 */         charCounts[2] = charCounts[2] + 2.6666667F;
/*     */       } else {
/* 276 */         charCounts[2] = charCounts[2] + 1.3333334F;
/*     */       } 
/*     */ 
/*     */       
/* 280 */       if (isNativeX12(c)) {
/* 281 */         charCounts[3] = charCounts[3] + 0.6666667F;
/* 282 */       } else if (isExtendedASCII(c)) {
/* 283 */         charCounts[3] = charCounts[3] + 4.3333335F;
/*     */       } else {
/* 285 */         charCounts[3] = charCounts[3] + 3.3333333F;
/*     */       } 
/*     */ 
/*     */       
/* 289 */       if (isNativeEDIFACT(c)) {
/* 290 */         charCounts[4] = charCounts[4] + 0.75F;
/* 291 */       } else if (isExtendedASCII(c)) {
/* 292 */         charCounts[4] = charCounts[4] + 4.25F;
/*     */       } else {
/* 294 */         charCounts[4] = charCounts[4] + 3.25F;
/*     */       } 
/*     */ 
/*     */       
/* 298 */       if (isSpecialB256(c)) {
/* 299 */         charCounts[5] = charCounts[5] + 4.0F;
/*     */       } else {
/* 301 */         charCounts[5] = charCounts[5] + 1.0F;
/*     */       } 
/*     */ 
/*     */       
/* 305 */       if (charsProcessed >= 4) {
/* 306 */         int[] intCharCounts = new int[6];
/* 307 */         byte[] mins = new byte[6];
/* 308 */         findMinimums(charCounts, intCharCounts, 2147483647, mins);
/* 309 */         int minCount = getMinimumCount(mins);
/*     */         
/* 311 */         if (intCharCounts[0] < intCharCounts[5] && intCharCounts[0] < intCharCounts[1] && intCharCounts[0] < intCharCounts[2] && intCharCounts[0] < intCharCounts[3] && intCharCounts[0] < intCharCounts[4])
/*     */         {
/*     */ 
/*     */ 
/*     */           
/* 316 */           return 0;
/*     */         }
/* 318 */         if (intCharCounts[5] < intCharCounts[0] || mins[1] + mins[2] + mins[3] + mins[4] == 0)
/*     */         {
/* 320 */           return 5;
/*     */         }
/* 322 */         if (minCount == 1 && mins[4] > 0) {
/* 323 */           return 4;
/*     */         }
/* 325 */         if (minCount == 1 && mins[2] > 0) {
/* 326 */           return 2;
/*     */         }
/* 328 */         if (minCount == 1 && mins[3] > 0) {
/* 329 */           return 3;
/*     */         }
/* 331 */         if (intCharCounts[1] + 1 < intCharCounts[0] && intCharCounts[1] + 1 < intCharCounts[5] && intCharCounts[1] + 1 < intCharCounts[4] && intCharCounts[1] + 1 < intCharCounts[2]) {
/*     */ 
/*     */ 
/*     */           
/* 335 */           if (intCharCounts[1] < intCharCounts[3]) {
/* 336 */             return 1;
/*     */           }
/* 338 */           if (intCharCounts[1] == intCharCounts[3]) {
/* 339 */             int p = startpos + charsProcessed + 1;
/* 340 */             while (p < msg.length()) {
/* 341 */               char tc = msg.charAt(p);
/* 342 */               if (isX12TermSep(tc)) {
/* 343 */                 return 3;
/*     */               }
/* 345 */               if (!isNativeX12(tc)) {
/*     */                 break;
/*     */               }
/* 348 */               p++;
/*     */             } 
/* 350 */             return 1;
/*     */           } 
/*     */         } 
/*     */       } 
/*     */     } 
/*     */   }
/*     */   
/*     */   private static int findMinimums(float[] charCounts, int[] intCharCounts, int min, byte[] mins) {
/* 358 */     Arrays.fill(mins, (byte)0);
/* 359 */     for (int i = 0; i < 6; i++) {
/* 360 */       intCharCounts[i] = (int)Math.ceil(charCounts[i]);
/* 361 */       int current = intCharCounts[i];
/* 362 */       if (min > current) {
/* 363 */         min = current;
/* 364 */         Arrays.fill(mins, (byte)0);
/*     */       } 
/* 366 */       if (min == current) {
/* 367 */         mins[i] = (byte)(mins[i] + 1);
/*     */       }
/*     */     } 
/*     */     
/* 371 */     return min;
/*     */   }
/*     */   
/*     */   private static int getMinimumCount(byte[] mins) {
/* 375 */     int minCount = 0;
/* 376 */     for (int i = 0; i < 6; i++) {
/* 377 */       minCount += mins[i];
/*     */     }
/* 379 */     return minCount;
/*     */   }
/*     */   
/*     */   static boolean isDigit(char ch) {
/* 383 */     return (ch >= '0' && ch <= '9');
/*     */   }
/*     */   
/*     */   static boolean isExtendedASCII(char ch) {
/* 387 */     return (ch >= '' && ch <= 'ÿ');
/*     */   }
/*     */   
/*     */   private static boolean isNativeC40(char ch) {
/* 391 */     return (ch == ' ' || (ch >= '0' && ch <= '9') || (ch >= 'A' && ch <= 'Z'));
/*     */   }
/*     */   
/*     */   private static boolean isNativeText(char ch) {
/* 395 */     return (ch == ' ' || (ch >= '0' && ch <= '9') || (ch >= 'a' && ch <= 'z'));
/*     */   }
/*     */   
/*     */   private static boolean isNativeX12(char ch) {
/* 399 */     return (isX12TermSep(ch) || ch == ' ' || (ch >= '0' && ch <= '9') || (ch >= 'A' && ch <= 'Z'));
/*     */   }
/*     */   
/*     */   private static boolean isX12TermSep(char ch) {
/* 403 */     return (ch == '\r' || ch == '*' || ch == '>');
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   private static boolean isNativeEDIFACT(char ch) {
/* 409 */     return (ch >= ' ' && ch <= '^');
/*     */   }
/*     */   
/*     */   private static boolean isSpecialB256(char ch) {
/* 413 */     return false;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static int determineConsecutiveDigitCount(CharSequence msg, int startpos) {
/* 424 */     int count = 0;
/* 425 */     int len = msg.length();
/* 426 */     int idx = startpos;
/* 427 */     if (idx < len) {
/* 428 */       char ch = msg.charAt(idx);
/* 429 */       while (isDigit(ch) && idx < len) {
/* 430 */         count++;
/* 431 */         idx++;
/* 432 */         if (idx < len) {
/* 433 */           ch = msg.charAt(idx);
/*     */         }
/*     */       } 
/*     */     } 
/* 437 */     return count;
/*     */   }
/*     */   
/*     */   static void illegalCharacter(char c) {
/* 441 */     String hex = Integer.toHexString(c);
/* 442 */     hex = "0000".substring(0, 4 - hex.length()) + hex;
/* 443 */     throw new IllegalArgumentException("Illegal character: " + c + " (0x" + hex + ')');
/*     */   }
/*     */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\com\google\zxing\datamatrix\encoder\HighLevelEncoder.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       1.1.3
 */