/*     */ package com.google.zxing.oned;
/*     */ 
/*     */ import com.google.zxing.BarcodeFormat;
/*     */ import com.google.zxing.DecodeHintType;
/*     */ import com.google.zxing.NotFoundException;
/*     */ import com.google.zxing.Result;
/*     */ import com.google.zxing.ResultPoint;
/*     */ import com.google.zxing.common.BitArray;
/*     */ import java.util.Arrays;
/*     */ import java.util.Map;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public final class CodaBarReader
/*     */   extends OneDReader
/*     */ {
/*     */   private static final int MAX_ACCEPTABLE = 512;
/*     */   private static final int PADDING = 384;
/*     */   private static final String ALPHABET_STRING = "0123456789-$:/.+ABCD";
/*  44 */   static final char[] ALPHABET = "0123456789-$:/.+ABCD".toCharArray();
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  50 */   static final int[] CHARACTER_ENCODINGS = new int[] { 3, 6, 9, 96, 18, 66, 33, 36, 48, 72, 12, 24, 69, 81, 84, 21, 26, 41, 11, 14 };
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static final int MIN_CHARACTER_LENGTH = 3;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  61 */   private static final char[] STARTEND_ENCODING = new char[] { 'A', 'B', 'C', 'D' };
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  74 */   private final StringBuilder decodeRowResult = new StringBuilder(20);
/*  75 */   private int[] counters = new int[80];
/*  76 */   private int counterLength = 0;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Result decodeRow(int rowNumber, BitArray row, Map<DecodeHintType, ?> hints) throws NotFoundException {
/*  82 */     Arrays.fill(this.counters, 0);
/*  83 */     setCounters(row);
/*  84 */     int startOffset = findStartPattern();
/*  85 */     int nextStart = startOffset;
/*     */     
/*  87 */     this.decodeRowResult.setLength(0);
/*     */     do {
/*  89 */       int charOffset = toNarrowWidePattern(nextStart);
/*  90 */       if (charOffset == -1) {
/*  91 */         throw NotFoundException.getNotFoundInstance();
/*     */       }
/*     */ 
/*     */ 
/*     */       
/*  96 */       this.decodeRowResult.append((char)charOffset);
/*  97 */       nextStart += 8;
/*     */       
/*  99 */       if (this.decodeRowResult.length() > 1 && arrayContains(STARTEND_ENCODING, ALPHABET[charOffset])) {
/*     */         break;
/*     */       }
/*     */     }
/* 103 */     while (nextStart < this.counterLength);
/*     */ 
/*     */     
/* 106 */     int trailingWhitespace = this.counters[nextStart - 1];
/* 107 */     int lastPatternSize = 0; int i;
/* 108 */     for (i = -8; i < -1; i++) {
/* 109 */       lastPatternSize += this.counters[nextStart + i];
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 115 */     if (nextStart < this.counterLength && trailingWhitespace < lastPatternSize / 2) {
/* 116 */       throw NotFoundException.getNotFoundInstance();
/*     */     }
/*     */     
/* 119 */     validatePattern(startOffset);
/*     */ 
/*     */     
/* 122 */     for (i = 0; i < this.decodeRowResult.length(); i++) {
/* 123 */       this.decodeRowResult.setCharAt(i, ALPHABET[this.decodeRowResult.charAt(i)]);
/*     */     }
/*     */     
/* 126 */     char startchar = this.decodeRowResult.charAt(0);
/* 127 */     if (!arrayContains(STARTEND_ENCODING, startchar)) {
/* 128 */       throw NotFoundException.getNotFoundInstance();
/*     */     }
/* 130 */     char endchar = this.decodeRowResult.charAt(this.decodeRowResult.length() - 1);
/* 131 */     if (!arrayContains(STARTEND_ENCODING, endchar)) {
/* 132 */       throw NotFoundException.getNotFoundInstance();
/*     */     }
/*     */ 
/*     */     
/* 136 */     if (this.decodeRowResult.length() <= 3)
/*     */     {
/* 138 */       throw NotFoundException.getNotFoundInstance();
/*     */     }
/*     */     
/* 141 */     this.decodeRowResult.deleteCharAt(this.decodeRowResult.length() - 1);
/* 142 */     this.decodeRowResult.deleteCharAt(0);
/*     */     
/* 144 */     int runningCount = 0;
/* 145 */     for (int j = 0; j < startOffset; j++) {
/* 146 */       runningCount += this.counters[j];
/*     */     }
/* 148 */     float left = runningCount;
/* 149 */     for (int k = startOffset; k < nextStart - 1; k++) {
/* 150 */       runningCount += this.counters[k];
/*     */     }
/* 152 */     float right = runningCount;
/* 153 */     return new Result(this.decodeRowResult.toString(), null, new ResultPoint[] { new ResultPoint(left, rowNumber), new ResultPoint(right, rowNumber) }BarcodeFormat.CODABAR);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   void validatePattern(int start) throws NotFoundException {
/* 164 */     int[] sizes = { 0, 0, 0, 0 };
/* 165 */     int[] counts = { 0, 0, 0, 0 };
/* 166 */     int end = this.decodeRowResult.length() - 1;
/*     */ 
/*     */ 
/*     */     
/* 170 */     int pos = start;
/* 171 */     for (int i = 0;; i++) {
/* 172 */       int pattern = CHARACTER_ENCODINGS[this.decodeRowResult.charAt(i)];
/* 173 */       for (int k = 6; k >= 0; k--) {
/*     */ 
/*     */         
/* 176 */         int category = (k & 0x1) + (pattern & 0x1) * 2;
/* 177 */         sizes[category] = sizes[category] + this.counters[pos + k];
/* 178 */         counts[category] = counts[category] + 1;
/* 179 */         pattern >>= 1;
/*     */       } 
/* 181 */       if (i >= end) {
/*     */         break;
/*     */       }
/*     */       
/* 185 */       pos += 8;
/*     */     } 
/*     */ 
/*     */     
/* 189 */     int[] maxes = new int[4];
/* 190 */     int[] mins = new int[4];
/*     */     
/*     */     int j;
/*     */     
/* 194 */     for (j = 0; j < 2; j++) {
/* 195 */       mins[j] = 0;
/* 196 */       mins[j + 2] = (sizes[j] << 8) / counts[j] + (sizes[j + 2] << 8) / counts[j + 2] >> 1;
/*     */       
/* 198 */       maxes[j] = mins[j + 2];
/* 199 */       maxes[j + 2] = (sizes[j + 2] * 512 + 384) / counts[j + 2];
/*     */     } 
/*     */ 
/*     */     
/* 203 */     pos = start;
/* 204 */     for (j = 0;; j++) {
/* 205 */       int pattern = CHARACTER_ENCODINGS[this.decodeRowResult.charAt(j)];
/* 206 */       for (int k = 6; k >= 0; k--) {
/*     */ 
/*     */         
/* 209 */         int category = (k & 0x1) + (pattern & 0x1) * 2;
/* 210 */         int size = this.counters[pos + k] << 8;
/* 211 */         if (size < mins[category] || size > maxes[category]) {
/* 212 */           throw NotFoundException.getNotFoundInstance();
/*     */         }
/* 214 */         pattern >>= 1;
/*     */       } 
/* 216 */       if (j >= end) {
/*     */         break;
/*     */       }
/* 219 */       pos += 8;
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private void setCounters(BitArray row) throws NotFoundException {
/* 230 */     this.counterLength = 0;
/*     */     
/* 232 */     int i = row.getNextUnset(0);
/* 233 */     int end = row.getSize();
/* 234 */     if (i >= end) {
/* 235 */       throw NotFoundException.getNotFoundInstance();
/*     */     }
/* 237 */     boolean isWhite = true;
/* 238 */     int count = 0;
/* 239 */     for (; i < end; i++) {
/* 240 */       if (row.get(i) ^ isWhite) {
/* 241 */         count++;
/*     */       } else {
/* 243 */         counterAppend(count);
/* 244 */         count = 1;
/* 245 */         isWhite = !isWhite;
/*     */       } 
/*     */     } 
/* 248 */     counterAppend(count);
/*     */   }
/*     */   
/*     */   private void counterAppend(int e) {
/* 252 */     this.counters[this.counterLength] = e;
/* 253 */     this.counterLength++;
/* 254 */     if (this.counterLength >= this.counters.length) {
/* 255 */       int[] temp = new int[this.counterLength * 2];
/* 256 */       System.arraycopy(this.counters, 0, temp, 0, this.counterLength);
/* 257 */       this.counters = temp;
/*     */     } 
/*     */   }
/*     */   
/*     */   private int findStartPattern() throws NotFoundException {
/* 262 */     for (int i = 1; i < this.counterLength; i += 2) {
/* 263 */       int charOffset = toNarrowWidePattern(i);
/* 264 */       if (charOffset != -1 && arrayContains(STARTEND_ENCODING, ALPHABET[charOffset])) {
/*     */ 
/*     */         
/* 267 */         int patternSize = 0;
/* 268 */         for (int j = i; j < i + 7; j++) {
/* 269 */           patternSize += this.counters[j];
/*     */         }
/* 271 */         if (i == 1 || this.counters[i - 1] >= patternSize / 2) {
/* 272 */           return i;
/*     */         }
/*     */       } 
/*     */     } 
/* 276 */     throw NotFoundException.getNotFoundInstance();
/*     */   }
/*     */   
/*     */   static boolean arrayContains(char[] array, char key) {
/* 280 */     if (array != null) {
/* 281 */       for (char c : array) {
/* 282 */         if (c == key) {
/* 283 */           return true;
/*     */         }
/*     */       } 
/*     */     }
/* 287 */     return false;
/*     */   }
/*     */ 
/*     */   
/*     */   private int toNarrowWidePattern(int position) {
/* 292 */     int end = position + 7;
/* 293 */     if (end >= this.counterLength) {
/* 294 */       return -1;
/*     */     }
/*     */     
/* 297 */     int[] theCounters = this.counters;
/*     */     
/* 299 */     int maxBar = 0;
/* 300 */     int minBar = Integer.MAX_VALUE;
/* 301 */     for (int j = position; j < end; j += 2) {
/* 302 */       int currentCounter = theCounters[j];
/* 303 */       if (currentCounter < minBar) {
/* 304 */         minBar = currentCounter;
/*     */       }
/* 306 */       if (currentCounter > maxBar) {
/* 307 */         maxBar = currentCounter;
/*     */       }
/*     */     } 
/* 310 */     int thresholdBar = (minBar + maxBar) / 2;
/*     */     
/* 312 */     int maxSpace = 0;
/* 313 */     int minSpace = Integer.MAX_VALUE;
/* 314 */     for (int k = position + 1; k < end; k += 2) {
/* 315 */       int currentCounter = theCounters[k];
/* 316 */       if (currentCounter < minSpace) {
/* 317 */         minSpace = currentCounter;
/*     */       }
/* 319 */       if (currentCounter > maxSpace) {
/* 320 */         maxSpace = currentCounter;
/*     */       }
/*     */     } 
/* 323 */     int thresholdSpace = (minSpace + maxSpace) / 2;
/*     */     
/* 325 */     int bitmask = 128;
/* 326 */     int pattern = 0; int i;
/* 327 */     for (i = 0; i < 7; i++) {
/* 328 */       int threshold = ((i & 0x1) == 0) ? thresholdBar : thresholdSpace;
/* 329 */       bitmask >>= 1;
/* 330 */       if (theCounters[position + i] > threshold) {
/* 331 */         pattern |= bitmask;
/*     */       }
/*     */     } 
/*     */     
/* 335 */     for (i = 0; i < CHARACTER_ENCODINGS.length; i++) {
/* 336 */       if (CHARACTER_ENCODINGS[i] == pattern) {
/* 337 */         return i;
/*     */       }
/*     */     } 
/* 340 */     return -1;
/*     */   }
/*     */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\com\google\zxing\oned\CodaBarReader.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       1.1.3
 */