/*     */ package com.google.zxing.oned;
/*     */ 
/*     */ import com.google.zxing.BarcodeFormat;
/*     */ import com.google.zxing.ChecksumException;
/*     */ import com.google.zxing.DecodeHintType;
/*     */ import com.google.zxing.FormatException;
/*     */ import com.google.zxing.NotFoundException;
/*     */ import com.google.zxing.Result;
/*     */ import com.google.zxing.ResultPoint;
/*     */ import com.google.zxing.common.BitArray;
/*     */ import java.util.ArrayList;
/*     */ import java.util.List;
/*     */ import java.util.Map;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public final class Code128Reader
/*     */   extends OneDReader
/*     */ {
/*  39 */   static final int[][] CODE_PATTERNS = new int[][] { { 2, 1, 2, 2, 2, 2 }, { 2, 2, 2, 1, 2, 2 }, { 2, 2, 2, 2, 2, 1 }, { 1, 2, 1, 2, 2, 3 }, { 1, 2, 1, 3, 2, 2 }, { 1, 3, 1, 2, 2, 2 }, { 1, 2, 2, 2, 1, 3 }, { 1, 2, 2, 3, 1, 2 }, { 1, 3, 2, 2, 1, 2 }, { 2, 2, 1, 2, 1, 3 }, { 2, 2, 1, 3, 1, 2 }, { 2, 3, 1, 2, 1, 2 }, { 1, 1, 2, 2, 3, 2 }, { 1, 2, 2, 1, 3, 2 }, { 1, 2, 2, 2, 3, 1 }, { 1, 1, 3, 2, 2, 2 }, { 1, 2, 3, 1, 2, 2 }, { 1, 2, 3, 2, 2, 1 }, { 2, 2, 3, 2, 1, 1 }, { 2, 2, 1, 1, 3, 2 }, { 2, 2, 1, 2, 3, 1 }, { 2, 1, 3, 2, 1, 2 }, { 2, 2, 3, 1, 1, 2 }, { 3, 1, 2, 1, 3, 1 }, { 3, 1, 1, 2, 2, 2 }, { 3, 2, 1, 1, 2, 2 }, { 3, 2, 1, 2, 2, 1 }, { 3, 1, 2, 2, 1, 2 }, { 3, 2, 2, 1, 1, 2 }, { 3, 2, 2, 2, 1, 1 }, { 2, 1, 2, 1, 2, 3 }, { 2, 1, 2, 3, 2, 1 }, { 2, 3, 2, 1, 2, 1 }, { 1, 1, 1, 3, 2, 3 }, { 1, 3, 1, 1, 2, 3 }, { 1, 3, 1, 3, 2, 1 }, { 1, 1, 2, 3, 1, 3 }, { 1, 3, 2, 1, 1, 3 }, { 1, 3, 2, 3, 1, 1 }, { 2, 1, 1, 3, 1, 3 }, { 2, 3, 1, 1, 1, 3 }, { 2, 3, 1, 3, 1, 1 }, { 1, 1, 2, 1, 3, 3 }, { 1, 1, 2, 3, 3, 1 }, { 1, 3, 2, 1, 3, 1 }, { 1, 1, 3, 1, 2, 3 }, { 1, 1, 3, 3, 2, 1 }, { 1, 3, 3, 1, 2, 1 }, { 3, 1, 3, 1, 2, 1 }, { 2, 1, 1, 3, 3, 1 }, { 2, 3, 1, 1, 3, 1 }, { 2, 1, 3, 1, 1, 3 }, { 2, 1, 3, 3, 1, 1 }, { 2, 1, 3, 1, 3, 1 }, { 3, 1, 1, 1, 2, 3 }, { 3, 1, 1, 3, 2, 1 }, { 3, 3, 1, 1, 2, 1 }, { 3, 1, 2, 1, 1, 3 }, { 3, 1, 2, 3, 1, 1 }, { 3, 3, 2, 1, 1, 1 }, { 3, 1, 4, 1, 1, 1 }, { 2, 2, 1, 4, 1, 1 }, { 4, 3, 1, 1, 1, 1 }, { 1, 1, 1, 2, 2, 4 }, { 1, 1, 1, 4, 2, 2 }, { 1, 2, 1, 1, 2, 4 }, { 1, 2, 1, 4, 2, 1 }, { 1, 4, 1, 1, 2, 2 }, { 1, 4, 1, 2, 2, 1 }, { 1, 1, 2, 2, 1, 4 }, { 1, 1, 2, 4, 1, 2 }, { 1, 2, 2, 1, 1, 4 }, { 1, 2, 2, 4, 1, 1 }, { 1, 4, 2, 1, 1, 2 }, { 1, 4, 2, 2, 1, 1 }, { 2, 4, 1, 2, 1, 1 }, { 2, 2, 1, 1, 1, 4 }, { 4, 1, 3, 1, 1, 1 }, { 2, 4, 1, 1, 1, 2 }, { 1, 3, 4, 1, 1, 1 }, { 1, 1, 1, 2, 4, 2 }, { 1, 2, 1, 1, 4, 2 }, { 1, 2, 1, 2, 4, 1 }, { 1, 1, 4, 2, 1, 2 }, { 1, 2, 4, 1, 1, 2 }, { 1, 2, 4, 2, 1, 1 }, { 4, 1, 1, 2, 1, 2 }, { 4, 2, 1, 1, 1, 2 }, { 4, 2, 1, 2, 1, 1 }, { 2, 1, 2, 1, 4, 1 }, { 2, 1, 4, 1, 2, 1 }, { 4, 1, 2, 1, 2, 1 }, { 1, 1, 1, 1, 4, 3 }, { 1, 1, 1, 3, 4, 1 }, { 1, 3, 1, 1, 4, 1 }, { 1, 1, 4, 1, 1, 3 }, { 1, 1, 4, 3, 1, 1 }, { 4, 1, 1, 1, 1, 3 }, { 4, 1, 1, 3, 1, 1 }, { 1, 1, 3, 1, 4, 1 }, { 1, 1, 4, 1, 3, 1 }, { 3, 1, 1, 1, 4, 1 }, { 4, 1, 1, 1, 3, 1 }, { 2, 1, 1, 4, 1, 2 }, { 2, 1, 1, 2, 1, 4 }, { 2, 1, 1, 2, 3, 2 }, { 2, 3, 3, 1, 1, 1, 2 } };
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static final int MAX_AVG_VARIANCE = 64;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static final int MAX_INDIVIDUAL_VARIANCE = 179;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static final int CODE_SHIFT = 98;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static final int CODE_CODE_C = 99;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static final int CODE_CODE_B = 100;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static final int CODE_CODE_A = 101;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static final int CODE_FNC_1 = 102;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static final int CODE_FNC_2 = 97;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static final int CODE_FNC_3 = 96;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static final int CODE_FNC_4_A = 101;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static final int CODE_FNC_4_B = 100;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static final int CODE_START_A = 103;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static final int CODE_START_B = 104;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static final int CODE_START_C = 105;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static final int CODE_STOP = 106;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static int[] findStartPattern(BitArray row) throws NotFoundException {
/* 170 */     int width = row.getSize();
/* 171 */     int rowOffset = row.getNextSet(0);
/*     */     
/* 173 */     int counterPosition = 0;
/* 174 */     int[] counters = new int[6];
/* 175 */     int patternStart = rowOffset;
/* 176 */     boolean isWhite = false;
/* 177 */     int patternLength = counters.length;
/*     */     
/* 179 */     for (int i = rowOffset; i < width; i++) {
/* 180 */       if (row.get(i) ^ isWhite) {
/* 181 */         counters[counterPosition] = counters[counterPosition] + 1;
/*     */       } else {
/* 183 */         if (counterPosition == patternLength - 1) {
/* 184 */           int bestVariance = 64;
/* 185 */           int bestMatch = -1;
/* 186 */           for (int startCode = 103; startCode <= 105; startCode++) {
/* 187 */             int variance = patternMatchVariance(counters, CODE_PATTERNS[startCode], 179);
/*     */             
/* 189 */             if (variance < bestVariance) {
/* 190 */               bestVariance = variance;
/* 191 */               bestMatch = startCode;
/*     */             } 
/*     */           } 
/*     */           
/* 195 */           if (bestMatch >= 0 && row.isRange(Math.max(0, patternStart - (i - patternStart) / 2), patternStart, false))
/*     */           {
/* 197 */             return new int[] { patternStart, i, bestMatch };
/*     */           }
/* 199 */           patternStart += counters[0] + counters[1];
/* 200 */           System.arraycopy(counters, 2, counters, 0, patternLength - 2);
/* 201 */           counters[patternLength - 2] = 0;
/* 202 */           counters[patternLength - 1] = 0;
/* 203 */           counterPosition--;
/*     */         } else {
/* 205 */           counterPosition++;
/*     */         } 
/* 207 */         counters[counterPosition] = 1;
/* 208 */         isWhite = !isWhite;
/*     */       } 
/*     */     } 
/* 211 */     throw NotFoundException.getNotFoundInstance();
/*     */   }
/*     */ 
/*     */   
/*     */   private static int decodeCode(BitArray row, int[] counters, int rowOffset) throws NotFoundException {
/* 216 */     recordPattern(row, rowOffset, counters);
/* 217 */     int bestVariance = 64;
/* 218 */     int bestMatch = -1;
/* 219 */     for (int d = 0; d < CODE_PATTERNS.length; d++) {
/* 220 */       int[] pattern = CODE_PATTERNS[d];
/* 221 */       int variance = patternMatchVariance(counters, pattern, 179);
/* 222 */       if (variance < bestVariance) {
/* 223 */         bestVariance = variance;
/* 224 */         bestMatch = d;
/*     */       } 
/*     */     } 
/*     */     
/* 228 */     if (bestMatch >= 0) {
/* 229 */       return bestMatch;
/*     */     }
/* 231 */     throw NotFoundException.getNotFoundInstance();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Result decodeRow(int rowNumber, BitArray row, Map<DecodeHintType, ?> hints) throws NotFoundException, FormatException, ChecksumException {
/*     */     int codeSet;
/* 239 */     boolean convertFNC1 = (hints != null && hints.containsKey(DecodeHintType.ASSUME_GS1));
/*     */     
/* 241 */     int[] startPatternInfo = findStartPattern(row);
/* 242 */     int startCode = startPatternInfo[2];
/*     */     
/* 244 */     switch (startCode) {
/*     */       case 103:
/* 246 */         codeSet = 101;
/*     */         break;
/*     */       case 104:
/* 249 */         codeSet = 100;
/*     */         break;
/*     */       case 105:
/* 252 */         codeSet = 99;
/*     */         break;
/*     */       default:
/* 255 */         throw FormatException.getFormatInstance();
/*     */     } 
/*     */     
/* 258 */     boolean done = false;
/* 259 */     boolean isNextShifted = false;
/*     */     
/* 261 */     StringBuilder result = new StringBuilder(20);
/* 262 */     List<Byte> rawCodes = new ArrayList<Byte>(20);
/*     */     
/* 264 */     int lastStart = startPatternInfo[0];
/* 265 */     int nextStart = startPatternInfo[1];
/* 266 */     int[] counters = new int[6];
/*     */     
/* 268 */     int lastCode = 0;
/* 269 */     int code = 0;
/* 270 */     int checksumTotal = startCode;
/* 271 */     int multiplier = 0;
/* 272 */     boolean lastCharacterWasPrintable = true;
/*     */     
/* 274 */     while (!done) {
/*     */       
/* 276 */       boolean unshift = isNextShifted;
/* 277 */       isNextShifted = false;
/*     */ 
/*     */       
/* 280 */       lastCode = code;
/*     */ 
/*     */       
/* 283 */       code = decodeCode(row, counters, nextStart);
/*     */       
/* 285 */       rawCodes.add(Byte.valueOf((byte)code));
/*     */ 
/*     */       
/* 288 */       if (code != 106) {
/* 289 */         lastCharacterWasPrintable = true;
/*     */       }
/*     */ 
/*     */       
/* 293 */       if (code != 106) {
/* 294 */         multiplier++;
/* 295 */         checksumTotal += multiplier * code;
/*     */       } 
/*     */ 
/*     */       
/* 299 */       lastStart = nextStart;
/* 300 */       for (int counter : counters) {
/* 301 */         nextStart += counter;
/*     */       }
/*     */ 
/*     */       
/* 305 */       switch (code) {
/*     */         case 103:
/*     */         case 104:
/*     */         case 105:
/* 309 */           throw FormatException.getFormatInstance();
/*     */       } 
/*     */       
/* 312 */       switch (codeSet) {
/*     */         
/*     */         case 101:
/* 315 */           if (code < 64) {
/* 316 */             result.append((char)(32 + code)); break;
/* 317 */           }  if (code < 96) {
/* 318 */             result.append((char)(code - 64));
/*     */             
/*     */             break;
/*     */           } 
/* 322 */           if (code != 106) {
/* 323 */             lastCharacterWasPrintable = false;
/*     */           }
/* 325 */           switch (code) {
/*     */             case 102:
/* 327 */               if (convertFNC1) {
/* 328 */                 if (result.length() == 0) {
/*     */ 
/*     */                   
/* 331 */                   result.append("]C1");
/*     */                   break;
/*     */                 } 
/* 334 */                 result.append('\035');
/*     */               } 
/*     */               break;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */             
/*     */             case 98:
/* 344 */               isNextShifted = true;
/* 345 */               codeSet = 100;
/*     */               break;
/*     */             case 100:
/* 348 */               codeSet = 100;
/*     */               break;
/*     */             case 99:
/* 351 */               codeSet = 99;
/*     */               break;
/*     */             case 106:
/* 354 */               done = true;
/*     */               break;
/*     */           } 
/*     */           
/*     */           break;
/*     */         case 100:
/* 360 */           if (code < 96) {
/* 361 */             result.append((char)(32 + code)); break;
/*     */           } 
/* 363 */           if (code != 106) {
/* 364 */             lastCharacterWasPrintable = false;
/*     */           }
/* 366 */           switch (code) {
/*     */             case 102:
/* 368 */               if (convertFNC1) {
/* 369 */                 if (result.length() == 0) {
/*     */ 
/*     */                   
/* 372 */                   result.append("]C1");
/*     */                   break;
/*     */                 } 
/* 375 */                 result.append('\035');
/*     */               } 
/*     */               break;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */             
/*     */             case 98:
/* 385 */               isNextShifted = true;
/* 386 */               codeSet = 101;
/*     */               break;
/*     */             case 101:
/* 389 */               codeSet = 101;
/*     */               break;
/*     */             case 99:
/* 392 */               codeSet = 99;
/*     */               break;
/*     */             case 106:
/* 395 */               done = true;
/*     */               break;
/*     */           } 
/*     */           
/*     */           break;
/*     */         case 99:
/* 401 */           if (code < 100) {
/* 402 */             if (code < 10) {
/* 403 */               result.append('0');
/*     */             }
/* 405 */             result.append(code); break;
/*     */           } 
/* 407 */           if (code != 106) {
/* 408 */             lastCharacterWasPrintable = false;
/*     */           }
/* 410 */           switch (code) {
/*     */             case 102:
/* 412 */               if (convertFNC1) {
/* 413 */                 if (result.length() == 0) {
/*     */ 
/*     */                   
/* 416 */                   result.append("]C1");
/*     */                   break;
/*     */                 } 
/* 419 */                 result.append('\035');
/*     */               } 
/*     */               break;
/*     */             
/*     */             case 101:
/* 424 */               codeSet = 101;
/*     */               break;
/*     */             case 100:
/* 427 */               codeSet = 100;
/*     */               break;
/*     */             case 106:
/* 430 */               done = true;
/*     */               break;
/*     */           } 
/*     */ 
/*     */           
/*     */           break;
/*     */       } 
/*     */       
/* 438 */       if (unshift) {
/* 439 */         codeSet = (codeSet == 101) ? 100 : 101;
/*     */       }
/*     */     } 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 447 */     nextStart = row.getNextUnset(nextStart);
/* 448 */     if (!row.isRange(nextStart, Math.min(row.getSize(), nextStart + (nextStart - lastStart) / 2), false))
/*     */     {
/*     */       
/* 451 */       throw NotFoundException.getNotFoundInstance();
/*     */     }
/*     */ 
/*     */     
/* 455 */     checksumTotal -= multiplier * lastCode;
/*     */     
/* 457 */     if (checksumTotal % 103 != lastCode) {
/* 458 */       throw ChecksumException.getChecksumInstance();
/*     */     }
/*     */ 
/*     */     
/* 462 */     int resultLength = result.length();
/* 463 */     if (resultLength == 0)
/*     */     {
/* 465 */       throw NotFoundException.getNotFoundInstance();
/*     */     }
/*     */ 
/*     */ 
/*     */     
/* 470 */     if (resultLength > 0 && lastCharacterWasPrintable) {
/* 471 */       if (codeSet == 99) {
/* 472 */         result.delete(resultLength - 2, resultLength);
/*     */       } else {
/* 474 */         result.delete(resultLength - 1, resultLength);
/*     */       } 
/*     */     }
/*     */     
/* 478 */     float left = (startPatternInfo[1] + startPatternInfo[0]) / 2.0F;
/* 479 */     float right = (nextStart + lastStart) / 2.0F;
/*     */     
/* 481 */     int rawCodesSize = rawCodes.size();
/* 482 */     byte[] rawBytes = new byte[rawCodesSize];
/* 483 */     for (int i = 0; i < rawCodesSize; i++) {
/* 484 */       rawBytes[i] = ((Byte)rawCodes.get(i)).byteValue();
/*     */     }
/*     */     
/* 487 */     return new Result(result.toString(), rawBytes, new ResultPoint[] { new ResultPoint(left, rowNumber), new ResultPoint(right, rowNumber) }BarcodeFormat.CODE_128);
/*     */   }
/*     */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\com\google\zxing\oned\Code128Reader.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       1.1.3
 */