/*     */ package com.google.zxing.oned;
/*     */ 
/*     */ import com.google.zxing.BarcodeFormat;
/*     */ import com.google.zxing.EncodeHintType;
/*     */ import com.google.zxing.WriterException;
/*     */ import com.google.zxing.common.BitMatrix;
/*     */ import java.util.ArrayList;
/*     */ import java.util.Collection;
/*     */ import java.util.Map;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public final class Code128Writer
/*     */   extends OneDimensionalCodeWriter
/*     */ {
/*     */   private static final int CODE_START_B = 104;
/*     */   private static final int CODE_START_C = 105;
/*     */   private static final int CODE_CODE_B = 100;
/*     */   private static final int CODE_CODE_C = 99;
/*     */   private static final int CODE_STOP = 106;
/*     */   private static final char ESCAPE_FNC_1 = 'ñ';
/*     */   private static final char ESCAPE_FNC_2 = 'ò';
/*     */   private static final char ESCAPE_FNC_3 = 'ó';
/*     */   private static final char ESCAPE_FNC_4 = 'ô';
/*     */   private static final int CODE_FNC_1 = 102;
/*     */   private static final int CODE_FNC_2 = 97;
/*     */   private static final int CODE_FNC_3 = 96;
/*     */   private static final int CODE_FNC_4_B = 100;
/*     */   
/*     */   public BitMatrix encode(String contents, BarcodeFormat format, int width, int height, Map<EncodeHintType, ?> hints) throws WriterException {
/*  58 */     if (format != BarcodeFormat.CODE_128) {
/*  59 */       throw new IllegalArgumentException("Can only encode CODE_128, but got " + format);
/*     */     }
/*  61 */     return super.encode(contents, format, width, height, hints);
/*     */   }
/*     */ 
/*     */   
/*     */   public boolean[] encode(String contents) {
/*  66 */     int length = contents.length();
/*     */     
/*  68 */     if (length < 1 || length > 80) {
/*  69 */       throw new IllegalArgumentException("Contents length should be between 1 and 80 characters, but got " + length);
/*     */     }
/*     */ 
/*     */     
/*  73 */     for (int i = 0; i < length; i++) {
/*  74 */       char c = contents.charAt(i);
/*  75 */       if (c < ' ' || c > '~') {
/*  76 */         switch (c) {
/*     */           case 'ñ':
/*     */           case 'ò':
/*     */           case 'ó':
/*     */           case 'ô':
/*     */             break;
/*     */           default:
/*  83 */             throw new IllegalArgumentException("Bad character in input: " + c);
/*     */         } 
/*     */       
/*     */       }
/*     */     } 
/*  88 */     Collection<int[]> patterns = (Collection)new ArrayList<int>();
/*  89 */     int checkSum = 0;
/*  90 */     int checkWeight = 1;
/*  91 */     int codeSet = 0;
/*  92 */     int position = 0;
/*     */     
/*  94 */     while (position < length) {
/*     */       
/*  96 */       int newCodeSet, patternIndex, requiredDigitCount = (codeSet == 99) ? 2 : 4;
/*     */       
/*  98 */       if (isDigits(contents, position, requiredDigitCount)) {
/*  99 */         newCodeSet = 99;
/*     */       } else {
/* 101 */         newCodeSet = 100;
/*     */       } 
/*     */ 
/*     */ 
/*     */       
/* 106 */       if (newCodeSet == codeSet) {
/*     */         
/* 108 */         if (codeSet == 100) {
/* 109 */           patternIndex = contents.charAt(position) - 32;
/* 110 */           position++;
/*     */         } else {
/* 112 */           switch (contents.charAt(position)) {
/*     */             case 'ñ':
/* 114 */               patternIndex = 102;
/* 115 */               position++;
/*     */               break;
/*     */             case 'ò':
/* 118 */               patternIndex = 97;
/* 119 */               position++;
/*     */               break;
/*     */             case 'ó':
/* 122 */               patternIndex = 96;
/* 123 */               position++;
/*     */               break;
/*     */             case 'ô':
/* 126 */               patternIndex = 100;
/* 127 */               position++;
/*     */               break;
/*     */             default:
/* 130 */               patternIndex = Integer.parseInt(contents.substring(position, position + 2));
/* 131 */               position += 2;
/*     */               break;
/*     */           } 
/*     */ 
/*     */         
/*     */         } 
/*     */       } else {
/* 138 */         if (codeSet == 0) {
/*     */           
/* 140 */           if (newCodeSet == 100) {
/* 141 */             patternIndex = 104;
/*     */           } else {
/*     */             
/* 144 */             patternIndex = 105;
/*     */           } 
/*     */         } else {
/*     */           
/* 148 */           patternIndex = newCodeSet;
/*     */         } 
/* 150 */         codeSet = newCodeSet;
/*     */       } 
/*     */ 
/*     */       
/* 154 */       patterns.add(Code128Reader.CODE_PATTERNS[patternIndex]);
/*     */ 
/*     */       
/* 157 */       checkSum += patternIndex * checkWeight;
/* 158 */       if (position != 0) {
/* 159 */         checkWeight++;
/*     */       }
/*     */     } 
/*     */ 
/*     */     
/* 164 */     checkSum %= 103;
/* 165 */     patterns.add(Code128Reader.CODE_PATTERNS[checkSum]);
/*     */ 
/*     */     
/* 168 */     patterns.add(Code128Reader.CODE_PATTERNS[106]);
/*     */ 
/*     */     
/* 171 */     int codeWidth = 0;
/* 172 */     for (int[] pattern : patterns) {
/* 173 */       for (int width : pattern) {
/* 174 */         codeWidth += width;
/*     */       }
/*     */     } 
/*     */ 
/*     */     
/* 179 */     boolean[] result = new boolean[codeWidth];
/* 180 */     int pos = 0;
/* 181 */     for (int[] pattern : patterns) {
/* 182 */       pos += appendPattern(result, pos, pattern, true);
/*     */     }
/*     */     
/* 185 */     return result;
/*     */   }
/*     */   
/*     */   private static boolean isDigits(CharSequence value, int start, int length) {
/* 189 */     int end = start + length;
/* 190 */     int last = value.length();
/* 191 */     for (int i = start; i < end && i < last; i++) {
/* 192 */       char c = value.charAt(i);
/* 193 */       if (c < '0' || c > '9') {
/* 194 */         if (c != 'ñ') {
/* 195 */           return false;
/*     */         }
/* 197 */         end++;
/*     */       } 
/*     */     } 
/* 200 */     return (end <= last);
/*     */   }
/*     */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\com\google\zxing\oned\Code128Writer.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       1.1.3
 */