/*     */ package com.google.zxing.oned;
/*     */ 
/*     */ import com.google.zxing.BarcodeFormat;
/*     */ import com.google.zxing.ChecksumException;
/*     */ import com.google.zxing.DecodeHintType;
/*     */ import com.google.zxing.FormatException;
/*     */ import com.google.zxing.NotFoundException;
/*     */ import com.google.zxing.Result;
/*     */ import com.google.zxing.ResultPoint;
/*     */ import com.google.zxing.common.BitArray;
/*     */ import java.util.Arrays;
/*     */ import java.util.Map;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public final class Code93Reader
/*     */   extends OneDReader
/*     */ {
/*     */   private static final String ALPHABET_STRING = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ-. $/+%abcd*";
/*  41 */   private static final char[] ALPHABET = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ-. $/+%abcd*".toCharArray();
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  47 */   private static final int[] CHARACTER_ENCODINGS = new int[] { 276, 328, 324, 322, 296, 292, 290, 336, 274, 266, 424, 420, 418, 404, 402, 394, 360, 356, 354, 308, 282, 344, 332, 326, 300, 278, 436, 434, 428, 422, 406, 410, 364, 358, 310, 314, 302, 468, 466, 458, 366, 374, 430, 294, 474, 470, 306, 350 };
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  55 */   private static final int ASTERISK_ENCODING = CHARACTER_ENCODINGS[47];
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  61 */   private final StringBuilder decodeRowResult = new StringBuilder(20);
/*  62 */   private final int[] counters = new int[6];
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Result decodeRow(int rowNumber, BitArray row, Map<DecodeHintType, ?> hints) throws NotFoundException, ChecksumException, FormatException {
/*  69 */     int[] start = findAsteriskPattern(row);
/*     */     
/*  71 */     int nextStart = row.getNextSet(start[1]);
/*  72 */     int end = row.getSize();
/*     */     
/*  74 */     int[] theCounters = this.counters;
/*  75 */     Arrays.fill(theCounters, 0);
/*  76 */     StringBuilder result = this.decodeRowResult;
/*  77 */     result.setLength(0);
/*     */ 
/*     */ 
/*     */     
/*     */     while (true) {
/*  82 */       recordPattern(row, nextStart, theCounters);
/*  83 */       int pattern = toPattern(theCounters);
/*  84 */       if (pattern < 0) {
/*  85 */         throw NotFoundException.getNotFoundInstance();
/*     */       }
/*  87 */       char decodedChar = patternToChar(pattern);
/*  88 */       result.append(decodedChar);
/*  89 */       int lastStart = nextStart;
/*  90 */       for (int counter : theCounters) {
/*  91 */         nextStart += counter;
/*     */       }
/*     */       
/*  94 */       nextStart = row.getNextSet(nextStart);
/*  95 */       if (decodedChar == '*') {
/*  96 */         result.deleteCharAt(result.length() - 1);
/*     */ 
/*     */         
/*  99 */         if (nextStart == end || !row.get(nextStart)) {
/* 100 */           throw NotFoundException.getNotFoundInstance();
/*     */         }
/*     */         
/* 103 */         if (result.length() < 2)
/*     */         {
/* 105 */           throw NotFoundException.getNotFoundInstance();
/*     */         }
/*     */         
/* 108 */         checkChecksums(result);
/*     */         
/* 110 */         result.setLength(result.length() - 2);
/*     */         
/* 112 */         String resultString = decodeExtended(result);
/*     */         
/* 114 */         float left = (start[1] + start[0]) / 2.0F;
/* 115 */         float right = (nextStart + lastStart) / 2.0F;
/* 116 */         return new Result(resultString, null, new ResultPoint[] { new ResultPoint(left, rowNumber), new ResultPoint(right, rowNumber) }BarcodeFormat.CODE_93);
/*     */       } 
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private int[] findAsteriskPattern(BitArray row) throws NotFoundException {
/* 127 */     int width = row.getSize();
/* 128 */     int rowOffset = row.getNextSet(0);
/*     */     
/* 130 */     Arrays.fill(this.counters, 0);
/* 131 */     int[] theCounters = this.counters;
/* 132 */     int patternStart = rowOffset;
/* 133 */     boolean isWhite = false;
/* 134 */     int patternLength = theCounters.length;
/*     */     
/* 136 */     int counterPosition = 0;
/* 137 */     for (int i = rowOffset; i < width; i++) {
/* 138 */       if (row.get(i) ^ isWhite) {
/* 139 */         theCounters[counterPosition] = theCounters[counterPosition] + 1;
/*     */       } else {
/* 141 */         if (counterPosition == patternLength - 1) {
/* 142 */           if (toPattern(theCounters) == ASTERISK_ENCODING) {
/* 143 */             return new int[] { patternStart, i };
/*     */           }
/* 145 */           patternStart += theCounters[0] + theCounters[1];
/* 146 */           System.arraycopy(theCounters, 2, theCounters, 0, patternLength - 2);
/* 147 */           theCounters[patternLength - 2] = 0;
/* 148 */           theCounters[patternLength - 1] = 0;
/* 149 */           counterPosition--;
/*     */         } else {
/* 151 */           counterPosition++;
/*     */         } 
/* 153 */         theCounters[counterPosition] = 1;
/* 154 */         isWhite = !isWhite;
/*     */       } 
/*     */     } 
/* 157 */     throw NotFoundException.getNotFoundInstance();
/*     */   }
/*     */   
/*     */   private static int toPattern(int[] counters) {
/* 161 */     int max = counters.length;
/* 162 */     int sum = 0;
/* 163 */     for (int counter : counters) {
/* 164 */       sum += counter;
/*     */     }
/* 166 */     int pattern = 0;
/* 167 */     for (int i = 0; i < max; i++) {
/* 168 */       int scaledShifted = (counters[i] << 8) * 9 / sum;
/* 169 */       int scaledUnshifted = scaledShifted >> 8;
/* 170 */       if ((scaledShifted & 0xFF) > 127) {
/* 171 */         scaledUnshifted++;
/*     */       }
/* 173 */       if (scaledUnshifted < 1 || scaledUnshifted > 4) {
/* 174 */         return -1;
/*     */       }
/* 176 */       if ((i & 0x1) == 0) {
/* 177 */         for (int j = 0; j < scaledUnshifted; j++) {
/* 178 */           pattern = pattern << 1 | 0x1;
/*     */         }
/*     */       } else {
/* 181 */         pattern <<= scaledUnshifted;
/*     */       } 
/*     */     } 
/* 184 */     return pattern;
/*     */   }
/*     */   
/*     */   private static char patternToChar(int pattern) throws NotFoundException {
/* 188 */     for (int i = 0; i < CHARACTER_ENCODINGS.length; i++) {
/* 189 */       if (CHARACTER_ENCODINGS[i] == pattern) {
/* 190 */         return ALPHABET[i];
/*     */       }
/*     */     } 
/* 193 */     throw NotFoundException.getNotFoundInstance();
/*     */   }
/*     */   
/*     */   private static String decodeExtended(CharSequence encoded) throws FormatException {
/* 197 */     int length = encoded.length();
/* 198 */     StringBuilder decoded = new StringBuilder(length);
/* 199 */     for (int i = 0; i < length; i++) {
/* 200 */       char c = encoded.charAt(i);
/* 201 */       if (c >= 'a' && c <= 'd') {
/* 202 */         if (i >= length - 1) {
/* 203 */           throw FormatException.getFormatInstance();
/*     */         }
/* 205 */         char next = encoded.charAt(i + 1);
/* 206 */         char decodedChar = Character.MIN_VALUE;
/* 207 */         switch (c) {
/*     */           
/*     */           case 'd':
/* 210 */             if (next >= 'A' && next <= 'Z') {
/* 211 */               decodedChar = (char)(next + 32); break;
/*     */             } 
/* 213 */             throw FormatException.getFormatInstance();
/*     */ 
/*     */ 
/*     */           
/*     */           case 'a':
/* 218 */             if (next >= 'A' && next <= 'Z') {
/* 219 */               decodedChar = (char)(next - 64); break;
/*     */             } 
/* 221 */             throw FormatException.getFormatInstance();
/*     */ 
/*     */ 
/*     */           
/*     */           case 'b':
/* 226 */             if (next >= 'A' && next <= 'E') {
/* 227 */               decodedChar = (char)(next - 38); break;
/* 228 */             }  if (next >= 'F' && next <= 'W') {
/* 229 */               decodedChar = (char)(next - 11); break;
/*     */             } 
/* 231 */             throw FormatException.getFormatInstance();
/*     */ 
/*     */ 
/*     */           
/*     */           case 'c':
/* 236 */             if (next >= 'A' && next <= 'O') {
/* 237 */               decodedChar = (char)(next - 32); break;
/* 238 */             }  if (next == 'Z') {
/* 239 */               decodedChar = ':'; break;
/*     */             } 
/* 241 */             throw FormatException.getFormatInstance();
/*     */         } 
/*     */ 
/*     */         
/* 245 */         decoded.append(decodedChar);
/*     */         
/* 247 */         i++;
/*     */       } else {
/* 249 */         decoded.append(c);
/*     */       } 
/*     */     } 
/* 252 */     return decoded.toString();
/*     */   }
/*     */   
/*     */   private static void checkChecksums(CharSequence result) throws ChecksumException {
/* 256 */     int length = result.length();
/* 257 */     checkOneChecksum(result, length - 2, 20);
/* 258 */     checkOneChecksum(result, length - 1, 15);
/*     */   }
/*     */ 
/*     */   
/*     */   private static void checkOneChecksum(CharSequence result, int checkPosition, int weightMax) throws ChecksumException {
/* 263 */     int weight = 1;
/* 264 */     int total = 0;
/* 265 */     for (int i = checkPosition - 1; i >= 0; i--) {
/* 266 */       total += weight * "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ-. $/+%abcd*".indexOf(result.charAt(i));
/* 267 */       if (++weight > weightMax) {
/* 268 */         weight = 1;
/*     */       }
/*     */     } 
/* 271 */     if (result.charAt(checkPosition) != ALPHABET[total % 47])
/* 272 */       throw ChecksumException.getChecksumInstance(); 
/*     */   }
/*     */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\com\google\zxing\oned\Code93Reader.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       1.1.3
 */