/*     */ package com.google.zxing.oned;
/*     */ 
/*     */ import com.google.zxing.BarcodeFormat;
/*     */ import com.google.zxing.DecodeHintType;
/*     */ import com.google.zxing.FormatException;
/*     */ import com.google.zxing.NotFoundException;
/*     */ import com.google.zxing.Result;
/*     */ import com.google.zxing.ResultPoint;
/*     */ import com.google.zxing.common.BitArray;
/*     */ import java.util.Map;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public final class ITFReader
/*     */   extends OneDReader
/*     */ {
/*     */   private static final int MAX_AVG_VARIANCE = 107;
/*     */   private static final int MAX_INDIVIDUAL_VARIANCE = 204;
/*     */   private static final int W = 3;
/*     */   private static final int N = 1;
/*  53 */   private static final int[] DEFAULT_ALLOWED_LENGTHS = new int[] { 48, 44, 24, 20, 18, 16, 14, 12, 10, 8, 6 };
/*     */ 
/*     */   
/*  56 */   private int narrowLineWidth = -1;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  64 */   private static final int[] START_PATTERN = new int[] { 1, 1, 1, 1 };
/*  65 */   private static final int[] END_PATTERN_REVERSED = new int[] { 1, 1, 3 };
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  70 */   static final int[][] PATTERNS = new int[][] { { 1, 1, 3, 3, 1 }, { 3, 1, 1, 1, 3 }, { 1, 3, 1, 1, 3 }, { 3, 3, 1, 1, 1 }, { 1, 1, 3, 1, 3 }, { 3, 1, 3, 1, 1 }, { 1, 3, 3, 1, 1 }, { 1, 1, 1, 3, 3 }, { 3, 1, 1, 3, 1 }, { 1, 3, 1, 3, 1 } };
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Result decodeRow(int rowNumber, BitArray row, Map<DecodeHintType, ?> hints) throws FormatException, NotFoundException {
/*  88 */     int[] startRange = decodeStart(row);
/*  89 */     int[] endRange = decodeEnd(row);
/*     */     
/*  91 */     StringBuilder result = new StringBuilder(20);
/*  92 */     decodeMiddle(row, startRange[1], endRange[0], result);
/*  93 */     String resultString = result.toString();
/*     */     
/*  95 */     int[] allowedLengths = null;
/*  96 */     if (hints != null) {
/*  97 */       allowedLengths = (int[])hints.get(DecodeHintType.ALLOWED_LENGTHS);
/*     */     }
/*     */     
/* 100 */     if (allowedLengths == null) {
/* 101 */       allowedLengths = DEFAULT_ALLOWED_LENGTHS;
/*     */     }
/*     */ 
/*     */ 
/*     */     
/* 106 */     int length = resultString.length();
/* 107 */     boolean lengthOK = false;
/* 108 */     for (int allowedLength : allowedLengths) {
/* 109 */       if (length == allowedLength) {
/* 110 */         lengthOK = true;
/*     */         break;
/*     */       } 
/*     */     } 
/* 114 */     if (!lengthOK) {
/* 115 */       throw FormatException.getFormatInstance();
/*     */     }
/*     */     
/* 118 */     return new Result(resultString, null, new ResultPoint[] { new ResultPoint(startRange[1], rowNumber), new ResultPoint(endRange[0], rowNumber) }BarcodeFormat.ITF);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static void decodeMiddle(BitArray row, int payloadStart, int payloadEnd, StringBuilder resultString) throws NotFoundException {
/* 142 */     int[] counterDigitPair = new int[10];
/* 143 */     int[] counterBlack = new int[5];
/* 144 */     int[] counterWhite = new int[5];
/*     */     
/* 146 */     while (payloadStart < payloadEnd) {
/*     */ 
/*     */       
/* 149 */       recordPattern(row, payloadStart, counterDigitPair);
/*     */       
/* 151 */       for (int k = 0; k < 5; k++) {
/* 152 */         int twoK = k << 1;
/* 153 */         counterBlack[k] = counterDigitPair[twoK];
/* 154 */         counterWhite[k] = counterDigitPair[twoK + 1];
/*     */       } 
/*     */       
/* 157 */       int bestMatch = decodeDigit(counterBlack);
/* 158 */       resultString.append((char)(48 + bestMatch));
/* 159 */       bestMatch = decodeDigit(counterWhite);
/* 160 */       resultString.append((char)(48 + bestMatch));
/*     */       
/* 162 */       for (int counterDigit : counterDigitPair) {
/* 163 */         payloadStart += counterDigit;
/*     */       }
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   int[] decodeStart(BitArray row) throws NotFoundException {
/* 177 */     int endStart = skipWhiteSpace(row);
/* 178 */     int[] startPattern = findGuardPattern(row, endStart, START_PATTERN);
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 183 */     this.narrowLineWidth = startPattern[1] - startPattern[0] >> 2;
/*     */     
/* 185 */     validateQuietZone(row, startPattern[0]);
/*     */     
/* 187 */     return startPattern;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private void validateQuietZone(BitArray row, int startPattern) throws NotFoundException {
/* 207 */     int quietCount = this.narrowLineWidth * 10;
/*     */     
/* 209 */     for (int i = startPattern - 1; quietCount > 0 && i >= 0 && 
/* 210 */       !row.get(i); i--)
/*     */     {
/*     */       
/* 213 */       quietCount--;
/*     */     }
/* 215 */     if (quietCount != 0)
/*     */     {
/* 217 */       throw NotFoundException.getNotFoundInstance();
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static int skipWhiteSpace(BitArray row) throws NotFoundException {
/* 229 */     int width = row.getSize();
/* 230 */     int endStart = row.getNextSet(0);
/* 231 */     if (endStart == width) {
/* 232 */       throw NotFoundException.getNotFoundInstance();
/*     */     }
/*     */     
/* 235 */     return endStart;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   int[] decodeEnd(BitArray row) throws NotFoundException {
/* 250 */     row.reverse();
/*     */     try {
/* 252 */       int endStart = skipWhiteSpace(row);
/* 253 */       int[] endPattern = findGuardPattern(row, endStart, END_PATTERN_REVERSED);
/*     */ 
/*     */ 
/*     */ 
/*     */       
/* 258 */       validateQuietZone(row, endPattern[0]);
/*     */ 
/*     */ 
/*     */ 
/*     */       
/* 263 */       int temp = endPattern[0];
/* 264 */       endPattern[0] = row.getSize() - endPattern[1];
/* 265 */       endPattern[1] = row.getSize() - temp;
/*     */       
/* 267 */       return endPattern;
/*     */     } finally {
/*     */       
/* 270 */       row.reverse();
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static int[] findGuardPattern(BitArray row, int rowOffset, int[] pattern) throws NotFoundException {
/* 289 */     int patternLength = pattern.length;
/* 290 */     int[] counters = new int[patternLength];
/* 291 */     int width = row.getSize();
/* 292 */     boolean isWhite = false;
/*     */     
/* 294 */     int counterPosition = 0;
/* 295 */     int patternStart = rowOffset;
/* 296 */     for (int x = rowOffset; x < width; x++) {
/* 297 */       if (row.get(x) ^ isWhite) {
/* 298 */         counters[counterPosition] = counters[counterPosition] + 1;
/*     */       } else {
/* 300 */         if (counterPosition == patternLength - 1) {
/* 301 */           if (patternMatchVariance(counters, pattern, 204) < 107) {
/* 302 */             return new int[] { patternStart, x };
/*     */           }
/* 304 */           patternStart += counters[0] + counters[1];
/* 305 */           System.arraycopy(counters, 2, counters, 0, patternLength - 2);
/* 306 */           counters[patternLength - 2] = 0;
/* 307 */           counters[patternLength - 1] = 0;
/* 308 */           counterPosition--;
/*     */         } else {
/* 310 */           counterPosition++;
/*     */         } 
/* 312 */         counters[counterPosition] = 1;
/* 313 */         isWhite = !isWhite;
/*     */       } 
/*     */     } 
/* 316 */     throw NotFoundException.getNotFoundInstance();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static int decodeDigit(int[] counters) throws NotFoundException {
/* 329 */     int bestVariance = 107;
/* 330 */     int bestMatch = -1;
/* 331 */     int max = PATTERNS.length;
/* 332 */     for (int i = 0; i < max; i++) {
/* 333 */       int[] pattern = PATTERNS[i];
/* 334 */       int variance = patternMatchVariance(counters, pattern, 204);
/* 335 */       if (variance < bestVariance) {
/* 336 */         bestVariance = variance;
/* 337 */         bestMatch = i;
/*     */       } 
/*     */     } 
/* 340 */     if (bestMatch >= 0) {
/* 341 */       return bestMatch;
/*     */     }
/* 343 */     throw NotFoundException.getNotFoundInstance();
/*     */   }
/*     */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\com\google\zxing\oned\ITFReader.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       1.1.3
 */