/*     */ package com.google.zxing.oned;
/*     */ 
/*     */ import com.google.zxing.BinaryBitmap;
/*     */ import com.google.zxing.ChecksumException;
/*     */ import com.google.zxing.DecodeHintType;
/*     */ import com.google.zxing.FormatException;
/*     */ import com.google.zxing.NotFoundException;
/*     */ import com.google.zxing.Reader;
/*     */ import com.google.zxing.ReaderException;
/*     */ import com.google.zxing.Result;
/*     */ import com.google.zxing.ResultMetadataType;
/*     */ import com.google.zxing.ResultPoint;
/*     */ import com.google.zxing.common.BitArray;
/*     */ import java.util.Arrays;
/*     */ import java.util.EnumMap;
/*     */ import java.util.Map;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public abstract class OneDReader
/*     */   implements Reader
/*     */ {
/*     */   protected static final int INTEGER_MATH_SHIFT = 8;
/*     */   protected static final int PATTERN_MATCH_RESULT_SCALE_FACTOR = 256;
/*     */   
/*     */   public Result decode(BinaryBitmap image) throws NotFoundException, FormatException {
/*  49 */     return decode(image, null);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Result decode(BinaryBitmap image, Map<DecodeHintType, ?> hints) throws NotFoundException, FormatException {
/*     */     try {
/*  57 */       return doDecode(image, hints);
/*  58 */     } catch (NotFoundException nfe) {
/*  59 */       boolean tryHarder = (hints != null && hints.containsKey(DecodeHintType.TRY_HARDER));
/*  60 */       if (tryHarder && image.isRotateSupported()) {
/*  61 */         BinaryBitmap rotatedImage = image.rotateCounterClockwise();
/*  62 */         Result result = doDecode(rotatedImage, hints);
/*     */         
/*  64 */         Map<ResultMetadataType, ?> metadata = result.getResultMetadata();
/*  65 */         int orientation = 270;
/*  66 */         if (metadata != null && metadata.containsKey(ResultMetadataType.ORIENTATION))
/*     */         {
/*  68 */           orientation = (orientation + ((Integer)metadata.get(ResultMetadataType.ORIENTATION)).intValue()) % 360;
/*     */         }
/*     */         
/*  71 */         result.putMetadata(ResultMetadataType.ORIENTATION, Integer.valueOf(orientation));
/*     */         
/*  73 */         ResultPoint[] points = result.getResultPoints();
/*  74 */         if (points != null) {
/*  75 */           int height = rotatedImage.getHeight();
/*  76 */           for (int i = 0; i < points.length; i++) {
/*  77 */             points[i] = new ResultPoint(height - points[i].getY() - 1.0F, points[i].getX());
/*     */           }
/*     */         } 
/*  80 */         return result;
/*     */       } 
/*  82 */       throw nfe;
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void reset() {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private Result doDecode(BinaryBitmap image, Map<DecodeHintType, ?> hints) throws NotFoundException {
/* 108 */     int maxLines, width = image.getWidth();
/* 109 */     int height = image.getHeight();
/* 110 */     BitArray row = new BitArray(width);
/*     */     
/* 112 */     int middle = height >> 1;
/* 113 */     boolean tryHarder = (hints != null && hints.containsKey(DecodeHintType.TRY_HARDER));
/* 114 */     int rowStep = Math.max(1, height >> (tryHarder ? 8 : 5));
/*     */     
/* 116 */     if (tryHarder) {
/* 117 */       maxLines = height;
/*     */     } else {
/* 119 */       maxLines = 15;
/*     */     } 
/*     */     
/* 122 */     for (int x = 0; x < maxLines; x++) {
/*     */ 
/*     */       
/* 125 */       int rowStepsAboveOrBelow = x + 1 >> 1;
/* 126 */       boolean isAbove = ((x & 0x1) == 0);
/* 127 */       int rowNumber = middle + rowStep * (isAbove ? rowStepsAboveOrBelow : -rowStepsAboveOrBelow);
/* 128 */       if (rowNumber < 0 || rowNumber >= height) {
/*     */         break;
/*     */       }
/*     */ 
/*     */ 
/*     */       
/*     */       try {
/* 135 */         row = image.getBlackRow(rowNumber, row);
/* 136 */       } catch (NotFoundException ignored) {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */       
/* 142 */       for (int attempt = 0; attempt < 2; attempt++) {
/* 143 */         if (attempt == 1) {
/* 144 */           row.reverse();
/*     */ 
/*     */ 
/*     */ 
/*     */           
/* 149 */           if (hints != null && hints.containsKey(DecodeHintType.NEED_RESULT_POINT_CALLBACK)) {
/* 150 */             Map<DecodeHintType, Object> newHints = new EnumMap<DecodeHintType, Object>(DecodeHintType.class);
/* 151 */             newHints.putAll(hints);
/* 152 */             newHints.remove(DecodeHintType.NEED_RESULT_POINT_CALLBACK);
/* 153 */             hints = newHints;
/*     */           } 
/*     */         } 
/*     */         
/*     */         try {
/* 158 */           Result result = decodeRow(rowNumber, row, hints);
/*     */           
/* 160 */           if (attempt == 1) {
/*     */             
/* 162 */             result.putMetadata(ResultMetadataType.ORIENTATION, Integer.valueOf(180));
/*     */             
/* 164 */             ResultPoint[] points = result.getResultPoints();
/* 165 */             if (points != null) {
/* 166 */               points[0] = new ResultPoint(width - points[0].getX() - 1.0F, points[0].getY());
/* 167 */               points[1] = new ResultPoint(width - points[1].getX() - 1.0F, points[1].getY());
/*     */             } 
/*     */           } 
/* 170 */           return result;
/* 171 */         } catch (ReaderException re) {}
/*     */       } 
/*     */     } 
/*     */ 
/*     */ 
/*     */     
/* 177 */     throw NotFoundException.getNotFoundInstance();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected static void recordPattern(BitArray row, int start, int[] counters) throws NotFoundException {
/* 196 */     int numCounters = counters.length;
/* 197 */     Arrays.fill(counters, 0, numCounters, 0);
/* 198 */     int end = row.getSize();
/* 199 */     if (start >= end) {
/* 200 */       throw NotFoundException.getNotFoundInstance();
/*     */     }
/* 202 */     boolean isWhite = !row.get(start);
/* 203 */     int counterPosition = 0;
/* 204 */     int i = start;
/* 205 */     while (i < end) {
/* 206 */       if (row.get(i) ^ isWhite) {
/* 207 */         counters[counterPosition] = counters[counterPosition] + 1;
/*     */       } else {
/* 209 */         counterPosition++;
/* 210 */         if (counterPosition == numCounters) {
/*     */           break;
/*     */         }
/* 213 */         counters[counterPosition] = 1;
/* 214 */         isWhite = !isWhite;
/*     */       } 
/*     */       
/* 217 */       i++;
/*     */     } 
/*     */ 
/*     */     
/* 221 */     if (counterPosition != numCounters && (counterPosition != numCounters - 1 || i != end)) {
/* 222 */       throw NotFoundException.getNotFoundInstance();
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   protected static void recordPatternInReverse(BitArray row, int start, int[] counters) throws NotFoundException {
/* 229 */     int numTransitionsLeft = counters.length;
/* 230 */     boolean last = row.get(start);
/* 231 */     while (start > 0 && numTransitionsLeft >= 0) {
/* 232 */       if (row.get(--start) != last) {
/* 233 */         numTransitionsLeft--;
/* 234 */         last = !last;
/*     */       } 
/*     */     } 
/* 237 */     if (numTransitionsLeft >= 0) {
/* 238 */       throw NotFoundException.getNotFoundInstance();
/*     */     }
/* 240 */     recordPattern(row, start + 1, counters);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected static int patternMatchVariance(int[] counters, int[] pattern, int maxIndividualVariance) {
/* 259 */     int numCounters = counters.length;
/* 260 */     int total = 0;
/* 261 */     int patternLength = 0;
/* 262 */     for (int i = 0; i < numCounters; i++) {
/* 263 */       total += counters[i];
/* 264 */       patternLength += pattern[i];
/*     */     } 
/* 266 */     if (total < patternLength)
/*     */     {
/*     */       
/* 269 */       return Integer.MAX_VALUE;
/*     */     }
/*     */ 
/*     */ 
/*     */     
/* 274 */     int unitBarWidth = (total << 8) / patternLength;
/* 275 */     maxIndividualVariance = maxIndividualVariance * unitBarWidth >> 8;
/*     */     
/* 277 */     int totalVariance = 0;
/* 278 */     for (int x = 0; x < numCounters; x++) {
/* 279 */       int counter = counters[x] << 8;
/* 280 */       int scaledPattern = pattern[x] * unitBarWidth;
/* 281 */       int variance = (counter > scaledPattern) ? (counter - scaledPattern) : (scaledPattern - counter);
/* 282 */       if (variance > maxIndividualVariance) {
/* 283 */         return Integer.MAX_VALUE;
/*     */       }
/* 285 */       totalVariance += variance;
/*     */     } 
/* 287 */     return totalVariance / total;
/*     */   }
/*     */   
/*     */   public abstract Result decodeRow(int paramInt, BitArray paramBitArray, Map<DecodeHintType, ?> paramMap) throws NotFoundException, ChecksumException, FormatException;
/*     */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\com\google\zxing\oned\OneDReader.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       1.1.3
 */