/*     */ package com.google.zxing.oned;
/*     */ 
/*     */ import com.google.zxing.BarcodeFormat;
/*     */ import com.google.zxing.ChecksumException;
/*     */ import com.google.zxing.DecodeHintType;
/*     */ import com.google.zxing.FormatException;
/*     */ import com.google.zxing.NotFoundException;
/*     */ import com.google.zxing.ReaderException;
/*     */ import com.google.zxing.Result;
/*     */ import com.google.zxing.ResultMetadataType;
/*     */ import com.google.zxing.ResultPoint;
/*     */ import com.google.zxing.ResultPointCallback;
/*     */ import com.google.zxing.common.BitArray;
/*     */ import java.util.Arrays;
/*     */ import java.util.Map;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public abstract class UPCEANReader
/*     */   extends OneDReader
/*     */ {
/*     */   private static final int MAX_AVG_VARIANCE = 122;
/*     */   private static final int MAX_INDIVIDUAL_VARIANCE = 179;
/*  53 */   static final int[] START_END_PATTERN = new int[] { 1, 1, 1 };
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  58 */   static final int[] MIDDLE_PATTERN = new int[] { 1, 1, 1, 1, 1 };
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  63 */   static final int[][] L_PATTERNS = new int[][] { { 3, 2, 1, 1 }, { 2, 2, 2, 1 }, { 2, 1, 2, 2 }, { 1, 4, 1, 1 }, { 1, 1, 3, 2 }, { 1, 2, 3, 1 }, { 1, 1, 1, 4 }, { 1, 3, 1, 2 }, { 1, 2, 1, 3 }, { 3, 1, 1, 2 } };
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  82 */   static final int[][] L_AND_G_PATTERNS = new int[20][]; static {
/*  83 */     System.arraycopy(L_PATTERNS, 0, L_AND_G_PATTERNS, 0, 10);
/*  84 */     for (int i = 10; i < 20; i++) {
/*  85 */       int[] widths = L_PATTERNS[i - 10];
/*  86 */       int[] reversedWidths = new int[widths.length];
/*  87 */       for (int j = 0; j < widths.length; j++) {
/*  88 */         reversedWidths[j] = widths[widths.length - j - 1];
/*     */       }
/*  90 */       L_AND_G_PATTERNS[i] = reversedWidths;
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  99 */   private final StringBuilder decodeRowStringBuffer = new StringBuilder(20);
/* 100 */   private final UPCEANExtensionSupport extensionReader = new UPCEANExtensionSupport();
/* 101 */   private final EANManufacturerOrgSupport eanManSupport = new EANManufacturerOrgSupport();
/*     */ 
/*     */   
/*     */   static int[] findStartGuardPattern(BitArray row) throws NotFoundException {
/* 105 */     boolean foundStart = false;
/* 106 */     int[] startRange = null;
/* 107 */     int nextStart = 0;
/* 108 */     int[] counters = new int[START_END_PATTERN.length];
/* 109 */     while (!foundStart) {
/* 110 */       Arrays.fill(counters, 0, START_END_PATTERN.length, 0);
/* 111 */       startRange = findGuardPattern(row, nextStart, false, START_END_PATTERN, counters);
/* 112 */       int start = startRange[0];
/* 113 */       nextStart = startRange[1];
/*     */ 
/*     */ 
/*     */       
/* 117 */       int quietStart = start - nextStart - start;
/* 118 */       if (quietStart >= 0) {
/* 119 */         foundStart = row.isRange(quietStart, start, false);
/*     */       }
/*     */     } 
/* 122 */     return startRange;
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   public Result decodeRow(int rowNumber, BitArray row, Map<DecodeHintType, ?> hints) throws NotFoundException, ChecksumException, FormatException {
/* 128 */     return decodeRow(rowNumber, row, findStartGuardPattern(row), hints);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Result decodeRow(int rowNumber, BitArray row, int[] startGuardRange, Map<DecodeHintType, ?> hints) throws NotFoundException, ChecksumException, FormatException {
/* 142 */     ResultPointCallback resultPointCallback = (hints == null) ? null : (ResultPointCallback)hints.get(DecodeHintType.NEED_RESULT_POINT_CALLBACK);
/*     */ 
/*     */     
/* 145 */     if (resultPointCallback != null) {
/* 146 */       resultPointCallback.foundPossibleResultPoint(new ResultPoint((startGuardRange[0] + startGuardRange[1]) / 2.0F, rowNumber));
/*     */     }
/*     */ 
/*     */ 
/*     */     
/* 151 */     StringBuilder result = this.decodeRowStringBuffer;
/* 152 */     result.setLength(0);
/* 153 */     int endStart = decodeMiddle(row, startGuardRange, result);
/*     */     
/* 155 */     if (resultPointCallback != null) {
/* 156 */       resultPointCallback.foundPossibleResultPoint(new ResultPoint(endStart, rowNumber));
/*     */     }
/*     */ 
/*     */ 
/*     */     
/* 161 */     int[] endRange = decodeEnd(row, endStart);
/*     */     
/* 163 */     if (resultPointCallback != null) {
/* 164 */       resultPointCallback.foundPossibleResultPoint(new ResultPoint((endRange[0] + endRange[1]) / 2.0F, rowNumber));
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 172 */     int end = endRange[1];
/* 173 */     int quietEnd = end + end - endRange[0];
/* 174 */     if (quietEnd >= row.getSize() || !row.isRange(end, quietEnd, false)) {
/* 175 */       throw NotFoundException.getNotFoundInstance();
/*     */     }
/*     */     
/* 178 */     String resultString = result.toString();
/* 179 */     if (!checkChecksum(resultString)) {
/* 180 */       throw ChecksumException.getChecksumInstance();
/*     */     }
/*     */     
/* 183 */     float left = (startGuardRange[1] + startGuardRange[0]) / 2.0F;
/* 184 */     float right = (endRange[1] + endRange[0]) / 2.0F;
/* 185 */     BarcodeFormat format = getBarcodeFormat();
/* 186 */     Result decodeResult = new Result(resultString, null, new ResultPoint[] { new ResultPoint(left, rowNumber), new ResultPoint(right, rowNumber) }format);
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     try {
/* 194 */       Result extensionResult = this.extensionReader.decodeRow(rowNumber, row, endRange[1]);
/* 195 */       decodeResult.putMetadata(ResultMetadataType.UPC_EAN_EXTENSION, extensionResult.getText());
/* 196 */       decodeResult.putAllMetadata(extensionResult.getResultMetadata());
/* 197 */       decodeResult.addResultPoints(extensionResult.getResultPoints());
/* 198 */     } catch (ReaderException re) {}
/*     */ 
/*     */ 
/*     */     
/* 202 */     if (format == BarcodeFormat.EAN_13 || format == BarcodeFormat.UPC_A) {
/* 203 */       String countryID = this.eanManSupport.lookupCountryIdentifier(resultString);
/* 204 */       if (countryID != null) {
/* 205 */         decodeResult.putMetadata(ResultMetadataType.POSSIBLE_COUNTRY, countryID);
/*     */       }
/*     */     } 
/*     */     
/* 209 */     return decodeResult;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   boolean checkChecksum(String s) throws ChecksumException, FormatException {
/* 216 */     return checkStandardUPCEANChecksum(s);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   static boolean checkStandardUPCEANChecksum(CharSequence s) throws FormatException {
/* 228 */     int length = s.length();
/* 229 */     if (length == 0) {
/* 230 */       return false;
/*     */     }
/*     */     
/* 233 */     int sum = 0; int i;
/* 234 */     for (i = length - 2; i >= 0; i -= 2) {
/* 235 */       int digit = s.charAt(i) - 48;
/* 236 */       if (digit < 0 || digit > 9) {
/* 237 */         throw FormatException.getFormatInstance();
/*     */       }
/* 239 */       sum += digit;
/*     */     } 
/* 241 */     sum *= 3;
/* 242 */     for (i = length - 1; i >= 0; i -= 2) {
/* 243 */       int digit = s.charAt(i) - 48;
/* 244 */       if (digit < 0 || digit > 9) {
/* 245 */         throw FormatException.getFormatInstance();
/*     */       }
/* 247 */       sum += digit;
/*     */     } 
/* 249 */     return (sum % 10 == 0);
/*     */   }
/*     */   
/*     */   int[] decodeEnd(BitArray row, int endStart) throws NotFoundException {
/* 253 */     return findGuardPattern(row, endStart, false, START_END_PATTERN);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   static int[] findGuardPattern(BitArray row, int rowOffset, boolean whiteFirst, int[] pattern) throws NotFoundException {
/* 260 */     return findGuardPattern(row, rowOffset, whiteFirst, pattern, new int[pattern.length]);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static int[] findGuardPattern(BitArray row, int rowOffset, boolean whiteFirst, int[] pattern, int[] counters) throws NotFoundException {
/* 279 */     int patternLength = pattern.length;
/* 280 */     int width = row.getSize();
/* 281 */     boolean isWhite = whiteFirst;
/* 282 */     rowOffset = whiteFirst ? row.getNextUnset(rowOffset) : row.getNextSet(rowOffset);
/* 283 */     int counterPosition = 0;
/* 284 */     int patternStart = rowOffset;
/* 285 */     for (int x = rowOffset; x < width; x++) {
/* 286 */       if (row.get(x) ^ isWhite) {
/* 287 */         counters[counterPosition] = counters[counterPosition] + 1;
/*     */       } else {
/* 289 */         if (counterPosition == patternLength - 1) {
/* 290 */           if (patternMatchVariance(counters, pattern, 179) < 122) {
/* 291 */             return new int[] { patternStart, x };
/*     */           }
/* 293 */           patternStart += counters[0] + counters[1];
/* 294 */           System.arraycopy(counters, 2, counters, 0, patternLength - 2);
/* 295 */           counters[patternLength - 2] = 0;
/* 296 */           counters[patternLength - 1] = 0;
/* 297 */           counterPosition--;
/*     */         } else {
/* 299 */           counterPosition++;
/*     */         } 
/* 301 */         counters[counterPosition] = 1;
/* 302 */         isWhite = !isWhite;
/*     */       } 
/*     */     } 
/* 305 */     throw NotFoundException.getNotFoundInstance();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   static int decodeDigit(BitArray row, int[] counters, int rowOffset, int[][] patterns) throws NotFoundException {
/* 322 */     recordPattern(row, rowOffset, counters);
/* 323 */     int bestVariance = 122;
/* 324 */     int bestMatch = -1;
/* 325 */     int max = patterns.length;
/* 326 */     for (int i = 0; i < max; i++) {
/* 327 */       int[] pattern = patterns[i];
/* 328 */       int variance = patternMatchVariance(counters, pattern, 179);
/* 329 */       if (variance < bestVariance) {
/* 330 */         bestVariance = variance;
/* 331 */         bestMatch = i;
/*     */       } 
/*     */     } 
/* 334 */     if (bestMatch >= 0) {
/* 335 */       return bestMatch;
/*     */     }
/* 337 */     throw NotFoundException.getNotFoundInstance();
/*     */   }
/*     */   
/*     */   abstract BarcodeFormat getBarcodeFormat();
/*     */   
/*     */   protected abstract int decodeMiddle(BitArray paramBitArray, int[] paramArrayOfint, StringBuilder paramStringBuilder) throws NotFoundException;
/*     */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\com\google\zxing\oned\UPCEANReader.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       1.1.3
 */