/*     */ package com.google.zxing.oned.rss.expanded;
/*     */ 
/*     */ import com.google.zxing.BarcodeFormat;
/*     */ import com.google.zxing.DecodeHintType;
/*     */ import com.google.zxing.NotFoundException;
/*     */ import com.google.zxing.Result;
/*     */ import com.google.zxing.ResultPoint;
/*     */ import com.google.zxing.common.BitArray;
/*     */ import com.google.zxing.oned.rss.AbstractRSSReader;
/*     */ import com.google.zxing.oned.rss.DataCharacter;
/*     */ import com.google.zxing.oned.rss.FinderPattern;
/*     */ import com.google.zxing.oned.rss.RSSUtils;
/*     */ import com.google.zxing.oned.rss.expanded.decoders.AbstractExpandedDecoder;
/*     */ import java.util.ArrayList;
/*     */ import java.util.Collections;
/*     */ import java.util.Iterator;
/*     */ import java.util.List;
/*     */ import java.util.Map;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public final class RSSExpandedReader
/*     */   extends AbstractRSSReader
/*     */ {
/*  53 */   private static final int[] SYMBOL_WIDEST = new int[] { 7, 5, 4, 3, 1 };
/*  54 */   private static final int[] EVEN_TOTAL_SUBSET = new int[] { 4, 20, 52, 104, 204 };
/*  55 */   private static final int[] GSUM = new int[] { 0, 348, 1388, 2948, 3988 };
/*     */   
/*  57 */   private static final int[][] FINDER_PATTERNS = new int[][] { { 1, 8, 4, 1 }, { 3, 6, 4, 1 }, { 3, 4, 6, 1 }, { 3, 2, 8, 1 }, { 2, 6, 5, 1 }, { 2, 2, 9, 1 } };
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  66 */   private static final int[][] WEIGHTS = new int[][] { { 1, 3, 9, 27, 81, 32, 96, 77 }, { 20, 60, 180, 118, 143, 7, 21, 63 }, { 189, 145, 13, 39, 117, 140, 209, 205 }, { 193, 157, 49, 147, 19, 57, 171, 91 }, { 62, 186, 136, 197, 169, 85, 44, 132 }, { 185, 133, 188, 142, 4, 12, 36, 108 }, { 113, 128, 173, 97, 80, 29, 87, 50 }, { 150, 28, 84, 41, 123, 158, 52, 156 }, { 46, 138, 203, 187, 139, 206, 196, 166 }, { 76, 17, 51, 153, 37, 111, 122, 155 }, { 43, 129, 176, 106, 107, 110, 119, 146 }, { 16, 48, 144, 10, 30, 90, 59, 177 }, { 109, 116, 137, 200, 178, 112, 125, 164 }, { 70, 210, 208, 202, 184, 130, 179, 115 }, { 134, 191, 151, 31, 93, 68, 204, 190 }, { 148, 22, 66, 198, 172, 94, 71, 2 }, { 6, 18, 54, 162, 64, 192, 154, 40 }, { 120, 149, 25, 75, 14, 42, 126, 167 }, { 79, 26, 78, 23, 69, 207, 199, 175 }, { 103, 98, 83, 38, 114, 131, 182, 124 }, { 161, 61, 183, 127, 170, 88, 53, 159 }, { 55, 165, 73, 8, 24, 72, 5, 15 }, { 45, 135, 194, 160, 58, 174, 100, 89 } };
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static final int FINDER_PAT_A = 0;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static final int FINDER_PAT_B = 1;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static final int FINDER_PAT_C = 2;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static final int FINDER_PAT_D = 3;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static final int FINDER_PAT_E = 4;
/*     */ 
/*     */ 
/*     */   
/*     */   private static final int FINDER_PAT_F = 5;
/*     */ 
/*     */ 
/*     */   
/*  99 */   private static final int[][] FINDER_PATTERN_SEQUENCES = new int[][] { { 0, 0 }, { 0, 1, 1 }, { 0, 2, 1, 3 }, { 0, 4, 1, 3, 2 }, { 0, 4, 1, 3, 3, 5 }, { 0, 4, 1, 3, 4, 5, 5 }, { 0, 0, 1, 1, 2, 2, 3, 3 }, { 0, 0, 1, 1, 2, 2, 3, 4, 4 }, { 0, 0, 1, 1, 2, 2, 3, 4, 5, 5 }, { 0, 0, 1, 1, 2, 3, 3, 4, 4, 5, 5 } };
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static final int MAX_PAIRS = 11;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 116 */   private final List<ExpandedPair> pairs = new ArrayList<ExpandedPair>(11);
/* 117 */   private final List<ExpandedRow> rows = new ArrayList<ExpandedRow>();
/* 118 */   private final int[] startEnd = new int[2];
/*     */ 
/*     */ 
/*     */   
/*     */   private boolean startFromEven = false;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Result decodeRow(int rowNumber, BitArray row, Map<DecodeHintType, ?> hints) throws NotFoundException {
/* 128 */     this.pairs.clear();
/* 129 */     this.startFromEven = false;
/*     */     try {
/* 131 */       List<ExpandedPair> pairs = decodeRow2pairs(rowNumber, row);
/* 132 */       return constructResult(pairs);
/* 133 */     } catch (NotFoundException e) {
/*     */ 
/*     */ 
/*     */       
/* 137 */       this.pairs.clear();
/* 138 */       this.startFromEven = true;
/* 139 */       List<ExpandedPair> pairs = decodeRow2pairs(rowNumber, row);
/* 140 */       return constructResult(pairs);
/*     */     } 
/*     */   }
/*     */   
/*     */   public void reset() {
/* 145 */     this.pairs.clear();
/* 146 */     this.rows.clear();
/*     */   }
/*     */ 
/*     */   
/*     */   List<ExpandedPair> decodeRow2pairs(int rowNumber, BitArray row) throws NotFoundException {
/*     */     try {
/*     */       while (true) {
/* 153 */         ExpandedPair nextPair = retrieveNextPair(row, this.pairs, rowNumber);
/* 154 */         this.pairs.add(nextPair);
/*     */       }
/*     */     
/*     */     }
/* 158 */     catch (NotFoundException nfe) {
/* 159 */       if (this.pairs.isEmpty()) {
/* 160 */         throw nfe;
/*     */       }
/*     */ 
/*     */ 
/*     */       
/* 165 */       if (checkChecksum()) {
/* 166 */         return this.pairs;
/*     */       }
/*     */       
/* 169 */       boolean tryStackedDecode = !this.rows.isEmpty();
/* 170 */       boolean wasReversed = false;
/* 171 */       storeRow(rowNumber, wasReversed);
/* 172 */       if (tryStackedDecode) {
/*     */ 
/*     */         
/* 175 */         List<ExpandedPair> ps = checkRows(false);
/* 176 */         if (ps != null) {
/* 177 */           return ps;
/*     */         }
/* 179 */         ps = checkRows(true);
/* 180 */         if (ps != null) {
/* 181 */           return ps;
/*     */         }
/*     */       } 
/*     */       
/* 185 */       throw NotFoundException.getNotFoundInstance();
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   private List<ExpandedPair> checkRows(boolean reverse) {
/* 192 */     if (this.rows.size() > 25) {
/* 193 */       this.rows.clear();
/* 194 */       return null;
/*     */     } 
/*     */     
/* 197 */     this.pairs.clear();
/* 198 */     if (reverse) {
/* 199 */       Collections.reverse(this.rows);
/*     */     }
/*     */     
/* 202 */     List<ExpandedPair> ps = null;
/*     */     try {
/* 204 */       ps = checkRows(new ArrayList<ExpandedRow>(), 0);
/* 205 */     } catch (NotFoundException e) {}
/*     */ 
/*     */ 
/*     */     
/* 209 */     if (reverse) {
/* 210 */       Collections.reverse(this.rows);
/*     */     }
/*     */     
/* 213 */     return ps;
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   private List<ExpandedPair> checkRows(List<ExpandedRow> collectedRows, int currentRow) throws NotFoundException {
/* 219 */     for (int i = currentRow; i < this.rows.size(); i++) {
/* 220 */       ExpandedRow row = this.rows.get(i);
/* 221 */       this.pairs.clear();
/* 222 */       int size = collectedRows.size();
/* 223 */       for (int j = 0; j < size; j++) {
/* 224 */         this.pairs.addAll(((ExpandedRow)collectedRows.get(j)).getPairs());
/*     */       }
/* 226 */       this.pairs.addAll(row.getPairs());
/*     */       
/* 228 */       if (isValidSequence(this.pairs)) {
/*     */ 
/*     */ 
/*     */         
/* 232 */         if (checkChecksum()) {
/* 233 */           return this.pairs;
/*     */         }
/*     */         
/* 236 */         List<ExpandedRow> rs = new ArrayList<ExpandedRow>();
/* 237 */         rs.addAll(collectedRows);
/* 238 */         rs.add(row);
/*     */         
/*     */         try {
/* 241 */           return checkRows(rs, i + 1);
/* 242 */         } catch (NotFoundException e) {}
/*     */       } 
/*     */     } 
/*     */ 
/*     */     
/* 247 */     throw NotFoundException.getNotFoundInstance();
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   private static boolean isValidSequence(List<ExpandedPair> pairs) {
/* 253 */     for (int[] sequence : FINDER_PATTERN_SEQUENCES) {
/* 254 */       if (pairs.size() <= sequence.length) {
/*     */ 
/*     */ 
/*     */         
/* 258 */         boolean stop = true;
/* 259 */         for (int j = 0; j < pairs.size(); j++) {
/* 260 */           if (((ExpandedPair)pairs.get(j)).getFinderPattern().getValue() != sequence[j]) {
/* 261 */             stop = false;
/*     */             
/*     */             break;
/*     */           } 
/*     */         } 
/* 266 */         if (stop) {
/* 267 */           return true;
/*     */         }
/*     */       } 
/*     */     } 
/* 271 */     return false;
/*     */   }
/*     */ 
/*     */   
/*     */   private void storeRow(int rowNumber, boolean wasReversed) {
/* 276 */     int insertPos = 0;
/* 277 */     boolean prevIsSame = false;
/* 278 */     boolean nextIsSame = false;
/* 279 */     while (insertPos < this.rows.size()) {
/* 280 */       ExpandedRow erow = this.rows.get(insertPos);
/* 281 */       if (erow.getRowNumber() > rowNumber) {
/* 282 */         nextIsSame = erow.isEquivalent(this.pairs);
/*     */         break;
/*     */       } 
/* 285 */       prevIsSame = erow.isEquivalent(this.pairs);
/* 286 */       insertPos++;
/*     */     } 
/* 288 */     if (nextIsSame || prevIsSame) {
/*     */       return;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 297 */     if (isPartialRow(this.pairs, this.rows)) {
/*     */       return;
/*     */     }
/*     */     
/* 301 */     this.rows.add(insertPos, new ExpandedRow(this.pairs, rowNumber, wasReversed));
/*     */     
/* 303 */     removePartialRows(this.pairs, this.rows);
/*     */   }
/*     */ 
/*     */   
/*     */   private static void removePartialRows(List<ExpandedPair> pairs, List<ExpandedRow> rows) {
/* 308 */     for (Iterator<ExpandedRow> iterator = rows.iterator(); iterator.hasNext(); ) {
/* 309 */       ExpandedRow r = iterator.next();
/* 310 */       if (r.getPairs().size() == pairs.size()) {
/*     */         continue;
/*     */       }
/* 313 */       boolean allFound = true;
/* 314 */       for (ExpandedPair p : r.getPairs()) {
/* 315 */         boolean found = false;
/* 316 */         for (ExpandedPair pp : pairs) {
/* 317 */           if (p.equals(pp)) {
/* 318 */             found = true;
/*     */             break;
/*     */           } 
/*     */         } 
/* 322 */         if (!found) {
/* 323 */           allFound = false;
/*     */           break;
/*     */         } 
/*     */       } 
/* 327 */       if (allFound)
/*     */       {
/* 329 */         iterator.remove();
/*     */       }
/*     */     } 
/*     */   }
/*     */ 
/*     */   
/*     */   private static boolean isPartialRow(Iterable<ExpandedPair> pairs, Iterable<ExpandedRow> rows) {
/* 336 */     for (ExpandedRow r : rows) {
/* 337 */       boolean allFound = true;
/* 338 */       for (ExpandedPair p : pairs) {
/* 339 */         boolean found = false;
/* 340 */         for (ExpandedPair pp : r.getPairs()) {
/* 341 */           if (p.equals(pp)) {
/* 342 */             found = true;
/*     */             break;
/*     */           } 
/*     */         } 
/* 346 */         if (!found) {
/* 347 */           allFound = false;
/*     */           break;
/*     */         } 
/*     */       } 
/* 351 */       if (allFound)
/*     */       {
/* 353 */         return true;
/*     */       }
/*     */     } 
/* 356 */     return false;
/*     */   }
/*     */ 
/*     */   
/*     */   List<ExpandedRow> getRows() {
/* 361 */     return this.rows;
/*     */   }
/*     */ 
/*     */   
/*     */   static Result constructResult(List<ExpandedPair> pairs) throws NotFoundException {
/* 366 */     BitArray binary = BitArrayBuilder.buildBitArray(pairs);
/*     */     
/* 368 */     AbstractExpandedDecoder decoder = AbstractExpandedDecoder.createDecoder(binary);
/* 369 */     String resultingString = decoder.parseInformation();
/*     */     
/* 371 */     ResultPoint[] firstPoints = ((ExpandedPair)pairs.get(0)).getFinderPattern().getResultPoints();
/* 372 */     ResultPoint[] lastPoints = ((ExpandedPair)pairs.get(pairs.size() - 1)).getFinderPattern().getResultPoints();
/*     */     
/* 374 */     return new Result(resultingString, null, new ResultPoint[] { firstPoints[0], firstPoints[1], lastPoints[0], lastPoints[1] }, BarcodeFormat.RSS_EXPANDED);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private boolean checkChecksum() {
/* 383 */     ExpandedPair firstPair = this.pairs.get(0);
/* 384 */     DataCharacter checkCharacter = firstPair.getLeftChar();
/* 385 */     DataCharacter firstCharacter = firstPair.getRightChar();
/*     */     
/* 387 */     if (firstCharacter == null) {
/* 388 */       return false;
/*     */     }
/*     */     
/* 391 */     int checksum = firstCharacter.getChecksumPortion();
/* 392 */     int s = 2;
/*     */     
/* 394 */     for (int i = 1; i < this.pairs.size(); i++) {
/* 395 */       ExpandedPair currentPair = this.pairs.get(i);
/* 396 */       checksum += currentPair.getLeftChar().getChecksumPortion();
/* 397 */       s++;
/* 398 */       DataCharacter currentRightChar = currentPair.getRightChar();
/* 399 */       if (currentRightChar != null) {
/* 400 */         checksum += currentRightChar.getChecksumPortion();
/* 401 */         s++;
/*     */       } 
/*     */     } 
/*     */     
/* 405 */     checksum %= 211;
/*     */     
/* 407 */     int checkCharacterValue = 211 * (s - 4) + checksum;
/*     */     
/* 409 */     return (checkCharacterValue == checkCharacter.getValue());
/*     */   }
/*     */   
/*     */   private static int getNextSecondBar(BitArray row, int initialPos) {
/*     */     int currentPos;
/* 414 */     if (row.get(initialPos)) {
/* 415 */       currentPos = row.getNextUnset(initialPos);
/* 416 */       currentPos = row.getNextSet(currentPos);
/*     */     } else {
/* 418 */       currentPos = row.getNextSet(initialPos);
/* 419 */       currentPos = row.getNextUnset(currentPos);
/*     */     } 
/* 421 */     return currentPos;
/*     */   }
/*     */   
/*     */   ExpandedPair retrieveNextPair(BitArray row, List<ExpandedPair> previousPairs, int rowNumber) throws NotFoundException {
/*     */     FinderPattern pattern;
/*     */     DataCharacter dataCharacter1;
/* 427 */     boolean isOddPattern = (previousPairs.size() % 2 == 0);
/* 428 */     if (this.startFromEven) {
/* 429 */       isOddPattern = !isOddPattern;
/*     */     }
/*     */ 
/*     */ 
/*     */     
/* 434 */     boolean keepFinding = true;
/* 435 */     int forcedOffset = -1;
/*     */     do {
/* 437 */       findNextPair(row, previousPairs, forcedOffset);
/* 438 */       pattern = parseFoundFinderPattern(row, rowNumber, isOddPattern);
/* 439 */       if (pattern == null) {
/* 440 */         forcedOffset = getNextSecondBar(row, this.startEnd[0]);
/*     */       } else {
/* 442 */         keepFinding = false;
/*     */       } 
/* 444 */     } while (keepFinding);
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 449 */     DataCharacter leftChar = decodeDataCharacter(row, pattern, isOddPattern, true);
/*     */     
/* 451 */     if (!previousPairs.isEmpty() && ((ExpandedPair)previousPairs.get(previousPairs.size() - 1)).mustBeLast()) {
/* 452 */       throw NotFoundException.getNotFoundInstance();
/*     */     }
/*     */ 
/*     */     
/*     */     try {
/* 457 */       dataCharacter1 = decodeDataCharacter(row, pattern, isOddPattern, false);
/* 458 */     } catch (NotFoundException ignored) {
/* 459 */       dataCharacter1 = null;
/*     */     } 
/* 461 */     boolean mayBeLast = true;
/* 462 */     return new ExpandedPair(leftChar, dataCharacter1, pattern, mayBeLast);
/*     */   }
/*     */ 
/*     */   
/*     */   private void findNextPair(BitArray row, List<ExpandedPair> previousPairs, int forcedOffset) throws NotFoundException {
/* 467 */     int rowOffset, counters[] = getDecodeFinderCounters();
/* 468 */     counters[0] = 0;
/* 469 */     counters[1] = 0;
/* 470 */     counters[2] = 0;
/* 471 */     counters[3] = 0;
/*     */     
/* 473 */     int width = row.getSize();
/*     */ 
/*     */     
/* 476 */     if (forcedOffset >= 0) {
/* 477 */       rowOffset = forcedOffset;
/* 478 */     } else if (previousPairs.isEmpty()) {
/* 479 */       rowOffset = 0;
/*     */     } else {
/* 481 */       ExpandedPair lastPair = previousPairs.get(previousPairs.size() - 1);
/* 482 */       rowOffset = lastPair.getFinderPattern().getStartEnd()[1];
/*     */     } 
/* 484 */     boolean searchingEvenPair = (previousPairs.size() % 2 != 0);
/* 485 */     if (this.startFromEven) {
/* 486 */       searchingEvenPair = !searchingEvenPair;
/*     */     }
/*     */     
/* 489 */     boolean isWhite = false;
/* 490 */     while (rowOffset < width) {
/* 491 */       isWhite = !row.get(rowOffset);
/* 492 */       if (!isWhite) {
/*     */         break;
/*     */       }
/* 495 */       rowOffset++;
/*     */     } 
/*     */     
/* 498 */     int counterPosition = 0;
/* 499 */     int patternStart = rowOffset;
/* 500 */     for (int x = rowOffset; x < width; x++) {
/* 501 */       if (row.get(x) ^ isWhite) {
/* 502 */         counters[counterPosition] = counters[counterPosition] + 1;
/*     */       } else {
/* 504 */         if (counterPosition == 3) {
/* 505 */           if (searchingEvenPair) {
/* 506 */             reverseCounters(counters);
/*     */           }
/*     */           
/* 509 */           if (isFinderPattern(counters)) {
/* 510 */             this.startEnd[0] = patternStart;
/* 511 */             this.startEnd[1] = x;
/*     */             
/*     */             return;
/*     */           } 
/* 515 */           if (searchingEvenPair) {
/* 516 */             reverseCounters(counters);
/*     */           }
/*     */           
/* 519 */           patternStart += counters[0] + counters[1];
/* 520 */           counters[0] = counters[2];
/* 521 */           counters[1] = counters[3];
/* 522 */           counters[2] = 0;
/* 523 */           counters[3] = 0;
/* 524 */           counterPosition--;
/*     */         } else {
/* 526 */           counterPosition++;
/*     */         } 
/* 528 */         counters[counterPosition] = 1;
/* 529 */         isWhite = !isWhite;
/*     */       } 
/*     */     } 
/* 532 */     throw NotFoundException.getNotFoundInstance();
/*     */   }
/*     */   
/*     */   private static void reverseCounters(int[] counters) {
/* 536 */     int length = counters.length;
/* 537 */     for (int i = 0; i < length / 2; i++) {
/* 538 */       int tmp = counters[i];
/* 539 */       counters[i] = counters[length - i - 1];
/* 540 */       counters[length - i - 1] = tmp;
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private FinderPattern parseFoundFinderPattern(BitArray row, int rowNumber, boolean oddPattern) {
/*     */     int firstCounter, start, end, value;
/* 550 */     if (oddPattern) {
/*     */ 
/*     */       
/* 553 */       int firstElementStart = this.startEnd[0] - 1;
/*     */       
/* 555 */       while (firstElementStart >= 0 && !row.get(firstElementStart)) {
/* 556 */         firstElementStart--;
/*     */       }
/*     */       
/* 559 */       firstElementStart++;
/* 560 */       firstCounter = this.startEnd[0] - firstElementStart;
/* 561 */       start = firstElementStart;
/* 562 */       end = this.startEnd[1];
/*     */     
/*     */     }
/*     */     else {
/*     */       
/* 567 */       start = this.startEnd[0];
/*     */       
/* 569 */       end = row.getNextUnset(this.startEnd[1] + 1);
/* 570 */       firstCounter = end - this.startEnd[1];
/*     */     } 
/*     */ 
/*     */     
/* 574 */     int[] counters = getDecodeFinderCounters();
/* 575 */     System.arraycopy(counters, 0, counters, 1, counters.length - 1);
/*     */     
/* 577 */     counters[0] = firstCounter;
/*     */     
/*     */     try {
/* 580 */       value = parseFinderValue(counters, FINDER_PATTERNS);
/* 581 */     } catch (NotFoundException ignored) {
/* 582 */       return null;
/*     */     } 
/* 584 */     return new FinderPattern(value, new int[] { start, end }, start, end, rowNumber);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   DataCharacter decodeDataCharacter(BitArray row, FinderPattern pattern, boolean isOddPattern, boolean leftChar) throws NotFoundException {
/* 591 */     int[] counters = getDataCharacterCounters();
/* 592 */     counters[0] = 0;
/* 593 */     counters[1] = 0;
/* 594 */     counters[2] = 0;
/* 595 */     counters[3] = 0;
/* 596 */     counters[4] = 0;
/* 597 */     counters[5] = 0;
/* 598 */     counters[6] = 0;
/* 599 */     counters[7] = 0;
/*     */     
/* 601 */     if (leftChar) {
/* 602 */       recordPatternInReverse(row, pattern.getStartEnd()[0], counters);
/*     */     } else {
/* 604 */       recordPattern(row, pattern.getStartEnd()[1], counters);
/*     */       
/* 606 */       for (int m = 0, n = counters.length - 1; m < n; m++, n--) {
/* 607 */         int temp = counters[m];
/* 608 */         counters[m] = counters[n];
/* 609 */         counters[n] = temp;
/*     */       } 
/*     */     } 
/*     */     
/* 613 */     int numModules = 17;
/* 614 */     float elementWidth = count(counters) / numModules;
/*     */ 
/*     */     
/* 617 */     float expectedElementWidth = (pattern.getStartEnd()[1] - pattern.getStartEnd()[0]) / 15.0F;
/* 618 */     if (Math.abs(elementWidth - expectedElementWidth) / expectedElementWidth > 0.3F) {
/* 619 */       throw NotFoundException.getNotFoundInstance();
/*     */     }
/*     */     
/* 622 */     int[] oddCounts = getOddCounts();
/* 623 */     int[] evenCounts = getEvenCounts();
/* 624 */     float[] oddRoundingErrors = getOddRoundingErrors();
/* 625 */     float[] evenRoundingErrors = getEvenRoundingErrors();
/*     */     
/* 627 */     for (int i = 0; i < counters.length; i++) {
/* 628 */       float f = 1.0F * counters[i] / elementWidth;
/* 629 */       int count = (int)(f + 0.5F);
/* 630 */       if (count < 1) {
/* 631 */         if (f < 0.3F) {
/* 632 */           throw NotFoundException.getNotFoundInstance();
/*     */         }
/* 634 */         count = 1;
/* 635 */       } else if (count > 8) {
/* 636 */         if (f > 8.7F) {
/* 637 */           throw NotFoundException.getNotFoundInstance();
/*     */         }
/* 639 */         count = 8;
/*     */       } 
/* 641 */       int offset = i >> 1;
/* 642 */       if ((i & 0x1) == 0) {
/* 643 */         oddCounts[offset] = count;
/* 644 */         oddRoundingErrors[offset] = f - count;
/*     */       } else {
/* 646 */         evenCounts[offset] = count;
/* 647 */         evenRoundingErrors[offset] = f - count;
/*     */       } 
/*     */     } 
/*     */     
/* 651 */     adjustOddEvenCounts(numModules);
/*     */     
/* 653 */     int weightRowNumber = 4 * pattern.getValue() + (isOddPattern ? 0 : 2) + (leftChar ? 0 : 1) - 1;
/*     */     
/* 655 */     int oddSum = 0;
/* 656 */     int oddChecksumPortion = 0;
/* 657 */     for (int j = oddCounts.length - 1; j >= 0; j--) {
/* 658 */       if (isNotA1left(pattern, isOddPattern, leftChar)) {
/* 659 */         int weight = WEIGHTS[weightRowNumber][2 * j];
/* 660 */         oddChecksumPortion += oddCounts[j] * weight;
/*     */       } 
/* 662 */       oddSum += oddCounts[j];
/*     */     } 
/* 664 */     int evenChecksumPortion = 0;
/*     */     
/* 666 */     for (int k = evenCounts.length - 1; k >= 0; k--) {
/* 667 */       if (isNotA1left(pattern, isOddPattern, leftChar)) {
/* 668 */         int weight = WEIGHTS[weightRowNumber][2 * k + 1];
/* 669 */         evenChecksumPortion += evenCounts[k] * weight;
/*     */       } 
/*     */     } 
/*     */     
/* 673 */     int checksumPortion = oddChecksumPortion + evenChecksumPortion;
/*     */     
/* 675 */     if ((oddSum & 0x1) != 0 || oddSum > 13 || oddSum < 4) {
/* 676 */       throw NotFoundException.getNotFoundInstance();
/*     */     }
/*     */     
/* 679 */     int group = (13 - oddSum) / 2;
/* 680 */     int oddWidest = SYMBOL_WIDEST[group];
/* 681 */     int evenWidest = 9 - oddWidest;
/* 682 */     int vOdd = RSSUtils.getRSSvalue(oddCounts, oddWidest, true);
/* 683 */     int vEven = RSSUtils.getRSSvalue(evenCounts, evenWidest, false);
/* 684 */     int tEven = EVEN_TOTAL_SUBSET[group];
/* 685 */     int gSum = GSUM[group];
/* 686 */     int value = vOdd * tEven + vEven + gSum;
/*     */     
/* 688 */     return new DataCharacter(value, checksumPortion);
/*     */   }
/*     */ 
/*     */   
/*     */   private static boolean isNotA1left(FinderPattern pattern, boolean isOddPattern, boolean leftChar) {
/* 693 */     return (pattern.getValue() != 0 || !isOddPattern || !leftChar);
/*     */   }
/*     */ 
/*     */   
/*     */   private void adjustOddEvenCounts(int numModules) throws NotFoundException {
/* 698 */     int oddSum = count(getOddCounts());
/* 699 */     int evenSum = count(getEvenCounts());
/* 700 */     int mismatch = oddSum + evenSum - numModules;
/* 701 */     boolean oddParityBad = ((oddSum & 0x1) == 1);
/* 702 */     boolean evenParityBad = ((evenSum & 0x1) == 0);
/*     */     
/* 704 */     boolean incrementOdd = false;
/* 705 */     boolean decrementOdd = false;
/*     */     
/* 707 */     if (oddSum > 13) {
/* 708 */       decrementOdd = true;
/* 709 */     } else if (oddSum < 4) {
/* 710 */       incrementOdd = true;
/*     */     } 
/* 712 */     boolean incrementEven = false;
/* 713 */     boolean decrementEven = false;
/* 714 */     if (evenSum > 13) {
/* 715 */       decrementEven = true;
/* 716 */     } else if (evenSum < 4) {
/* 717 */       incrementEven = true;
/*     */     } 
/*     */     
/* 720 */     if (mismatch == 1) {
/* 721 */       if (oddParityBad) {
/* 722 */         if (evenParityBad) {
/* 723 */           throw NotFoundException.getNotFoundInstance();
/*     */         }
/* 725 */         decrementOdd = true;
/*     */       } else {
/* 727 */         if (!evenParityBad) {
/* 728 */           throw NotFoundException.getNotFoundInstance();
/*     */         }
/* 730 */         decrementEven = true;
/*     */       } 
/* 732 */     } else if (mismatch == -1) {
/* 733 */       if (oddParityBad) {
/* 734 */         if (evenParityBad) {
/* 735 */           throw NotFoundException.getNotFoundInstance();
/*     */         }
/* 737 */         incrementOdd = true;
/*     */       } else {
/* 739 */         if (!evenParityBad) {
/* 740 */           throw NotFoundException.getNotFoundInstance();
/*     */         }
/* 742 */         incrementEven = true;
/*     */       } 
/* 744 */     } else if (mismatch == 0) {
/* 745 */       if (oddParityBad) {
/* 746 */         if (!evenParityBad) {
/* 747 */           throw NotFoundException.getNotFoundInstance();
/*     */         }
/*     */         
/* 750 */         if (oddSum < evenSum) {
/* 751 */           incrementOdd = true;
/* 752 */           decrementEven = true;
/*     */         } else {
/* 754 */           decrementOdd = true;
/* 755 */           incrementEven = true;
/*     */         }
/*     */       
/* 758 */       } else if (evenParityBad) {
/* 759 */         throw NotFoundException.getNotFoundInstance();
/*     */       }
/*     */     
/*     */     } else {
/*     */       
/* 764 */       throw NotFoundException.getNotFoundInstance();
/*     */     } 
/*     */     
/* 767 */     if (incrementOdd) {
/* 768 */       if (decrementOdd) {
/* 769 */         throw NotFoundException.getNotFoundInstance();
/*     */       }
/* 771 */       increment(getOddCounts(), getOddRoundingErrors());
/*     */     } 
/* 773 */     if (decrementOdd) {
/* 774 */       decrement(getOddCounts(), getOddRoundingErrors());
/*     */     }
/* 776 */     if (incrementEven) {
/* 777 */       if (decrementEven) {
/* 778 */         throw NotFoundException.getNotFoundInstance();
/*     */       }
/* 780 */       increment(getEvenCounts(), getOddRoundingErrors());
/*     */     } 
/* 782 */     if (decrementEven)
/* 783 */       decrement(getEvenCounts(), getEvenRoundingErrors()); 
/*     */   }
/*     */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\com\google\zxing\oned\rss\expanded\RSSExpandedReader.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       1.1.3
 */