/*     */ package com.google.zxing.oned.rss.expanded.decoders;
/*     */ 
/*     */ import com.google.zxing.NotFoundException;
/*     */ import com.google.zxing.common.BitArray;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ final class GeneralAppIdDecoder
/*     */ {
/*     */   private final BitArray information;
/*  39 */   private final CurrentParsingState current = new CurrentParsingState();
/*  40 */   private final StringBuilder buffer = new StringBuilder();
/*     */   
/*     */   GeneralAppIdDecoder(BitArray information) {
/*  43 */     this.information = information;
/*     */   }
/*     */   
/*     */   String decodeAllCodes(StringBuilder buff, int initialPosition) throws NotFoundException {
/*  47 */     int currentPosition = initialPosition;
/*  48 */     String remaining = null;
/*     */     while (true) {
/*  50 */       DecodedInformation info = decodeGeneralPurposeField(currentPosition, remaining);
/*  51 */       String parsedFields = FieldParser.parseFieldsInGeneralPurpose(info.getNewString());
/*  52 */       if (parsedFields != null) {
/*  53 */         buff.append(parsedFields);
/*     */       }
/*  55 */       if (info.isRemaining()) {
/*  56 */         remaining = String.valueOf(info.getRemainingValue());
/*     */       } else {
/*  58 */         remaining = null;
/*     */       } 
/*     */       
/*  61 */       if (currentPosition == info.getNewPosition()) {
/*     */         break;
/*     */       }
/*  64 */       currentPosition = info.getNewPosition();
/*     */     } 
/*     */     
/*  67 */     return buff.toString();
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   private boolean isStillNumeric(int pos) {
/*  73 */     if (pos + 7 > this.information.getSize()) {
/*  74 */       return (pos + 4 <= this.information.getSize());
/*     */     }
/*     */     
/*  77 */     for (int i = pos; i < pos + 3; i++) {
/*  78 */       if (this.information.get(i)) {
/*  79 */         return true;
/*     */       }
/*     */     } 
/*     */     
/*  83 */     return this.information.get(pos + 3);
/*     */   }
/*     */   
/*     */   private DecodedNumeric decodeNumeric(int pos) {
/*  87 */     if (pos + 7 > this.information.getSize()) {
/*  88 */       int i = extractNumericValueFromBitArray(pos, 4);
/*  89 */       if (i == 0) {
/*  90 */         return new DecodedNumeric(this.information.getSize(), 10, 10);
/*     */       }
/*  92 */       return new DecodedNumeric(this.information.getSize(), i - 1, 10);
/*     */     } 
/*  94 */     int numeric = extractNumericValueFromBitArray(pos, 7);
/*     */     
/*  96 */     int digit1 = (numeric - 8) / 11;
/*  97 */     int digit2 = (numeric - 8) % 11;
/*     */     
/*  99 */     return new DecodedNumeric(pos + 7, digit1, digit2);
/*     */   }
/*     */   
/*     */   int extractNumericValueFromBitArray(int pos, int bits) {
/* 103 */     return extractNumericValueFromBitArray(this.information, pos, bits);
/*     */   }
/*     */   
/*     */   static int extractNumericValueFromBitArray(BitArray information, int pos, int bits) {
/* 107 */     if (bits > 32) {
/* 108 */       throw new IllegalArgumentException("extractNumberValueFromBitArray can't handle more than 32 bits");
/*     */     }
/*     */     
/* 111 */     int value = 0;
/* 112 */     for (int i = 0; i < bits; i++) {
/* 113 */       if (information.get(pos + i)) {
/* 114 */         value |= 1 << bits - i - 1;
/*     */       }
/*     */     } 
/*     */     
/* 118 */     return value;
/*     */   }
/*     */   
/*     */   DecodedInformation decodeGeneralPurposeField(int pos, String remaining) {
/* 122 */     this.buffer.setLength(0);
/*     */     
/* 124 */     if (remaining != null) {
/* 125 */       this.buffer.append(remaining);
/*     */     }
/*     */     
/* 128 */     this.current.setPosition(pos);
/*     */     
/* 130 */     DecodedInformation lastDecoded = parseBlocks();
/* 131 */     if (lastDecoded != null && lastDecoded.isRemaining()) {
/* 132 */       return new DecodedInformation(this.current.getPosition(), this.buffer.toString(), lastDecoded.getRemainingValue());
/*     */     }
/* 134 */     return new DecodedInformation(this.current.getPosition(), this.buffer.toString());
/*     */   }
/*     */   
/*     */   private DecodedInformation parseBlocks() {
/*     */     boolean isFinished;
/*     */     BlockParsedResult result;
/*     */     do {
/* 141 */       int initialPosition = this.current.getPosition();
/*     */       
/* 143 */       if (this.current.isAlpha()) {
/* 144 */         result = parseAlphaBlock();
/* 145 */         isFinished = result.isFinished();
/* 146 */       } else if (this.current.isIsoIec646()) {
/* 147 */         result = parseIsoIec646Block();
/* 148 */         isFinished = result.isFinished();
/*     */       } else {
/* 150 */         result = parseNumericBlock();
/* 151 */         isFinished = result.isFinished();
/*     */       } 
/*     */       
/* 154 */       boolean positionChanged = (initialPosition != this.current.getPosition());
/* 155 */       if (!positionChanged && !isFinished) {
/*     */         break;
/*     */       }
/* 158 */     } while (!isFinished);
/*     */     
/* 160 */     return result.getDecodedInformation();
/*     */   }
/*     */   
/*     */   private BlockParsedResult parseNumericBlock() {
/* 164 */     while (isStillNumeric(this.current.getPosition())) {
/* 165 */       DecodedNumeric numeric = decodeNumeric(this.current.getPosition());
/* 166 */       this.current.setPosition(numeric.getNewPosition());
/*     */       
/* 168 */       if (numeric.isFirstDigitFNC1()) {
/*     */         DecodedInformation information;
/* 170 */         if (numeric.isSecondDigitFNC1()) {
/* 171 */           information = new DecodedInformation(this.current.getPosition(), this.buffer.toString());
/*     */         } else {
/* 173 */           information = new DecodedInformation(this.current.getPosition(), this.buffer.toString(), numeric.getSecondDigit());
/*     */         } 
/* 175 */         return new BlockParsedResult(information, true);
/*     */       } 
/* 177 */       this.buffer.append(numeric.getFirstDigit());
/*     */       
/* 179 */       if (numeric.isSecondDigitFNC1()) {
/* 180 */         DecodedInformation information = new DecodedInformation(this.current.getPosition(), this.buffer.toString());
/* 181 */         return new BlockParsedResult(information, true);
/*     */       } 
/* 183 */       this.buffer.append(numeric.getSecondDigit());
/*     */     } 
/*     */     
/* 186 */     if (isNumericToAlphaNumericLatch(this.current.getPosition())) {
/* 187 */       this.current.setAlpha();
/* 188 */       this.current.incrementPosition(4);
/*     */     } 
/* 190 */     return new BlockParsedResult(false);
/*     */   }
/*     */   
/*     */   private BlockParsedResult parseIsoIec646Block() {
/* 194 */     while (isStillIsoIec646(this.current.getPosition())) {
/* 195 */       DecodedChar iso = decodeIsoIec646(this.current.getPosition());
/* 196 */       this.current.setPosition(iso.getNewPosition());
/*     */       
/* 198 */       if (iso.isFNC1()) {
/* 199 */         DecodedInformation information = new DecodedInformation(this.current.getPosition(), this.buffer.toString());
/* 200 */         return new BlockParsedResult(information, true);
/*     */       } 
/* 202 */       this.buffer.append(iso.getValue());
/*     */     } 
/*     */     
/* 205 */     if (isAlphaOr646ToNumericLatch(this.current.getPosition())) {
/* 206 */       this.current.incrementPosition(3);
/* 207 */       this.current.setNumeric();
/* 208 */     } else if (isAlphaTo646ToAlphaLatch(this.current.getPosition())) {
/* 209 */       if (this.current.getPosition() + 5 < this.information.getSize()) {
/* 210 */         this.current.incrementPosition(5);
/*     */       } else {
/* 212 */         this.current.setPosition(this.information.getSize());
/*     */       } 
/*     */       
/* 215 */       this.current.setAlpha();
/*     */     } 
/* 217 */     return new BlockParsedResult(false);
/*     */   }
/*     */   
/*     */   private BlockParsedResult parseAlphaBlock() {
/* 221 */     while (isStillAlpha(this.current.getPosition())) {
/* 222 */       DecodedChar alpha = decodeAlphanumeric(this.current.getPosition());
/* 223 */       this.current.setPosition(alpha.getNewPosition());
/*     */       
/* 225 */       if (alpha.isFNC1()) {
/* 226 */         DecodedInformation information = new DecodedInformation(this.current.getPosition(), this.buffer.toString());
/* 227 */         return new BlockParsedResult(information, true);
/*     */       } 
/*     */       
/* 230 */       this.buffer.append(alpha.getValue());
/*     */     } 
/*     */     
/* 233 */     if (isAlphaOr646ToNumericLatch(this.current.getPosition())) {
/* 234 */       this.current.incrementPosition(3);
/* 235 */       this.current.setNumeric();
/* 236 */     } else if (isAlphaTo646ToAlphaLatch(this.current.getPosition())) {
/* 237 */       if (this.current.getPosition() + 5 < this.information.getSize()) {
/* 238 */         this.current.incrementPosition(5);
/*     */       } else {
/* 240 */         this.current.setPosition(this.information.getSize());
/*     */       } 
/*     */       
/* 243 */       this.current.setIsoIec646();
/*     */     } 
/* 245 */     return new BlockParsedResult(false);
/*     */   }
/*     */   
/*     */   private boolean isStillIsoIec646(int pos) {
/* 249 */     if (pos + 5 > this.information.getSize()) {
/* 250 */       return false;
/*     */     }
/*     */     
/* 253 */     int fiveBitValue = extractNumericValueFromBitArray(pos, 5);
/* 254 */     if (fiveBitValue >= 5 && fiveBitValue < 16) {
/* 255 */       return true;
/*     */     }
/*     */     
/* 258 */     if (pos + 7 > this.information.getSize()) {
/* 259 */       return false;
/*     */     }
/*     */     
/* 262 */     int sevenBitValue = extractNumericValueFromBitArray(pos, 7);
/* 263 */     if (sevenBitValue >= 64 && sevenBitValue < 116) {
/* 264 */       return true;
/*     */     }
/*     */     
/* 267 */     if (pos + 8 > this.information.getSize()) {
/* 268 */       return false;
/*     */     }
/*     */     
/* 271 */     int eightBitValue = extractNumericValueFromBitArray(pos, 8);
/* 272 */     return (eightBitValue >= 232 && eightBitValue < 253);
/*     */   }
/*     */   
/*     */   private DecodedChar decodeIsoIec646(int pos) {
/*     */     char c;
/* 277 */     int fiveBitValue = extractNumericValueFromBitArray(pos, 5);
/* 278 */     if (fiveBitValue == 15) {
/* 279 */       return new DecodedChar(pos + 5, '$');
/*     */     }
/*     */     
/* 282 */     if (fiveBitValue >= 5 && fiveBitValue < 15) {
/* 283 */       return new DecodedChar(pos + 5, (char)(48 + fiveBitValue - 5));
/*     */     }
/*     */     
/* 286 */     int sevenBitValue = extractNumericValueFromBitArray(pos, 7);
/*     */     
/* 288 */     if (sevenBitValue >= 64 && sevenBitValue < 90) {
/* 289 */       return new DecodedChar(pos + 7, (char)(sevenBitValue + 1));
/*     */     }
/*     */     
/* 292 */     if (sevenBitValue >= 90 && sevenBitValue < 116) {
/* 293 */       return new DecodedChar(pos + 7, (char)(sevenBitValue + 7));
/*     */     }
/*     */     
/* 296 */     int eightBitValue = extractNumericValueFromBitArray(pos, 8);
/*     */     
/* 298 */     switch (eightBitValue) {
/*     */       case 232:
/* 300 */         c = '!';
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */         
/* 365 */         return new DecodedChar(pos + 8, c);case 233: c = '"'; return new DecodedChar(pos + 8, c);case 234: c = '%'; return new DecodedChar(pos + 8, c);case 235: c = '&'; return new DecodedChar(pos + 8, c);case 236: c = '\''; return new DecodedChar(pos + 8, c);case 237: c = '('; return new DecodedChar(pos + 8, c);case 238: c = ')'; return new DecodedChar(pos + 8, c);case 239: c = '*'; return new DecodedChar(pos + 8, c);case 240: c = '+'; return new DecodedChar(pos + 8, c);case 241: c = ','; return new DecodedChar(pos + 8, c);case 242: c = '-'; return new DecodedChar(pos + 8, c);case 243: c = '.'; return new DecodedChar(pos + 8, c);case 244: c = '/'; return new DecodedChar(pos + 8, c);case 245: c = ':'; return new DecodedChar(pos + 8, c);case 246: c = ';'; return new DecodedChar(pos + 8, c);case 247: c = '<'; return new DecodedChar(pos + 8, c);case 248: c = '='; return new DecodedChar(pos + 8, c);case 249: c = '>'; return new DecodedChar(pos + 8, c);case 250: c = '?'; return new DecodedChar(pos + 8, c);case 251: c = '_'; return new DecodedChar(pos + 8, c);case 252: c = ' '; return new DecodedChar(pos + 8, c);
/*     */     } 
/*     */     throw new IllegalArgumentException("Decoding invalid ISO/IEC 646 value: " + eightBitValue);
/*     */   } private boolean isStillAlpha(int pos) {
/* 369 */     if (pos + 5 > this.information.getSize()) {
/* 370 */       return false;
/*     */     }
/*     */ 
/*     */     
/* 374 */     int fiveBitValue = extractNumericValueFromBitArray(pos, 5);
/* 375 */     if (fiveBitValue >= 5 && fiveBitValue < 16) {
/* 376 */       return true;
/*     */     }
/*     */     
/* 379 */     if (pos + 6 > this.information.getSize()) {
/* 380 */       return false;
/*     */     }
/*     */     
/* 383 */     int sixBitValue = extractNumericValueFromBitArray(pos, 6);
/* 384 */     return (sixBitValue >= 16 && sixBitValue < 63);
/*     */   }
/*     */   private DecodedChar decodeAlphanumeric(int pos) {
/*     */     char c;
/* 388 */     int fiveBitValue = extractNumericValueFromBitArray(pos, 5);
/* 389 */     if (fiveBitValue == 15) {
/* 390 */       return new DecodedChar(pos + 5, '$');
/*     */     }
/*     */     
/* 393 */     if (fiveBitValue >= 5 && fiveBitValue < 15) {
/* 394 */       return new DecodedChar(pos + 5, (char)(48 + fiveBitValue - 5));
/*     */     }
/*     */     
/* 397 */     int sixBitValue = extractNumericValueFromBitArray(pos, 6);
/*     */     
/* 399 */     if (sixBitValue >= 32 && sixBitValue < 58) {
/* 400 */       return new DecodedChar(pos + 6, (char)(sixBitValue + 33));
/*     */     }
/*     */ 
/*     */     
/* 404 */     switch (sixBitValue) {
/*     */       case 58:
/* 406 */         c = '*';
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */         
/* 423 */         return new DecodedChar(pos + 6, c);case 59: c = ','; return new DecodedChar(pos + 6, c);case 60: c = '-'; return new DecodedChar(pos + 6, c);case 61: c = '.'; return new DecodedChar(pos + 6, c);case 62: c = '/'; return new DecodedChar(pos + 6, c);
/*     */     } 
/*     */     throw new IllegalStateException("Decoding invalid alphanumeric value: " + sixBitValue);
/*     */   } private boolean isAlphaTo646ToAlphaLatch(int pos) {
/* 427 */     if (pos + 1 > this.information.getSize()) {
/* 428 */       return false;
/*     */     }
/*     */     
/* 431 */     for (int i = 0; i < 5 && i + pos < this.information.getSize(); i++) {
/* 432 */       if (i == 2) {
/* 433 */         if (!this.information.get(pos + 2)) {
/* 434 */           return false;
/*     */         }
/* 436 */       } else if (this.information.get(pos + i)) {
/* 437 */         return false;
/*     */       } 
/*     */     } 
/*     */     
/* 441 */     return true;
/*     */   }
/*     */ 
/*     */   
/*     */   private boolean isAlphaOr646ToNumericLatch(int pos) {
/* 446 */     if (pos + 3 > this.information.getSize()) {
/* 447 */       return false;
/*     */     }
/*     */     
/* 450 */     for (int i = pos; i < pos + 3; i++) {
/* 451 */       if (this.information.get(i)) {
/* 452 */         return false;
/*     */       }
/*     */     } 
/* 455 */     return true;
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   private boolean isNumericToAlphaNumericLatch(int pos) {
/* 461 */     if (pos + 1 > this.information.getSize()) {
/* 462 */       return false;
/*     */     }
/*     */     
/* 465 */     for (int i = 0; i < 4 && i + pos < this.information.getSize(); i++) {
/* 466 */       if (this.information.get(pos + i)) {
/* 467 */         return false;
/*     */       }
/*     */     } 
/* 470 */     return true;
/*     */   }
/*     */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\com\google\zxing\oned\rss\expanded\decoders\GeneralAppIdDecoder.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       1.1.3
 */