/*     */ package com.google.zxing.pdf417;
/*     */ 
/*     */ import com.google.zxing.BarcodeFormat;
/*     */ import com.google.zxing.BinaryBitmap;
/*     */ import com.google.zxing.ChecksumException;
/*     */ import com.google.zxing.DecodeHintType;
/*     */ import com.google.zxing.FormatException;
/*     */ import com.google.zxing.NotFoundException;
/*     */ import com.google.zxing.Reader;
/*     */ import com.google.zxing.Result;
/*     */ import com.google.zxing.ResultMetadataType;
/*     */ import com.google.zxing.ResultPoint;
/*     */ import com.google.zxing.common.DecoderResult;
/*     */ import com.google.zxing.multi.MultipleBarcodeReader;
/*     */ import com.google.zxing.pdf417.decoder.PDF417ScanningDecoder;
/*     */ import com.google.zxing.pdf417.detector.Detector;
/*     */ import com.google.zxing.pdf417.detector.PDF417DetectorResult;
/*     */ import java.util.ArrayList;
/*     */ import java.util.List;
/*     */ import java.util.Map;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public final class PDF417Reader
/*     */   implements Reader, MultipleBarcodeReader
/*     */ {
/*     */   public Result decode(BinaryBitmap image) throws NotFoundException, FormatException, ChecksumException {
/*  55 */     return decode(image, null);
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   public Result decode(BinaryBitmap image, Map<DecodeHintType, ?> hints) throws NotFoundException, FormatException, ChecksumException {
/*  61 */     Result[] result = decode(image, hints, false);
/*  62 */     if (result == null || result.length == 0 || result[0] == null) {
/*  63 */       throw NotFoundException.getNotFoundInstance();
/*     */     }
/*  65 */     return result[0];
/*     */   }
/*     */ 
/*     */   
/*     */   public Result[] decodeMultiple(BinaryBitmap image) throws NotFoundException {
/*  70 */     return decodeMultiple(image, null);
/*     */   }
/*     */ 
/*     */   
/*     */   public Result[] decodeMultiple(BinaryBitmap image, Map<DecodeHintType, ?> hints) throws NotFoundException {
/*     */     try {
/*  76 */       return decode(image, hints, true);
/*  77 */     } catch (FormatException ignored) {
/*  78 */       throw NotFoundException.getNotFoundInstance();
/*  79 */     } catch (ChecksumException ignored) {
/*  80 */       throw NotFoundException.getNotFoundInstance();
/*     */     } 
/*     */   }
/*     */ 
/*     */   
/*     */   private static Result[] decode(BinaryBitmap image, Map<DecodeHintType, ?> hints, boolean multiple) throws NotFoundException, FormatException, ChecksumException {
/*  86 */     List<Result> results = new ArrayList<Result>();
/*  87 */     PDF417DetectorResult detectorResult = Detector.detect(image, hints, multiple);
/*  88 */     for (ResultPoint[] points : detectorResult.getPoints()) {
/*  89 */       DecoderResult decoderResult = PDF417ScanningDecoder.decode(detectorResult.getBits(), points[4], points[5], points[6], points[7], getMinCodewordWidth(points), getMaxCodewordWidth(points));
/*     */       
/*  91 */       if (decoderResult == null) {
/*  92 */         throw NotFoundException.getNotFoundInstance();
/*     */       }
/*  94 */       Result result = new Result(decoderResult.getText(), decoderResult.getRawBytes(), points, BarcodeFormat.PDF_417);
/*  95 */       result.putMetadata(ResultMetadataType.ERROR_CORRECTION_LEVEL, decoderResult.getECLevel());
/*  96 */       PDF417ResultMetadata pdf417ResultMetadata = (PDF417ResultMetadata)decoderResult.getOther();
/*  97 */       if (pdf417ResultMetadata != null) {
/*  98 */         result.putMetadata(ResultMetadataType.PDF417_EXTRA_METADATA, pdf417ResultMetadata);
/*     */       }
/* 100 */       results.add(result);
/*     */     } 
/* 102 */     return results.<Result>toArray(new Result[results.size()]);
/*     */   }
/*     */   
/*     */   private static int getMaxWidth(ResultPoint p1, ResultPoint p2) {
/* 106 */     if (p1 == null || p2 == null) {
/* 107 */       return 0;
/*     */     }
/* 109 */     return (int)Math.abs(p1.getX() - p2.getX());
/*     */   }
/*     */   
/*     */   private static int getMinWidth(ResultPoint p1, ResultPoint p2) {
/* 113 */     if (p1 == null || p2 == null) {
/* 114 */       return Integer.MAX_VALUE;
/*     */     }
/* 116 */     return (int)Math.abs(p1.getX() - p2.getX());
/*     */   }
/*     */   
/*     */   private static int getMaxCodewordWidth(ResultPoint[] p) {
/* 120 */     return Math.max(Math.max(getMaxWidth(p[0], p[4]), getMaxWidth(p[6], p[2]) * 17 / 18), Math.max(getMaxWidth(p[1], p[5]), getMaxWidth(p[7], p[3]) * 17 / 18));
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static int getMinCodewordWidth(ResultPoint[] p) {
/* 128 */     return Math.min(Math.min(getMinWidth(p[0], p[4]), getMinWidth(p[6], p[2]) * 17 / 18), Math.min(getMinWidth(p[1], p[5]), getMinWidth(p[7], p[3]) * 17 / 18));
/*     */   }
/*     */   
/*     */   public void reset() {}
/*     */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\com\google\zxing\pdf417\PDF417Reader.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       1.1.3
 */