/*     */ package com.google.zxing.pdf417;
/*     */ 
/*     */ import com.google.zxing.BarcodeFormat;
/*     */ import com.google.zxing.EncodeHintType;
/*     */ import com.google.zxing.Writer;
/*     */ import com.google.zxing.WriterException;
/*     */ import com.google.zxing.common.BitMatrix;
/*     */ import com.google.zxing.pdf417.encoder.Compaction;
/*     */ import com.google.zxing.pdf417.encoder.Dimensions;
/*     */ import com.google.zxing.pdf417.encoder.PDF417;
/*     */ import java.util.Map;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public final class PDF417Writer
/*     */   implements Writer
/*     */ {
/*     */   public BitMatrix encode(String contents, BarcodeFormat format, int width, int height, Map<EncodeHintType, ?> hints) throws WriterException {
/*  42 */     if (format != BarcodeFormat.PDF_417) {
/*  43 */       throw new IllegalArgumentException("Can only encode PDF_417, but got " + format);
/*     */     }
/*     */     
/*  46 */     PDF417 encoder = new PDF417();
/*     */     
/*  48 */     if (hints != null) {
/*  49 */       if (hints.containsKey(EncodeHintType.PDF417_COMPACT)) {
/*  50 */         encoder.setCompact(((Boolean)hints.get(EncodeHintType.PDF417_COMPACT)).booleanValue());
/*     */       }
/*  52 */       if (hints.containsKey(EncodeHintType.PDF417_COMPACTION)) {
/*  53 */         encoder.setCompaction((Compaction)hints.get(EncodeHintType.PDF417_COMPACTION));
/*     */       }
/*  55 */       if (hints.containsKey(EncodeHintType.PDF417_DIMENSIONS)) {
/*  56 */         Dimensions dimensions = (Dimensions)hints.get(EncodeHintType.PDF417_DIMENSIONS);
/*  57 */         encoder.setDimensions(dimensions.getMaxCols(), dimensions.getMinCols(), dimensions.getMaxRows(), dimensions.getMinRows());
/*     */       } 
/*     */     } 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*  64 */     return bitMatrixFromEncoder(encoder, contents, width, height);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public BitMatrix encode(String contents, BarcodeFormat format, int width, int height) throws WriterException {
/*  72 */     return encode(contents, format, width, height, null);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static BitMatrix bitMatrixFromEncoder(PDF417 encoder, String contents, int width, int height) throws WriterException {
/*  82 */     int scale, errorCorrectionLevel = 2;
/*  83 */     encoder.generateBarcodeLogic(contents, errorCorrectionLevel);
/*     */     
/*  85 */     int lineThickness = 2;
/*  86 */     int aspectRatio = 4;
/*  87 */     byte[][] originalScale = encoder.getBarcodeMatrix().getScaledMatrix(lineThickness, aspectRatio * lineThickness);
/*  88 */     boolean rotated = false;
/*  89 */     if ((((height > width) ? 1 : 0) ^ (((originalScale[0]).length < originalScale.length) ? 1 : 0)) != 0) {
/*  90 */       originalScale = rotateArray(originalScale);
/*  91 */       rotated = true;
/*     */     } 
/*     */     
/*  94 */     int scaleX = width / (originalScale[0]).length;
/*  95 */     int scaleY = height / originalScale.length;
/*     */ 
/*     */     
/*  98 */     if (scaleX < scaleY) {
/*  99 */       scale = scaleX;
/*     */     } else {
/* 101 */       scale = scaleY;
/*     */     } 
/*     */     
/* 104 */     if (scale > 1) {
/* 105 */       byte[][] scaledMatrix = encoder.getBarcodeMatrix().getScaledMatrix(scale * lineThickness, scale * aspectRatio * lineThickness);
/*     */       
/* 107 */       if (rotated) {
/* 108 */         scaledMatrix = rotateArray(scaledMatrix);
/*     */       }
/* 110 */       return bitMatrixFrombitArray(scaledMatrix);
/*     */     } 
/* 112 */     return bitMatrixFrombitArray(originalScale);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static BitMatrix bitMatrixFrombitArray(byte[][] input) {
/* 123 */     int whiteSpace = 30;
/*     */ 
/*     */     
/* 126 */     BitMatrix output = new BitMatrix((input[0]).length + 2 * whiteSpace, input.length + 2 * whiteSpace);
/* 127 */     output.clear();
/* 128 */     for (int y = 0, yOutput = output.getHeight() - whiteSpace; y < input.length; y++, yOutput--) {
/* 129 */       for (int x = 0; x < (input[0]).length; x++) {
/*     */         
/* 131 */         if (input[y][x] == 1) {
/* 132 */           output.set(x + whiteSpace, yOutput);
/*     */         }
/*     */       } 
/*     */     } 
/* 136 */     return output;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static byte[][] rotateArray(byte[][] bitarray) {
/* 143 */     byte[][] temp = new byte[(bitarray[0]).length][bitarray.length];
/* 144 */     for (int ii = 0; ii < bitarray.length; ii++) {
/*     */ 
/*     */       
/* 147 */       int inverseii = bitarray.length - ii - 1;
/* 148 */       for (int jj = 0; jj < (bitarray[0]).length; jj++) {
/* 149 */         temp[jj][inverseii] = bitarray[ii][jj];
/*     */       }
/*     */     } 
/* 152 */     return temp;
/*     */   }
/*     */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\com\google\zxing\pdf417\PDF417Writer.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       1.1.3
 */