/*     */ package com.google.zxing.pdf417.decoder;
/*     */ 
/*     */ import com.google.zxing.FormatException;
/*     */ import com.google.zxing.common.DecoderResult;
/*     */ import com.google.zxing.pdf417.PDF417ResultMetadata;
/*     */ import java.math.BigInteger;
/*     */ import java.util.Arrays;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ final class DecodedBitStreamParser
/*     */ {
/*     */   private static final int TEXT_COMPACTION_MODE_LATCH = 900;
/*     */   private static final int BYTE_COMPACTION_MODE_LATCH = 901;
/*     */   private static final int NUMERIC_COMPACTION_MODE_LATCH = 902;
/*     */   private static final int BYTE_COMPACTION_MODE_LATCH_6 = 924;
/*     */   private static final int BEGIN_MACRO_PDF417_CONTROL_BLOCK = 928;
/*     */   private static final int BEGIN_MACRO_PDF417_OPTIONAL_FIELD = 923;
/*     */   private static final int MACRO_PDF417_TERMINATOR = 922;
/*     */   private static final int MODE_SHIFT_TO_BYTE_COMPACTION_MODE = 913;
/*     */   private static final int MAX_NUMERIC_CODEWORDS = 15;
/*     */   private static final int PL = 25;
/*     */   private static final int LL = 27;
/*     */   private static final int AS = 27;
/*     */   private static final int ML = 28;
/*     */   private static final int AL = 28;
/*     */   private static final int PS = 29;
/*     */   private static final int PAL = 29;
/*     */   
/*     */   private enum Mode
/*     */   {
/*  35 */     ALPHA,
/*  36 */     LOWER,
/*  37 */     MIXED,
/*  38 */     PUNCT,
/*  39 */     ALPHA_SHIFT,
/*  40 */     PUNCT_SHIFT;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  61 */   private static final char[] PUNCT_CHARS = new char[] { ';', '<', '>', '@', '[', '\\', '}', '_', '`', '~', '!', '\r', '\t', ',', ':', '\n', '-', '.', '$', '/', '"', '|', '*', '(', ')', '?', '{', '}', '\'' };
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  66 */   private static final char[] MIXED_CHARS = new char[] { '0', '1', '2', '3', '4', '5', '6', '7', '8', '9', '&', '\r', '\t', ',', ':', '#', '-', '.', '$', '/', '+', '%', '*', '=', '^' };
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  77 */   private static final BigInteger[] EXP900 = new BigInteger[16]; static {
/*  78 */     EXP900[0] = BigInteger.ONE;
/*  79 */     BigInteger nineHundred = BigInteger.valueOf(900L);
/*  80 */     EXP900[1] = nineHundred;
/*  81 */     for (int i = 2; i < EXP900.length; i++) {
/*  82 */       EXP900[i] = EXP900[i - 1].multiply(nineHundred);
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   private static final int NUMBER_OF_SEQUENCE_CODEWORDS = 2;
/*     */ 
/*     */   
/*     */   static DecoderResult decode(int[] codewords, String ecLevel) throws FormatException {
/*  92 */     StringBuilder result = new StringBuilder(codewords.length * 2);
/*     */     
/*  94 */     int codeIndex = 1;
/*  95 */     int code = codewords[codeIndex++];
/*  96 */     PDF417ResultMetadata resultMetadata = new PDF417ResultMetadata();
/*  97 */     while (codeIndex < codewords[0]) {
/*  98 */       switch (code) {
/*     */         case 900:
/* 100 */           codeIndex = textCompaction(codewords, codeIndex, result);
/*     */           break;
/*     */         case 901:
/* 103 */           codeIndex = byteCompaction(code, codewords, codeIndex, result);
/*     */           break;
/*     */         case 902:
/* 106 */           codeIndex = numericCompaction(codewords, codeIndex, result);
/*     */           break;
/*     */         case 913:
/* 109 */           codeIndex = byteCompaction(code, codewords, codeIndex, result);
/*     */           break;
/*     */         case 924:
/* 112 */           codeIndex = byteCompaction(code, codewords, codeIndex, result);
/*     */           break;
/*     */         case 928:
/* 115 */           codeIndex = decodeMacroBlock(codewords, codeIndex, resultMetadata);
/*     */           break;
/*     */ 
/*     */ 
/*     */         
/*     */         default:
/* 121 */           codeIndex--;
/* 122 */           codeIndex = textCompaction(codewords, codeIndex, result);
/*     */           break;
/*     */       } 
/* 125 */       if (codeIndex < codewords.length) {
/* 126 */         code = codewords[codeIndex++]; continue;
/*     */       } 
/* 128 */       throw FormatException.getFormatInstance();
/*     */     } 
/*     */     
/* 131 */     if (result.length() == 0) {
/* 132 */       throw FormatException.getFormatInstance();
/*     */     }
/* 134 */     DecoderResult decoderResult = new DecoderResult(null, result.toString(), null, ecLevel);
/* 135 */     decoderResult.setOther(resultMetadata);
/* 136 */     return decoderResult;
/*     */   }
/*     */ 
/*     */   
/*     */   private static int decodeMacroBlock(int[] codewords, int codeIndex, PDF417ResultMetadata resultMetadata) throws FormatException {
/* 141 */     if (codeIndex + 2 > codewords[0])
/*     */     {
/* 143 */       throw FormatException.getFormatInstance();
/*     */     }
/* 145 */     int[] segmentIndexArray = new int[2];
/* 146 */     for (int i = 0; i < 2; i++, codeIndex++) {
/* 147 */       segmentIndexArray[i] = codewords[codeIndex];
/*     */     }
/* 149 */     resultMetadata.setSegmentIndex(Integer.parseInt(decodeBase900toBase10(segmentIndexArray, 2)));
/*     */ 
/*     */     
/* 152 */     StringBuilder fileId = new StringBuilder();
/* 153 */     codeIndex = textCompaction(codewords, codeIndex, fileId);
/* 154 */     resultMetadata.setFileId(fileId.toString());
/*     */     
/* 156 */     if (codewords[codeIndex] == 923) {
/* 157 */       codeIndex++;
/* 158 */       int[] additionalOptionCodeWords = new int[codewords[0] - codeIndex];
/* 159 */       int additionalOptionCodeWordsIndex = 0;
/*     */       
/* 161 */       boolean end = false;
/* 162 */       while (codeIndex < codewords[0] && !end) {
/* 163 */         int code = codewords[codeIndex++];
/* 164 */         if (code < 900) {
/* 165 */           additionalOptionCodeWords[additionalOptionCodeWordsIndex++] = code; continue;
/*     */         } 
/* 167 */         switch (code) {
/*     */           case 922:
/* 169 */             resultMetadata.setLastSegment(true);
/* 170 */             codeIndex++;
/* 171 */             end = true;
/*     */             continue;
/*     */         } 
/* 174 */         throw FormatException.getFormatInstance();
/*     */       } 
/*     */ 
/*     */ 
/*     */       
/* 179 */       resultMetadata.setOptionalData(Arrays.copyOf(additionalOptionCodeWords, additionalOptionCodeWordsIndex));
/* 180 */     } else if (codewords[codeIndex] == 922) {
/* 181 */       resultMetadata.setLastSegment(true);
/* 182 */       codeIndex++;
/*     */     } 
/*     */     
/* 185 */     return codeIndex;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static int textCompaction(int[] codewords, int codeIndex, StringBuilder result) {
/* 200 */     int[] textCompactionData = new int[codewords[0] - codeIndex << 1];
/*     */     
/* 202 */     int[] byteCompactionData = new int[codewords[0] - codeIndex << 1];
/*     */     
/* 204 */     int index = 0;
/* 205 */     boolean end = false;
/* 206 */     while (codeIndex < codewords[0] && !end) {
/* 207 */       int code = codewords[codeIndex++];
/* 208 */       if (code < 900) {
/* 209 */         textCompactionData[index] = code / 30;
/* 210 */         textCompactionData[index + 1] = code % 30;
/* 211 */         index += 2; continue;
/*     */       } 
/* 213 */       switch (code) {
/*     */         
/*     */         case 900:
/* 216 */           textCompactionData[index++] = 900;
/*     */         
/*     */         case 901:
/* 219 */           codeIndex--;
/* 220 */           end = true;
/*     */         
/*     */         case 902:
/* 223 */           codeIndex--;
/* 224 */           end = true;
/*     */         
/*     */         case 928:
/* 227 */           codeIndex--;
/* 228 */           end = true;
/*     */         
/*     */         case 923:
/* 231 */           codeIndex--;
/* 232 */           end = true;
/*     */         
/*     */         case 922:
/* 235 */           codeIndex--;
/* 236 */           end = true;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */         
/*     */         case 913:
/* 245 */           textCompactionData[index] = 913;
/* 246 */           code = codewords[codeIndex++];
/* 247 */           byteCompactionData[index] = code;
/* 248 */           index++;
/*     */         
/*     */         case 924:
/* 251 */           codeIndex--;
/* 252 */           end = true;
/*     */       } 
/*     */ 
/*     */     
/*     */     } 
/* 257 */     decodeTextCompaction(textCompactionData, byteCompactionData, index, result);
/* 258 */     return codeIndex;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static void decodeTextCompaction(int[] textCompactionData, int[] byteCompactionData, int length, StringBuilder result) {
/* 285 */     Mode subMode = Mode.ALPHA;
/* 286 */     Mode priorToShiftMode = Mode.ALPHA;
/* 287 */     int i = 0;
/* 288 */     while (i < length) {
/* 289 */       int subModeCh = textCompactionData[i];
/* 290 */       char ch = Character.MIN_VALUE;
/* 291 */       switch (subMode) {
/*     */         
/*     */         case ALPHA:
/* 294 */           if (subModeCh < 26) {
/*     */             
/* 296 */             ch = (char)(65 + subModeCh); break;
/*     */           } 
/* 298 */           if (subModeCh == 26) {
/* 299 */             ch = ' '; break;
/* 300 */           }  if (subModeCh == 27) {
/* 301 */             subMode = Mode.LOWER; break;
/* 302 */           }  if (subModeCh == 28) {
/* 303 */             subMode = Mode.MIXED; break;
/* 304 */           }  if (subModeCh == 29) {
/*     */             
/* 306 */             priorToShiftMode = subMode;
/* 307 */             subMode = Mode.PUNCT_SHIFT; break;
/* 308 */           }  if (subModeCh == 913) {
/* 309 */             result.append((char)byteCompactionData[i]); break;
/* 310 */           }  if (subModeCh == 900) {
/* 311 */             subMode = Mode.ALPHA;
/*     */           }
/*     */           break;
/*     */ 
/*     */ 
/*     */         
/*     */         case LOWER:
/* 318 */           if (subModeCh < 26) {
/* 319 */             ch = (char)(97 + subModeCh); break;
/*     */           } 
/* 321 */           if (subModeCh == 26) {
/* 322 */             ch = ' '; break;
/* 323 */           }  if (subModeCh == 27) {
/*     */             
/* 325 */             priorToShiftMode = subMode;
/* 326 */             subMode = Mode.ALPHA_SHIFT; break;
/* 327 */           }  if (subModeCh == 28) {
/* 328 */             subMode = Mode.MIXED; break;
/* 329 */           }  if (subModeCh == 29) {
/*     */             
/* 331 */             priorToShiftMode = subMode;
/* 332 */             subMode = Mode.PUNCT_SHIFT; break;
/* 333 */           }  if (subModeCh == 913) {
/* 334 */             result.append((char)byteCompactionData[i]); break;
/* 335 */           }  if (subModeCh == 900) {
/* 336 */             subMode = Mode.ALPHA;
/*     */           }
/*     */           break;
/*     */ 
/*     */ 
/*     */         
/*     */         case MIXED:
/* 343 */           if (subModeCh < 25) {
/* 344 */             ch = MIXED_CHARS[subModeCh]; break;
/*     */           } 
/* 346 */           if (subModeCh == 25) {
/* 347 */             subMode = Mode.PUNCT; break;
/* 348 */           }  if (subModeCh == 26) {
/* 349 */             ch = ' '; break;
/* 350 */           }  if (subModeCh == 27) {
/* 351 */             subMode = Mode.LOWER; break;
/* 352 */           }  if (subModeCh == 28) {
/* 353 */             subMode = Mode.ALPHA; break;
/* 354 */           }  if (subModeCh == 29) {
/*     */             
/* 356 */             priorToShiftMode = subMode;
/* 357 */             subMode = Mode.PUNCT_SHIFT; break;
/* 358 */           }  if (subModeCh == 913) {
/* 359 */             result.append((char)byteCompactionData[i]); break;
/* 360 */           }  if (subModeCh == 900) {
/* 361 */             subMode = Mode.ALPHA;
/*     */           }
/*     */           break;
/*     */ 
/*     */ 
/*     */         
/*     */         case PUNCT:
/* 368 */           if (subModeCh < 29) {
/* 369 */             ch = PUNCT_CHARS[subModeCh]; break;
/*     */           } 
/* 371 */           if (subModeCh == 29) {
/* 372 */             subMode = Mode.ALPHA; break;
/* 373 */           }  if (subModeCh == 913) {
/* 374 */             result.append((char)byteCompactionData[i]); break;
/* 375 */           }  if (subModeCh == 900) {
/* 376 */             subMode = Mode.ALPHA;
/*     */           }
/*     */           break;
/*     */ 
/*     */ 
/*     */         
/*     */         case ALPHA_SHIFT:
/* 383 */           subMode = priorToShiftMode;
/* 384 */           if (subModeCh < 26) {
/* 385 */             ch = (char)(65 + subModeCh); break;
/*     */           } 
/* 387 */           if (subModeCh == 26) {
/* 388 */             ch = ' '; break;
/* 389 */           }  if (subModeCh == 900) {
/* 390 */             subMode = Mode.ALPHA;
/*     */           }
/*     */           break;
/*     */ 
/*     */ 
/*     */         
/*     */         case PUNCT_SHIFT:
/* 397 */           subMode = priorToShiftMode;
/* 398 */           if (subModeCh < 29) {
/* 399 */             ch = PUNCT_CHARS[subModeCh]; break;
/*     */           } 
/* 401 */           if (subModeCh == 29) {
/* 402 */             subMode = Mode.ALPHA; break;
/* 403 */           }  if (subModeCh == 913) {
/*     */ 
/*     */             
/* 406 */             result.append((char)byteCompactionData[i]); break;
/* 407 */           }  if (subModeCh == 900) {
/* 408 */             subMode = Mode.ALPHA;
/*     */           }
/*     */           break;
/*     */       } 
/*     */       
/* 413 */       if (ch != '\000')
/*     */       {
/* 415 */         result.append(ch);
/*     */       }
/* 417 */       i++;
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static int byteCompaction(int mode, int[] codewords, int codeIndex, StringBuilder result) {
/* 433 */     if (mode == 901) {
/*     */ 
/*     */       
/* 436 */       int count = 0;
/* 437 */       long value = 0L;
/* 438 */       char[] decodedData = new char[6];
/* 439 */       int[] byteCompactedCodewords = new int[6];
/* 440 */       boolean end = false;
/* 441 */       int nextCode = codewords[codeIndex++];
/* 442 */       while (codeIndex < codewords[0] && !end) {
/* 443 */         byteCompactedCodewords[count++] = nextCode;
/*     */         
/* 445 */         value = 900L * value + nextCode;
/* 446 */         nextCode = codewords[codeIndex++];
/*     */         
/* 448 */         if (nextCode == 900 || nextCode == 901 || nextCode == 902 || nextCode == 924 || nextCode == 928 || nextCode == 923 || nextCode == 922) {
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */           
/* 455 */           codeIndex--;
/* 456 */           end = true; continue;
/*     */         } 
/* 458 */         if (count % 5 == 0 && count > 0) {
/*     */ 
/*     */           
/* 461 */           for (int j = 0; j < 6; j++) {
/* 462 */             decodedData[5 - j] = (char)(int)(value % 256L);
/* 463 */             value >>= 8L;
/*     */           } 
/* 465 */           result.append(decodedData);
/* 466 */           count = 0;
/*     */         } 
/*     */       } 
/*     */ 
/*     */ 
/*     */       
/* 472 */       if (codeIndex == codewords[0] && nextCode < 900) {
/* 473 */         byteCompactedCodewords[count++] = nextCode;
/*     */       }
/*     */ 
/*     */ 
/*     */ 
/*     */       
/* 479 */       for (int i = 0; i < count; i++) {
/* 480 */         result.append((char)byteCompactedCodewords[i]);
/*     */       }
/*     */     }
/* 483 */     else if (mode == 924) {
/*     */ 
/*     */       
/* 486 */       int count = 0;
/* 487 */       long value = 0L;
/* 488 */       boolean end = false;
/* 489 */       while (codeIndex < codewords[0] && !end) {
/* 490 */         int code = codewords[codeIndex++];
/* 491 */         if (code < 900) {
/* 492 */           count++;
/*     */           
/* 494 */           value = 900L * value + code;
/*     */         }
/* 496 */         else if (code == 900 || code == 901 || code == 902 || code == 924 || code == 928 || code == 923 || code == 922) {
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */           
/* 503 */           codeIndex--;
/* 504 */           end = true;
/*     */         } 
/*     */         
/* 507 */         if (count % 5 == 0 && count > 0) {
/*     */ 
/*     */           
/* 510 */           char[] decodedData = new char[6];
/* 511 */           for (int j = 0; j < 6; j++) {
/* 512 */             decodedData[5 - j] = (char)(int)(value & 0xFFL);
/* 513 */             value >>= 8L;
/*     */           } 
/* 515 */           result.append(decodedData);
/* 516 */           count = 0;
/*     */         } 
/*     */       } 
/*     */     } 
/* 520 */     return codeIndex;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static int numericCompaction(int[] codewords, int codeIndex, StringBuilder result) throws FormatException {
/* 532 */     int count = 0;
/* 533 */     boolean end = false;
/*     */     
/* 535 */     int[] numericCodewords = new int[15];
/*     */     
/* 537 */     while (codeIndex < codewords[0] && !end) {
/* 538 */       int code = codewords[codeIndex++];
/* 539 */       if (codeIndex == codewords[0]) {
/* 540 */         end = true;
/*     */       }
/* 542 */       if (code < 900) {
/* 543 */         numericCodewords[count] = code;
/* 544 */         count++;
/*     */       }
/* 546 */       else if (code == 900 || code == 901 || code == 924 || code == 928 || code == 923 || code == 922) {
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */         
/* 552 */         codeIndex--;
/* 553 */         end = true;
/*     */       } 
/*     */       
/* 556 */       if (count % 15 == 0 || code == 902 || end) {
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */         
/* 563 */         String s = decodeBase900toBase10(numericCodewords, count);
/* 564 */         result.append(s);
/* 565 */         count = 0;
/*     */       } 
/*     */     } 
/* 568 */     return codeIndex;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static String decodeBase900toBase10(int[] codewords, int count) throws FormatException {
/* 615 */     BigInteger result = BigInteger.ZERO;
/* 616 */     for (int i = 0; i < count; i++) {
/* 617 */       result = result.add(EXP900[count - i - 1].multiply(BigInteger.valueOf(codewords[i])));
/*     */     }
/* 619 */     String resultString = result.toString();
/* 620 */     if (resultString.charAt(0) != '1') {
/* 621 */       throw FormatException.getFormatInstance();
/*     */     }
/* 623 */     return resultString.substring(1);
/*     */   }
/*     */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\com\google\zxing\pdf417\decoder\DecodedBitStreamParser.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       1.1.3
 */