/*     */ package com.google.zxing.pdf417.decoder;
/*     */ 
/*     */ import java.util.Formatter;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ final class DetectionResult
/*     */ {
/*     */   private static final int ADJUST_ROW_NUMBER_SKIP = 2;
/*     */   private final BarcodeMetadata barcodeMetadata;
/*     */   private final DetectionResultColumn[] detectionResultColumns;
/*     */   private BoundingBox boundingBox;
/*     */   private final int barcodeColumnCount;
/*     */   
/*     */   DetectionResult(BarcodeMetadata barcodeMetadata, BoundingBox boundingBox) {
/*  36 */     this.barcodeMetadata = barcodeMetadata;
/*  37 */     this.barcodeColumnCount = barcodeMetadata.getColumnCount();
/*  38 */     this.boundingBox = boundingBox;
/*  39 */     this.detectionResultColumns = new DetectionResultColumn[this.barcodeColumnCount + 2];
/*     */   }
/*     */   DetectionResultColumn[] getDetectionResultColumns() {
/*     */     int previousUnadjustedCount;
/*  43 */     adjustIndicatorColumnRowNumbers(this.detectionResultColumns[0]);
/*  44 */     adjustIndicatorColumnRowNumbers(this.detectionResultColumns[this.barcodeColumnCount + 1]);
/*  45 */     int unadjustedCodewordCount = 928;
/*     */     
/*     */     do {
/*  48 */       previousUnadjustedCount = unadjustedCodewordCount;
/*  49 */       unadjustedCodewordCount = adjustRowNumbers();
/*  50 */     } while (unadjustedCodewordCount > 0 && unadjustedCodewordCount < previousUnadjustedCount);
/*  51 */     return this.detectionResultColumns;
/*     */   }
/*     */   
/*     */   private void adjustIndicatorColumnRowNumbers(DetectionResultColumn detectionResultColumn) {
/*  55 */     if (detectionResultColumn != null) {
/*  56 */       ((DetectionResultRowIndicatorColumn)detectionResultColumn).adjustCompleteIndicatorColumnRowNumbers(this.barcodeMetadata);
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private int adjustRowNumbers() {
/*  69 */     int unadjustedCount = adjustRowNumbersByRow();
/*  70 */     if (unadjustedCount == 0) {
/*  71 */       return 0;
/*     */     }
/*  73 */     for (int barcodeColumn = 1; barcodeColumn < this.barcodeColumnCount + 1; barcodeColumn++) {
/*  74 */       Codeword[] codewords = this.detectionResultColumns[barcodeColumn].getCodewords();
/*  75 */       for (int codewordsRow = 0; codewordsRow < codewords.length; codewordsRow++) {
/*  76 */         if (codewords[codewordsRow] != null)
/*     */         {
/*     */           
/*  79 */           if (!codewords[codewordsRow].hasValidRowNumber())
/*  80 */             adjustRowNumbers(barcodeColumn, codewordsRow, codewords); 
/*     */         }
/*     */       } 
/*     */     } 
/*  84 */     return unadjustedCount;
/*     */   }
/*     */   
/*     */   private int adjustRowNumbersByRow() {
/*  88 */     adjustRowNumbersFromBothRI();
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*  93 */     int unadjustedCount = adjustRowNumbersFromLRI();
/*  94 */     return unadjustedCount + adjustRowNumbersFromRRI();
/*     */   }
/*     */   
/*     */   private int adjustRowNumbersFromBothRI() {
/*  98 */     if (this.detectionResultColumns[0] == null || this.detectionResultColumns[this.barcodeColumnCount + 1] == null) {
/*  99 */       return 0;
/*     */     }
/* 101 */     Codeword[] LRIcodewords = this.detectionResultColumns[0].getCodewords();
/* 102 */     Codeword[] RRIcodewords = this.detectionResultColumns[this.barcodeColumnCount + 1].getCodewords();
/* 103 */     for (int codewordsRow = 0; codewordsRow < LRIcodewords.length; codewordsRow++) {
/* 104 */       if (LRIcodewords[codewordsRow] != null && RRIcodewords[codewordsRow] != null && LRIcodewords[codewordsRow].getRowNumber() == RRIcodewords[codewordsRow].getRowNumber())
/*     */       {
/*     */         
/* 107 */         for (int barcodeColumn = 1; barcodeColumn <= this.barcodeColumnCount; barcodeColumn++) {
/* 108 */           Codeword codeword = this.detectionResultColumns[barcodeColumn].getCodewords()[codewordsRow];
/* 109 */           if (codeword != null) {
/*     */ 
/*     */             
/* 112 */             codeword.setRowNumber(LRIcodewords[codewordsRow].getRowNumber());
/* 113 */             if (!codeword.hasValidRowNumber())
/* 114 */               this.detectionResultColumns[barcodeColumn].getCodewords()[codewordsRow] = null; 
/*     */           } 
/*     */         } 
/*     */       }
/*     */     } 
/* 119 */     return 0;
/*     */   }
/*     */   
/*     */   private int adjustRowNumbersFromRRI() {
/* 123 */     if (this.detectionResultColumns[this.barcodeColumnCount + 1] == null) {
/* 124 */       return 0;
/*     */     }
/* 126 */     int unadjustedCount = 0;
/* 127 */     Codeword[] codewords = this.detectionResultColumns[this.barcodeColumnCount + 1].getCodewords();
/* 128 */     for (int codewordsRow = 0; codewordsRow < codewords.length; codewordsRow++) {
/* 129 */       if (codewords[codewordsRow] != null) {
/*     */ 
/*     */         
/* 132 */         int rowIndicatorRowNumber = codewords[codewordsRow].getRowNumber();
/* 133 */         int invalidRowCounts = 0;
/* 134 */         for (int barcodeColumn = this.barcodeColumnCount + 1; barcodeColumn > 0 && invalidRowCounts < 2; barcodeColumn--) {
/* 135 */           Codeword codeword = this.detectionResultColumns[barcodeColumn].getCodewords()[codewordsRow];
/* 136 */           if (codeword != null) {
/* 137 */             invalidRowCounts = adjustRowNumberIfValid(rowIndicatorRowNumber, invalidRowCounts, codeword);
/* 138 */             if (!codeword.hasValidRowNumber())
/* 139 */               unadjustedCount++; 
/*     */           } 
/*     */         } 
/*     */       } 
/*     */     } 
/* 144 */     return unadjustedCount;
/*     */   }
/*     */   
/*     */   private int adjustRowNumbersFromLRI() {
/* 148 */     if (this.detectionResultColumns[0] == null) {
/* 149 */       return 0;
/*     */     }
/* 151 */     int unadjustedCount = 0;
/* 152 */     Codeword[] codewords = this.detectionResultColumns[0].getCodewords();
/* 153 */     for (int codewordsRow = 0; codewordsRow < codewords.length; codewordsRow++) {
/* 154 */       if (codewords[codewordsRow] != null) {
/*     */ 
/*     */         
/* 157 */         int rowIndicatorRowNumber = codewords[codewordsRow].getRowNumber();
/* 158 */         int invalidRowCounts = 0;
/* 159 */         for (int barcodeColumn = 1; barcodeColumn < this.barcodeColumnCount + 1 && invalidRowCounts < 2; barcodeColumn++) {
/* 160 */           Codeword codeword = this.detectionResultColumns[barcodeColumn].getCodewords()[codewordsRow];
/* 161 */           if (codeword != null) {
/* 162 */             invalidRowCounts = adjustRowNumberIfValid(rowIndicatorRowNumber, invalidRowCounts, codeword);
/* 163 */             if (!codeword.hasValidRowNumber())
/* 164 */               unadjustedCount++; 
/*     */           } 
/*     */         } 
/*     */       } 
/*     */     } 
/* 169 */     return unadjustedCount;
/*     */   }
/*     */   
/*     */   private static int adjustRowNumberIfValid(int rowIndicatorRowNumber, int invalidRowCounts, Codeword codeword) {
/* 173 */     if (codeword == null) {
/* 174 */       return invalidRowCounts;
/*     */     }
/* 176 */     if (!codeword.hasValidRowNumber()) {
/* 177 */       if (codeword.isValidRowNumber(rowIndicatorRowNumber)) {
/* 178 */         codeword.setRowNumber(rowIndicatorRowNumber);
/* 179 */         invalidRowCounts = 0;
/*     */       } else {
/* 181 */         invalidRowCounts++;
/*     */       } 
/*     */     }
/* 184 */     return invalidRowCounts;
/*     */   }
/*     */   
/*     */   private void adjustRowNumbers(int barcodeColumn, int codewordsRow, Codeword[] codewords) {
/* 188 */     Codeword codeword = codewords[codewordsRow];
/* 189 */     Codeword[] previousColumnCodewords = this.detectionResultColumns[barcodeColumn - 1].getCodewords();
/* 190 */     Codeword[] nextColumnCodewords = previousColumnCodewords;
/* 191 */     if (this.detectionResultColumns[barcodeColumn + 1] != null) {
/* 192 */       nextColumnCodewords = this.detectionResultColumns[barcodeColumn + 1].getCodewords();
/*     */     }
/*     */     
/* 195 */     Codeword[] otherCodewords = new Codeword[14];
/*     */     
/* 197 */     otherCodewords[2] = previousColumnCodewords[codewordsRow];
/* 198 */     otherCodewords[3] = nextColumnCodewords[codewordsRow];
/*     */     
/* 200 */     if (codewordsRow > 0) {
/* 201 */       otherCodewords[0] = codewords[codewordsRow - 1];
/* 202 */       otherCodewords[4] = previousColumnCodewords[codewordsRow - 1];
/* 203 */       otherCodewords[5] = nextColumnCodewords[codewordsRow - 1];
/*     */     } 
/* 205 */     if (codewordsRow > 1) {
/* 206 */       otherCodewords[8] = codewords[codewordsRow - 2];
/* 207 */       otherCodewords[10] = previousColumnCodewords[codewordsRow - 2];
/* 208 */       otherCodewords[11] = nextColumnCodewords[codewordsRow - 2];
/*     */     } 
/* 210 */     if (codewordsRow < codewords.length - 1) {
/* 211 */       otherCodewords[1] = codewords[codewordsRow + 1];
/* 212 */       otherCodewords[6] = previousColumnCodewords[codewordsRow + 1];
/* 213 */       otherCodewords[7] = nextColumnCodewords[codewordsRow + 1];
/*     */     } 
/* 215 */     if (codewordsRow < codewords.length - 2) {
/* 216 */       otherCodewords[9] = codewords[codewordsRow + 2];
/* 217 */       otherCodewords[12] = previousColumnCodewords[codewordsRow + 2];
/* 218 */       otherCodewords[13] = nextColumnCodewords[codewordsRow + 2];
/*     */     } 
/* 220 */     for (Codeword otherCodeword : otherCodewords) {
/* 221 */       if (adjustRowNumber(codeword, otherCodeword)) {
/*     */         return;
/*     */       }
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static boolean adjustRowNumber(Codeword codeword, Codeword otherCodeword) {
/* 231 */     if (otherCodeword == null) {
/* 232 */       return false;
/*     */     }
/* 234 */     if (otherCodeword.hasValidRowNumber() && otherCodeword.getBucket() == codeword.getBucket()) {
/* 235 */       codeword.setRowNumber(otherCodeword.getRowNumber());
/* 236 */       return true;
/*     */     } 
/* 238 */     return false;
/*     */   }
/*     */   
/*     */   int getBarcodeColumnCount() {
/* 242 */     return this.barcodeColumnCount;
/*     */   }
/*     */   
/*     */   int getBarcodeRowCount() {
/* 246 */     return this.barcodeMetadata.getRowCount();
/*     */   }
/*     */   
/*     */   int getBarcodeECLevel() {
/* 250 */     return this.barcodeMetadata.getErrorCorrectionLevel();
/*     */   }
/*     */   
/*     */   public void setBoundingBox(BoundingBox boundingBox) {
/* 254 */     this.boundingBox = boundingBox;
/*     */   }
/*     */   
/*     */   BoundingBox getBoundingBox() {
/* 258 */     return this.boundingBox;
/*     */   }
/*     */   
/*     */   void setDetectionResultColumn(int barcodeColumn, DetectionResultColumn detectionResultColumn) {
/* 262 */     this.detectionResultColumns[barcodeColumn] = detectionResultColumn;
/*     */   }
/*     */   
/*     */   DetectionResultColumn getDetectionResultColumn(int barcodeColumn) {
/* 266 */     return this.detectionResultColumns[barcodeColumn];
/*     */   }
/*     */ 
/*     */   
/*     */   public String toString() {
/* 271 */     DetectionResultColumn rowIndicatorColumn = this.detectionResultColumns[0];
/* 272 */     if (rowIndicatorColumn == null) {
/* 273 */       rowIndicatorColumn = this.detectionResultColumns[this.barcodeColumnCount + 1];
/*     */     }
/* 275 */     Formatter formatter = new Formatter();
/* 276 */     for (int codewordsRow = 0; codewordsRow < (rowIndicatorColumn.getCodewords()).length; codewordsRow++) {
/* 277 */       formatter.format("CW %3d:", new Object[] { Integer.valueOf(codewordsRow) });
/* 278 */       for (int barcodeColumn = 0; barcodeColumn < this.barcodeColumnCount + 2; barcodeColumn++) {
/* 279 */         if (this.detectionResultColumns[barcodeColumn] == null) {
/* 280 */           formatter.format("    |   ", new Object[0]);
/*     */         } else {
/*     */           
/* 283 */           Codeword codeword = this.detectionResultColumns[barcodeColumn].getCodewords()[codewordsRow];
/* 284 */           if (codeword == null)
/* 285 */           { formatter.format("    |   ", new Object[0]); }
/*     */           else
/*     */           
/* 288 */           { formatter.format(" %3d|%3d", new Object[] { Integer.valueOf(codeword.getRowNumber()), Integer.valueOf(codeword.getValue()) }); } 
/*     */         } 
/* 290 */       }  formatter.format("\n", new Object[0]);
/*     */     } 
/* 292 */     String result = formatter.toString();
/* 293 */     formatter.close();
/* 294 */     return result;
/*     */   }
/*     */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\com\google\zxing\pdf417\decoder\DetectionResult.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       1.1.3
 */