/*     */ package com.google.zxing.pdf417.decoder;
/*     */ 
/*     */ import com.google.zxing.ChecksumException;
/*     */ import com.google.zxing.FormatException;
/*     */ import com.google.zxing.NotFoundException;
/*     */ import com.google.zxing.ResultPoint;
/*     */ import com.google.zxing.common.BitMatrix;
/*     */ import com.google.zxing.common.DecoderResult;
/*     */ import com.google.zxing.pdf417.PDF417Common;
/*     */ import com.google.zxing.pdf417.decoder.ec.ErrorCorrection;
/*     */ import java.util.ArrayList;
/*     */ import java.util.Collection;
/*     */ import java.util.Formatter;
/*     */ import java.util.List;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public final class PDF417ScanningDecoder
/*     */ {
/*     */   private static final int CODEWORD_SKEW_SIZE = 2;
/*     */   private static final int MAX_ERRORS = 3;
/*     */   private static final int MAX_EC_CODEWORDS = 512;
/*  42 */   private static final ErrorCorrection errorCorrection = new ErrorCorrection();
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static DecoderResult decode(BitMatrix image, ResultPoint imageTopLeft, ResultPoint imageBottomLeft, ResultPoint imageTopRight, ResultPoint imageBottomRight, int minCodewordWidth, int maxCodewordWidth) throws NotFoundException, FormatException, ChecksumException {
/*  58 */     BoundingBox boundingBox = new BoundingBox(image, imageTopLeft, imageBottomLeft, imageTopRight, imageBottomRight);
/*  59 */     DetectionResultRowIndicatorColumn leftRowIndicatorColumn = null;
/*  60 */     DetectionResultRowIndicatorColumn rightRowIndicatorColumn = null;
/*  61 */     DetectionResult detectionResult = null;
/*  62 */     for (int i = 0; i < 2; i++) {
/*  63 */       if (imageTopLeft != null) {
/*  64 */         leftRowIndicatorColumn = getRowIndicatorColumn(image, boundingBox, imageTopLeft, true, minCodewordWidth, maxCodewordWidth);
/*     */       }
/*     */       
/*  67 */       if (imageTopRight != null) {
/*  68 */         rightRowIndicatorColumn = getRowIndicatorColumn(image, boundingBox, imageTopRight, false, minCodewordWidth, maxCodewordWidth);
/*     */       }
/*     */       
/*  71 */       detectionResult = merge(leftRowIndicatorColumn, rightRowIndicatorColumn);
/*  72 */       if (detectionResult == null) {
/*  73 */         throw NotFoundException.getNotFoundInstance();
/*     */       }
/*  75 */       if (i == 0 && (detectionResult.getBoundingBox().getMinY() < boundingBox.getMinY() || detectionResult.getBoundingBox().getMaxY() > boundingBox.getMaxY())) {
/*     */ 
/*     */         
/*  78 */         boundingBox = detectionResult.getBoundingBox();
/*     */       } else {
/*  80 */         detectionResult.setBoundingBox(boundingBox);
/*     */         break;
/*     */       } 
/*     */     } 
/*  84 */     int maxBarcodeColumn = detectionResult.getBarcodeColumnCount() + 1;
/*  85 */     detectionResult.setDetectionResultColumn(0, leftRowIndicatorColumn);
/*  86 */     detectionResult.setDetectionResultColumn(maxBarcodeColumn, rightRowIndicatorColumn);
/*     */     
/*  88 */     boolean leftToRight = (leftRowIndicatorColumn != null);
/*  89 */     for (int barcodeColumnCount = 1; barcodeColumnCount <= maxBarcodeColumn; barcodeColumnCount++) {
/*  90 */       int barcodeColumn = leftToRight ? barcodeColumnCount : (maxBarcodeColumn - barcodeColumnCount);
/*  91 */       if (detectionResult.getDetectionResultColumn(barcodeColumn) == null) {
/*     */         DetectionResultColumn detectionResultColumn;
/*     */ 
/*     */ 
/*     */         
/*  96 */         if (barcodeColumn == 0 || barcodeColumn == maxBarcodeColumn) {
/*  97 */           detectionResultColumn = new DetectionResultRowIndicatorColumn(boundingBox, (barcodeColumn == 0));
/*     */         } else {
/*  99 */           detectionResultColumn = new DetectionResultColumn(boundingBox);
/*     */         } 
/* 101 */         detectionResult.setDetectionResultColumn(barcodeColumn, detectionResultColumn);
/* 102 */         int startColumn = -1;
/* 103 */         int previousStartColumn = startColumn;
/*     */         
/* 105 */         for (int imageRow = boundingBox.getMinY(); imageRow <= boundingBox.getMaxY(); imageRow++) {
/* 106 */           startColumn = getStartColumn(detectionResult, barcodeColumn, imageRow, leftToRight);
/* 107 */           if (startColumn < 0 || startColumn > boundingBox.getMaxX()) {
/* 108 */             if (previousStartColumn == -1) {
/*     */               continue;
/*     */             }
/* 111 */             startColumn = previousStartColumn;
/*     */           } 
/* 113 */           Codeword codeword = detectCodeword(image, boundingBox.getMinX(), boundingBox.getMaxX(), leftToRight, startColumn, imageRow, minCodewordWidth, maxCodewordWidth);
/*     */           
/* 115 */           if (codeword != null) {
/* 116 */             detectionResultColumn.setCodeword(imageRow, codeword);
/* 117 */             previousStartColumn = startColumn;
/* 118 */             minCodewordWidth = Math.min(minCodewordWidth, codeword.getWidth());
/* 119 */             maxCodewordWidth = Math.max(maxCodewordWidth, codeword.getWidth());
/*     */           }  continue;
/*     */         } 
/*     */       } 
/* 123 */     }  return createDecoderResult(detectionResult);
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   private static DetectionResult merge(DetectionResultRowIndicatorColumn leftRowIndicatorColumn, DetectionResultRowIndicatorColumn rightRowIndicatorColumn) throws NotFoundException {
/* 129 */     if (leftRowIndicatorColumn == null && rightRowIndicatorColumn == null) {
/* 130 */       return null;
/*     */     }
/* 132 */     BarcodeMetadata barcodeMetadata = getBarcodeMetadata(leftRowIndicatorColumn, rightRowIndicatorColumn);
/* 133 */     if (barcodeMetadata == null) {
/* 134 */       return null;
/*     */     }
/* 136 */     BoundingBox boundingBox = BoundingBox.merge(adjustBoundingBox(leftRowIndicatorColumn), adjustBoundingBox(rightRowIndicatorColumn));
/*     */     
/* 138 */     return new DetectionResult(barcodeMetadata, boundingBox);
/*     */   }
/*     */ 
/*     */   
/*     */   private static BoundingBox adjustBoundingBox(DetectionResultRowIndicatorColumn rowIndicatorColumn) throws NotFoundException {
/* 143 */     if (rowIndicatorColumn == null) {
/* 144 */       return null;
/*     */     }
/* 146 */     int[] rowHeights = rowIndicatorColumn.getRowHeights();
/* 147 */     int maxRowHeight = getMax(rowHeights);
/* 148 */     int missingStartRows = 0;
/* 149 */     for (int rowHeight : rowHeights) {
/* 150 */       missingStartRows += maxRowHeight - rowHeight;
/* 151 */       if (rowHeight > 0) {
/*     */         break;
/*     */       }
/*     */     } 
/* 155 */     Codeword[] codewords = rowIndicatorColumn.getCodewords();
/* 156 */     for (int row = 0; missingStartRows > 0 && codewords[row] == null; row++) {
/* 157 */       missingStartRows--;
/*     */     }
/* 159 */     int missingEndRows = 0; int i;
/* 160 */     for (i = rowHeights.length - 1; i >= 0; i--) {
/* 161 */       missingEndRows += maxRowHeight - rowHeights[i];
/* 162 */       if (rowHeights[i] > 0) {
/*     */         break;
/*     */       }
/*     */     } 
/* 166 */     for (i = codewords.length - 1; missingEndRows > 0 && codewords[i] == null; i--) {
/* 167 */       missingEndRows--;
/*     */     }
/* 169 */     return rowIndicatorColumn.getBoundingBox().addMissingRows(missingStartRows, missingEndRows, rowIndicatorColumn.isLeft());
/*     */   }
/*     */ 
/*     */   
/*     */   private static int getMax(int[] values) {
/* 174 */     int maxValue = -1;
/* 175 */     for (int value : values) {
/* 176 */       maxValue = Math.max(maxValue, value);
/*     */     }
/* 178 */     return maxValue;
/*     */   }
/*     */ 
/*     */   
/*     */   private static BarcodeMetadata getBarcodeMetadata(DetectionResultRowIndicatorColumn leftRowIndicatorColumn, DetectionResultRowIndicatorColumn rightRowIndicatorColumn) {
/* 183 */     if (leftRowIndicatorColumn == null || leftRowIndicatorColumn.getBarcodeMetadata() == null) {
/* 184 */       return (rightRowIndicatorColumn == null) ? null : rightRowIndicatorColumn.getBarcodeMetadata();
/*     */     }
/* 186 */     if (rightRowIndicatorColumn == null || rightRowIndicatorColumn.getBarcodeMetadata() == null) {
/* 187 */       return (leftRowIndicatorColumn == null) ? null : leftRowIndicatorColumn.getBarcodeMetadata();
/*     */     }
/* 189 */     BarcodeMetadata leftBarcodeMetadata = leftRowIndicatorColumn.getBarcodeMetadata();
/* 190 */     BarcodeMetadata rightBarcodeMetadata = rightRowIndicatorColumn.getBarcodeMetadata();
/*     */     
/* 192 */     if (leftBarcodeMetadata.getColumnCount() != rightBarcodeMetadata.getColumnCount() && leftBarcodeMetadata.getErrorCorrectionLevel() != rightBarcodeMetadata.getErrorCorrectionLevel() && leftBarcodeMetadata.getRowCount() != rightBarcodeMetadata.getRowCount())
/*     */     {
/*     */       
/* 195 */       return null;
/*     */     }
/* 197 */     return leftBarcodeMetadata;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static DetectionResultRowIndicatorColumn getRowIndicatorColumn(BitMatrix image, BoundingBox boundingBox, ResultPoint startPoint, boolean leftToRight, int minCodewordWidth, int maxCodewordWidth) {
/* 206 */     DetectionResultRowIndicatorColumn rowIndicatorColumn = new DetectionResultRowIndicatorColumn(boundingBox, leftToRight);
/*     */     
/* 208 */     for (int i = 0; i < 2; i++) {
/* 209 */       int increment = (i == 0) ? 1 : -1;
/* 210 */       int startColumn = (int)startPoint.getX(); int imageRow;
/* 211 */       for (imageRow = (int)startPoint.getY(); imageRow <= boundingBox.getMaxY() && imageRow >= boundingBox.getMinY(); 
/* 212 */         imageRow += increment) {
/* 213 */         Codeword codeword = detectCodeword(image, 0, image.getWidth(), leftToRight, startColumn, imageRow, minCodewordWidth, maxCodewordWidth);
/*     */         
/* 215 */         if (codeword != null) {
/* 216 */           rowIndicatorColumn.setCodeword(imageRow, codeword);
/* 217 */           if (leftToRight) {
/* 218 */             startColumn = codeword.getStartX();
/*     */           } else {
/* 220 */             startColumn = codeword.getEndX();
/*     */           } 
/*     */         } 
/*     */       } 
/*     */     } 
/* 225 */     return rowIndicatorColumn;
/*     */   }
/*     */ 
/*     */   
/*     */   private static void adjustCodewordCount(DetectionResult detectionResult, BarcodeValue[][] barcodeMatrix) throws NotFoundException {
/* 230 */     int[] numberOfCodewords = barcodeMatrix[0][1].getValue();
/* 231 */     int calculatedNumberOfCodewords = detectionResult.getBarcodeColumnCount() * detectionResult.getBarcodeRowCount() - getNumberOfECCodeWords(detectionResult.getBarcodeECLevel());
/*     */ 
/*     */     
/* 234 */     if (numberOfCodewords.length == 0) {
/* 235 */       if (calculatedNumberOfCodewords < 1 || calculatedNumberOfCodewords > 928) {
/* 236 */         throw NotFoundException.getNotFoundInstance();
/*     */       }
/* 238 */       barcodeMatrix[0][1].setValue(calculatedNumberOfCodewords);
/* 239 */     } else if (numberOfCodewords[0] != calculatedNumberOfCodewords) {
/*     */       
/* 241 */       barcodeMatrix[0][1].setValue(calculatedNumberOfCodewords);
/*     */     } 
/*     */   }
/*     */ 
/*     */   
/*     */   private static DecoderResult createDecoderResult(DetectionResult detectionResult) throws FormatException, ChecksumException, NotFoundException {
/* 247 */     BarcodeValue[][] barcodeMatrix = createBarcodeMatrix(detectionResult);
/* 248 */     adjustCodewordCount(detectionResult, barcodeMatrix);
/* 249 */     Collection<Integer> erasures = new ArrayList<Integer>();
/* 250 */     int[] codewords = new int[detectionResult.getBarcodeRowCount() * detectionResult.getBarcodeColumnCount()];
/* 251 */     List<int[]> ambiguousIndexValuesList = (List)new ArrayList<int>();
/* 252 */     List<Integer> ambiguousIndexesList = new ArrayList<Integer>();
/* 253 */     for (int row = 0; row < detectionResult.getBarcodeRowCount(); row++) {
/* 254 */       for (int column = 0; column < detectionResult.getBarcodeColumnCount(); column++) {
/* 255 */         int[] values = barcodeMatrix[row][column + 1].getValue();
/* 256 */         int codewordIndex = row * detectionResult.getBarcodeColumnCount() + column;
/* 257 */         if (values.length == 0) {
/* 258 */           erasures.add(Integer.valueOf(codewordIndex));
/* 259 */         } else if (values.length == 1) {
/* 260 */           codewords[codewordIndex] = values[0];
/*     */         } else {
/* 262 */           ambiguousIndexesList.add(Integer.valueOf(codewordIndex));
/* 263 */           ambiguousIndexValuesList.add(values);
/*     */         } 
/*     */       } 
/*     */     } 
/* 267 */     int[][] ambiguousIndexValues = new int[ambiguousIndexValuesList.size()][];
/* 268 */     for (int i = 0; i < ambiguousIndexValues.length; i++) {
/* 269 */       ambiguousIndexValues[i] = ambiguousIndexValuesList.get(i);
/*     */     }
/* 271 */     return createDecoderResultFromAmbiguousValues(detectionResult.getBarcodeECLevel(), codewords, PDF417Common.toIntArray(erasures), PDF417Common.toIntArray(ambiguousIndexesList), ambiguousIndexValues);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static DecoderResult createDecoderResultFromAmbiguousValues(int ecLevel, int[] codewords, int[] erasureArray, int[] ambiguousIndexes, int[][] ambiguousIndexValues) throws FormatException, ChecksumException {
/* 298 */     int[] ambiguousIndexCount = new int[ambiguousIndexes.length];
/*     */     
/* 300 */     int tries = 100;
/* 301 */     while (tries-- > 0) {
/* 302 */       for (int i = 0; i < ambiguousIndexCount.length; i++) {
/* 303 */         codewords[ambiguousIndexes[i]] = ambiguousIndexValues[i][ambiguousIndexCount[i]];
/*     */       }
/*     */       try {
/* 306 */         return decodeCodewords(codewords, ecLevel, erasureArray);
/* 307 */       } catch (ChecksumException ignored) {
/*     */ 
/*     */         
/* 310 */         if (ambiguousIndexCount.length == 0) {
/* 311 */           throw ChecksumException.getChecksumInstance();
/*     */         }
/* 313 */         for (int j = 0; j < ambiguousIndexCount.length; j++) {
/* 314 */           if (ambiguousIndexCount[j] < (ambiguousIndexValues[j]).length - 1) {
/* 315 */             ambiguousIndexCount[j] = ambiguousIndexCount[j] + 1;
/*     */             break;
/*     */           } 
/* 318 */           ambiguousIndexCount[j] = 0;
/* 319 */           if (j == ambiguousIndexCount.length - 1) {
/* 320 */             throw ChecksumException.getChecksumInstance();
/*     */           }
/*     */         } 
/*     */       } 
/*     */     } 
/* 325 */     throw ChecksumException.getChecksumInstance();
/*     */   }
/*     */   
/*     */   private static BarcodeValue[][] createBarcodeMatrix(DetectionResult detectionResult) {
/* 329 */     BarcodeValue[][] barcodeMatrix = new BarcodeValue[detectionResult.getBarcodeRowCount()][detectionResult.getBarcodeColumnCount() + 2];
/*     */     
/* 331 */     for (int row = 0; row < barcodeMatrix.length; row++) {
/* 332 */       for (int i = 0; i < (barcodeMatrix[row]).length; i++) {
/* 333 */         barcodeMatrix[row][i] = new BarcodeValue();
/*     */       }
/*     */     } 
/*     */     
/* 337 */     int column = -1;
/* 338 */     for (DetectionResultColumn detectionResultColumn : detectionResult.getDetectionResultColumns()) {
/* 339 */       column++;
/* 340 */       if (detectionResultColumn != null)
/*     */       {
/*     */         
/* 343 */         for (Codeword codeword : detectionResultColumn.getCodewords()) {
/* 344 */           if (codeword != null && codeword.getRowNumber() != -1)
/*     */           {
/*     */             
/* 347 */             barcodeMatrix[codeword.getRowNumber()][column].setValue(codeword.getValue()); } 
/*     */         }  } 
/*     */     } 
/* 350 */     return barcodeMatrix;
/*     */   }
/*     */   
/*     */   private static boolean isValidBarcodeColumn(DetectionResult detectionResult, int barcodeColumn) {
/* 354 */     return (barcodeColumn >= 0 && barcodeColumn <= detectionResult.getBarcodeColumnCount() + 1);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static int getStartColumn(DetectionResult detectionResult, int barcodeColumn, int imageRow, boolean leftToRight) {
/* 361 */     int offset = leftToRight ? 1 : -1;
/* 362 */     Codeword codeword = null;
/* 363 */     if (isValidBarcodeColumn(detectionResult, barcodeColumn - offset)) {
/* 364 */       codeword = detectionResult.getDetectionResultColumn(barcodeColumn - offset).getCodeword(imageRow);
/*     */     }
/* 366 */     if (codeword != null) {
/* 367 */       return leftToRight ? codeword.getEndX() : codeword.getStartX();
/*     */     }
/* 369 */     codeword = detectionResult.getDetectionResultColumn(barcodeColumn).getCodewordNearby(imageRow);
/* 370 */     if (codeword != null) {
/* 371 */       return leftToRight ? codeword.getStartX() : codeword.getEndX();
/*     */     }
/* 373 */     if (isValidBarcodeColumn(detectionResult, barcodeColumn - offset)) {
/* 374 */       codeword = detectionResult.getDetectionResultColumn(barcodeColumn - offset).getCodewordNearby(imageRow);
/*     */     }
/* 376 */     if (codeword != null) {
/* 377 */       return leftToRight ? codeword.getEndX() : codeword.getStartX();
/*     */     }
/* 379 */     int skippedColumns = 0;
/*     */     
/* 381 */     while (isValidBarcodeColumn(detectionResult, barcodeColumn - offset)) {
/* 382 */       barcodeColumn -= offset;
/* 383 */       for (Codeword previousRowCodeword : detectionResult.getDetectionResultColumn(barcodeColumn).getCodewords()) {
/* 384 */         if (previousRowCodeword != null) {
/* 385 */           return (leftToRight ? previousRowCodeword.getEndX() : previousRowCodeword.getStartX()) + offset * skippedColumns * (previousRowCodeword.getEndX() - previousRowCodeword.getStartX());
/*     */         }
/*     */       } 
/*     */ 
/*     */ 
/*     */       
/* 391 */       skippedColumns++;
/*     */     } 
/* 393 */     return leftToRight ? detectionResult.getBoundingBox().getMinX() : detectionResult.getBoundingBox().getMaxX();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static Codeword detectCodeword(BitMatrix image, int minColumn, int maxColumn, boolean leftToRight, int startColumn, int imageRow, int minCodewordWidth, int maxCodewordWidth) {
/*     */     int endColumn;
/* 404 */     startColumn = adjustCodewordStartColumn(image, minColumn, maxColumn, leftToRight, startColumn, imageRow);
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 409 */     int[] moduleBitCount = getModuleBitCount(image, minColumn, maxColumn, leftToRight, startColumn, imageRow);
/* 410 */     if (moduleBitCount == null) {
/* 411 */       return null;
/*     */     }
/*     */     
/* 414 */     int codewordBitCount = PDF417Common.getBitCountSum(moduleBitCount);
/* 415 */     if (leftToRight) {
/* 416 */       endColumn = startColumn + codewordBitCount;
/*     */     } else {
/* 418 */       for (int i = 0; i < moduleBitCount.length >> 1; i++) {
/* 419 */         int tmpCount = moduleBitCount[i];
/* 420 */         moduleBitCount[i] = moduleBitCount[moduleBitCount.length - 1 - i];
/* 421 */         moduleBitCount[moduleBitCount.length - 1 - i] = tmpCount;
/*     */       } 
/* 423 */       endColumn = startColumn;
/* 424 */       startColumn = endColumn - codewordBitCount;
/*     */     } 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 440 */     if (!checkCodewordSkew(codewordBitCount, minCodewordWidth, maxCodewordWidth))
/*     */     {
/*     */       
/* 443 */       return null;
/*     */     }
/*     */     
/* 446 */     int decodedValue = PDF417CodewordDecoder.getDecodedValue(moduleBitCount);
/* 447 */     int codeword = PDF417Common.getCodeword(decodedValue);
/* 448 */     if (codeword == -1) {
/* 449 */       return null;
/*     */     }
/* 451 */     return new Codeword(startColumn, endColumn, getCodewordBucketNumber(decodedValue), codeword);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static int[] getModuleBitCount(BitMatrix image, int minColumn, int maxColumn, boolean leftToRight, int startColumn, int imageRow) {
/* 460 */     int imageColumn = startColumn;
/* 461 */     int[] moduleBitCount = new int[8];
/* 462 */     int moduleNumber = 0;
/* 463 */     int increment = leftToRight ? 1 : -1;
/* 464 */     boolean previousPixelValue = leftToRight;
/* 465 */     while (((leftToRight && imageColumn < maxColumn) || (!leftToRight && imageColumn >= minColumn)) && moduleNumber < moduleBitCount.length) {
/*     */       
/* 467 */       if (image.get(imageColumn, imageRow) == previousPixelValue) {
/* 468 */         moduleBitCount[moduleNumber] = moduleBitCount[moduleNumber] + 1;
/* 469 */         imageColumn += increment; continue;
/*     */       } 
/* 471 */       moduleNumber++;
/* 472 */       previousPixelValue = !previousPixelValue;
/*     */     } 
/*     */     
/* 475 */     if (moduleNumber == moduleBitCount.length || (((leftToRight && imageColumn == maxColumn) || (!leftToRight && imageColumn == minColumn)) && moduleNumber == moduleBitCount.length - 1))
/*     */     {
/* 477 */       return moduleBitCount;
/*     */     }
/* 479 */     return null;
/*     */   }
/*     */   
/*     */   private static int getNumberOfECCodeWords(int barcodeECLevel) {
/* 483 */     return 2 << barcodeECLevel;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static int adjustCodewordStartColumn(BitMatrix image, int minColumn, int maxColumn, boolean leftToRight, int codewordStartColumn, int imageRow) {
/* 492 */     int correctedStartColumn = codewordStartColumn;
/* 493 */     int increment = leftToRight ? -1 : 1;
/*     */     
/* 495 */     for (int i = 0; i < 2; i++) {
/* 496 */       while (((leftToRight && correctedStartColumn >= minColumn) || (!leftToRight && correctedStartColumn < maxColumn)) && leftToRight == image.get(correctedStartColumn, imageRow)) {
/*     */         
/* 498 */         if (Math.abs(codewordStartColumn - correctedStartColumn) > 2) {
/* 499 */           return codewordStartColumn;
/*     */         }
/* 501 */         correctedStartColumn += increment;
/*     */       } 
/* 503 */       increment = -increment;
/* 504 */       leftToRight = !leftToRight;
/*     */     } 
/* 506 */     return correctedStartColumn;
/*     */   }
/*     */   
/*     */   private static boolean checkCodewordSkew(int codewordSize, int minCodewordWidth, int maxCodewordWidth) {
/* 510 */     return (minCodewordWidth - 2 <= codewordSize && codewordSize <= maxCodewordWidth + 2);
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   private static DecoderResult decodeCodewords(int[] codewords, int ecLevel, int[] erasures) throws FormatException, ChecksumException {
/* 516 */     if (codewords.length == 0) {
/* 517 */       throw FormatException.getFormatInstance();
/*     */     }
/*     */     
/* 520 */     int numECCodewords = 1 << ecLevel + 1;
/* 521 */     int correctedErrorsCount = correctErrors(codewords, erasures, numECCodewords);
/* 522 */     verifyCodewordCount(codewords, numECCodewords);
/*     */ 
/*     */     
/* 525 */     DecoderResult decoderResult = DecodedBitStreamParser.decode(codewords, String.valueOf(ecLevel));
/* 526 */     decoderResult.setErrorsCorrected(Integer.valueOf(correctedErrorsCount));
/* 527 */     decoderResult.setErasures(Integer.valueOf(erasures.length));
/* 528 */     return decoderResult;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static int correctErrors(int[] codewords, int[] erasures, int numECCodewords) throws ChecksumException {
/* 541 */     if ((erasures != null && erasures.length > numECCodewords / 2 + 3) || numECCodewords < 0 || numECCodewords > 512)
/*     */     {
/*     */ 
/*     */ 
/*     */       
/* 546 */       throw ChecksumException.getChecksumInstance();
/*     */     }
/* 548 */     return errorCorrection.decode(codewords, numECCodewords, erasures);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static void verifyCodewordCount(int[] codewords, int numECCodewords) throws FormatException {
/* 558 */     if (codewords.length < 4)
/*     */     {
/*     */       
/* 561 */       throw FormatException.getFormatInstance();
/*     */     }
/*     */ 
/*     */ 
/*     */     
/* 566 */     int numberOfCodewords = codewords[0];
/* 567 */     if (numberOfCodewords > codewords.length) {
/* 568 */       throw FormatException.getFormatInstance();
/*     */     }
/* 570 */     if (numberOfCodewords == 0)
/*     */     {
/* 572 */       if (numECCodewords < codewords.length) {
/* 573 */         codewords[0] = codewords.length - numECCodewords;
/*     */       } else {
/* 575 */         throw FormatException.getFormatInstance();
/*     */       } 
/*     */     }
/*     */   }
/*     */   
/*     */   private static int[] getBitCountForCodeword(int codeword) {
/* 581 */     int[] result = new int[8];
/* 582 */     int previousValue = 0;
/* 583 */     int i = result.length - 1;
/*     */     while (true) {
/* 585 */       if ((codeword & 0x1) != previousValue) {
/* 586 */         previousValue = codeword & 0x1;
/* 587 */         i--;
/* 588 */         if (i < 0) {
/*     */           break;
/*     */         }
/*     */       } 
/* 592 */       result[i] = result[i] + 1;
/* 593 */       codeword >>= 1;
/*     */     } 
/* 595 */     return result;
/*     */   }
/*     */   
/*     */   private static int getCodewordBucketNumber(int codeword) {
/* 599 */     return getCodewordBucketNumber(getBitCountForCodeword(codeword));
/*     */   }
/*     */   
/*     */   private static int getCodewordBucketNumber(int[] moduleBitCount) {
/* 603 */     return (moduleBitCount[0] - moduleBitCount[2] + moduleBitCount[4] - moduleBitCount[6] + 9) % 9;
/*     */   }
/*     */   
/*     */   public static String toString(BarcodeValue[][] barcodeMatrix) {
/* 607 */     Formatter formatter = new Formatter();
/* 608 */     for (int row = 0; row < barcodeMatrix.length; row++) {
/* 609 */       formatter.format("Row %2d: ", new Object[] { Integer.valueOf(row) });
/* 610 */       for (int column = 0; column < (barcodeMatrix[row]).length; column++) {
/* 611 */         BarcodeValue barcodeValue = barcodeMatrix[row][column];
/* 612 */         if ((barcodeValue.getValue()).length == 0) {
/* 613 */           formatter.format("        ", (Object[])null);
/*     */         } else {
/* 615 */           formatter.format("%4d(%2d)", new Object[] { Integer.valueOf(barcodeValue.getValue()[0]), barcodeValue.getConfidence(barcodeValue.getValue()[0]) });
/*     */         } 
/*     */       } 
/*     */       
/* 619 */       formatter.format("\n", new Object[0]);
/*     */     } 
/* 621 */     String result = formatter.toString();
/* 622 */     formatter.close();
/* 623 */     return result;
/*     */   }
/*     */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\com\google\zxing\pdf417\decoder\PDF417ScanningDecoder.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       1.1.3
 */