/*     */ package com.google.zxing.pdf417.decoder.ec;
/*     */ 
/*     */ import com.google.zxing.ChecksumException;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public final class ErrorCorrection
/*     */ {
/*  35 */   private final ModulusGF field = ModulusGF.PDF417_GF;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public int decode(int[] received, int numECCodewords, int[] erasures) throws ChecksumException {
/*  45 */     ModulusPoly poly = new ModulusPoly(this.field, received);
/*  46 */     int[] S = new int[numECCodewords];
/*  47 */     boolean error = false;
/*  48 */     for (int i = numECCodewords; i > 0; i--) {
/*  49 */       int eval = poly.evaluateAt(this.field.exp(i));
/*  50 */       S[numECCodewords - i] = eval;
/*  51 */       if (eval != 0) {
/*  52 */         error = true;
/*     */       }
/*     */     } 
/*     */     
/*  56 */     if (!error) {
/*  57 */       return 0;
/*     */     }
/*     */     
/*  60 */     ModulusPoly knownErrors = this.field.getOne();
/*  61 */     for (int erasure : erasures) {
/*  62 */       int b = this.field.exp(received.length - 1 - erasure);
/*     */       
/*  64 */       ModulusPoly term = new ModulusPoly(this.field, new int[] { this.field.subtract(0, b), 1 });
/*  65 */       knownErrors = knownErrors.multiply(term);
/*     */     } 
/*     */     
/*  68 */     ModulusPoly syndrome = new ModulusPoly(this.field, S);
/*     */ 
/*     */     
/*  71 */     ModulusPoly[] sigmaOmega = runEuclideanAlgorithm(this.field.buildMonomial(numECCodewords, 1), syndrome, numECCodewords);
/*     */     
/*  73 */     ModulusPoly sigma = sigmaOmega[0];
/*  74 */     ModulusPoly omega = sigmaOmega[1];
/*     */ 
/*     */ 
/*     */     
/*  78 */     int[] errorLocations = findErrorLocations(sigma);
/*  79 */     int[] errorMagnitudes = findErrorMagnitudes(omega, sigma, errorLocations);
/*     */     
/*  81 */     for (int j = 0; j < errorLocations.length; j++) {
/*  82 */       int position = received.length - 1 - this.field.log(errorLocations[j]);
/*  83 */       if (position < 0) {
/*  84 */         throw ChecksumException.getChecksumInstance();
/*     */       }
/*  86 */       received[position] = this.field.subtract(received[position], errorMagnitudes[j]);
/*     */     } 
/*  88 */     return errorLocations.length;
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   private ModulusPoly[] runEuclideanAlgorithm(ModulusPoly a, ModulusPoly b, int R) throws ChecksumException {
/*  94 */     if (a.getDegree() < b.getDegree()) {
/*  95 */       ModulusPoly temp = a;
/*  96 */       a = b;
/*  97 */       b = temp;
/*     */     } 
/*     */     
/* 100 */     ModulusPoly rLast = a;
/* 101 */     ModulusPoly r = b;
/* 102 */     ModulusPoly tLast = this.field.getZero();
/* 103 */     ModulusPoly t = this.field.getOne();
/*     */ 
/*     */     
/* 106 */     while (r.getDegree() >= R / 2) {
/* 107 */       ModulusPoly rLastLast = rLast;
/* 108 */       ModulusPoly tLastLast = tLast;
/* 109 */       rLast = r;
/* 110 */       tLast = t;
/*     */ 
/*     */       
/* 113 */       if (rLast.isZero())
/*     */       {
/* 115 */         throw ChecksumException.getChecksumInstance();
/*     */       }
/* 117 */       r = rLastLast;
/* 118 */       ModulusPoly q = this.field.getZero();
/* 119 */       int denominatorLeadingTerm = rLast.getCoefficient(rLast.getDegree());
/* 120 */       int dltInverse = this.field.inverse(denominatorLeadingTerm);
/* 121 */       while (r.getDegree() >= rLast.getDegree() && !r.isZero()) {
/* 122 */         int degreeDiff = r.getDegree() - rLast.getDegree();
/* 123 */         int scale = this.field.multiply(r.getCoefficient(r.getDegree()), dltInverse);
/* 124 */         q = q.add(this.field.buildMonomial(degreeDiff, scale));
/* 125 */         r = r.subtract(rLast.multiplyByMonomial(degreeDiff, scale));
/*     */       } 
/*     */       
/* 128 */       t = q.multiply(tLast).subtract(tLastLast).negative();
/*     */     } 
/*     */     
/* 131 */     int sigmaTildeAtZero = t.getCoefficient(0);
/* 132 */     if (sigmaTildeAtZero == 0) {
/* 133 */       throw ChecksumException.getChecksumInstance();
/*     */     }
/*     */     
/* 136 */     int inverse = this.field.inverse(sigmaTildeAtZero);
/* 137 */     ModulusPoly sigma = t.multiply(inverse);
/* 138 */     ModulusPoly omega = r.multiply(inverse);
/* 139 */     return new ModulusPoly[] { sigma, omega };
/*     */   }
/*     */ 
/*     */   
/*     */   private int[] findErrorLocations(ModulusPoly errorLocator) throws ChecksumException {
/* 144 */     int numErrors = errorLocator.getDegree();
/* 145 */     int[] result = new int[numErrors];
/* 146 */     int e = 0;
/* 147 */     for (int i = 1; i < this.field.getSize() && e < numErrors; i++) {
/* 148 */       if (errorLocator.evaluateAt(i) == 0) {
/* 149 */         result[e] = this.field.inverse(i);
/* 150 */         e++;
/*     */       } 
/*     */     } 
/* 153 */     if (e != numErrors) {
/* 154 */       throw ChecksumException.getChecksumInstance();
/*     */     }
/* 156 */     return result;
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   private int[] findErrorMagnitudes(ModulusPoly errorEvaluator, ModulusPoly errorLocator, int[] errorLocations) {
/* 162 */     int errorLocatorDegree = errorLocator.getDegree();
/* 163 */     int[] formalDerivativeCoefficients = new int[errorLocatorDegree];
/* 164 */     for (int i = 1; i <= errorLocatorDegree; i++) {
/* 165 */       formalDerivativeCoefficients[errorLocatorDegree - i] = this.field.multiply(i, errorLocator.getCoefficient(i));
/*     */     }
/*     */     
/* 168 */     ModulusPoly formalDerivative = new ModulusPoly(this.field, formalDerivativeCoefficients);
/*     */ 
/*     */     
/* 171 */     int s = errorLocations.length;
/* 172 */     int[] result = new int[s];
/* 173 */     for (int j = 0; j < s; j++) {
/* 174 */       int xiInverse = this.field.inverse(errorLocations[j]);
/* 175 */       int numerator = this.field.subtract(0, errorEvaluator.evaluateAt(xiInverse));
/* 176 */       int denominator = this.field.inverse(formalDerivative.evaluateAt(xiInverse));
/* 177 */       result[j] = this.field.multiply(numerator, denominator);
/*     */     } 
/* 179 */     return result;
/*     */   }
/*     */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\com\google\zxing\pdf417\decoder\ec\ErrorCorrection.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       1.1.3
 */