/*     */ package com.google.zxing.pdf417.detector;
/*     */ 
/*     */ import com.google.zxing.BinaryBitmap;
/*     */ import com.google.zxing.DecodeHintType;
/*     */ import com.google.zxing.NotFoundException;
/*     */ import com.google.zxing.ResultPoint;
/*     */ import com.google.zxing.common.BitArray;
/*     */ import com.google.zxing.common.BitMatrix;
/*     */ import java.util.ArrayList;
/*     */ import java.util.Arrays;
/*     */ import java.util.List;
/*     */ import java.util.Map;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public final class Detector
/*     */ {
/*  41 */   private static final int[] INDEXES_START_PATTERN = new int[] { 0, 4, 1, 5 };
/*  42 */   private static final int[] INDEXES_STOP_PATTERN = new int[] { 6, 2, 7, 3 };
/*     */   
/*     */   private static final int INTEGER_MATH_SHIFT = 8;
/*     */   
/*     */   private static final int PATTERN_MATCH_RESULT_SCALE_FACTOR = 256;
/*     */   
/*     */   private static final int MAX_AVG_VARIANCE = 107;
/*     */   private static final int MAX_INDIVIDUAL_VARIANCE = 204;
/*  50 */   private static final int[] START_PATTERN = new int[] { 8, 1, 1, 1, 1, 1, 1, 3 };
/*     */   
/*  52 */   private static final int[] STOP_PATTERN = new int[] { 7, 1, 1, 3, 1, 1, 1, 2, 1 };
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static final int MAX_PIXEL_DRIFT = 3;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static final int MAX_PATTERN_DRIFT = 5;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static final int SKIPPED_ROW_COUNT_MAX = 25;
/*     */ 
/*     */ 
/*     */   
/*     */   private static final int ROW_STEP = 5;
/*     */ 
/*     */ 
/*     */   
/*     */   private static final int BARCODE_MIN_HEIGHT = 10;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static PDF417DetectorResult detect(BinaryBitmap image, Map<DecodeHintType, ?> hints, boolean multiple) throws NotFoundException {
/*  81 */     BitMatrix bitMatrix = image.getBlackMatrix();
/*     */     
/*  83 */     List<ResultPoint[]> barcodeCoordinates = detect(multiple, bitMatrix);
/*  84 */     if (barcodeCoordinates.isEmpty()) {
/*  85 */       rotate180(bitMatrix);
/*  86 */       barcodeCoordinates = detect(multiple, bitMatrix);
/*     */     } 
/*  88 */     return new PDF417DetectorResult(bitMatrix, barcodeCoordinates);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static List<ResultPoint[]> detect(boolean multiple, BitMatrix bitMatrix) {
/*  99 */     List<ResultPoint[]> barcodeCoordinates = (List)new ArrayList<ResultPoint>();
/* 100 */     int row = 0;
/* 101 */     int column = 0;
/* 102 */     boolean foundBarcodeInRow = false;
/* 103 */     while (row < bitMatrix.getHeight()) {
/* 104 */       ResultPoint[] vertices = findVertices(bitMatrix, row, column);
/*     */       
/* 106 */       if (vertices[0] == null && vertices[3] == null) {
/* 107 */         if (!foundBarcodeInRow) {
/*     */           break;
/*     */         }
/*     */ 
/*     */ 
/*     */         
/* 113 */         foundBarcodeInRow = false;
/* 114 */         column = 0;
/* 115 */         for (ResultPoint[] barcodeCoordinate : barcodeCoordinates) {
/* 116 */           if (barcodeCoordinate[1] != null) {
/* 117 */             row = (int)Math.max(row, barcodeCoordinate[1].getY());
/*     */           }
/* 119 */           if (barcodeCoordinate[3] != null) {
/* 120 */             row = Math.max(row, (int)barcodeCoordinate[3].getY());
/*     */           }
/*     */         } 
/* 123 */         row += 5;
/*     */         continue;
/*     */       } 
/* 126 */       foundBarcodeInRow = true;
/* 127 */       barcodeCoordinates.add(vertices);
/* 128 */       if (!multiple) {
/*     */         break;
/*     */       }
/*     */ 
/*     */       
/* 133 */       if (vertices[2] != null) {
/* 134 */         column = (int)vertices[2].getX();
/* 135 */         row = (int)vertices[2].getY(); continue;
/*     */       } 
/* 137 */       column = (int)vertices[4].getX();
/* 138 */       row = (int)vertices[4].getY();
/*     */     } 
/*     */     
/* 141 */     return barcodeCoordinates;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   static void rotate180(BitMatrix bitMatrix) {
/* 151 */     int width = bitMatrix.getWidth();
/* 152 */     int height = bitMatrix.getHeight();
/* 153 */     BitArray firstRowBitArray = new BitArray(width);
/* 154 */     BitArray secondRowBitArray = new BitArray(width);
/* 155 */     BitArray tmpBitArray = new BitArray(width);
/* 156 */     for (int y = 0; y < height + 1 >> 1; y++) {
/* 157 */       firstRowBitArray = bitMatrix.getRow(y, firstRowBitArray);
/* 158 */       bitMatrix.setRow(y, mirror(bitMatrix.getRow(height - 1 - y, secondRowBitArray), tmpBitArray));
/* 159 */       bitMatrix.setRow(height - 1 - y, mirror(firstRowBitArray, tmpBitArray));
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   static BitArray mirror(BitArray input, BitArray result) {
/* 167 */     result.clear();
/* 168 */     int size = input.getSize();
/* 169 */     for (int i = 0; i < size; i++) {
/* 170 */       if (input.get(i)) {
/* 171 */         result.set(size - 1 - i);
/*     */       }
/*     */     } 
/* 174 */     return result;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static ResultPoint[] findVertices(BitMatrix matrix, int startRow, int startColumn) {
/* 193 */     int height = matrix.getHeight();
/* 194 */     int width = matrix.getWidth();
/*     */     
/* 196 */     ResultPoint[] result = new ResultPoint[8];
/* 197 */     copyToResult(result, findRowsWithPattern(matrix, height, width, startRow, startColumn, START_PATTERN), INDEXES_START_PATTERN);
/*     */ 
/*     */     
/* 200 */     if (result[4] != null) {
/* 201 */       startColumn = (int)result[4].getX();
/* 202 */       startRow = (int)result[4].getY();
/*     */     } 
/* 204 */     copyToResult(result, findRowsWithPattern(matrix, height, width, startRow, startColumn, STOP_PATTERN), INDEXES_STOP_PATTERN);
/*     */     
/* 206 */     return result;
/*     */   }
/*     */   
/*     */   private static void copyToResult(ResultPoint[] result, ResultPoint[] tmpResult, int[] destinationIndexes) {
/* 210 */     for (int i = 0; i < destinationIndexes.length; i++) {
/* 211 */       result[destinationIndexes[i]] = tmpResult[i];
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static ResultPoint[] findRowsWithPattern(BitMatrix matrix, int height, int width, int startRow, int startColumn, int[] pattern) {
/* 221 */     ResultPoint[] result = new ResultPoint[4];
/* 222 */     boolean found = false;
/* 223 */     int[] counters = new int[pattern.length];
/* 224 */     for (; startRow < height; startRow += 5) {
/* 225 */       int[] loc = findGuardPattern(matrix, startColumn, startRow, width, false, pattern, counters);
/* 226 */       if (loc != null) {
/* 227 */         while (startRow > 0) {
/* 228 */           int[] previousRowLoc = findGuardPattern(matrix, startColumn, --startRow, width, false, pattern, counters);
/* 229 */           if (previousRowLoc != null) {
/* 230 */             loc = previousRowLoc; continue;
/*     */           } 
/* 232 */           startRow++;
/*     */         } 
/*     */ 
/*     */         
/* 236 */         result[0] = new ResultPoint(loc[0], startRow);
/* 237 */         result[1] = new ResultPoint(loc[1], startRow);
/* 238 */         found = true;
/*     */         break;
/*     */       } 
/*     */     } 
/* 242 */     int stopRow = startRow + 1;
/*     */     
/* 244 */     if (found) {
/* 245 */       int skippedRowCount = 0;
/* 246 */       int[] previousRowLoc = { (int)result[0].getX(), (int)result[1].getX() };
/* 247 */       for (; stopRow < height; stopRow++) {
/* 248 */         int[] loc = findGuardPattern(matrix, previousRowLoc[0], stopRow, width, false, pattern, counters);
/*     */ 
/*     */ 
/*     */ 
/*     */         
/* 253 */         if (loc != null && Math.abs(previousRowLoc[0] - loc[0]) < 5 && Math.abs(previousRowLoc[1] - loc[1]) < 5) {
/*     */ 
/*     */           
/* 256 */           previousRowLoc = loc;
/* 257 */           skippedRowCount = 0;
/*     */         } else {
/* 259 */           if (skippedRowCount > 25) {
/*     */             break;
/*     */           }
/* 262 */           skippedRowCount++;
/*     */         } 
/*     */       } 
/*     */       
/* 266 */       stopRow -= skippedRowCount + 1;
/* 267 */       result[2] = new ResultPoint(previousRowLoc[0], stopRow);
/* 268 */       result[3] = new ResultPoint(previousRowLoc[1], stopRow);
/*     */     } 
/* 270 */     if (stopRow - startRow < 10) {
/* 271 */       for (int i = 0; i < result.length; i++) {
/* 272 */         result[i] = null;
/*     */       }
/*     */     }
/* 275 */     return result;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static int[] findGuardPattern(BitMatrix matrix, int column, int row, int width, boolean whiteFirst, int[] pattern, int[] counters) {
/* 295 */     Arrays.fill(counters, 0, counters.length, 0);
/* 296 */     int patternLength = pattern.length;
/* 297 */     boolean isWhite = whiteFirst;
/* 298 */     int patternStart = column;
/* 299 */     int pixelDrift = 0;
/*     */ 
/*     */     
/* 302 */     while (matrix.get(patternStart, row) && patternStart > 0 && pixelDrift++ < 3) {
/* 303 */       patternStart--;
/*     */     }
/* 305 */     int x = patternStart;
/* 306 */     int counterPosition = 0;
/* 307 */     for (; x < width; x++) {
/* 308 */       boolean pixel = matrix.get(x, row);
/* 309 */       if (pixel ^ isWhite) {
/* 310 */         counters[counterPosition] = counters[counterPosition] + 1;
/*     */       } else {
/* 312 */         if (counterPosition == patternLength - 1) {
/* 313 */           if (patternMatchVariance(counters, pattern, 204) < 107) {
/* 314 */             return new int[] { patternStart, x };
/*     */           }
/* 316 */           patternStart += counters[0] + counters[1];
/* 317 */           System.arraycopy(counters, 2, counters, 0, patternLength - 2);
/* 318 */           counters[patternLength - 2] = 0;
/* 319 */           counters[patternLength - 1] = 0;
/* 320 */           counterPosition--;
/*     */         } else {
/* 322 */           counterPosition++;
/*     */         } 
/* 324 */         counters[counterPosition] = 1;
/* 325 */         isWhite = !isWhite;
/*     */       } 
/*     */     } 
/* 328 */     if (counterPosition == patternLength - 1 && 
/* 329 */       patternMatchVariance(counters, pattern, 204) < 107) {
/* 330 */       return new int[] { patternStart, x - 1 };
/*     */     }
/*     */     
/* 333 */     return null;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static int patternMatchVariance(int[] counters, int[] pattern, int maxIndividualVariance) {
/* 352 */     int numCounters = counters.length;
/* 353 */     int total = 0;
/* 354 */     int patternLength = 0;
/* 355 */     for (int i = 0; i < numCounters; i++) {
/* 356 */       total += counters[i];
/* 357 */       patternLength += pattern[i];
/*     */     } 
/* 359 */     if (total < patternLength)
/*     */     {
/*     */       
/* 362 */       return Integer.MAX_VALUE;
/*     */     }
/*     */ 
/*     */ 
/*     */     
/* 367 */     int unitBarWidth = (total << 8) / patternLength;
/* 368 */     maxIndividualVariance = maxIndividualVariance * unitBarWidth >> 8;
/*     */     
/* 370 */     int totalVariance = 0;
/* 371 */     for (int x = 0; x < numCounters; x++) {
/* 372 */       int counter = counters[x] << 8;
/* 373 */       int scaledPattern = pattern[x] * unitBarWidth;
/* 374 */       int variance = (counter > scaledPattern) ? (counter - scaledPattern) : (scaledPattern - counter);
/* 375 */       if (variance > maxIndividualVariance) {
/* 376 */         return Integer.MAX_VALUE;
/*     */       }
/* 378 */       totalVariance += variance;
/*     */     } 
/* 380 */     return totalVariance / total;
/*     */   }
/*     */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\com\google\zxing\pdf417\detector\Detector.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       1.1.3
 */