/*     */ package com.google.zxing.pdf417.encoder;
/*     */ 
/*     */ import com.google.zxing.WriterException;
/*     */ import java.math.BigInteger;
/*     */ import java.util.Arrays;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ final class PDF417HighLevelEncoder
/*     */ {
/*     */   private static final int TEXT_COMPACTION = 0;
/*     */   private static final int BYTE_COMPACTION = 1;
/*     */   private static final int NUMERIC_COMPACTION = 2;
/*     */   private static final int SUBMODE_ALPHA = 0;
/*     */   private static final int SUBMODE_LOWER = 1;
/*     */   private static final int SUBMODE_MIXED = 2;
/*     */   private static final int SUBMODE_PUNCTUATION = 3;
/*     */   private static final int LATCH_TO_TEXT = 900;
/*     */   private static final int LATCH_TO_BYTE_PADDED = 901;
/*     */   private static final int LATCH_TO_NUMERIC = 902;
/*     */   private static final int SHIFT_TO_BYTE = 913;
/*     */   private static final int LATCH_TO_BYTE = 924;
/*  97 */   private static final byte[] TEXT_MIXED_RAW = new byte[] { 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 38, 13, 9, 44, 58, 35, 45, 46, 36, 47, 43, 37, 42, 61, 94, 0, 32, 0, 0, 0 };
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 104 */   private static final byte[] TEXT_PUNCTUATION_RAW = new byte[] { 59, 60, 62, 64, 91, 92, 93, 95, 96, 126, 33, 13, 9, 44, 58, 10, 45, 46, 36, 47, 34, 124, 42, 40, 41, 63, 123, 125, 39, 0 };
/*     */ 
/*     */ 
/*     */   
/* 108 */   private static final byte[] MIXED = new byte[128];
/* 109 */   private static final byte[] PUNCTUATION = new byte[128];
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   static {
/* 116 */     Arrays.fill(MIXED, (byte)-1); byte i;
/* 117 */     for (i = 0; i < TEXT_MIXED_RAW.length; i = (byte)(i + 1)) {
/* 118 */       byte b = TEXT_MIXED_RAW[i];
/* 119 */       if (b > 0) {
/* 120 */         MIXED[b] = i;
/*     */       }
/*     */     } 
/* 123 */     Arrays.fill(PUNCTUATION, (byte)-1);
/* 124 */     for (i = 0; i < TEXT_PUNCTUATION_RAW.length; i = (byte)(i + 1)) {
/* 125 */       byte b = TEXT_PUNCTUATION_RAW[i];
/* 126 */       if (b > 0) {
/* 127 */         PUNCTUATION[b] = i;
/*     */       }
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static byte[] getBytesForMessage(String msg) {
/* 140 */     return msg.getBytes();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   static String encodeHighLevel(String msg, Compaction compaction) throws WriterException {
/* 152 */     byte[] bytes = null;
/*     */ 
/*     */     
/* 155 */     StringBuilder sb = new StringBuilder(msg.length());
/*     */     
/* 157 */     int len = msg.length();
/* 158 */     int p = 0;
/* 159 */     int textSubMode = 0;
/*     */ 
/*     */     
/* 162 */     if (compaction == Compaction.TEXT) {
/* 163 */       encodeText(msg, p, len, sb, textSubMode);
/*     */     }
/* 165 */     else if (compaction == Compaction.BYTE) {
/* 166 */       bytes = getBytesForMessage(msg);
/* 167 */       encodeBinary(bytes, p, bytes.length, 1, sb);
/*     */     }
/* 169 */     else if (compaction == Compaction.NUMERIC) {
/* 170 */       sb.append('Ά');
/* 171 */       encodeNumeric(msg, p, len, sb);
/*     */     } else {
/*     */       
/* 174 */       int encodingMode = 0;
/* 175 */       while (p < len) {
/* 176 */         int n = determineConsecutiveDigitCount(msg, p);
/* 177 */         if (n >= 13) {
/* 178 */           sb.append('Ά');
/* 179 */           encodingMode = 2;
/* 180 */           textSubMode = 0;
/* 181 */           encodeNumeric(msg, p, n, sb);
/* 182 */           p += n; continue;
/*     */         } 
/* 184 */         int t = determineConsecutiveTextCount(msg, p);
/* 185 */         if (t >= 5 || n == len) {
/* 186 */           if (encodingMode != 0) {
/* 187 */             sb.append('΄');
/* 188 */             encodingMode = 0;
/* 189 */             textSubMode = 0;
/*     */           } 
/* 191 */           textSubMode = encodeText(msg, p, t, sb, textSubMode);
/* 192 */           p += t; continue;
/*     */         } 
/* 194 */         if (bytes == null) {
/* 195 */           bytes = getBytesForMessage(msg);
/*     */         }
/* 197 */         int b = determineConsecutiveBinaryCount(msg, bytes, p);
/* 198 */         if (b == 0) {
/* 199 */           b = 1;
/*     */         }
/* 201 */         if (b == 1 && encodingMode == 0) {
/*     */           
/* 203 */           encodeBinary(bytes, p, 1, 0, sb);
/*     */         } else {
/*     */           
/* 206 */           encodeBinary(bytes, p, b, encodingMode, sb);
/* 207 */           encodingMode = 1;
/* 208 */           textSubMode = 0;
/*     */         } 
/* 210 */         p += b;
/*     */       } 
/*     */     } 
/*     */ 
/*     */ 
/*     */     
/* 216 */     return sb.toString();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static int encodeText(CharSequence msg, int startpos, int count, StringBuilder sb, int initialSubmode) {
/* 235 */     StringBuilder tmp = new StringBuilder(count);
/* 236 */     int submode = initialSubmode;
/* 237 */     int idx = 0;
/*     */     while (true) {
/* 239 */       char ch = msg.charAt(startpos + idx);
/* 240 */       switch (submode) {
/*     */         case 0:
/* 242 */           if (isAlphaUpper(ch)) {
/* 243 */             if (ch == ' ') {
/* 244 */               tmp.append('\032'); break;
/*     */             } 
/* 246 */             tmp.append((char)(ch - 65));
/*     */             break;
/*     */           } 
/* 249 */           if (isAlphaLower(ch)) {
/* 250 */             submode = 1;
/* 251 */             tmp.append('\033'); continue;
/*     */           } 
/* 253 */           if (isMixed(ch)) {
/* 254 */             submode = 2;
/* 255 */             tmp.append('\034');
/*     */             continue;
/*     */           } 
/* 258 */           tmp.append('\035');
/* 259 */           tmp.append((char)PUNCTUATION[ch]);
/*     */           break;
/*     */ 
/*     */ 
/*     */         
/*     */         case 1:
/* 265 */           if (isAlphaLower(ch)) {
/* 266 */             if (ch == ' ') {
/* 267 */               tmp.append('\032'); break;
/*     */             } 
/* 269 */             tmp.append((char)(ch - 97));
/*     */             break;
/*     */           } 
/* 272 */           if (isAlphaUpper(ch)) {
/* 273 */             tmp.append('\033');
/* 274 */             tmp.append((char)(ch - 65));
/*     */             break;
/*     */           } 
/* 277 */           if (isMixed(ch)) {
/* 278 */             submode = 2;
/* 279 */             tmp.append('\034');
/*     */             continue;
/*     */           } 
/* 282 */           tmp.append('\035');
/* 283 */           tmp.append((char)PUNCTUATION[ch]);
/*     */           break;
/*     */ 
/*     */ 
/*     */         
/*     */         case 2:
/* 289 */           if (isMixed(ch)) {
/* 290 */             tmp.append((char)MIXED[ch]); break;
/*     */           } 
/* 292 */           if (isAlphaUpper(ch)) {
/* 293 */             submode = 0;
/* 294 */             tmp.append('\034'); continue;
/*     */           } 
/* 296 */           if (isAlphaLower(ch)) {
/* 297 */             submode = 1;
/* 298 */             tmp.append('\033');
/*     */             continue;
/*     */           } 
/* 301 */           if (startpos + idx + 1 < count) {
/* 302 */             char next = msg.charAt(startpos + idx + 1);
/* 303 */             if (isPunctuation(next)) {
/* 304 */               submode = 3;
/* 305 */               tmp.append('\031');
/*     */               continue;
/*     */             } 
/*     */           } 
/* 309 */           tmp.append('\035');
/* 310 */           tmp.append((char)PUNCTUATION[ch]);
/*     */           break;
/*     */ 
/*     */         
/*     */         default:
/* 315 */           if (isPunctuation(ch)) {
/* 316 */             tmp.append((char)PUNCTUATION[ch]); break;
/*     */           } 
/* 318 */           submode = 0;
/* 319 */           tmp.append('\035');
/*     */           continue;
/*     */       } 
/*     */       
/* 323 */       idx++;
/* 324 */       if (idx >= count) {
/*     */         break;
/*     */       }
/*     */     } 
/* 328 */     char h = Character.MIN_VALUE;
/* 329 */     int len = tmp.length();
/* 330 */     for (int i = 0; i < len; i++) {
/* 331 */       boolean odd = (i % 2 != 0);
/* 332 */       if (odd) {
/* 333 */         h = (char)(h * 30 + tmp.charAt(i));
/* 334 */         sb.append(h);
/*     */       } else {
/* 336 */         h = tmp.charAt(i);
/*     */       } 
/*     */     } 
/* 339 */     if (len % 2 != 0) {
/* 340 */       sb.append((char)(h * 30 + 29));
/*     */     }
/* 342 */     return submode;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static void encodeBinary(byte[] bytes, int startpos, int count, int startmode, StringBuilder sb) {
/* 361 */     if (count == 1 && startmode == 0) {
/* 362 */       sb.append('Α');
/*     */     }
/*     */     
/* 365 */     int idx = startpos;
/*     */     
/* 367 */     if (count >= 6) {
/* 368 */       sb.append('Μ');
/* 369 */       char[] chars = new char[5];
/* 370 */       while (startpos + count - idx >= 6) {
/* 371 */         long t = 0L; int j;
/* 372 */         for (j = 0; j < 6; j++) {
/* 373 */           t <<= 8L;
/* 374 */           t += (bytes[idx + j] & 0xFF);
/*     */         } 
/* 376 */         for (j = 0; j < 5; j++) {
/* 377 */           chars[j] = (char)(int)(t % 900L);
/* 378 */           t /= 900L;
/*     */         } 
/* 380 */         for (j = chars.length - 1; j >= 0; j--) {
/* 381 */           sb.append(chars[j]);
/*     */         }
/* 383 */         idx += 6;
/*     */       } 
/*     */     } 
/*     */     
/* 387 */     if (idx < startpos + count) {
/* 388 */       sb.append('΅');
/*     */     }
/* 390 */     for (int i = idx; i < startpos + count; i++) {
/* 391 */       int ch = bytes[i] & 0xFF;
/* 392 */       sb.append((char)ch);
/*     */     } 
/*     */   }
/*     */   
/*     */   private static void encodeNumeric(String msg, int startpos, int count, StringBuilder sb) {
/* 397 */     int idx = 0;
/* 398 */     StringBuilder tmp = new StringBuilder(count / 3 + 1);
/* 399 */     BigInteger num900 = BigInteger.valueOf(900L);
/* 400 */     BigInteger num0 = BigInteger.valueOf(0L);
/* 401 */     while (idx < count - 1) {
/* 402 */       tmp.setLength(0);
/* 403 */       int len = Math.min(44, count - idx);
/* 404 */       String part = '1' + msg.substring(startpos + idx, startpos + idx + len);
/* 405 */       BigInteger bigint = new BigInteger(part);
/*     */       do {
/* 407 */         BigInteger c = bigint.mod(num900);
/* 408 */         tmp.append((char)c.intValue());
/* 409 */         bigint = bigint.divide(num900);
/* 410 */       } while (!bigint.equals(num0));
/*     */ 
/*     */       
/* 413 */       for (int i = tmp.length() - 1; i >= 0; i--) {
/* 414 */         sb.append(tmp.charAt(i));
/*     */       }
/* 416 */       idx += len;
/*     */     } 
/*     */   }
/*     */ 
/*     */   
/*     */   private static boolean isDigit(char ch) {
/* 422 */     return (ch >= '0' && ch <= '9');
/*     */   }
/*     */   
/*     */   private static boolean isAlphaUpper(char ch) {
/* 426 */     return (ch == ' ' || (ch >= 'A' && ch <= 'Z'));
/*     */   }
/*     */   
/*     */   private static boolean isAlphaLower(char ch) {
/* 430 */     return (ch == ' ' || (ch >= 'a' && ch <= 'z'));
/*     */   }
/*     */   
/*     */   private static boolean isMixed(char ch) {
/* 434 */     return (MIXED[ch] != -1);
/*     */   }
/*     */   
/*     */   private static boolean isPunctuation(char ch) {
/* 438 */     return (PUNCTUATION[ch] != -1);
/*     */   }
/*     */   
/*     */   private static boolean isText(char ch) {
/* 442 */     return (ch == '\t' || ch == '\n' || ch == '\r' || (ch >= ' ' && ch <= '~'));
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static int determineConsecutiveDigitCount(CharSequence msg, int startpos) {
/* 453 */     int count = 0;
/* 454 */     int len = msg.length();
/* 455 */     int idx = startpos;
/* 456 */     if (idx < len) {
/* 457 */       char ch = msg.charAt(idx);
/* 458 */       while (isDigit(ch) && idx < len) {
/* 459 */         count++;
/* 460 */         idx++;
/* 461 */         if (idx < len) {
/* 462 */           ch = msg.charAt(idx);
/*     */         }
/*     */       } 
/*     */     } 
/* 466 */     return count;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static int determineConsecutiveTextCount(CharSequence msg, int startpos) {
/* 477 */     int len = msg.length();
/* 478 */     int idx = startpos;
/* 479 */     while (idx < len) {
/* 480 */       char ch = msg.charAt(idx);
/* 481 */       int numericCount = 0;
/* 482 */       while (numericCount < 13 && isDigit(ch) && idx < len) {
/* 483 */         numericCount++;
/* 484 */         idx++;
/* 485 */         if (idx < len) {
/* 486 */           ch = msg.charAt(idx);
/*     */         }
/*     */       } 
/* 489 */       if (numericCount >= 13) {
/* 490 */         return idx - startpos - numericCount;
/*     */       }
/* 492 */       if (numericCount > 0) {
/*     */         continue;
/*     */       }
/*     */       
/* 496 */       ch = msg.charAt(idx);
/*     */ 
/*     */       
/* 499 */       if (!isText(ch)) {
/*     */         break;
/*     */       }
/* 502 */       idx++;
/*     */     } 
/* 504 */     return idx - startpos;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static int determineConsecutiveBinaryCount(CharSequence msg, byte[] bytes, int startpos) throws WriterException {
/* 517 */     int len = msg.length();
/* 518 */     int idx = startpos;
/* 519 */     while (idx < len) {
/* 520 */       char ch = msg.charAt(idx);
/* 521 */       int numericCount = 0;
/*     */       
/* 523 */       while (numericCount < 13 && isDigit(ch)) {
/* 524 */         numericCount++;
/*     */         
/* 526 */         int i = idx + numericCount;
/* 527 */         if (i >= len) {
/*     */           break;
/*     */         }
/* 530 */         ch = msg.charAt(i);
/*     */       } 
/* 532 */       if (numericCount >= 13) {
/* 533 */         return idx - startpos;
/*     */       }
/* 535 */       int textCount = 0;
/* 536 */       while (textCount < 5 && isText(ch)) {
/* 537 */         textCount++;
/* 538 */         int i = idx + textCount;
/* 539 */         if (i >= len) {
/*     */           break;
/*     */         }
/* 542 */         ch = msg.charAt(i);
/*     */       } 
/* 544 */       if (textCount >= 5) {
/* 545 */         return idx - startpos;
/*     */       }
/* 547 */       ch = msg.charAt(idx);
/*     */ 
/*     */ 
/*     */ 
/*     */       
/* 552 */       if (bytes[idx] == 63 && ch != '?') {
/* 553 */         throw new WriterException("Non-encodable character detected: " + ch + " (Unicode: " + ch + ')');
/*     */       }
/* 555 */       idx++;
/*     */     } 
/* 557 */     return idx - startpos;
/*     */   }
/*     */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\com\google\zxing\pdf417\encoder\PDF417HighLevelEncoder.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       1.1.3
 */