/*     */ package com.google.zxing.qrcode;
/*     */ 
/*     */ import com.google.zxing.BarcodeFormat;
/*     */ import com.google.zxing.BinaryBitmap;
/*     */ import com.google.zxing.ChecksumException;
/*     */ import com.google.zxing.DecodeHintType;
/*     */ import com.google.zxing.FormatException;
/*     */ import com.google.zxing.NotFoundException;
/*     */ import com.google.zxing.Reader;
/*     */ import com.google.zxing.Result;
/*     */ import com.google.zxing.ResultMetadataType;
/*     */ import com.google.zxing.ResultPoint;
/*     */ import com.google.zxing.common.BitMatrix;
/*     */ import com.google.zxing.common.DecoderResult;
/*     */ import com.google.zxing.common.DetectorResult;
/*     */ import com.google.zxing.qrcode.decoder.Decoder;
/*     */ import com.google.zxing.qrcode.detector.Detector;
/*     */ import java.util.List;
/*     */ import java.util.Map;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class QRCodeReader
/*     */   implements Reader
/*     */ {
/*  45 */   private static final ResultPoint[] NO_POINTS = new ResultPoint[0];
/*     */   
/*  47 */   private final Decoder decoder = new Decoder();
/*     */   
/*     */   protected final Decoder getDecoder() {
/*  50 */     return this.decoder;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Result decode(BinaryBitmap image) throws NotFoundException, ChecksumException, FormatException {
/*  63 */     return decode(image, null);
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   public final Result decode(BinaryBitmap image, Map<DecodeHintType, ?> hints) throws NotFoundException, ChecksumException, FormatException {
/*     */     DecoderResult decoderResult;
/*     */     ResultPoint[] points;
/*  71 */     if (hints != null && hints.containsKey(DecodeHintType.PURE_BARCODE)) {
/*  72 */       BitMatrix bits = extractPureBits(image.getBlackMatrix());
/*  73 */       decoderResult = this.decoder.decode(bits, hints);
/*  74 */       points = NO_POINTS;
/*     */     } else {
/*  76 */       DetectorResult detectorResult = (new Detector(image.getBlackMatrix())).detect(hints);
/*  77 */       decoderResult = this.decoder.decode(detectorResult.getBits(), hints);
/*  78 */       points = detectorResult.getPoints();
/*     */     } 
/*     */     
/*  81 */     Result result = new Result(decoderResult.getText(), decoderResult.getRawBytes(), points, BarcodeFormat.QR_CODE);
/*  82 */     List<byte[]> byteSegments = decoderResult.getByteSegments();
/*  83 */     if (byteSegments != null) {
/*  84 */       result.putMetadata(ResultMetadataType.BYTE_SEGMENTS, byteSegments);
/*     */     }
/*  86 */     String ecLevel = decoderResult.getECLevel();
/*  87 */     if (ecLevel != null) {
/*  88 */       result.putMetadata(ResultMetadataType.ERROR_CORRECTION_LEVEL, ecLevel);
/*     */     }
/*  90 */     return result;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void reset() {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static BitMatrix extractPureBits(BitMatrix image) throws NotFoundException {
/* 108 */     int[] leftTopBlack = image.getTopLeftOnBit();
/* 109 */     int[] rightBottomBlack = image.getBottomRightOnBit();
/* 110 */     if (leftTopBlack == null || rightBottomBlack == null) {
/* 111 */       throw NotFoundException.getNotFoundInstance();
/*     */     }
/*     */     
/* 114 */     float moduleSize = moduleSize(leftTopBlack, image);
/*     */     
/* 116 */     int top = leftTopBlack[1];
/* 117 */     int bottom = rightBottomBlack[1];
/* 118 */     int left = leftTopBlack[0];
/* 119 */     int right = rightBottomBlack[0];
/*     */ 
/*     */     
/* 122 */     if (left >= right || top >= bottom) {
/* 123 */       throw NotFoundException.getNotFoundInstance();
/*     */     }
/*     */     
/* 126 */     if (bottom - top != right - left)
/*     */     {
/*     */       
/* 129 */       right = left + bottom - top;
/*     */     }
/*     */     
/* 132 */     int matrixWidth = Math.round((right - left + 1) / moduleSize);
/* 133 */     int matrixHeight = Math.round((bottom - top + 1) / moduleSize);
/* 134 */     if (matrixWidth <= 0 || matrixHeight <= 0) {
/* 135 */       throw NotFoundException.getNotFoundInstance();
/*     */     }
/* 137 */     if (matrixHeight != matrixWidth)
/*     */     {
/* 139 */       throw NotFoundException.getNotFoundInstance();
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 145 */     int nudge = (int)(moduleSize / 2.0F);
/* 146 */     top += nudge;
/* 147 */     left += nudge;
/*     */ 
/*     */     
/* 150 */     int nudgedTooFarRight = left + (int)((matrixWidth - 1) * moduleSize) - right - 1;
/* 151 */     if (nudgedTooFarRight > 0) {
/* 152 */       left -= nudgedTooFarRight;
/*     */     }
/* 154 */     int nudgedTooFarDown = top + (int)((matrixHeight - 1) * moduleSize) - bottom - 1;
/* 155 */     if (nudgedTooFarDown > 0) {
/* 156 */       top -= nudgedTooFarDown;
/*     */     }
/*     */ 
/*     */     
/* 160 */     BitMatrix bits = new BitMatrix(matrixWidth, matrixHeight);
/* 161 */     for (int y = 0; y < matrixHeight; y++) {
/* 162 */       int iOffset = top + (int)(y * moduleSize);
/* 163 */       for (int x = 0; x < matrixWidth; x++) {
/* 164 */         if (image.get(left + (int)(x * moduleSize), iOffset)) {
/* 165 */           bits.set(x, y);
/*     */         }
/*     */       } 
/*     */     } 
/* 169 */     return bits;
/*     */   }
/*     */   
/*     */   private static float moduleSize(int[] leftTopBlack, BitMatrix image) throws NotFoundException {
/* 173 */     int height = image.getHeight();
/* 174 */     int width = image.getWidth();
/* 175 */     int x = leftTopBlack[0];
/* 176 */     int y = leftTopBlack[1];
/* 177 */     boolean inBlack = true;
/* 178 */     int transitions = 0;
/* 179 */     while (x < width && y < height) {
/* 180 */       if (inBlack != image.get(x, y)) {
/* 181 */         if (++transitions == 5) {
/*     */           break;
/*     */         }
/* 184 */         inBlack = !inBlack;
/*     */       } 
/* 186 */       x++;
/* 187 */       y++;
/*     */     } 
/* 189 */     if (x == width || y == height) {
/* 190 */       throw NotFoundException.getNotFoundInstance();
/*     */     }
/* 192 */     return (x - leftTopBlack[0]) / 7.0F;
/*     */   }
/*     */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\com\google\zxing\qrcode\QRCodeReader.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       1.1.3
 */