/*     */ package com.google.zxing.qrcode.decoder;
/*     */ 
/*     */ import com.google.zxing.FormatException;
/*     */ import com.google.zxing.common.BitMatrix;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ final class BitMatrixParser
/*     */ {
/*     */   private final BitMatrix bitMatrix;
/*     */   private Version parsedVersion;
/*     */   private FormatInformation parsedFormatInfo;
/*     */   
/*     */   BitMatrixParser(BitMatrix bitMatrix) throws FormatException {
/*  36 */     int dimension = bitMatrix.getHeight();
/*  37 */     if (dimension < 21 || (dimension & 0x3) != 1) {
/*  38 */       throw FormatException.getFormatInstance();
/*     */     }
/*  40 */     this.bitMatrix = bitMatrix;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   FormatInformation readFormatInformation() throws FormatException {
/*  52 */     if (this.parsedFormatInfo != null) {
/*  53 */       return this.parsedFormatInfo;
/*     */     }
/*     */ 
/*     */     
/*  57 */     int formatInfoBits1 = 0;
/*  58 */     for (int i = 0; i < 6; i++) {
/*  59 */       formatInfoBits1 = copyBit(i, 8, formatInfoBits1);
/*     */     }
/*     */     
/*  62 */     formatInfoBits1 = copyBit(7, 8, formatInfoBits1);
/*  63 */     formatInfoBits1 = copyBit(8, 8, formatInfoBits1);
/*  64 */     formatInfoBits1 = copyBit(8, 7, formatInfoBits1);
/*     */     
/*  66 */     for (int j = 5; j >= 0; j--) {
/*  67 */       formatInfoBits1 = copyBit(8, j, formatInfoBits1);
/*     */     }
/*     */ 
/*     */     
/*  71 */     int dimension = this.bitMatrix.getHeight();
/*  72 */     int formatInfoBits2 = 0;
/*  73 */     int jMin = dimension - 7;
/*  74 */     for (int m = dimension - 1; m >= jMin; m--) {
/*  75 */       formatInfoBits2 = copyBit(8, m, formatInfoBits2);
/*     */     }
/*  77 */     for (int k = dimension - 8; k < dimension; k++) {
/*  78 */       formatInfoBits2 = copyBit(k, 8, formatInfoBits2);
/*     */     }
/*     */     
/*  81 */     this.parsedFormatInfo = FormatInformation.decodeFormatInformation(formatInfoBits1, formatInfoBits2);
/*  82 */     if (this.parsedFormatInfo != null) {
/*  83 */       return this.parsedFormatInfo;
/*     */     }
/*  85 */     throw FormatException.getFormatInstance();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   Version readVersion() throws FormatException {
/*  97 */     if (this.parsedVersion != null) {
/*  98 */       return this.parsedVersion;
/*     */     }
/*     */     
/* 101 */     int dimension = this.bitMatrix.getHeight();
/*     */     
/* 103 */     int provisionalVersion = dimension - 17 >> 2;
/* 104 */     if (provisionalVersion <= 6) {
/* 105 */       return Version.getVersionForNumber(provisionalVersion);
/*     */     }
/*     */ 
/*     */     
/* 109 */     int versionBits = 0;
/* 110 */     int ijMin = dimension - 11;
/* 111 */     for (int j = 5; j >= 0; j--) {
/* 112 */       for (int k = dimension - 9; k >= ijMin; k--) {
/* 113 */         versionBits = copyBit(k, j, versionBits);
/*     */       }
/*     */     } 
/*     */     
/* 117 */     Version theParsedVersion = Version.decodeVersionInformation(versionBits);
/* 118 */     if (theParsedVersion != null && theParsedVersion.getDimensionForVersion() == dimension) {
/* 119 */       this.parsedVersion = theParsedVersion;
/* 120 */       return theParsedVersion;
/*     */     } 
/*     */ 
/*     */     
/* 124 */     versionBits = 0;
/* 125 */     for (int i = 5; i >= 0; i--) {
/* 126 */       for (int k = dimension - 9; k >= ijMin; k--) {
/* 127 */         versionBits = copyBit(i, k, versionBits);
/*     */       }
/*     */     } 
/*     */     
/* 131 */     theParsedVersion = Version.decodeVersionInformation(versionBits);
/* 132 */     if (theParsedVersion != null && theParsedVersion.getDimensionForVersion() == dimension) {
/* 133 */       this.parsedVersion = theParsedVersion;
/* 134 */       return theParsedVersion;
/*     */     } 
/* 136 */     throw FormatException.getFormatInstance();
/*     */   }
/*     */   
/*     */   private int copyBit(int i, int j, int versionBits) {
/* 140 */     return this.bitMatrix.get(i, j) ? (versionBits << 1 | 0x1) : (versionBits << 1);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   byte[] readCodewords() throws FormatException {
/* 153 */     FormatInformation formatInfo = readFormatInformation();
/* 154 */     Version version = readVersion();
/*     */ 
/*     */ 
/*     */     
/* 158 */     DataMask dataMask = DataMask.forReference(formatInfo.getDataMask());
/* 159 */     int dimension = this.bitMatrix.getHeight();
/* 160 */     dataMask.unmaskBitMatrix(this.bitMatrix, dimension);
/*     */     
/* 162 */     BitMatrix functionPattern = version.buildFunctionPattern();
/*     */     
/* 164 */     boolean readingUp = true;
/* 165 */     byte[] result = new byte[version.getTotalCodewords()];
/* 166 */     int resultOffset = 0;
/* 167 */     int currentByte = 0;
/* 168 */     int bitsRead = 0;
/*     */     
/* 170 */     for (int j = dimension - 1; j > 0; j -= 2) {
/* 171 */       if (j == 6)
/*     */       {
/*     */         
/* 174 */         j--;
/*     */       }
/*     */       
/* 177 */       for (int count = 0; count < dimension; count++) {
/* 178 */         int k = readingUp ? (dimension - 1 - count) : count;
/* 179 */         for (int col = 0; col < 2; col++) {
/*     */           
/* 181 */           if (!functionPattern.get(j - col, k)) {
/*     */             
/* 183 */             bitsRead++;
/* 184 */             currentByte <<= 1;
/* 185 */             if (this.bitMatrix.get(j - col, k)) {
/* 186 */               currentByte |= 0x1;
/*     */             }
/*     */             
/* 189 */             if (bitsRead == 8) {
/* 190 */               result[resultOffset++] = (byte)currentByte;
/* 191 */               bitsRead = 0;
/* 192 */               currentByte = 0;
/*     */             } 
/*     */           } 
/*     */         } 
/*     */       } 
/* 197 */       int i = readingUp ^ true;
/*     */     } 
/* 199 */     if (resultOffset != version.getTotalCodewords()) {
/* 200 */       throw FormatException.getFormatInstance();
/*     */     }
/* 202 */     return result;
/*     */   }
/*     */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\com\google\zxing\qrcode\decoder\BitMatrixParser.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       1.1.3
 */