/*     */ package com.google.zxing.qrcode.decoder;
/*     */ 
/*     */ import com.google.zxing.DecodeHintType;
/*     */ import com.google.zxing.FormatException;
/*     */ import com.google.zxing.common.BitSource;
/*     */ import com.google.zxing.common.CharacterSetECI;
/*     */ import com.google.zxing.common.DecoderResult;
/*     */ import com.google.zxing.common.StringUtils;
/*     */ import java.io.UnsupportedEncodingException;
/*     */ import java.util.ArrayList;
/*     */ import java.util.Collection;
/*     */ import java.util.List;
/*     */ import java.util.Map;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ final class DecodedBitStreamParser
/*     */ {
/*  45 */   private static final char[] ALPHANUMERIC_CHARS = new char[] { '0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I', 'J', 'K', 'L', 'M', 'N', 'O', 'P', 'Q', 'R', 'S', 'T', 'U', 'V', 'W', 'X', 'Y', 'Z', ' ', '$', '%', '*', '+', '-', '.', '/', ':' };
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static final int GB2312_SUBSET = 1;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   static DecoderResult decode(byte[] bytes, Version version, ErrorCorrectionLevel ecLevel, Map<DecodeHintType, ?> hints) throws FormatException {
/*  60 */     BitSource bits = new BitSource(bytes);
/*  61 */     StringBuilder result = new StringBuilder(50);
/*  62 */     List<byte[]> byteSegments = (List)new ArrayList<byte>(1); try {
/*     */       Mode mode;
/*  64 */       CharacterSetECI currentCharacterSetECI = null;
/*  65 */       boolean fc1InEffect = false;
/*     */ 
/*     */       
/*     */       do {
/*  69 */         if (bits.available() < 4) {
/*     */           
/*  71 */           mode = Mode.TERMINATOR;
/*     */         } else {
/*  73 */           mode = Mode.forBits(bits.readBits(4));
/*     */         } 
/*  75 */         if (mode == Mode.TERMINATOR)
/*  76 */           continue;  if (mode == Mode.FNC1_FIRST_POSITION || mode == Mode.FNC1_SECOND_POSITION) {
/*     */           
/*  78 */           fc1InEffect = true;
/*  79 */         } else if (mode == Mode.STRUCTURED_APPEND) {
/*  80 */           if (bits.available() < 16) {
/*  81 */             throw FormatException.getFormatInstance();
/*     */           }
/*     */ 
/*     */           
/*  85 */           bits.readBits(16);
/*  86 */         } else if (mode == Mode.ECI) {
/*     */           
/*  88 */           int value = parseECIValue(bits);
/*  89 */           currentCharacterSetECI = CharacterSetECI.getCharacterSetECIByValue(value);
/*  90 */           if (currentCharacterSetECI == null) {
/*  91 */             throw FormatException.getFormatInstance();
/*     */           
/*     */           }
/*     */         }
/*  95 */         else if (mode == Mode.HANZI) {
/*     */           
/*  97 */           int subset = bits.readBits(4);
/*  98 */           int countHanzi = bits.readBits(mode.getCharacterCountBits(version));
/*  99 */           if (subset == 1) {
/* 100 */             decodeHanziSegment(bits, result, countHanzi);
/*     */           }
/*     */         }
/*     */         else {
/*     */           
/* 105 */           int count = bits.readBits(mode.getCharacterCountBits(version));
/* 106 */           if (mode == Mode.NUMERIC) {
/* 107 */             decodeNumericSegment(bits, result, count);
/* 108 */           } else if (mode == Mode.ALPHANUMERIC) {
/* 109 */             decodeAlphanumericSegment(bits, result, count, fc1InEffect);
/* 110 */           } else if (mode == Mode.BYTE) {
/* 111 */             decodeByteSegment(bits, result, count, currentCharacterSetECI, (Collection<byte[]>)byteSegments, hints);
/* 112 */           } else if (mode == Mode.KANJI) {
/* 113 */             decodeKanjiSegment(bits, result, count);
/*     */           } else {
/* 115 */             throw FormatException.getFormatInstance();
/*     */           }
/*     */         
/*     */         }
/*     */       
/* 120 */       } while (mode != Mode.TERMINATOR);
/* 121 */     } catch (IllegalArgumentException iae) {
/*     */       
/* 123 */       throw FormatException.getFormatInstance();
/*     */     } 
/*     */     
/* 126 */     return new DecoderResult(bytes, result.toString(), byteSegments.isEmpty() ? null : byteSegments, (ecLevel == null) ? null : ecLevel.toString());
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static void decodeHanziSegment(BitSource bits, StringBuilder result, int count) throws FormatException {
/* 139 */     if (count * 13 > bits.available()) {
/* 140 */       throw FormatException.getFormatInstance();
/*     */     }
/*     */ 
/*     */ 
/*     */     
/* 145 */     byte[] buffer = new byte[2 * count];
/* 146 */     int offset = 0;
/* 147 */     while (count > 0) {
/*     */       
/* 149 */       int twoBytes = bits.readBits(13);
/* 150 */       int assembledTwoBytes = twoBytes / 96 << 8 | twoBytes % 96;
/* 151 */       if (assembledTwoBytes < 959) {
/*     */         
/* 153 */         assembledTwoBytes += 41377;
/*     */       } else {
/*     */         
/* 156 */         assembledTwoBytes += 42657;
/*     */       } 
/* 158 */       buffer[offset] = (byte)(assembledTwoBytes >> 8 & 0xFF);
/* 159 */       buffer[offset + 1] = (byte)(assembledTwoBytes & 0xFF);
/* 160 */       offset += 2;
/* 161 */       count--;
/*     */     } 
/*     */     
/*     */     try {
/* 165 */       result.append(new String(buffer, "GB2312"));
/* 166 */     } catch (UnsupportedEncodingException ignored) {
/* 167 */       throw FormatException.getFormatInstance();
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static void decodeKanjiSegment(BitSource bits, StringBuilder result, int count) throws FormatException {
/* 175 */     if (count * 13 > bits.available()) {
/* 176 */       throw FormatException.getFormatInstance();
/*     */     }
/*     */ 
/*     */ 
/*     */     
/* 181 */     byte[] buffer = new byte[2 * count];
/* 182 */     int offset = 0;
/* 183 */     while (count > 0) {
/*     */       
/* 185 */       int twoBytes = bits.readBits(13);
/* 186 */       int assembledTwoBytes = twoBytes / 192 << 8 | twoBytes % 192;
/* 187 */       if (assembledTwoBytes < 7936) {
/*     */         
/* 189 */         assembledTwoBytes += 33088;
/*     */       } else {
/*     */         
/* 192 */         assembledTwoBytes += 49472;
/*     */       } 
/* 194 */       buffer[offset] = (byte)(assembledTwoBytes >> 8);
/* 195 */       buffer[offset + 1] = (byte)assembledTwoBytes;
/* 196 */       offset += 2;
/* 197 */       count--;
/*     */     } 
/*     */     
/*     */     try {
/* 201 */       result.append(new String(buffer, "SJIS"));
/* 202 */     } catch (UnsupportedEncodingException ignored) {
/* 203 */       throw FormatException.getFormatInstance();
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static void decodeByteSegment(BitSource bits, StringBuilder result, int count, CharacterSetECI currentCharacterSetECI, Collection<byte[]> byteSegments, Map<DecodeHintType, ?> hints) throws FormatException {
/*     */     String encoding;
/* 214 */     if (count << 3 > bits.available()) {
/* 215 */       throw FormatException.getFormatInstance();
/*     */     }
/*     */     
/* 218 */     byte[] readBytes = new byte[count];
/* 219 */     for (int i = 0; i < count; i++) {
/* 220 */       readBytes[i] = (byte)bits.readBits(8);
/*     */     }
/*     */     
/* 223 */     if (currentCharacterSetECI == null) {
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */       
/* 229 */       encoding = StringUtils.guessEncoding(readBytes, hints);
/*     */     } else {
/* 231 */       encoding = currentCharacterSetECI.name();
/*     */     } 
/*     */     try {
/* 234 */       result.append(new String(readBytes, encoding));
/* 235 */     } catch (UnsupportedEncodingException ignored) {
/* 236 */       throw FormatException.getFormatInstance();
/*     */     } 
/* 238 */     byteSegments.add(readBytes);
/*     */   }
/*     */   
/*     */   private static char toAlphaNumericChar(int value) throws FormatException {
/* 242 */     if (value >= ALPHANUMERIC_CHARS.length) {
/* 243 */       throw FormatException.getFormatInstance();
/*     */     }
/* 245 */     return ALPHANUMERIC_CHARS[value];
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static void decodeAlphanumericSegment(BitSource bits, StringBuilder result, int count, boolean fc1InEffect) throws FormatException {
/* 253 */     int start = result.length();
/* 254 */     while (count > 1) {
/* 255 */       if (bits.available() < 11) {
/* 256 */         throw FormatException.getFormatInstance();
/*     */       }
/* 258 */       int nextTwoCharsBits = bits.readBits(11);
/* 259 */       result.append(toAlphaNumericChar(nextTwoCharsBits / 45));
/* 260 */       result.append(toAlphaNumericChar(nextTwoCharsBits % 45));
/* 261 */       count -= 2;
/*     */     } 
/* 263 */     if (count == 1) {
/*     */       
/* 265 */       if (bits.available() < 6) {
/* 266 */         throw FormatException.getFormatInstance();
/*     */       }
/* 268 */       result.append(toAlphaNumericChar(bits.readBits(6)));
/*     */     } 
/*     */     
/* 271 */     if (fc1InEffect)
/*     */     {
/* 273 */       for (int i = start; i < result.length(); i++) {
/* 274 */         if (result.charAt(i) == '%') {
/* 275 */           if (i < result.length() - 1 && result.charAt(i + 1) == '%') {
/*     */             
/* 277 */             result.deleteCharAt(i + 1);
/*     */           } else {
/*     */             
/* 280 */             result.setCharAt(i, '\035');
/*     */           } 
/*     */         }
/*     */       } 
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static void decodeNumericSegment(BitSource bits, StringBuilder result, int count) throws FormatException {
/* 291 */     while (count >= 3) {
/*     */       
/* 293 */       if (bits.available() < 10) {
/* 294 */         throw FormatException.getFormatInstance();
/*     */       }
/* 296 */       int threeDigitsBits = bits.readBits(10);
/* 297 */       if (threeDigitsBits >= 1000) {
/* 298 */         throw FormatException.getFormatInstance();
/*     */       }
/* 300 */       result.append(toAlphaNumericChar(threeDigitsBits / 100));
/* 301 */       result.append(toAlphaNumericChar(threeDigitsBits / 10 % 10));
/* 302 */       result.append(toAlphaNumericChar(threeDigitsBits % 10));
/* 303 */       count -= 3;
/*     */     } 
/* 305 */     if (count == 2) {
/*     */       
/* 307 */       if (bits.available() < 7) {
/* 308 */         throw FormatException.getFormatInstance();
/*     */       }
/* 310 */       int twoDigitsBits = bits.readBits(7);
/* 311 */       if (twoDigitsBits >= 100) {
/* 312 */         throw FormatException.getFormatInstance();
/*     */       }
/* 314 */       result.append(toAlphaNumericChar(twoDigitsBits / 10));
/* 315 */       result.append(toAlphaNumericChar(twoDigitsBits % 10));
/* 316 */     } else if (count == 1) {
/*     */       
/* 318 */       if (bits.available() < 4) {
/* 319 */         throw FormatException.getFormatInstance();
/*     */       }
/* 321 */       int digitBits = bits.readBits(4);
/* 322 */       if (digitBits >= 10) {
/* 323 */         throw FormatException.getFormatInstance();
/*     */       }
/* 325 */       result.append(toAlphaNumericChar(digitBits));
/*     */     } 
/*     */   }
/*     */   
/*     */   private static int parseECIValue(BitSource bits) throws FormatException {
/* 330 */     int firstByte = bits.readBits(8);
/* 331 */     if ((firstByte & 0x80) == 0)
/*     */     {
/* 333 */       return firstByte & 0x7F;
/*     */     }
/* 335 */     if ((firstByte & 0xC0) == 128) {
/*     */       
/* 337 */       int secondByte = bits.readBits(8);
/* 338 */       return (firstByte & 0x3F) << 8 | secondByte;
/*     */     } 
/* 340 */     if ((firstByte & 0xE0) == 192) {
/*     */       
/* 342 */       int secondThirdBytes = bits.readBits(16);
/* 343 */       return (firstByte & 0x1F) << 16 | secondThirdBytes;
/*     */     } 
/* 345 */     throw FormatException.getFormatInstance();
/*     */   }
/*     */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\com\google\zxing\qrcode\decoder\DecodedBitStreamParser.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       1.1.3
 */