/*     */ package com.google.zxing.qrcode.decoder;
/*     */ 
/*     */ import com.google.zxing.ChecksumException;
/*     */ import com.google.zxing.DecodeHintType;
/*     */ import com.google.zxing.FormatException;
/*     */ import com.google.zxing.common.BitMatrix;
/*     */ import com.google.zxing.common.DecoderResult;
/*     */ import com.google.zxing.common.reedsolomon.GenericGF;
/*     */ import com.google.zxing.common.reedsolomon.ReedSolomonDecoder;
/*     */ import com.google.zxing.common.reedsolomon.ReedSolomonException;
/*     */ import java.util.Map;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public final class Decoder
/*     */ {
/*  41 */   private final ReedSolomonDecoder rsDecoder = new ReedSolomonDecoder(GenericGF.QR_CODE_FIELD_256);
/*     */ 
/*     */   
/*     */   public DecoderResult decode(boolean[][] image) throws ChecksumException, FormatException {
/*  45 */     return decode(image, (Map<DecodeHintType, ?>)null);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public DecoderResult decode(boolean[][] image, Map<DecodeHintType, ?> hints) throws ChecksumException, FormatException {
/*  59 */     int dimension = image.length;
/*  60 */     BitMatrix bits = new BitMatrix(dimension);
/*  61 */     for (int i = 0; i < dimension; i++) {
/*  62 */       for (int j = 0; j < dimension; j++) {
/*  63 */         if (image[i][j]) {
/*  64 */           bits.set(j, i);
/*     */         }
/*     */       } 
/*     */     } 
/*  68 */     return decode(bits, hints);
/*     */   }
/*     */   
/*     */   public DecoderResult decode(BitMatrix bits) throws ChecksumException, FormatException {
/*  72 */     return decode(bits, (Map<DecodeHintType, ?>)null);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public DecoderResult decode(BitMatrix bits, Map<DecodeHintType, ?> hints) throws FormatException, ChecksumException {
/*  87 */     BitMatrixParser parser = new BitMatrixParser(bits);
/*  88 */     Version version = parser.readVersion();
/*  89 */     ErrorCorrectionLevel ecLevel = parser.readFormatInformation().getErrorCorrectionLevel();
/*     */ 
/*     */     
/*  92 */     byte[] codewords = parser.readCodewords();
/*     */     
/*  94 */     DataBlock[] dataBlocks = DataBlock.getDataBlocks(codewords, version, ecLevel);
/*     */ 
/*     */     
/*  97 */     int totalBytes = 0;
/*  98 */     for (DataBlock dataBlock : dataBlocks) {
/*  99 */       totalBytes += dataBlock.getNumDataCodewords();
/*     */     }
/* 101 */     byte[] resultBytes = new byte[totalBytes];
/* 102 */     int resultOffset = 0;
/*     */ 
/*     */     
/* 105 */     for (DataBlock dataBlock : dataBlocks) {
/* 106 */       byte[] codewordBytes = dataBlock.getCodewords();
/* 107 */       int numDataCodewords = dataBlock.getNumDataCodewords();
/* 108 */       correctErrors(codewordBytes, numDataCodewords);
/* 109 */       for (int i = 0; i < numDataCodewords; i++) {
/* 110 */         resultBytes[resultOffset++] = codewordBytes[i];
/*     */       }
/*     */     } 
/*     */ 
/*     */     
/* 115 */     return DecodedBitStreamParser.decode(resultBytes, version, ecLevel, hints);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private void correctErrors(byte[] codewordBytes, int numDataCodewords) throws ChecksumException {
/* 127 */     int numCodewords = codewordBytes.length;
/*     */     
/* 129 */     int[] codewordsInts = new int[numCodewords];
/* 130 */     for (int i = 0; i < numCodewords; i++) {
/* 131 */       codewordsInts[i] = codewordBytes[i] & 0xFF;
/*     */     }
/* 133 */     int numECCodewords = codewordBytes.length - numDataCodewords;
/*     */     try {
/* 135 */       this.rsDecoder.decode(codewordsInts, numECCodewords);
/* 136 */     } catch (ReedSolomonException ignored) {
/* 137 */       throw ChecksumException.getChecksumInstance();
/*     */     } 
/*     */ 
/*     */     
/* 141 */     for (int j = 0; j < numDataCodewords; j++)
/* 142 */       codewordBytes[j] = (byte)codewordsInts[j]; 
/*     */   }
/*     */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\com\google\zxing\qrcode\decoder\Decoder.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       1.1.3
 */