/*     */ package com.google.zxing.qrcode.detector;
/*     */ 
/*     */ import com.google.zxing.DecodeHintType;
/*     */ import com.google.zxing.FormatException;
/*     */ import com.google.zxing.NotFoundException;
/*     */ import com.google.zxing.ResultPoint;
/*     */ import com.google.zxing.ResultPointCallback;
/*     */ import com.google.zxing.common.BitMatrix;
/*     */ import com.google.zxing.common.DetectorResult;
/*     */ import com.google.zxing.common.GridSampler;
/*     */ import com.google.zxing.common.PerspectiveTransform;
/*     */ import com.google.zxing.common.detector.MathUtils;
/*     */ import com.google.zxing.qrcode.decoder.Version;
/*     */ import java.util.Map;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class Detector
/*     */ {
/*     */   private final BitMatrix image;
/*     */   private ResultPointCallback resultPointCallback;
/*     */   
/*     */   public Detector(BitMatrix image) {
/*  45 */     this.image = image;
/*     */   }
/*     */   
/*     */   protected final BitMatrix getImage() {
/*  49 */     return this.image;
/*     */   }
/*     */   
/*     */   protected final ResultPointCallback getResultPointCallback() {
/*  53 */     return this.resultPointCallback;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public DetectorResult detect() throws NotFoundException, FormatException {
/*  63 */     return detect(null);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public final DetectorResult detect(Map<DecodeHintType, ?> hints) throws NotFoundException, FormatException {
/*  76 */     this.resultPointCallback = (hints == null) ? null : (ResultPointCallback)hints.get(DecodeHintType.NEED_RESULT_POINT_CALLBACK);
/*     */ 
/*     */     
/*  79 */     FinderPatternFinder finder = new FinderPatternFinder(this.image, this.resultPointCallback);
/*  80 */     FinderPatternInfo info = finder.find(hints);
/*     */     
/*  82 */     return processFinderPatternInfo(info);
/*     */   }
/*     */ 
/*     */   
/*     */   protected final DetectorResult processFinderPatternInfo(FinderPatternInfo info) throws NotFoundException, FormatException {
/*     */     ResultPoint[] points;
/*  88 */     FinderPattern topLeft = info.getTopLeft();
/*  89 */     FinderPattern topRight = info.getTopRight();
/*  90 */     FinderPattern bottomLeft = info.getBottomLeft();
/*     */     
/*  92 */     float moduleSize = calculateModuleSize(topLeft, topRight, bottomLeft);
/*  93 */     if (moduleSize < 1.0F) {
/*  94 */       throw NotFoundException.getNotFoundInstance();
/*     */     }
/*  96 */     int dimension = computeDimension(topLeft, topRight, bottomLeft, moduleSize);
/*  97 */     Version provisionalVersion = Version.getProvisionalVersionForDimension(dimension);
/*  98 */     int modulesBetweenFPCenters = provisionalVersion.getDimensionForVersion() - 7;
/*     */     
/* 100 */     AlignmentPattern alignmentPattern = null;
/*     */     
/* 102 */     if ((provisionalVersion.getAlignmentPatternCenters()).length > 0) {
/*     */ 
/*     */       
/* 105 */       float bottomRightX = topRight.getX() - topLeft.getX() + bottomLeft.getX();
/* 106 */       float bottomRightY = topRight.getY() - topLeft.getY() + bottomLeft.getY();
/*     */ 
/*     */ 
/*     */       
/* 110 */       float correctionToTopLeft = 1.0F - 3.0F / modulesBetweenFPCenters;
/* 111 */       int estAlignmentX = (int)(topLeft.getX() + correctionToTopLeft * (bottomRightX - topLeft.getX()));
/* 112 */       int estAlignmentY = (int)(topLeft.getY() + correctionToTopLeft * (bottomRightY - topLeft.getY()));
/*     */       
/*     */       int i;
/* 115 */       for (i = 4; i <= 16; i <<= 1) {
/*     */         try {
/* 117 */           alignmentPattern = findAlignmentInRegion(moduleSize, estAlignmentX, estAlignmentY, i);
/*     */ 
/*     */ 
/*     */           
/*     */           break;
/* 122 */         } catch (NotFoundException re) {}
/*     */       } 
/*     */     } 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 129 */     PerspectiveTransform transform = createTransform(topLeft, topRight, bottomLeft, alignmentPattern, dimension);
/*     */ 
/*     */     
/* 132 */     BitMatrix bits = sampleGrid(this.image, transform, dimension);
/*     */ 
/*     */     
/* 135 */     if (alignmentPattern == null) {
/* 136 */       points = new ResultPoint[] { bottomLeft, topLeft, topRight };
/*     */     } else {
/* 138 */       points = new ResultPoint[] { bottomLeft, topLeft, topRight, alignmentPattern };
/*     */     } 
/* 140 */     return new DetectorResult(bits, points);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static PerspectiveTransform createTransform(ResultPoint topLeft, ResultPoint topRight, ResultPoint bottomLeft, ResultPoint alignmentPattern, int dimension) {
/* 148 */     float bottomRightX, bottomRightY, sourceBottomRightX, sourceBottomRightY, dimMinusThree = dimension - 3.5F;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 153 */     if (alignmentPattern != null) {
/* 154 */       bottomRightX = alignmentPattern.getX();
/* 155 */       bottomRightY = alignmentPattern.getY();
/* 156 */       sourceBottomRightX = dimMinusThree - 3.0F;
/* 157 */       sourceBottomRightY = sourceBottomRightX;
/*     */     } else {
/*     */       
/* 160 */       bottomRightX = topRight.getX() - topLeft.getX() + bottomLeft.getX();
/* 161 */       bottomRightY = topRight.getY() - topLeft.getY() + bottomLeft.getY();
/* 162 */       sourceBottomRightX = dimMinusThree;
/* 163 */       sourceBottomRightY = dimMinusThree;
/*     */     } 
/*     */     
/* 166 */     return PerspectiveTransform.quadrilateralToQuadrilateral(3.5F, 3.5F, dimMinusThree, 3.5F, sourceBottomRightX, sourceBottomRightY, 3.5F, dimMinusThree, topLeft.getX(), topLeft.getY(), topRight.getX(), topRight.getY(), bottomRightX, bottomRightY, bottomLeft.getX(), bottomLeft.getY());
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static BitMatrix sampleGrid(BitMatrix image, PerspectiveTransform transform, int dimension) throws NotFoundException {
/* 189 */     GridSampler sampler = GridSampler.getInstance();
/* 190 */     return sampler.sampleGrid(image, dimension, dimension, transform);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static int computeDimension(ResultPoint topLeft, ResultPoint topRight, ResultPoint bottomLeft, float moduleSize) throws NotFoundException {
/* 201 */     int tltrCentersDimension = MathUtils.round(ResultPoint.distance(topLeft, topRight) / moduleSize);
/* 202 */     int tlblCentersDimension = MathUtils.round(ResultPoint.distance(topLeft, bottomLeft) / moduleSize);
/* 203 */     int dimension = (tltrCentersDimension + tlblCentersDimension >> 1) + 7;
/* 204 */     switch (dimension & 0x3) {
/*     */       case 0:
/* 206 */         dimension++;
/*     */         break;
/*     */       
/*     */       case 2:
/* 210 */         dimension--;
/*     */         break;
/*     */       case 3:
/* 213 */         throw NotFoundException.getNotFoundInstance();
/*     */     } 
/* 215 */     return dimension;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected final float calculateModuleSize(ResultPoint topLeft, ResultPoint topRight, ResultPoint bottomLeft) {
/* 226 */     return (calculateModuleSizeOneWay(topLeft, topRight) + calculateModuleSizeOneWay(topLeft, bottomLeft)) / 2.0F;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private float calculateModuleSizeOneWay(ResultPoint pattern, ResultPoint otherPattern) {
/* 236 */     float moduleSizeEst1 = sizeOfBlackWhiteBlackRunBothWays((int)pattern.getX(), (int)pattern.getY(), (int)otherPattern.getX(), (int)otherPattern.getY());
/*     */ 
/*     */ 
/*     */     
/* 240 */     float moduleSizeEst2 = sizeOfBlackWhiteBlackRunBothWays((int)otherPattern.getX(), (int)otherPattern.getY(), (int)pattern.getX(), (int)pattern.getY());
/*     */ 
/*     */ 
/*     */     
/* 244 */     if (Float.isNaN(moduleSizeEst1)) {
/* 245 */       return moduleSizeEst2 / 7.0F;
/*     */     }
/* 247 */     if (Float.isNaN(moduleSizeEst2)) {
/* 248 */       return moduleSizeEst1 / 7.0F;
/*     */     }
/*     */ 
/*     */     
/* 252 */     return (moduleSizeEst1 + moduleSizeEst2) / 14.0F;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private float sizeOfBlackWhiteBlackRunBothWays(int fromX, int fromY, int toX, int toY) {
/* 262 */     float result = sizeOfBlackWhiteBlackRun(fromX, fromY, toX, toY);
/*     */ 
/*     */     
/* 265 */     float scale = 1.0F;
/* 266 */     int otherToX = fromX - toX - fromX;
/* 267 */     if (otherToX < 0) {
/* 268 */       scale = fromX / (fromX - otherToX);
/* 269 */       otherToX = 0;
/* 270 */     } else if (otherToX >= this.image.getWidth()) {
/* 271 */       scale = (this.image.getWidth() - 1 - fromX) / (otherToX - fromX);
/* 272 */       otherToX = this.image.getWidth() - 1;
/*     */     } 
/* 274 */     int otherToY = (int)(fromY - (toY - fromY) * scale);
/*     */     
/* 276 */     scale = 1.0F;
/* 277 */     if (otherToY < 0) {
/* 278 */       scale = fromY / (fromY - otherToY);
/* 279 */       otherToY = 0;
/* 280 */     } else if (otherToY >= this.image.getHeight()) {
/* 281 */       scale = (this.image.getHeight() - 1 - fromY) / (otherToY - fromY);
/* 282 */       otherToY = this.image.getHeight() - 1;
/*     */     } 
/* 284 */     otherToX = (int)(fromX + (otherToX - fromX) * scale);
/*     */     
/* 286 */     result += sizeOfBlackWhiteBlackRun(fromX, fromY, otherToX, otherToY);
/*     */ 
/*     */     
/* 289 */     return result - 1.0F;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private float sizeOfBlackWhiteBlackRun(int fromX, int fromY, int toX, int toY) {
/* 303 */     boolean steep = (Math.abs(toY - fromY) > Math.abs(toX - fromX));
/* 304 */     if (steep) {
/* 305 */       int temp = fromX;
/* 306 */       fromX = fromY;
/* 307 */       fromY = temp;
/* 308 */       temp = toX;
/* 309 */       toX = toY;
/* 310 */       toY = temp;
/*     */     } 
/*     */     
/* 313 */     int dx = Math.abs(toX - fromX);
/* 314 */     int dy = Math.abs(toY - fromY);
/* 315 */     int error = -dx >> 1;
/* 316 */     int xstep = (fromX < toX) ? 1 : -1;
/* 317 */     int ystep = (fromY < toY) ? 1 : -1;
/*     */ 
/*     */     
/* 320 */     int state = 0;
/*     */     
/* 322 */     int xLimit = toX + xstep; int x, y;
/* 323 */     for (x = fromX, y = fromY; x != xLimit; x += xstep) {
/* 324 */       int realX = steep ? y : x;
/* 325 */       int realY = steep ? x : y;
/*     */ 
/*     */ 
/*     */ 
/*     */       
/* 330 */       if (((state == 1)) == this.image.get(realX, realY)) {
/* 331 */         if (state == 2) {
/* 332 */           return MathUtils.distance(x, y, fromX, fromY);
/*     */         }
/* 334 */         state++;
/*     */       } 
/*     */       
/* 337 */       error += dy;
/* 338 */       if (error > 0) {
/* 339 */         if (y == toY) {
/*     */           break;
/*     */         }
/* 342 */         y += ystep;
/* 343 */         error -= dx;
/*     */       } 
/*     */     } 
/*     */ 
/*     */ 
/*     */     
/* 349 */     if (state == 2) {
/* 350 */       return MathUtils.distance(toX + xstep, toY, fromX, fromY);
/*     */     }
/*     */     
/* 353 */     return Float.NaN;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected final AlignmentPattern findAlignmentInRegion(float overallEstModuleSize, int estAlignmentX, int estAlignmentY, float allowanceFactor) throws NotFoundException {
/* 374 */     int allowance = (int)(allowanceFactor * overallEstModuleSize);
/* 375 */     int alignmentAreaLeftX = Math.max(0, estAlignmentX - allowance);
/* 376 */     int alignmentAreaRightX = Math.min(this.image.getWidth() - 1, estAlignmentX + allowance);
/* 377 */     if ((alignmentAreaRightX - alignmentAreaLeftX) < overallEstModuleSize * 3.0F) {
/* 378 */       throw NotFoundException.getNotFoundInstance();
/*     */     }
/*     */     
/* 381 */     int alignmentAreaTopY = Math.max(0, estAlignmentY - allowance);
/* 382 */     int alignmentAreaBottomY = Math.min(this.image.getHeight() - 1, estAlignmentY + allowance);
/* 383 */     if ((alignmentAreaBottomY - alignmentAreaTopY) < overallEstModuleSize * 3.0F) {
/* 384 */       throw NotFoundException.getNotFoundInstance();
/*     */     }
/*     */     
/* 387 */     AlignmentPatternFinder alignmentFinder = new AlignmentPatternFinder(this.image, alignmentAreaLeftX, alignmentAreaTopY, alignmentAreaRightX - alignmentAreaLeftX, alignmentAreaBottomY - alignmentAreaTopY, overallEstModuleSize, this.resultPointCallback);
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 396 */     return alignmentFinder.find();
/*     */   }
/*     */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\com\google\zxing\qrcode\detector\Detector.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       1.1.3
 */