/*     */ package com.google.zxing.qrcode.detector;
/*     */ 
/*     */ import com.google.zxing.DecodeHintType;
/*     */ import com.google.zxing.NotFoundException;
/*     */ import com.google.zxing.ResultPoint;
/*     */ import com.google.zxing.ResultPointCallback;
/*     */ import com.google.zxing.common.BitMatrix;
/*     */ import java.io.Serializable;
/*     */ import java.util.ArrayList;
/*     */ import java.util.Collections;
/*     */ import java.util.Comparator;
/*     */ import java.util.List;
/*     */ import java.util.Map;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class FinderPatternFinder
/*     */ {
/*     */   private static final int CENTER_QUORUM = 2;
/*     */   protected static final int MIN_SKIP = 3;
/*     */   protected static final int MAX_MODULES = 57;
/*     */   private static final int INTEGER_MATH_SHIFT = 8;
/*     */   private final BitMatrix image;
/*     */   private final List<FinderPattern> possibleCenters;
/*     */   private boolean hasSkipped;
/*     */   private final int[] crossCheckStateCount;
/*     */   private final ResultPointCallback resultPointCallback;
/*     */   
/*     */   public FinderPatternFinder(BitMatrix image) {
/*  59 */     this(image, null);
/*     */   }
/*     */   
/*     */   public FinderPatternFinder(BitMatrix image, ResultPointCallback resultPointCallback) {
/*  63 */     this.image = image;
/*  64 */     this.possibleCenters = new ArrayList<FinderPattern>();
/*  65 */     this.crossCheckStateCount = new int[5];
/*  66 */     this.resultPointCallback = resultPointCallback;
/*     */   }
/*     */   
/*     */   protected final BitMatrix getImage() {
/*  70 */     return this.image;
/*     */   }
/*     */   
/*     */   protected final List<FinderPattern> getPossibleCenters() {
/*  74 */     return this.possibleCenters;
/*     */   }
/*     */   
/*     */   final FinderPatternInfo find(Map<DecodeHintType, ?> hints) throws NotFoundException {
/*  78 */     boolean tryHarder = (hints != null && hints.containsKey(DecodeHintType.TRY_HARDER));
/*  79 */     int maxI = this.image.getHeight();
/*  80 */     int maxJ = this.image.getWidth();
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*  88 */     int iSkip = 3 * maxI / 228;
/*  89 */     if (iSkip < 3 || tryHarder) {
/*  90 */       iSkip = 3;
/*     */     }
/*     */     
/*  93 */     boolean done = false;
/*  94 */     int[] stateCount = new int[5]; int i;
/*  95 */     for (i = iSkip - 1; i < maxI && !done; i += iSkip) {
/*     */       
/*  97 */       stateCount[0] = 0;
/*  98 */       stateCount[1] = 0;
/*  99 */       stateCount[2] = 0;
/* 100 */       stateCount[3] = 0;
/* 101 */       stateCount[4] = 0;
/* 102 */       int currentState = 0;
/* 103 */       int j = 0; while (true) { if (j < maxJ)
/* 104 */         { if (this.image.get(j, i)) {
/*     */             
/* 106 */             if ((currentState & 0x1) == 1) {
/* 107 */               currentState++;
/*     */             }
/* 109 */             stateCount[currentState] = stateCount[currentState] + 1;
/*     */           }
/* 111 */           else if ((currentState & 0x1) == 0) {
/* 112 */             if (currentState == 4) {
/* 113 */               if (foundPatternCross(stateCount)) {
/* 114 */                 boolean confirmed = handlePossibleCenter(stateCount, i, j);
/* 115 */                 if (confirmed) {
/*     */ 
/*     */                   
/* 118 */                   iSkip = 2;
/* 119 */                   if (this.hasSkipped) {
/* 120 */                     done = haveMultiplyConfirmedCenters();
/*     */                   } else {
/* 122 */                     int rowSkip = findRowSkip();
/* 123 */                     if (rowSkip > stateCount[2]) {
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */                       
/* 132 */                       i += rowSkip - stateCount[2] - iSkip;
/* 133 */                       j = maxJ - 1;
/*     */                     } 
/*     */                   } 
/*     */                 } else {
/* 137 */                   stateCount[0] = stateCount[2];
/* 138 */                   stateCount[1] = stateCount[3];
/* 139 */                   stateCount[2] = stateCount[4];
/* 140 */                   stateCount[3] = 1;
/* 141 */                   stateCount[4] = 0;
/* 142 */                   currentState = 3;
/*     */                   
/*     */                   j++;
/*     */                 } 
/* 146 */                 currentState = 0;
/* 147 */                 stateCount[0] = 0;
/* 148 */                 stateCount[1] = 0;
/* 149 */                 stateCount[2] = 0;
/* 150 */                 stateCount[3] = 0;
/* 151 */                 stateCount[4] = 0;
/*     */               } else {
/* 153 */                 stateCount[0] = stateCount[2];
/* 154 */                 stateCount[1] = stateCount[3];
/* 155 */                 stateCount[2] = stateCount[4];
/* 156 */                 stateCount[3] = 1;
/* 157 */                 stateCount[4] = 0;
/* 158 */                 currentState = 3;
/*     */               } 
/*     */             } else {
/* 161 */               stateCount[++currentState] = stateCount[++currentState] + 1;
/*     */             } 
/*     */           } else {
/* 164 */             stateCount[currentState] = stateCount[currentState] + 1;
/*     */           }  }
/*     */         else { break; }
/*     */          j++; }
/* 168 */        if (foundPatternCross(stateCount)) {
/* 169 */         boolean confirmed = handlePossibleCenter(stateCount, i, maxJ);
/* 170 */         if (confirmed) {
/* 171 */           iSkip = stateCount[0];
/* 172 */           if (this.hasSkipped)
/*     */           {
/* 174 */             done = haveMultiplyConfirmedCenters();
/*     */           }
/*     */         } 
/*     */       } 
/*     */     } 
/*     */     
/* 180 */     FinderPattern[] patternInfo = selectBestPatterns();
/* 181 */     ResultPoint.orderBestPatterns((ResultPoint[])patternInfo);
/*     */     
/* 183 */     return new FinderPatternInfo(patternInfo);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static float centerFromEnd(int[] stateCount, int end) {
/* 191 */     return (end - stateCount[4] - stateCount[3]) - stateCount[2] / 2.0F;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected static boolean foundPatternCross(int[] stateCount) {
/* 200 */     int totalModuleSize = 0;
/* 201 */     for (int i = 0; i < 5; i++) {
/* 202 */       int count = stateCount[i];
/* 203 */       if (count == 0) {
/* 204 */         return false;
/*     */       }
/* 206 */       totalModuleSize += count;
/*     */     } 
/* 208 */     if (totalModuleSize < 7) {
/* 209 */       return false;
/*     */     }
/* 211 */     int moduleSize = (totalModuleSize << 8) / 7;
/* 212 */     int maxVariance = moduleSize / 2;
/*     */     
/* 214 */     return (Math.abs(moduleSize - (stateCount[0] << 8)) < maxVariance && Math.abs(moduleSize - (stateCount[1] << 8)) < maxVariance && Math.abs(3 * moduleSize - (stateCount[2] << 8)) < 3 * maxVariance && Math.abs(moduleSize - (stateCount[3] << 8)) < maxVariance && Math.abs(moduleSize - (stateCount[4] << 8)) < maxVariance);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private int[] getCrossCheckStateCount() {
/* 222 */     this.crossCheckStateCount[0] = 0;
/* 223 */     this.crossCheckStateCount[1] = 0;
/* 224 */     this.crossCheckStateCount[2] = 0;
/* 225 */     this.crossCheckStateCount[3] = 0;
/* 226 */     this.crossCheckStateCount[4] = 0;
/* 227 */     return this.crossCheckStateCount;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private float crossCheckVertical(int startI, int centerJ, int maxCount, int originalStateCountTotal) {
/* 243 */     BitMatrix image = this.image;
/*     */     
/* 245 */     int maxI = image.getHeight();
/* 246 */     int[] stateCount = getCrossCheckStateCount();
/*     */ 
/*     */     
/* 249 */     int i = startI;
/* 250 */     while (i >= 0 && image.get(centerJ, i)) {
/* 251 */       stateCount[2] = stateCount[2] + 1;
/* 252 */       i--;
/*     */     } 
/* 254 */     if (i < 0) {
/* 255 */       return Float.NaN;
/*     */     }
/* 257 */     while (i >= 0 && !image.get(centerJ, i) && stateCount[1] <= maxCount) {
/* 258 */       stateCount[1] = stateCount[1] + 1;
/* 259 */       i--;
/*     */     } 
/*     */     
/* 262 */     if (i < 0 || stateCount[1] > maxCount) {
/* 263 */       return Float.NaN;
/*     */     }
/* 265 */     while (i >= 0 && image.get(centerJ, i) && stateCount[0] <= maxCount) {
/* 266 */       stateCount[0] = stateCount[0] + 1;
/* 267 */       i--;
/*     */     } 
/* 269 */     if (stateCount[0] > maxCount) {
/* 270 */       return Float.NaN;
/*     */     }
/*     */ 
/*     */     
/* 274 */     i = startI + 1;
/* 275 */     while (i < maxI && image.get(centerJ, i)) {
/* 276 */       stateCount[2] = stateCount[2] + 1;
/* 277 */       i++;
/*     */     } 
/* 279 */     if (i == maxI) {
/* 280 */       return Float.NaN;
/*     */     }
/* 282 */     while (i < maxI && !image.get(centerJ, i) && stateCount[3] < maxCount) {
/* 283 */       stateCount[3] = stateCount[3] + 1;
/* 284 */       i++;
/*     */     } 
/* 286 */     if (i == maxI || stateCount[3] >= maxCount) {
/* 287 */       return Float.NaN;
/*     */     }
/* 289 */     while (i < maxI && image.get(centerJ, i) && stateCount[4] < maxCount) {
/* 290 */       stateCount[4] = stateCount[4] + 1;
/* 291 */       i++;
/*     */     } 
/* 293 */     if (stateCount[4] >= maxCount) {
/* 294 */       return Float.NaN;
/*     */     }
/*     */ 
/*     */ 
/*     */     
/* 299 */     int stateCountTotal = stateCount[0] + stateCount[1] + stateCount[2] + stateCount[3] + stateCount[4];
/*     */     
/* 301 */     if (5 * Math.abs(stateCountTotal - originalStateCountTotal) >= 2 * originalStateCountTotal) {
/* 302 */       return Float.NaN;
/*     */     }
/*     */     
/* 305 */     return foundPatternCross(stateCount) ? centerFromEnd(stateCount, i) : Float.NaN;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private float crossCheckHorizontal(int startJ, int centerI, int maxCount, int originalStateCountTotal) {
/* 315 */     BitMatrix image = this.image;
/*     */     
/* 317 */     int maxJ = image.getWidth();
/* 318 */     int[] stateCount = getCrossCheckStateCount();
/*     */     
/* 320 */     int j = startJ;
/* 321 */     while (j >= 0 && image.get(j, centerI)) {
/* 322 */       stateCount[2] = stateCount[2] + 1;
/* 323 */       j--;
/*     */     } 
/* 325 */     if (j < 0) {
/* 326 */       return Float.NaN;
/*     */     }
/* 328 */     while (j >= 0 && !image.get(j, centerI) && stateCount[1] <= maxCount) {
/* 329 */       stateCount[1] = stateCount[1] + 1;
/* 330 */       j--;
/*     */     } 
/* 332 */     if (j < 0 || stateCount[1] > maxCount) {
/* 333 */       return Float.NaN;
/*     */     }
/* 335 */     while (j >= 0 && image.get(j, centerI) && stateCount[0] <= maxCount) {
/* 336 */       stateCount[0] = stateCount[0] + 1;
/* 337 */       j--;
/*     */     } 
/* 339 */     if (stateCount[0] > maxCount) {
/* 340 */       return Float.NaN;
/*     */     }
/*     */     
/* 343 */     j = startJ + 1;
/* 344 */     while (j < maxJ && image.get(j, centerI)) {
/* 345 */       stateCount[2] = stateCount[2] + 1;
/* 346 */       j++;
/*     */     } 
/* 348 */     if (j == maxJ) {
/* 349 */       return Float.NaN;
/*     */     }
/* 351 */     while (j < maxJ && !image.get(j, centerI) && stateCount[3] < maxCount) {
/* 352 */       stateCount[3] = stateCount[3] + 1;
/* 353 */       j++;
/*     */     } 
/* 355 */     if (j == maxJ || stateCount[3] >= maxCount) {
/* 356 */       return Float.NaN;
/*     */     }
/* 358 */     while (j < maxJ && image.get(j, centerI) && stateCount[4] < maxCount) {
/* 359 */       stateCount[4] = stateCount[4] + 1;
/* 360 */       j++;
/*     */     } 
/* 362 */     if (stateCount[4] >= maxCount) {
/* 363 */       return Float.NaN;
/*     */     }
/*     */ 
/*     */ 
/*     */     
/* 368 */     int stateCountTotal = stateCount[0] + stateCount[1] + stateCount[2] + stateCount[3] + stateCount[4];
/*     */     
/* 370 */     if (5 * Math.abs(stateCountTotal - originalStateCountTotal) >= originalStateCountTotal) {
/* 371 */       return Float.NaN;
/*     */     }
/*     */     
/* 374 */     return foundPatternCross(stateCount) ? centerFromEnd(stateCount, j) : Float.NaN;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected final boolean handlePossibleCenter(int[] stateCount, int i, int j) {
/* 394 */     int stateCountTotal = stateCount[0] + stateCount[1] + stateCount[2] + stateCount[3] + stateCount[4];
/*     */     
/* 396 */     float centerJ = centerFromEnd(stateCount, j);
/* 397 */     float centerI = crossCheckVertical(i, (int)centerJ, stateCount[2], stateCountTotal);
/* 398 */     if (!Float.isNaN(centerI)) {
/*     */       
/* 400 */       centerJ = crossCheckHorizontal((int)centerJ, (int)centerI, stateCount[2], stateCountTotal);
/* 401 */       if (!Float.isNaN(centerJ)) {
/* 402 */         float estimatedModuleSize = stateCountTotal / 7.0F;
/* 403 */         boolean found = false;
/* 404 */         for (int index = 0; index < this.possibleCenters.size(); index++) {
/* 405 */           FinderPattern center = this.possibleCenters.get(index);
/*     */           
/* 407 */           if (center.aboutEquals(estimatedModuleSize, centerI, centerJ)) {
/* 408 */             this.possibleCenters.set(index, center.combineEstimate(centerI, centerJ, estimatedModuleSize));
/* 409 */             found = true;
/*     */             break;
/*     */           } 
/*     */         } 
/* 413 */         if (!found) {
/* 414 */           FinderPattern point = new FinderPattern(centerJ, centerI, estimatedModuleSize);
/* 415 */           this.possibleCenters.add(point);
/* 416 */           if (this.resultPointCallback != null) {
/* 417 */             this.resultPointCallback.foundPossibleResultPoint(point);
/*     */           }
/*     */         } 
/* 420 */         return true;
/*     */       } 
/*     */     } 
/* 423 */     return false;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private int findRowSkip() {
/* 433 */     int max = this.possibleCenters.size();
/* 434 */     if (max <= 1) {
/* 435 */       return 0;
/*     */     }
/* 437 */     FinderPattern firstConfirmedCenter = null;
/* 438 */     for (FinderPattern center : this.possibleCenters) {
/* 439 */       if (center.getCount() >= 2) {
/* 440 */         if (firstConfirmedCenter == null) {
/* 441 */           firstConfirmedCenter = center;
/*     */ 
/*     */           
/*     */           continue;
/*     */         } 
/*     */ 
/*     */         
/* 448 */         this.hasSkipped = true;
/* 449 */         return (int)(Math.abs(firstConfirmedCenter.getX() - center.getX()) - Math.abs(firstConfirmedCenter.getY() - center.getY())) / 2;
/*     */       } 
/*     */     } 
/*     */ 
/*     */     
/* 454 */     return 0;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private boolean haveMultiplyConfirmedCenters() {
/* 463 */     int confirmedCount = 0;
/* 464 */     float totalModuleSize = 0.0F;
/* 465 */     int max = this.possibleCenters.size();
/* 466 */     for (FinderPattern pattern : this.possibleCenters) {
/* 467 */       if (pattern.getCount() >= 2) {
/* 468 */         confirmedCount++;
/* 469 */         totalModuleSize += pattern.getEstimatedModuleSize();
/*     */       } 
/*     */     } 
/* 472 */     if (confirmedCount < 3) {
/* 473 */       return false;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 479 */     float average = totalModuleSize / max;
/* 480 */     float totalDeviation = 0.0F;
/* 481 */     for (FinderPattern pattern : this.possibleCenters) {
/* 482 */       totalDeviation += Math.abs(pattern.getEstimatedModuleSize() - average);
/*     */     }
/* 484 */     return (totalDeviation <= 0.05F * totalModuleSize);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private FinderPattern[] selectBestPatterns() throws NotFoundException {
/* 495 */     int startSize = this.possibleCenters.size();
/* 496 */     if (startSize < 3)
/*     */     {
/* 498 */       throw NotFoundException.getNotFoundInstance();
/*     */     }
/*     */ 
/*     */     
/* 502 */     if (startSize > 3) {
/*     */       
/* 504 */       float totalModuleSize = 0.0F;
/* 505 */       float square = 0.0F;
/* 506 */       for (FinderPattern center : this.possibleCenters) {
/* 507 */         float size = center.getEstimatedModuleSize();
/* 508 */         totalModuleSize += size;
/* 509 */         square += size * size;
/*     */       } 
/* 511 */       float average = totalModuleSize / startSize;
/* 512 */       float stdDev = (float)Math.sqrt((square / startSize - average * average));
/*     */       
/* 514 */       Collections.sort(this.possibleCenters, new FurthestFromAverageComparator(average));
/*     */       
/* 516 */       float limit = Math.max(0.2F * average, stdDev);
/*     */       
/* 518 */       for (int i = 0; i < this.possibleCenters.size() && this.possibleCenters.size() > 3; i++) {
/* 519 */         FinderPattern pattern = this.possibleCenters.get(i);
/* 520 */         if (Math.abs(pattern.getEstimatedModuleSize() - average) > limit) {
/* 521 */           this.possibleCenters.remove(i);
/* 522 */           i--;
/*     */         } 
/*     */       } 
/*     */     } 
/*     */     
/* 527 */     if (this.possibleCenters.size() > 3) {
/*     */ 
/*     */       
/* 530 */       float totalModuleSize = 0.0F;
/* 531 */       for (FinderPattern possibleCenter : this.possibleCenters) {
/* 532 */         totalModuleSize += possibleCenter.getEstimatedModuleSize();
/*     */       }
/*     */       
/* 535 */       float average = totalModuleSize / this.possibleCenters.size();
/*     */       
/* 537 */       Collections.sort(this.possibleCenters, new CenterComparator(average));
/*     */       
/* 539 */       this.possibleCenters.subList(3, this.possibleCenters.size()).clear();
/*     */     } 
/*     */     
/* 542 */     return new FinderPattern[] { this.possibleCenters.get(0), this.possibleCenters.get(1), this.possibleCenters.get(2) };
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   private static final class FurthestFromAverageComparator
/*     */     implements Comparator<FinderPattern>, Serializable
/*     */   {
/*     */     private final float average;
/*     */ 
/*     */ 
/*     */     
/*     */     private FurthestFromAverageComparator(float f) {
/* 555 */       this.average = f;
/*     */     }
/*     */     
/*     */     public int compare(FinderPattern center1, FinderPattern center2) {
/* 559 */       float dA = Math.abs(center2.getEstimatedModuleSize() - this.average);
/* 560 */       float dB = Math.abs(center1.getEstimatedModuleSize() - this.average);
/* 561 */       return (dA < dB) ? -1 : ((dA == dB) ? 0 : 1);
/*     */     }
/*     */   }
/*     */   
/*     */   private static final class CenterComparator
/*     */     implements Comparator<FinderPattern>, Serializable
/*     */   {
/*     */     private final float average;
/*     */     
/*     */     private CenterComparator(float f) {
/* 571 */       this.average = f;
/*     */     }
/*     */     
/*     */     public int compare(FinderPattern center1, FinderPattern center2) {
/* 575 */       if (center2.getCount() == center1.getCount()) {
/* 576 */         float dA = Math.abs(center2.getEstimatedModuleSize() - this.average);
/* 577 */         float dB = Math.abs(center1.getEstimatedModuleSize() - this.average);
/* 578 */         return (dA < dB) ? 1 : ((dA == dB) ? 0 : -1);
/*     */       } 
/* 580 */       return center2.getCount() - center1.getCount();
/*     */     }
/*     */   }
/*     */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\com\google\zxing\qrcode\detector\FinderPatternFinder.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       1.1.3
 */