/*     */ package com.google.zxing.qrcode.encoder;
/*     */ 
/*     */ import com.google.zxing.EncodeHintType;
/*     */ import com.google.zxing.WriterException;
/*     */ import com.google.zxing.common.BitArray;
/*     */ import com.google.zxing.common.CharacterSetECI;
/*     */ import com.google.zxing.common.reedsolomon.GenericGF;
/*     */ import com.google.zxing.common.reedsolomon.ReedSolomonEncoder;
/*     */ import com.google.zxing.qrcode.decoder.ErrorCorrectionLevel;
/*     */ import com.google.zxing.qrcode.decoder.Mode;
/*     */ import com.google.zxing.qrcode.decoder.Version;
/*     */ import java.io.UnsupportedEncodingException;
/*     */ import java.util.ArrayList;
/*     */ import java.util.Collection;
/*     */ import java.util.Map;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public final class Encoder
/*     */ {
/*  41 */   private static final int[] ALPHANUMERIC_TABLE = new int[] { -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, 36, -1, -1, -1, 37, 38, -1, -1, -1, -1, 39, 40, -1, 41, 42, 43, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 44, -1, -1, -1, -1, -1, -1, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, -1, -1, -1, -1, -1 };
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   static final String DEFAULT_BYTE_MODE_ENCODING = "ISO-8859-1";
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static int calculateMaskPenalty(ByteMatrix matrix) {
/*  58 */     return MaskUtil.applyMaskPenaltyRule1(matrix) + MaskUtil.applyMaskPenaltyRule2(matrix) + MaskUtil.applyMaskPenaltyRule3(matrix) + MaskUtil.applyMaskPenaltyRule4(matrix);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static QRCode encode(String content, ErrorCorrectionLevel ecLevel) throws WriterException {
/*  76 */     return encode(content, ecLevel, null);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static QRCode encode(String content, ErrorCorrectionLevel ecLevel, Map<EncodeHintType, ?> hints) throws WriterException {
/*  84 */     String encoding = (hints == null) ? null : (String)hints.get(EncodeHintType.CHARACTER_SET);
/*  85 */     if (encoding == null) {
/*  86 */       encoding = "ISO-8859-1";
/*     */     }
/*     */ 
/*     */ 
/*     */     
/*  91 */     Mode mode = chooseMode(content, encoding);
/*     */ 
/*     */ 
/*     */     
/*  95 */     BitArray headerBits = new BitArray();
/*     */ 
/*     */     
/*  98 */     if (mode == Mode.BYTE && !"ISO-8859-1".equals(encoding)) {
/*  99 */       CharacterSetECI eci = CharacterSetECI.getCharacterSetECIByName(encoding);
/* 100 */       if (eci != null) {
/* 101 */         appendECI(eci, headerBits);
/*     */       }
/*     */     } 
/*     */ 
/*     */     
/* 106 */     appendModeInfo(mode, headerBits);
/*     */ 
/*     */ 
/*     */     
/* 110 */     BitArray dataBits = new BitArray();
/* 111 */     appendBytes(content, mode, dataBits, encoding);
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 117 */     int provisionalBitsNeeded = headerBits.getSize() + mode.getCharacterCountBits(Version.getVersionForNumber(1)) + dataBits.getSize();
/*     */ 
/*     */     
/* 120 */     Version provisionalVersion = chooseVersion(provisionalBitsNeeded, ecLevel);
/*     */ 
/*     */ 
/*     */     
/* 124 */     int bitsNeeded = headerBits.getSize() + mode.getCharacterCountBits(provisionalVersion) + dataBits.getSize();
/*     */ 
/*     */     
/* 127 */     Version version = chooseVersion(bitsNeeded, ecLevel);
/*     */     
/* 129 */     BitArray headerAndDataBits = new BitArray();
/* 130 */     headerAndDataBits.appendBitArray(headerBits);
/*     */     
/* 132 */     int numLetters = (mode == Mode.BYTE) ? dataBits.getSizeInBytes() : content.length();
/* 133 */     appendLengthInfo(numLetters, version, mode, headerAndDataBits);
/*     */     
/* 135 */     headerAndDataBits.appendBitArray(dataBits);
/*     */     
/* 137 */     Version.ECBlocks ecBlocks = version.getECBlocksForLevel(ecLevel);
/* 138 */     int numDataBytes = version.getTotalCodewords() - ecBlocks.getTotalECCodewords();
/*     */ 
/*     */     
/* 141 */     terminateBits(numDataBytes, headerAndDataBits);
/*     */ 
/*     */     
/* 144 */     BitArray finalBits = interleaveWithECBytes(headerAndDataBits, version.getTotalCodewords(), numDataBytes, ecBlocks.getNumBlocks());
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 149 */     QRCode qrCode = new QRCode();
/*     */     
/* 151 */     qrCode.setECLevel(ecLevel);
/* 152 */     qrCode.setMode(mode);
/* 153 */     qrCode.setVersion(version);
/*     */ 
/*     */     
/* 156 */     int dimension = version.getDimensionForVersion();
/* 157 */     ByteMatrix matrix = new ByteMatrix(dimension, dimension);
/* 158 */     int maskPattern = chooseMaskPattern(finalBits, ecLevel, version, matrix);
/* 159 */     qrCode.setMaskPattern(maskPattern);
/*     */ 
/*     */     
/* 162 */     MatrixUtil.buildMatrix(finalBits, ecLevel, version, maskPattern, matrix);
/* 163 */     qrCode.setMatrix(matrix);
/*     */     
/* 165 */     return qrCode;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   static int getAlphanumericCode(int code) {
/* 173 */     if (code < ALPHANUMERIC_TABLE.length) {
/* 174 */       return ALPHANUMERIC_TABLE[code];
/*     */     }
/* 176 */     return -1;
/*     */   }
/*     */   
/*     */   public static Mode chooseMode(String content) {
/* 180 */     return chooseMode(content, null);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static Mode chooseMode(String content, String encoding) {
/* 188 */     if ("Shift_JIS".equals(encoding))
/*     */     {
/* 190 */       return isOnlyDoubleByteKanji(content) ? Mode.KANJI : Mode.BYTE;
/*     */     }
/* 192 */     boolean hasNumeric = false;
/* 193 */     boolean hasAlphanumeric = false;
/* 194 */     for (int i = 0; i < content.length(); i++) {
/* 195 */       char c = content.charAt(i);
/* 196 */       if (c >= '0' && c <= '9') {
/* 197 */         hasNumeric = true;
/* 198 */       } else if (getAlphanumericCode(c) != -1) {
/* 199 */         hasAlphanumeric = true;
/*     */       } else {
/* 201 */         return Mode.BYTE;
/*     */       } 
/*     */     } 
/* 204 */     if (hasAlphanumeric) {
/* 205 */       return Mode.ALPHANUMERIC;
/*     */     }
/* 207 */     if (hasNumeric) {
/* 208 */       return Mode.NUMERIC;
/*     */     }
/* 210 */     return Mode.BYTE;
/*     */   }
/*     */   
/*     */   private static boolean isOnlyDoubleByteKanji(String content) {
/*     */     byte[] bytes;
/*     */     try {
/* 216 */       bytes = content.getBytes("Shift_JIS");
/* 217 */     } catch (UnsupportedEncodingException ignored) {
/* 218 */       return false;
/*     */     } 
/* 220 */     int length = bytes.length;
/* 221 */     if (length % 2 != 0) {
/* 222 */       return false;
/*     */     }
/* 224 */     for (int i = 0; i < length; i += 2) {
/* 225 */       int byte1 = bytes[i] & 0xFF;
/* 226 */       if ((byte1 < 129 || byte1 > 159) && (byte1 < 224 || byte1 > 235)) {
/* 227 */         return false;
/*     */       }
/*     */     } 
/* 230 */     return true;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static int chooseMaskPattern(BitArray bits, ErrorCorrectionLevel ecLevel, Version version, ByteMatrix matrix) throws WriterException {
/* 238 */     int minPenalty = Integer.MAX_VALUE;
/* 239 */     int bestMaskPattern = -1;
/*     */     
/* 241 */     for (int maskPattern = 0; maskPattern < 8; maskPattern++) {
/* 242 */       MatrixUtil.buildMatrix(bits, ecLevel, version, maskPattern, matrix);
/* 243 */       int penalty = calculateMaskPenalty(matrix);
/* 244 */       if (penalty < minPenalty) {
/* 245 */         minPenalty = penalty;
/* 246 */         bestMaskPattern = maskPattern;
/*     */       } 
/*     */     } 
/* 249 */     return bestMaskPattern;
/*     */   }
/*     */ 
/*     */   
/*     */   private static Version chooseVersion(int numInputBits, ErrorCorrectionLevel ecLevel) throws WriterException {
/* 254 */     for (int versionNum = 1; versionNum <= 40; versionNum++) {
/* 255 */       Version version = Version.getVersionForNumber(versionNum);
/*     */       
/* 257 */       int numBytes = version.getTotalCodewords();
/*     */       
/* 259 */       Version.ECBlocks ecBlocks = version.getECBlocksForLevel(ecLevel);
/* 260 */       int numEcBytes = ecBlocks.getTotalECCodewords();
/*     */       
/* 262 */       int numDataBytes = numBytes - numEcBytes;
/* 263 */       int totalInputBytes = (numInputBits + 7) / 8;
/* 264 */       if (numDataBytes >= totalInputBytes) {
/* 265 */         return version;
/*     */       }
/*     */     } 
/* 268 */     throw new WriterException("Data too big");
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   static void terminateBits(int numDataBytes, BitArray bits) throws WriterException {
/* 275 */     int capacity = numDataBytes << 3;
/* 276 */     if (bits.getSize() > capacity) {
/* 277 */       throw new WriterException("data bits cannot fit in the QR Code" + bits.getSize() + " > " + capacity);
/*     */     }
/*     */     
/* 280 */     for (int i = 0; i < 4 && bits.getSize() < capacity; i++) {
/* 281 */       bits.appendBit(false);
/*     */     }
/*     */ 
/*     */     
/* 285 */     int numBitsInLastByte = bits.getSize() & 0x7;
/* 286 */     if (numBitsInLastByte > 0) {
/* 287 */       for (int k = numBitsInLastByte; k < 8; k++) {
/* 288 */         bits.appendBit(false);
/*     */       }
/*     */     }
/*     */     
/* 292 */     int numPaddingBytes = numDataBytes - bits.getSizeInBytes();
/* 293 */     for (int j = 0; j < numPaddingBytes; j++) {
/* 294 */       bits.appendBits(((j & 0x1) == 0) ? 236 : 17, 8);
/*     */     }
/* 296 */     if (bits.getSize() != capacity) {
/* 297 */       throw new WriterException("Bits size does not equal capacity");
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   static void getNumDataBytesAndNumECBytesForBlockID(int numTotalBytes, int numDataBytes, int numRSBlocks, int blockID, int[] numDataBytesInBlock, int[] numECBytesInBlock) throws WriterException {
/* 312 */     if (blockID >= numRSBlocks) {
/* 313 */       throw new WriterException("Block ID too large");
/*     */     }
/*     */     
/* 316 */     int numRsBlocksInGroup2 = numTotalBytes % numRSBlocks;
/*     */     
/* 318 */     int numRsBlocksInGroup1 = numRSBlocks - numRsBlocksInGroup2;
/*     */     
/* 320 */     int numTotalBytesInGroup1 = numTotalBytes / numRSBlocks;
/*     */     
/* 322 */     int numTotalBytesInGroup2 = numTotalBytesInGroup1 + 1;
/*     */     
/* 324 */     int numDataBytesInGroup1 = numDataBytes / numRSBlocks;
/*     */     
/* 326 */     int numDataBytesInGroup2 = numDataBytesInGroup1 + 1;
/*     */     
/* 328 */     int numEcBytesInGroup1 = numTotalBytesInGroup1 - numDataBytesInGroup1;
/*     */     
/* 330 */     int numEcBytesInGroup2 = numTotalBytesInGroup2 - numDataBytesInGroup2;
/*     */ 
/*     */     
/* 333 */     if (numEcBytesInGroup1 != numEcBytesInGroup2) {
/* 334 */       throw new WriterException("EC bytes mismatch");
/*     */     }
/*     */     
/* 337 */     if (numRSBlocks != numRsBlocksInGroup1 + numRsBlocksInGroup2) {
/* 338 */       throw new WriterException("RS blocks mismatch");
/*     */     }
/*     */     
/* 341 */     if (numTotalBytes != (numDataBytesInGroup1 + numEcBytesInGroup1) * numRsBlocksInGroup1 + (numDataBytesInGroup2 + numEcBytesInGroup2) * numRsBlocksInGroup2)
/*     */     {
/*     */ 
/*     */ 
/*     */       
/* 346 */       throw new WriterException("Total bytes mismatch");
/*     */     }
/*     */     
/* 349 */     if (blockID < numRsBlocksInGroup1) {
/* 350 */       numDataBytesInBlock[0] = numDataBytesInGroup1;
/* 351 */       numECBytesInBlock[0] = numEcBytesInGroup1;
/*     */     } else {
/* 353 */       numDataBytesInBlock[0] = numDataBytesInGroup2;
/* 354 */       numECBytesInBlock[0] = numEcBytesInGroup2;
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   static BitArray interleaveWithECBytes(BitArray bits, int numTotalBytes, int numDataBytes, int numRSBlocks) throws WriterException {
/* 368 */     if (bits.getSizeInBytes() != numDataBytes) {
/* 369 */       throw new WriterException("Number of bits and data bytes does not match");
/*     */     }
/*     */ 
/*     */ 
/*     */     
/* 374 */     int dataBytesOffset = 0;
/* 375 */     int maxNumDataBytes = 0;
/* 376 */     int maxNumEcBytes = 0;
/*     */ 
/*     */     
/* 379 */     Collection<BlockPair> blocks = new ArrayList<BlockPair>(numRSBlocks);
/*     */     
/* 381 */     for (int i = 0; i < numRSBlocks; i++) {
/* 382 */       int[] numDataBytesInBlock = new int[1];
/* 383 */       int[] numEcBytesInBlock = new int[1];
/* 384 */       getNumDataBytesAndNumECBytesForBlockID(numTotalBytes, numDataBytes, numRSBlocks, i, numDataBytesInBlock, numEcBytesInBlock);
/*     */ 
/*     */ 
/*     */       
/* 388 */       int size = numDataBytesInBlock[0];
/* 389 */       byte[] dataBytes = new byte[size];
/* 390 */       bits.toBytes(8 * dataBytesOffset, dataBytes, 0, size);
/* 391 */       byte[] ecBytes = generateECBytes(dataBytes, numEcBytesInBlock[0]);
/* 392 */       blocks.add(new BlockPair(dataBytes, ecBytes));
/*     */       
/* 394 */       maxNumDataBytes = Math.max(maxNumDataBytes, size);
/* 395 */       maxNumEcBytes = Math.max(maxNumEcBytes, ecBytes.length);
/* 396 */       dataBytesOffset += numDataBytesInBlock[0];
/*     */     } 
/* 398 */     if (numDataBytes != dataBytesOffset) {
/* 399 */       throw new WriterException("Data bytes does not match offset");
/*     */     }
/*     */     
/* 402 */     BitArray result = new BitArray();
/*     */     
/*     */     int j;
/* 405 */     for (j = 0; j < maxNumDataBytes; j++) {
/* 406 */       for (BlockPair block : blocks) {
/* 407 */         byte[] dataBytes = block.getDataBytes();
/* 408 */         if (j < dataBytes.length) {
/* 409 */           result.appendBits(dataBytes[j], 8);
/*     */         }
/*     */       } 
/*     */     } 
/*     */     
/* 414 */     for (j = 0; j < maxNumEcBytes; j++) {
/* 415 */       for (BlockPair block : blocks) {
/* 416 */         byte[] ecBytes = block.getErrorCorrectionBytes();
/* 417 */         if (j < ecBytes.length) {
/* 418 */           result.appendBits(ecBytes[j], 8);
/*     */         }
/*     */       } 
/*     */     } 
/* 422 */     if (numTotalBytes != result.getSizeInBytes()) {
/* 423 */       throw new WriterException("Interleaving error: " + numTotalBytes + " and " + result.getSizeInBytes() + " differ.");
/*     */     }
/*     */ 
/*     */     
/* 427 */     return result;
/*     */   }
/*     */   
/*     */   static byte[] generateECBytes(byte[] dataBytes, int numEcBytesInBlock) {
/* 431 */     int numDataBytes = dataBytes.length;
/* 432 */     int[] toEncode = new int[numDataBytes + numEcBytesInBlock];
/* 433 */     for (int i = 0; i < numDataBytes; i++) {
/* 434 */       toEncode[i] = dataBytes[i] & 0xFF;
/*     */     }
/* 436 */     (new ReedSolomonEncoder(GenericGF.QR_CODE_FIELD_256)).encode(toEncode, numEcBytesInBlock);
/*     */     
/* 438 */     byte[] ecBytes = new byte[numEcBytesInBlock];
/* 439 */     for (int j = 0; j < numEcBytesInBlock; j++) {
/* 440 */       ecBytes[j] = (byte)toEncode[numDataBytes + j];
/*     */     }
/* 442 */     return ecBytes;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   static void appendModeInfo(Mode mode, BitArray bits) {
/* 449 */     bits.appendBits(mode.getBits(), 4);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   static void appendLengthInfo(int numLetters, Version version, Mode mode, BitArray bits) throws WriterException {
/* 457 */     int numBits = mode.getCharacterCountBits(version);
/* 458 */     if (numLetters >= 1 << numBits) {
/* 459 */       throw new WriterException(numLetters + " is bigger than " + ((1 << numBits) - 1));
/*     */     }
/* 461 */     bits.appendBits(numLetters, numBits);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   static void appendBytes(String content, Mode mode, BitArray bits, String encoding) throws WriterException {
/* 471 */     switch (mode) {
/*     */       case NUMERIC:
/* 473 */         appendNumericBytes(content, bits);
/*     */         return;
/*     */       case ALPHANUMERIC:
/* 476 */         appendAlphanumericBytes(content, bits);
/*     */         return;
/*     */       case BYTE:
/* 479 */         append8BitBytes(content, bits, encoding);
/*     */         return;
/*     */       case KANJI:
/* 482 */         appendKanjiBytes(content, bits);
/*     */         return;
/*     */     } 
/* 485 */     throw new WriterException("Invalid mode: " + mode);
/*     */   }
/*     */ 
/*     */   
/*     */   static void appendNumericBytes(CharSequence content, BitArray bits) {
/* 490 */     int length = content.length();
/* 491 */     int i = 0;
/* 492 */     while (i < length) {
/* 493 */       int num1 = content.charAt(i) - 48;
/* 494 */       if (i + 2 < length) {
/*     */         
/* 496 */         int num2 = content.charAt(i + 1) - 48;
/* 497 */         int num3 = content.charAt(i + 2) - 48;
/* 498 */         bits.appendBits(num1 * 100 + num2 * 10 + num3, 10);
/* 499 */         i += 3; continue;
/* 500 */       }  if (i + 1 < length) {
/*     */         
/* 502 */         int num2 = content.charAt(i + 1) - 48;
/* 503 */         bits.appendBits(num1 * 10 + num2, 7);
/* 504 */         i += 2;
/*     */         continue;
/*     */       } 
/* 507 */       bits.appendBits(num1, 4);
/* 508 */       i++;
/*     */     } 
/*     */   }
/*     */ 
/*     */   
/*     */   static void appendAlphanumericBytes(CharSequence content, BitArray bits) throws WriterException {
/* 514 */     int length = content.length();
/* 515 */     int i = 0;
/* 516 */     while (i < length) {
/* 517 */       int code1 = getAlphanumericCode(content.charAt(i));
/* 518 */       if (code1 == -1) {
/* 519 */         throw new WriterException();
/*     */       }
/* 521 */       if (i + 1 < length) {
/* 522 */         int code2 = getAlphanumericCode(content.charAt(i + 1));
/* 523 */         if (code2 == -1) {
/* 524 */           throw new WriterException();
/*     */         }
/*     */         
/* 527 */         bits.appendBits(code1 * 45 + code2, 11);
/* 528 */         i += 2;
/*     */         continue;
/*     */       } 
/* 531 */       bits.appendBits(code1, 6);
/* 532 */       i++;
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   static void append8BitBytes(String content, BitArray bits, String encoding) throws WriterException {
/*     */     byte[] bytes;
/*     */     try {
/* 541 */       bytes = content.getBytes(encoding);
/* 542 */     } catch (UnsupportedEncodingException uee) {
/* 543 */       throw new WriterException(uee);
/*     */     } 
/* 545 */     for (byte b : bytes) {
/* 546 */       bits.appendBits(b, 8);
/*     */     }
/*     */   }
/*     */   
/*     */   static void appendKanjiBytes(String content, BitArray bits) throws WriterException {
/*     */     byte[] bytes;
/*     */     try {
/* 553 */       bytes = content.getBytes("Shift_JIS");
/* 554 */     } catch (UnsupportedEncodingException uee) {
/* 555 */       throw new WriterException(uee);
/*     */     } 
/* 557 */     int length = bytes.length;
/* 558 */     for (int i = 0; i < length; i += 2) {
/* 559 */       int byte1 = bytes[i] & 0xFF;
/* 560 */       int byte2 = bytes[i + 1] & 0xFF;
/* 561 */       int code = byte1 << 8 | byte2;
/* 562 */       int subtracted = -1;
/* 563 */       if (code >= 33088 && code <= 40956) {
/* 564 */         subtracted = code - 33088;
/* 565 */       } else if (code >= 57408 && code <= 60351) {
/* 566 */         subtracted = code - 49472;
/*     */       } 
/* 568 */       if (subtracted == -1) {
/* 569 */         throw new WriterException("Invalid byte sequence");
/*     */       }
/* 571 */       int encoded = (subtracted >> 8) * 192 + (subtracted & 0xFF);
/* 572 */       bits.appendBits(encoded, 13);
/*     */     } 
/*     */   }
/*     */   
/*     */   private static void appendECI(CharacterSetECI eci, BitArray bits) {
/* 577 */     bits.appendBits(Mode.ECI.getBits(), 4);
/*     */     
/* 579 */     bits.appendBits(eci.getValue(), 8);
/*     */   }
/*     */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\com\google\zxing\qrcode\encoder\Encoder.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       1.1.3
 */