/*     */ package com.swtdesigner;
/*     */ 
/*     */ import java.io.BufferedInputStream;
/*     */ import java.io.FileInputStream;
/*     */ import java.io.InputStream;
/*     */ import java.util.HashMap;
/*     */ import java.util.Iterator;
/*     */ import org.eclipse.swt.graphics.Color;
/*     */ import org.eclipse.swt.graphics.Cursor;
/*     */ import org.eclipse.swt.graphics.Device;
/*     */ import org.eclipse.swt.graphics.Drawable;
/*     */ import org.eclipse.swt.graphics.Font;
/*     */ import org.eclipse.swt.graphics.FontData;
/*     */ import org.eclipse.swt.graphics.GC;
/*     */ import org.eclipse.swt.graphics.Image;
/*     */ import org.eclipse.swt.graphics.ImageData;
/*     */ import org.eclipse.swt.graphics.Point;
/*     */ import org.eclipse.swt.graphics.RGB;
/*     */ import org.eclipse.swt.graphics.Rectangle;
/*     */ import org.eclipse.swt.widgets.Canvas;
/*     */ import org.eclipse.swt.widgets.Composite;
/*     */ import org.eclipse.swt.widgets.Control;
/*     */ import org.eclipse.swt.widgets.CoolBar;
/*     */ import org.eclipse.swt.widgets.CoolItem;
/*     */ import org.eclipse.swt.widgets.Display;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class SWTResourceManager
/*     */ {
/*     */   public static void dispose() {
/*  49 */     disposeColors();
/*  50 */     disposeFonts();
/*  51 */     disposeImages();
/*  52 */     disposeCursors();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  62 */   private static HashMap<RGB, Color> m_ColorMap = new HashMap<RGB, Color>();
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static Color getColor(int systemColorID) {
/*  70 */     Display display = Display.getCurrent();
/*  71 */     return display.getSystemColor(systemColorID);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static Color getColor(int r, int g, int b) {
/*  82 */     return getColor(new RGB(r, g, b));
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static Color getColor(RGB rgb) {
/*  91 */     Color color = m_ColorMap.get(rgb);
/*  92 */     if (color == null) {
/*  93 */       Display display = Display.getCurrent();
/*  94 */       color = new Color((Device)display, rgb);
/*  95 */       m_ColorMap.put(rgb, color);
/*     */     } 
/*  97 */     return color;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static void disposeColors() {
/* 104 */     for (Iterator<Color> iter = m_ColorMap.values().iterator(); iter.hasNext();)
/* 105 */       ((Color)iter.next()).dispose(); 
/* 106 */     m_ColorMap.clear();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 116 */   private static HashMap<String, Image> m_ClassImageMap = new HashMap<String, Image>();
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 121 */   private static HashMap<Image, HashMap<Image, Image>> m_ImageToDecoratorMap = new HashMap<Image, HashMap<Image, Image>>();
/*     */   private static final int MISSING_IMAGE_SIZE = 10;
/*     */   public static final int TOP_LEFT = 1;
/*     */   public static final int TOP_RIGHT = 2;
/*     */   public static final int BOTTOM_LEFT = 3;
/*     */   public static final int BOTTOM_RIGHT = 4;
/*     */   
/*     */   protected static Image getImage(InputStream is) {
/* 129 */     Display display = Display.getCurrent();
/* 130 */     ImageData data = new ImageData(is);
/* 131 */     if (data.transparentPixel > 0)
/* 132 */       return new Image((Device)display, data, data.getTransparencyMask()); 
/* 133 */     return new Image((Device)display, data);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static Image getImage(String path) {
/* 142 */     return getImage("default", path);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static Image getImage(String section, String path) {
/* 152 */     String key = String.valueOf(section) + '|' + SWTResourceManager.class.getName() + '|' + path;
/* 153 */     Image image = m_ClassImageMap.get(key);
/* 154 */     if (image == null) {
/*     */       try {
/* 156 */         FileInputStream fis = new FileInputStream(path);
/* 157 */         image = getImage(fis);
/* 158 */         m_ClassImageMap.put(key, image);
/* 159 */         fis.close();
/* 160 */       } catch (Exception e) {
/* 161 */         image = getMissingImage();
/* 162 */         m_ClassImageMap.put(key, image);
/*     */       } 
/*     */     }
/* 165 */     return image;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static Image getImage(Class<?> clazz, String path) {
/* 175 */     String key = String.valueOf(clazz.getName()) + '|' + path;
/* 176 */     Image image = m_ClassImageMap.get(key);
/* 177 */     if (image == null) {
/*     */       try {
/* 179 */         if (path.length() > 0 && path.charAt(0) == '/') {
/* 180 */           String newPath = path.substring(1, path.length());
/* 181 */           image = getImage(new BufferedInputStream(clazz.getClassLoader().getResourceAsStream(newPath)));
/*     */         } else {
/* 183 */           image = getImage(clazz.getResourceAsStream(path));
/*     */         } 
/* 185 */         m_ClassImageMap.put(key, image);
/* 186 */       } catch (Exception e) {
/* 187 */         image = getMissingImage();
/* 188 */         m_ClassImageMap.put(key, image);
/*     */       } 
/*     */     }
/* 191 */     return image;
/*     */   }
/*     */ 
/*     */   
/*     */   private static Image getMissingImage() {
/* 196 */     Image image = new Image((Device)Display.getCurrent(), 10, 10);
/*     */     
/* 198 */     GC gc = new GC((Drawable)image);
/* 199 */     gc.setBackground(getColor(3));
/* 200 */     gc.fillRectangle(0, 0, 10, 10);
/* 201 */     gc.dispose();
/*     */     
/* 203 */     return image;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static Image decorateImage(Image baseImage, Image decorator) {
/* 230 */     return decorateImage(baseImage, decorator, 4);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static Image decorateImage(Image baseImage, Image decorator, int corner) {
/* 241 */     HashMap<Image, Image> decoratedMap = m_ImageToDecoratorMap.get(baseImage);
/* 242 */     if (decoratedMap == null) {
/* 243 */       decoratedMap = new HashMap<Image, Image>();
/* 244 */       m_ImageToDecoratorMap.put(baseImage, decoratedMap);
/*     */     } 
/* 246 */     Image result = decoratedMap.get(decorator);
/* 247 */     if (result == null) {
/* 248 */       Rectangle bid = baseImage.getBounds();
/* 249 */       Rectangle did = decorator.getBounds();
/* 250 */       result = new Image((Device)Display.getCurrent(), bid.width, bid.height);
/* 251 */       GC gc = new GC((Drawable)result);
/* 252 */       gc.drawImage(baseImage, 0, 0);
/*     */       
/* 254 */       if (corner == 1) {
/* 255 */         gc.drawImage(decorator, 0, 0);
/* 256 */       } else if (corner == 2) {
/* 257 */         gc.drawImage(decorator, bid.width - did.width - 1, 0);
/* 258 */       } else if (corner == 3) {
/* 259 */         gc.drawImage(decorator, 0, bid.height - did.height - 1);
/* 260 */       } else if (corner == 4) {
/* 261 */         gc.drawImage(decorator, bid.width - did.width - 1, bid.height - did.height - 1);
/*     */       } 
/*     */       
/* 264 */       gc.dispose();
/* 265 */       decoratedMap.put(decorator, result);
/*     */     } 
/* 267 */     return result;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static void disposeImages() {
/* 274 */     for (Iterator<Image> iterator = m_ClassImageMap.values().iterator(); iterator.hasNext();)
/* 275 */       ((Image)iterator.next()).dispose(); 
/* 276 */     m_ClassImageMap.clear();
/*     */     
/* 278 */     for (Iterator<HashMap<Image, Image>> I = m_ImageToDecoratorMap.values().iterator(); I.hasNext(); ) {
/* 279 */       HashMap<Image, Image> decoratedMap = I.next();
/* 280 */       for (Iterator<Image> J = decoratedMap.values().iterator(); J.hasNext(); ) {
/* 281 */         Image image = J.next();
/* 282 */         image.dispose();
/*     */       } 
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static void disposeImages(String section) {
/* 292 */     for (Iterator<String> I = m_ClassImageMap.keySet().iterator(); I.hasNext(); ) {
/* 293 */       String key = I.next();
/* 294 */       if (!key.startsWith(String.valueOf(section) + '|'))
/*     */         continue; 
/* 296 */       Image image = m_ClassImageMap.get(key);
/* 297 */       image.dispose();
/* 298 */       I.remove();
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 309 */   private static HashMap<String, Font> m_FontMap = new HashMap<String, Font>();
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 314 */   private static HashMap<Font, Font> m_FontToBoldFontMap = new HashMap<Font, Font>();
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static Font getFont(String name, int height, int style) {
/* 324 */     return getFont(name, height, style, false, false);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static Font getFont(String name, int size, int style, boolean strikeout, boolean underline) {
/* 339 */     String fontName = String.valueOf(name) + '|' + size + '|' + style + '|' + strikeout + '|' + underline;
/* 340 */     Font font = m_FontMap.get(fontName);
/* 341 */     if (font == null) {
/* 342 */       FontData fontData = new FontData(name, size, style);
/* 343 */       if (strikeout || underline) {
/*     */         try {
/* 345 */           Class<?> logFontClass = Class.forName("org.eclipse.swt.internal.win32.LOGFONT");
/* 346 */           Object logFont = FontData.class.getField("data").get(fontData);
/* 347 */           if (logFont != null && logFontClass != null) {
/* 348 */             if (strikeout) {
/* 349 */               logFontClass.getField("lfStrikeOut").set(logFont, new Byte((byte)1));
/*     */             }
/* 351 */             if (underline) {
/* 352 */               logFontClass.getField("lfUnderline").set(logFont, new Byte((byte)1));
/*     */             }
/*     */           } 
/* 355 */         } catch (Throwable e) {
/* 356 */           System.err.println(
/* 357 */               "Unable to set underline or strikeout (probably on a non-Windows platform). " + e);
/*     */         } 
/*     */       }
/* 360 */       font = new Font((Device)Display.getCurrent(), fontData);
/* 361 */       m_FontMap.put(fontName, font);
/*     */     } 
/* 363 */     return font;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static Font getBoldFont(Font baseFont) {
/* 373 */     Font font = m_FontToBoldFontMap.get(baseFont);
/* 374 */     if (font == null) {
/* 375 */       FontData[] fontDatas = baseFont.getFontData();
/* 376 */       FontData data = fontDatas[0];
/* 377 */       font = new Font((Device)Display.getCurrent(), data.getName(), data.getHeight(), 1);
/* 378 */       m_FontToBoldFontMap.put(baseFont, font);
/*     */     } 
/* 380 */     return font;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static void disposeFonts() {
/*     */     Iterator<Font> iter;
/* 388 */     for (iter = m_FontMap.values().iterator(); iter.hasNext();)
/* 389 */       ((Font)iter.next()).dispose(); 
/* 390 */     m_FontMap.clear();
/*     */     
/* 392 */     for (iter = m_FontToBoldFontMap.values().iterator(); iter.hasNext();)
/* 393 */       ((Font)iter.next()).dispose(); 
/* 394 */     m_FontToBoldFontMap.clear();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static void fixCoolBarSize(CoolBar bar) {
/* 406 */     CoolItem[] items = bar.getItems();
/*     */     int i;
/* 408 */     for (i = 0; i < items.length; i++) {
/* 409 */       CoolItem item = items[i];
/* 410 */       if (item.getControl() == null) {
/* 411 */         item.setControl((Control)new Canvas((Composite)bar, 0)
/*     */             {
/*     */               public Point computeSize(int wHint, int hHint, boolean changed) {
/* 414 */                 return new Point(20, 20);
/*     */               }
/*     */             });
/*     */       }
/*     */     } 
/* 419 */     for (i = 0; i < items.length; i++) {
/* 420 */       CoolItem item = items[i];
/* 421 */       Control control = item.getControl();
/* 422 */       control.pack();
/* 423 */       Point size = control.getSize();
/* 424 */       item.setSize(item.computeSize(size.x, size.y));
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 435 */   private static HashMap<Integer, Cursor> m_IdToCursorMap = new HashMap<Integer, Cursor>();
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static Cursor getCursor(int id) {
/* 443 */     Integer key = new Integer(id);
/* 444 */     Cursor cursor = m_IdToCursorMap.get(key);
/* 445 */     if (cursor == null) {
/* 446 */       cursor = new Cursor((Device)Display.getDefault(), id);
/* 447 */       m_IdToCursorMap.put(key, cursor);
/*     */     } 
/* 449 */     return cursor;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static void disposeCursors() {
/* 456 */     for (Iterator<Cursor> iter = m_IdToCursorMap.values().iterator(); iter.hasNext();)
/* 457 */       ((Cursor)iter.next()).dispose(); 
/* 458 */     m_IdToCursorMap.clear();
/*     */   }
/*     */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\com\swtdesigner\SWTResourceManager.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       1.1.3
 */