/*      */ package jpdf.printer;
/*      */ 
/*      */ import java.awt.Color;
/*      */ import java.awt.Dimension;
/*      */ import java.awt.Graphics;
/*      */ import java.awt.Graphics2D;
/*      */ import java.awt.Point;
/*      */ import java.awt.Rectangle;
/*      */ import java.awt.Shape;
/*      */ import java.awt.print.PageFormat;
/*      */ import java.util.ArrayList;
/*      */ import java.util.Date;
/*      */ import java.util.Iterator;
/*      */ import javax.print.attribute.AttributeSet;
/*      */ import javax.print.attribute.PrintRequestAttributeSet;
/*      */ import jpdf.ability.PrintTimeUpdateable;
/*      */ import jpdf.ability.Titled;
/*      */ import jpdf.attribute.AlignmentFactorHorizontal;
/*      */ import jpdf.attribute.AlignmentFactorVertical;
/*      */ import jpdf.attribute.ContentFrame;
/*      */ import jpdf.attribute.HeaderFooterDateFormat;
/*      */ import jpdf.attribute.HeaderFooterTimeFormat;
/*      */ import jpdf.attribute.PageContentFrame;
/*      */ import jpdf.diagnostics.JpdfNotEnoughPageSpaceException;
/*      */ import jpdf.manage.PrintJobAdministrator;
/*      */ import jpdf.manage.PrintManager;
/*      */ import jpdf.manage.PrintParameterHolder;
/*      */ import jpdf.printable.AttributeSetPrintable;
/*      */ import jpdf.printable.ValidatingPrintable;
/*      */ import jpdf.printer.observer.PrinterEvent;
/*      */ import jpdf.printer.observer.PrinterEventType;
/*      */ import jpdf.printer.observer.PrinterObserver;
/*      */ import jpdf.utility.PageDecorationUtility;
/*      */ import jpdf.wrap.graphics.NoDrawGraphics2DWrapper;
/*      */ import sun.print.ProxyGraphics2D;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ public abstract class AbstractPrinter
/*      */   implements PrintTimeUpdateable, Titled, AttributeSetPrintable, ValidatingPrintable
/*      */ {
/*      */   public static final boolean RUNNING_VM_1_4 = false;
/*      */   public static final int UNKNOWN_PAGE_COUNT = -1;
/*      */   public static final String NAME_MARKER = "[-N-]";
/*      */   
/*      */   public static class PrintWithImageOptions
/*      */   {
/*      */     public static final int LOW_RES = 1;
/*      */     public static final int HIGH_RES = 2;
/*      */     public static final int VERY_HIGH_RES = 3;
/*      */     private final int a;
/*      */     
/*      */     public PrintWithImageOptions(int param1Int) {
/*      */       String str;
/*      */       int i;
/*  133 */       if ((i = param1Int) != 1 && i != 2 && i != 3) { str = "Invalid Image Resolution Code: " + i; throw new IllegalArgumentException(str); }
/*      */       
/*  135 */       this.a = str;
/*      */     }
/*      */ 
/*      */     
/*      */     public int getImageResolutionCode() {
/*  140 */       return this.a;
/*      */     }
/*      */ 
/*      */ 
/*      */     
/*      */     public float getImageScaleFactor() {
/*  146 */       return getImageResolutionCode();
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private static boolean a = false;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected final PrintParameterHolder PRINT_PARAM_HOLDER;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  207 */   protected final PageDecorationUtility.DecorationOptions DECORATION_OPTIONS = new PageDecorationUtility.DecorationOptions();
/*      */ 
/*      */   
/*  210 */   private final ArrayList b = new ArrayList(4);
/*      */   
/*  212 */   private PrintRequestAttributeSet c = null;
/*  213 */   private PrintWithImageOptions d = null;
/*  214 */   private PrintCustomizer e = null;
/*      */   private boolean f = false;
/*      */   private boolean g = false;
/*      */   private boolean h = true;
/*  218 */   private int i = 0;
/*  219 */   private int j = -1;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public AbstractPrinter(String paramString) {
/*  232 */     this(paramString, PrintManager.getDefaultPrintAttributes());
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public AbstractPrinter(String paramString, AttributeSet paramAttributeSet) {
/*  245 */     this.PRINT_PARAM_HOLDER = createPrintParameterHolder();
/*      */ 
/*      */ 
/*      */     
/*  249 */     if (paramAttributeSet != null)
/*      */     {
/*  251 */       if (!(paramAttributeSet instanceof PrintRequestAttributeSet)) {
/*      */         
/*  253 */         paramString = "The Attribute Set must be an instance of javax.print.attribute.PrintRequestAttributeSet.";
/*      */         
/*  255 */         throw new IllegalArgumentException(paramString);
/*      */       } 
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  263 */     this.PRINT_PARAM_HOLDER.date = new Date();
/*  264 */     this.PRINT_PARAM_HOLDER.title = (paramString == null) ? "" : paramString;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  269 */     if (paramAttributeSet != null)
/*      */     {
/*  271 */       setAttributeSet((PrintRequestAttributeSet)paramAttributeSet);
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void addObserver(PrinterObserver paramPrinterObserver) {
/*  288 */     if (paramPrinterObserver == null)
/*  289 */       return;  if (this.b.contains(paramPrinterObserver))
/*      */       return; 
/*  291 */     this.b.add(paramPrinterObserver);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void broadcastEventToObservers(PrinterEventType paramPrinterEventType, Graphics2D paramGraphics2D, PageFormat paramPageFormat, int paramInt, float paramFloat) {
/*  307 */     if (this.b.size() == 0) {
/*      */       return;
/*      */     }
/*      */ 
/*      */ 
/*      */     
/*  313 */     PrinterEvent printerEvent = new PrinterEvent(paramPrinterEventType, this, paramGraphics2D, paramPageFormat, paramInt, paramFloat);
/*      */ 
/*      */ 
/*      */     
/*  317 */     for (Iterator<PrinterObserver> iterator = this.b.iterator(); iterator.hasNext();)
/*      */     {
/*  319 */       (printerObserver = iterator.next()).printerEventOccurred(printerEvent);
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public static void drawPoint(Graphics2D paramGraphics2D, Point paramPoint) {
/*  329 */     paramGraphics2D.fillRect(paramPoint.x - 2, paramPoint.y - 2, 5, 5);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public static void drawShapes(Graphics2D paramGraphics2D, Shape[] paramArrayOfShape) {
/*  338 */     if (paramArrayOfShape == null)
/*      */       return; 
/*  340 */     for (byte b = 0; b < paramArrayOfShape.length; b++) {
/*      */       
/*  342 */       if (paramArrayOfShape[b] != null) paramGraphics2D.draw(paramArrayOfShape[b]);
/*      */     
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public PrintRequestAttributeSet getAttributeSet() {
/*  352 */     return this.c;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public int getDisplayPageCount() {
/*  364 */     if (this.j == -1) return getPageCount();
/*      */     
/*  366 */     return this.j;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public int getDisplayPageNumberOffset() {
/*  380 */     return this.i;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public int getPageCount() {
/*  390 */     return -1;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public PrintCustomizer getPrintCustomizer() {
/*  399 */     return this.e;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public PrintWithImageOptions getPrintWithImageOptions() {
/*  409 */     return this.d;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public String getTitle() {
/*  418 */     return this.PRINT_PARAM_HOLDER.title;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public static boolean isToDebugPrinting() {
/*  429 */     return a;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public boolean isToPrintWithImage() {
/*  443 */     return (getPrintWithImageOptions() != null);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void removeObserver(PrinterObserver paramPrinterObserver) {
/*  454 */     this.b.remove(paramPrinterObserver);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public static String replaceNameMarker(String paramString1, String paramString2) {
/*  464 */     return PrintParameterHolder.replaceAll(paramString1, "[-N-]", paramString2);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void setAttributeSet(PrintRequestAttributeSet paramPrintRequestAttributeSet) {
/*  473 */     this.c = paramPrintRequestAttributeSet;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void setDisplayPageCount(int paramInt) {
/*  485 */     this.j = paramInt;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void setDisplayPageNumberOffset(int paramInt) {
/*  499 */     this.i = paramInt;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void setMinimumOffsets(int paramInt) {
/*  516 */     this.DECORATION_OPTIONS.minimumOffsets.top = paramInt;
/*  517 */     this.DECORATION_OPTIONS.minimumOffsets.left = paramInt;
/*  518 */     this.DECORATION_OPTIONS.minimumOffsets.bottom = paramInt;
/*  519 */     this.DECORATION_OPTIONS.minimumOffsets.right = paramInt;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void setMinimumOffsets(int paramInt1, int paramInt2, int paramInt3, int paramInt4) {
/*  537 */     this.DECORATION_OPTIONS.minimumOffsets.top = paramInt1;
/*  538 */     this.DECORATION_OPTIONS.minimumOffsets.left = paramInt2;
/*  539 */     this.DECORATION_OPTIONS.minimumOffsets.bottom = paramInt3;
/*  540 */     this.DECORATION_OPTIONS.minimumOffsets.right = paramInt4;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void setPrintCustomizer(PrintCustomizer paramPrintCustomizer) {
/*  549 */     this.e = paramPrintCustomizer;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public static void setToDebugPrinting(boolean paramBoolean) {
/*  564 */     a = paramBoolean;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void setToPrintWithImage(int paramInt) {
/*  581 */     setToPrintWithImage(new PrintWithImageOptions(paramInt));
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void setToPrintWithImage(PrintWithImageOptions paramPrintWithImageOptions) {
/*  604 */     this.d = paramPrintWithImageOptions;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public static void undoShiftAndScale(int paramInt1, int paramInt2, float paramFloat, Rectangle paramRectangle) {
/*  615 */     paramRectangle.x -= paramInt1;
/*  616 */     paramRectangle.y -= paramInt2;
/*  617 */     if (paramFloat != 1.0F) {
/*      */       
/*  619 */       paramRectangle.x = (int)(paramRectangle.x / paramFloat);
/*  620 */       paramRectangle.y = (int)(paramRectangle.y / paramFloat);
/*  621 */       paramRectangle.width = (int)(paramRectangle.width / paramFloat);
/*  622 */       paramRectangle.height = (int)(paramRectangle.height / paramFloat);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void updatePrintTime() {
/*  632 */     this.PRINT_PARAM_HOLDER.date = new Date();
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void updatePrintTime(Date paramDate) {
/*  641 */     this.PRINT_PARAM_HOLDER.date = paramDate;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void validate(PageFormat paramPageFormat) {
/*  652 */     byte b = 100;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  657 */     if (paramPageFormat.getWidth() < 200.0D || paramPageFormat.getHeight() < 200.0D)
/*      */     {
/*  659 */       b = 32;
/*      */     }
/*      */ 
/*      */ 
/*      */     
/*  664 */     if (paramPageFormat.getImageableWidth() < b || paramPageFormat.getImageableHeight() < b)
/*      */     {
/*      */       
/*  667 */       throw new JpdfNotEnoughPageSpaceException();
/*      */     }
/*      */ 
/*      */     
/*  671 */     this.PRINT_PARAM_HOLDER.pageNo = 1;
/*      */     
/*      */     Dimension dimension;
/*  674 */     if ((dimension = PageDecorationUtility.computeAvailablePageSpace(paramPageFormat, getAttributeSet(), this.DECORATION_OPTIONS, this.PRINT_PARAM_HOLDER)).width < b || dimension.height < b)
/*      */     {
/*  676 */       throw new JpdfNotEnoughPageSpaceException();
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected static Point computeAlignedContentStartPoint(Graphics2D paramGraphics2D, int paramInt1, int paramInt2, AttributeSet paramAttributeSet, float paramFloat) {
/*  703 */     Point point = new Point();
/*      */     
/*  705 */     Rectangle rectangle = paramGraphics2D.getClipBounds();
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     float f2;
/*      */ 
/*      */ 
/*      */     
/*  714 */     if ((f2 = AlignmentFactorHorizontal.getAlignmentFactor(paramAttributeSet)) > 0.0F) {
/*      */       
/*  716 */       point.x = rectangle.x + (int)((rectangle.width - paramInt1) * f2);
/*      */ 
/*      */ 
/*      */     
/*      */     }
/*  721 */     else if (paramFloat >= 1.0F) {
/*      */       
/*  723 */       point.x = rectangle.x + 3;
/*      */     }
/*      */     else {
/*      */       
/*  727 */       point.x = rectangle.x + (int)(3.0F / paramFloat);
/*      */     } 
/*      */ 
/*      */     
/*      */     float f1;
/*      */     
/*  733 */     if ((f1 = AlignmentFactorVertical.getAlignmentFactor(paramAttributeSet)) > 0.0F) {
/*      */       
/*  735 */       point.y = rectangle.y + (int)((rectangle.height - paramInt2) * f1);
/*      */ 
/*      */ 
/*      */     
/*      */     }
/*  740 */     else if (paramFloat >= 1.0F) {
/*      */       
/*  742 */       point.y = rectangle.y + 3;
/*      */     }
/*      */     else {
/*      */       
/*  746 */       point.y = rectangle.y + (int)(3.0F / paramFloat);
/*      */     } 
/*      */ 
/*      */     
/*  750 */     return point;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected int computeTotalAvailableHeight(PageFormat paramPageFormat, AttributeSet paramAttributeSet, int paramInt1, int paramInt2) {
/*  764 */     int i = 0;
/*  765 */     int j = getDisplayPageNumberOffset();
/*      */     
/*  767 */     paramInt1 += j;
/*  768 */     paramInt2 += j;
/*  769 */     for (paramInt1 = paramInt1; paramInt1 <= paramInt2; paramInt1++) {
/*      */       
/*  771 */       this.PRINT_PARAM_HOLDER.pageNo = paramInt1;
/*  772 */       i += PageDecorationUtility.computeAvailablePageHeight(paramPageFormat, paramAttributeSet, this.DECORATION_OPTIONS, this.PRINT_PARAM_HOLDER);
/*      */     } 
/*      */ 
/*      */ 
/*      */     
/*  777 */     return i;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected PrintParameterHolder createPrintParameterHolder() {
/*  787 */     return new PrintParameterHolder();
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void drawContentFrame(Graphics2D paramGraphics2D, Color paramColor, int paramInt1, int paramInt2, int paramInt3, int paramInt4) {
/*      */     Rectangle rectangle;
/*  802 */     (rectangle = paramGraphics2D.getClipBounds()).x--;
/*  803 */     rectangle.y--;
/*  804 */     rectangle.width += 2;
/*  805 */     rectangle.height += 2;
/*  806 */     paramGraphics2D.setClip(rectangle);
/*      */ 
/*      */     
/*  809 */     paramGraphics2D.setColor(paramColor);
/*  810 */     paramGraphics2D.drawRect(paramInt1, paramInt2, paramInt3, paramInt4);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected boolean isToPrintContentFrame() {
/*  820 */     return this.f;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected boolean isToPrintPageContentFrame() {
/*  830 */     return this.g;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected boolean isToPrintPageDecorations() {
/*  845 */     return this.h;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected static boolean isTransparentImageGraphics(Graphics paramGraphics) {
/*  857 */     return (paramGraphics.getClass() == ProxyGraphics2D.class);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void prepareForPrinting(PageFormat paramPageFormat, AttributeSet paramAttributeSet) {
/*  870 */     setToPrintContentFrame(ContentFrame.isToPrintFrame(paramAttributeSet));
/*  871 */     setToPrintPageContentFrame(PageContentFrame.isToPrintFrame(paramAttributeSet));
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  876 */     this.PRINT_PARAM_HOLDER.setDateStyle(HeaderFooterDateFormat.getDateStyle(paramAttributeSet));
/*  877 */     this.PRINT_PARAM_HOLDER.setTimeStyle(HeaderFooterTimeFormat.getTimeStyle(paramAttributeSet));
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void printPageDecorations(Graphics2D paramGraphics2D, PageFormat paramPageFormat, int paramInt1, int paramInt2, float paramFloat) {
/*      */     PrintRequestAttributeSet printRequestAttributeSet;
/*  894 */     if ((printRequestAttributeSet = getAttributeSet()) != null) {
/*      */       NoDrawGraphics2DWrapper noDrawGraphics2DWrapper;
/*      */       
/*  897 */       this.PRINT_PARAM_HOLDER.pageNo = paramInt1 + 1 + getDisplayPageNumberOffset();
/*  898 */       this.PRINT_PARAM_HOLDER.pageCount = paramInt2;
/*  899 */       this.PRINT_PARAM_HOLDER.scaleFactor = paramFloat;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*  905 */       if (!isToPrintPageDecorations()) noDrawGraphics2DWrapper = new NoDrawGraphics2DWrapper(paramGraphics2D);
/*      */ 
/*      */       
/*  908 */       PageDecorationUtility.printStandardPageDecorations(this, (Graphics2D)noDrawGraphics2DWrapper, paramPageFormat, this.DECORATION_OPTIONS, this.PRINT_PARAM_HOLDER, true);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void setToPrintContentFrame(boolean paramBoolean) {
/*  921 */     this.f = paramBoolean;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void setToPrintPageContentFrame(boolean paramBoolean) {
/*  931 */     this.g = paramBoolean;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void setToPrintPageDecorations(boolean paramBoolean) {
/*  946 */     this.h = paramBoolean;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void updatePrintJobStatus(String paramString) {
/*  961 */     PrintJobAdministrator.updatePrintJobStatus(paramString);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   static int[] a(int[] paramArrayOfint, int paramInt) {
/*  993 */     int[] arrayOfInt = new int[paramArrayOfint.length + paramInt];
/*      */ 
/*      */     
/*  996 */     for (byte b = 0; b < paramArrayOfint.length; b++)
/*      */     {
/*  998 */       arrayOfInt[b] = paramArrayOfint[b];
/*      */     }
/*      */     
/* 1001 */     return arrayOfInt;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   static int[] a(int[] paramArrayOfint, int paramInt1, int paramInt2) {
/* 1056 */     float f = paramInt1 / paramInt2;
/*      */     
/* 1058 */     f = f; paramArrayOfint = paramArrayOfint; if (f > 2.0F) { f = 2.0F; } else if (f < 1.2F) { f = 1.2F; }  int i; if ((i = (int)(paramArrayOfint.length * f)) - paramArrayOfint.length < 4) i = paramArrayOfint.length + 4;  int[] arrayOfInt; for (arrayOfInt = new int[i], paramInt2 = 0; paramInt2 < paramArrayOfint.length; ) { arrayOfInt[paramInt2] = paramArrayOfint[paramInt2]; paramInt2++; }  return arrayOfInt;
/*      */   }
/*      */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\lib\jpdf_demo.jar!\jpdf\printer\AbstractPrinter.class
 * Java compiler version: 5 (49.0)
 * JD-Core Version:       1.1.3
 */