/*     */ package jxl.biff;
/*     */ 
/*     */ import jxl.format.Colour;
/*     */ import jxl.read.biff.Record;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class PaletteRecord
/*     */   extends WritableRecordData
/*     */ {
/*     */   private static class RGB
/*     */   {
/*     */     int red;
/*     */     int green;
/*     */     int blue;
/*     */     
/*     */     RGB(int r, int g, int b) {
/*  59 */       this.red = r;
/*  60 */       this.green = g;
/*  61 */       this.blue = b;
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  68 */   private RGB[] rgbColours = new RGB[56];
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private boolean dirty;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private boolean read;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private boolean initialized;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static final int numColours = 56;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public PaletteRecord(Record t) {
/*  98 */     super(t);
/*     */     
/* 100 */     this.initialized = false;
/* 101 */     this.dirty = false;
/* 102 */     this.read = true;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public PaletteRecord() {
/* 110 */     super(Type.PALETTE);
/*     */     
/* 112 */     this.initialized = true;
/* 113 */     this.dirty = false;
/* 114 */     this.read = false;
/*     */ 
/*     */     
/* 117 */     Colour[] colours = Colour.getAllColours();
/*     */     
/* 119 */     for (int i = 0; i < colours.length; i++) {
/*     */       
/* 121 */       Colour c = colours[i];
/* 122 */       setColourRGB(c, c.getDefaultRed(), c.getDefaultGreen(), c.getDefaultBlue());
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public byte[] getData() {
/* 137 */     if (this.read && !this.dirty)
/*     */     {
/* 139 */       return getRecord().getData();
/*     */     }
/*     */     
/* 142 */     byte[] data = new byte[226];
/* 143 */     int pos = 0;
/*     */ 
/*     */     
/* 146 */     IntegerHelper.getTwoBytes(56, data, pos);
/*     */ 
/*     */     
/* 149 */     for (int i = 0; i < 56; i++) {
/*     */       
/* 151 */       pos = i * 4 + 2;
/* 152 */       data[pos] = (byte)(this.rgbColours[i]).red;
/* 153 */       data[pos + 1] = (byte)(this.rgbColours[i]).green;
/* 154 */       data[pos + 2] = (byte)(this.rgbColours[i]).blue;
/*     */     } 
/*     */     
/* 157 */     return data;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private void initialize() {
/* 165 */     byte[] data = getRecord().getData();
/*     */     
/* 167 */     int numrecords = IntegerHelper.getInt(data[0], data[1]);
/*     */     
/* 169 */     for (int i = 0; i < numrecords; i++) {
/*     */       
/* 171 */       int pos = i * 4 + 2;
/* 172 */       int red = IntegerHelper.getInt(data[pos], (byte)0);
/* 173 */       int green = IntegerHelper.getInt(data[pos + 1], (byte)0);
/* 174 */       int blue = IntegerHelper.getInt(data[pos + 2], (byte)0);
/* 175 */       this.rgbColours[i] = new RGB(red, green, blue);
/*     */     } 
/*     */     
/* 178 */     this.initialized = true;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public boolean isDirty() {
/* 189 */     return this.dirty;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void setColourRGB(Colour c, int r, int g, int b) {
/* 203 */     int pos = c.getValue() - 8;
/* 204 */     if (pos < 0 || pos >= 56) {
/*     */       return;
/*     */     }
/*     */ 
/*     */     
/* 209 */     if (!this.initialized)
/*     */     {
/* 211 */       initialize();
/*     */     }
/*     */ 
/*     */     
/* 215 */     r = setValueRange(r, 0, 255);
/* 216 */     g = setValueRange(g, 0, 255);
/* 217 */     b = setValueRange(b, 0, 255);
/*     */     
/* 219 */     this.rgbColours[pos] = new RGB(r, g, b);
/*     */ 
/*     */     
/* 222 */     this.dirty = true;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private int setValueRange(int val, int min, int max) {
/* 235 */     val = Math.max(val, min);
/* 236 */     val = Math.min(val, max);
/* 237 */     return val;
/*     */   }
/*     */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\lib\jxl.jar!\jxl\biff\PaletteRecord.class
 * Java compiler version: 2 (46.0)
 * JD-Core Version:       1.1.3
 */