/*     */ package jxl.write.biff;
/*     */ 
/*     */ import common.Assert;
/*     */ import common.Logger;
/*     */ import java.io.IOException;
/*     */ import java.util.ArrayList;
/*     */ import java.util.Iterator;
/*     */ import java.util.TreeSet;
/*     */ import jxl.Cell;
/*     */ import jxl.Range;
/*     */ import jxl.SheetSettings;
/*     */ import jxl.WorkbookSettings;
/*     */ import jxl.biff.ByteData;
/*     */ import jxl.biff.WorkspaceInformationRecord;
/*     */ import jxl.biff.XFRecord;
/*     */ import jxl.biff.drawing.Chart;
/*     */ import jxl.biff.drawing.SheetDrawingWriter;
/*     */ import jxl.format.Border;
/*     */ import jxl.format.BorderLineStyle;
/*     */ import jxl.format.CellFormat;
/*     */ import jxl.write.Blank;
/*     */ import jxl.write.WritableCell;
/*     */ import jxl.write.WritableHyperlink;
/*     */ import jxl.write.WritableWorkbook;
/*     */ import jxl.write.WriteException;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ final class SheetWriter
/*     */ {
/*  58 */   private static Logger logger = Logger.getLogger(SheetWriter.class);
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private File outputFile;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private RowRecord[] rows;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private int numRows;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private int numCols;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private HeaderRecord header;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private FooterRecord footer;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private SheetSettings settings;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private WorkbookSettings workbookSettings;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private ArrayList rowBreaks;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private ArrayList hyperlinks;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private MergedCells mergedCells;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private PLSRecord plsRecord;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private WorkspaceInformationRecord workspaceOptions;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private TreeSet columnFormats;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private SheetDrawingWriter drawingWriter;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private boolean chartOnly;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private WritableSheetImpl sheet;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SheetWriter(File of, WritableSheetImpl wsi, WorkbookSettings ws) {
/* 151 */     this.outputFile = of;
/* 152 */     this.sheet = wsi;
/* 153 */     this.workspaceOptions = new WorkspaceInformationRecord();
/* 154 */     this.workbookSettings = ws;
/* 155 */     this.chartOnly = false;
/* 156 */     this.drawingWriter = new SheetDrawingWriter(ws);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void write() throws IOException {
/* 169 */     Assert.verify((this.rows != null));
/*     */ 
/*     */     
/* 172 */     if (this.chartOnly) {
/*     */       
/* 174 */       this.drawingWriter.write(this.outputFile);
/*     */       
/*     */       return;
/*     */     } 
/* 178 */     int bofpos = this.outputFile.getPos();
/*     */     
/* 180 */     BOFRecord bof = new BOFRecord(BOFRecord.sheet);
/* 181 */     this.outputFile.write((ByteData)bof);
/*     */ 
/*     */     
/* 184 */     int numBlocks = this.numRows / 32;
/* 185 */     if (this.numRows - numBlocks * 32 != 0)
/*     */     {
/* 187 */       numBlocks++;
/*     */     }
/*     */     
/* 190 */     int indexPos = this.outputFile.getPos();
/*     */ 
/*     */ 
/*     */     
/* 194 */     IndexRecord indexRecord = new IndexRecord(0, this.numRows, numBlocks);
/* 195 */     this.outputFile.write((ByteData)indexRecord);
/*     */     
/* 197 */     CalcModeRecord cmr = new CalcModeRecord(CalcModeRecord.automatic);
/* 198 */     this.outputFile.write((ByteData)cmr);
/*     */     
/* 200 */     CalcCountRecord ccr = new CalcCountRecord(100);
/* 201 */     this.outputFile.write((ByteData)ccr);
/*     */     
/* 203 */     RefModeRecord rmr = new RefModeRecord();
/* 204 */     this.outputFile.write((ByteData)rmr);
/*     */     
/* 206 */     IterationRecord itr = new IterationRecord(false);
/* 207 */     this.outputFile.write((ByteData)itr);
/*     */     
/* 209 */     DeltaRecord dtr = new DeltaRecord(0.001D);
/* 210 */     this.outputFile.write((ByteData)dtr);
/*     */     
/* 212 */     SaveRecalcRecord srr = new SaveRecalcRecord(true);
/* 213 */     this.outputFile.write((ByteData)srr);
/*     */     
/* 215 */     PrintHeadersRecord phr = new PrintHeadersRecord(this.settings.getPrintHeaders());
/*     */     
/* 217 */     this.outputFile.write((ByteData)phr);
/*     */     
/* 219 */     PrintGridLinesRecord pglr = new PrintGridLinesRecord(this.settings.getPrintGridLines());
/*     */     
/* 221 */     this.outputFile.write((ByteData)pglr);
/*     */     
/* 223 */     GridSetRecord gsr = new GridSetRecord(true);
/* 224 */     this.outputFile.write((ByteData)gsr);
/*     */     
/* 226 */     GuttersRecord gutr = new GuttersRecord();
/* 227 */     this.outputFile.write((ByteData)gutr);
/*     */     
/* 229 */     DefaultRowHeightRecord drhr = new DefaultRowHeightRecord(this.settings.getDefaultRowHeight());
/*     */     
/* 231 */     this.outputFile.write((ByteData)drhr);
/*     */     
/* 233 */     this.workspaceOptions.setFitToPages(this.settings.getFitToPages());
/* 234 */     this.outputFile.write((ByteData)this.workspaceOptions);
/*     */     
/* 236 */     if (this.rowBreaks.size() > 0) {
/*     */       
/* 238 */       int[] rb = new int[this.rowBreaks.size()];
/*     */       
/* 240 */       for (int i = 0; i < rb.length; i++)
/*     */       {
/* 242 */         rb[i] = ((Integer)this.rowBreaks.get(i)).intValue();
/*     */       }
/*     */       
/* 245 */       HorizontalPageBreaksRecord hpbr = new HorizontalPageBreaksRecord(rb);
/* 246 */       this.outputFile.write((ByteData)hpbr);
/*     */     } 
/*     */     
/* 249 */     if (this.header == null)
/*     */     {
/* 251 */       this.header = new HeaderRecord(null, null, null);
/*     */     }
/*     */     
/* 254 */     if (this.footer == null)
/*     */     {
/* 256 */       this.footer = new FooterRecord(null, null, null);
/*     */     }
/*     */     
/* 259 */     this.outputFile.write((ByteData)this.header);
/* 260 */     this.outputFile.write((ByteData)this.footer);
/*     */     
/* 262 */     HorizontalCentreRecord hcr = new HorizontalCentreRecord(false);
/* 263 */     this.outputFile.write((ByteData)hcr);
/*     */     
/* 265 */     VerticalCentreRecord vcr = new VerticalCentreRecord(false);
/* 266 */     this.outputFile.write((ByteData)vcr);
/*     */ 
/*     */     
/* 269 */     if (this.settings.getLeftMargin() != this.settings.getDefaultWidthMargin()) {
/*     */       
/* 271 */       MarginRecord mr = new LeftMarginRecord(this.settings.getLeftMargin());
/* 272 */       this.outputFile.write((ByteData)mr);
/*     */     } 
/*     */     
/* 275 */     if (this.settings.getRightMargin() != this.settings.getDefaultWidthMargin()) {
/*     */       
/* 277 */       MarginRecord mr = new RightMarginRecord(this.settings.getRightMargin());
/* 278 */       this.outputFile.write((ByteData)mr);
/*     */     } 
/*     */     
/* 281 */     if (this.settings.getTopMargin() != this.settings.getDefaultHeightMargin()) {
/*     */       
/* 283 */       MarginRecord mr = new TopMarginRecord(this.settings.getTopMargin());
/* 284 */       this.outputFile.write((ByteData)mr);
/*     */     } 
/*     */     
/* 287 */     if (this.settings.getBottomMargin() != this.settings.getDefaultHeightMargin()) {
/*     */       
/* 289 */       MarginRecord mr = new BottomMarginRecord(this.settings.getBottomMargin());
/* 290 */       this.outputFile.write((ByteData)mr);
/*     */     } 
/*     */     
/* 293 */     if (this.plsRecord != null)
/*     */     {
/* 295 */       this.outputFile.write((ByteData)this.plsRecord);
/*     */     }
/*     */     
/* 298 */     SetupRecord setup = new SetupRecord(this.settings);
/* 299 */     this.outputFile.write((ByteData)setup);
/*     */     
/* 301 */     if (this.settings.isProtected()) {
/*     */       
/* 303 */       ProtectRecord pr = new ProtectRecord(this.settings.isProtected());
/* 304 */       this.outputFile.write((ByteData)pr);
/*     */       
/* 306 */       ScenarioProtectRecord spr = new ScenarioProtectRecord(this.settings.isProtected());
/*     */       
/* 308 */       this.outputFile.write((ByteData)spr);
/*     */       
/* 310 */       ObjectProtectRecord opr = new ObjectProtectRecord(this.settings.isProtected());
/*     */       
/* 312 */       this.outputFile.write((ByteData)opr);
/*     */       
/* 314 */       if (this.settings.getPassword() != null) {
/*     */         
/* 316 */         PasswordRecord pw = new PasswordRecord(this.settings.getPassword());
/* 317 */         this.outputFile.write((ByteData)pw);
/*     */       }
/* 319 */       else if (this.settings.getPasswordHash() != 0) {
/*     */         
/* 321 */         PasswordRecord pw = new PasswordRecord(this.settings.getPasswordHash());
/* 322 */         this.outputFile.write((ByteData)pw);
/*     */       } 
/*     */     } 
/*     */     
/* 326 */     indexRecord.setDataStartPosition(this.outputFile.getPos());
/* 327 */     DefaultColumnWidth dcw = new DefaultColumnWidth(this.settings.getDefaultColumnWidth());
/*     */     
/* 329 */     this.outputFile.write((ByteData)dcw);
/*     */ 
/*     */     
/* 332 */     ColumnInfoRecord cir = null;
/* 333 */     int tmpi = 0;
/* 334 */     for (Iterator colit = this.columnFormats.iterator(); colit.hasNext(); ) {
/*     */       
/* 336 */       cir = colit.next();
/*     */ 
/*     */       
/* 339 */       if (cir.getColumn() < 256)
/*     */       {
/* 341 */         this.outputFile.write((ByteData)cir);
/*     */       }
/*     */       
/* 344 */       XFRecord xfr = cir.getCellFormat();
/*     */       
/* 346 */       if (xfr != WritableWorkbook.NORMAL_STYLE && cir.getColumn() < 256) {
/*     */ 
/*     */         
/* 349 */         Cell[] cells = getColumn(cir.getColumn());
/*     */         
/* 351 */         for (int i = 0; i < cells.length; i++) {
/*     */           
/* 353 */           if (cells[i] != null && (cells[i].getCellFormat() == WritableWorkbook.NORMAL_STYLE || cells[i].getCellFormat() == DateRecord.defaultDateFormat))
/*     */           {
/*     */ 
/*     */ 
/*     */ 
/*     */             
/* 359 */             ((WritableCell)cells[i]).setCellFormat((CellFormat)xfr);
/*     */           }
/*     */         } 
/*     */       } 
/*     */     } 
/*     */ 
/*     */     
/* 366 */     Iterator hi = this.hyperlinks.iterator();
/* 367 */     WritableHyperlink hlr = null;
/* 368 */     while (hi.hasNext()) {
/*     */       
/* 370 */       hlr = hi.next();
/* 371 */       this.outputFile.write((ByteData)hlr);
/*     */     } 
/*     */     
/* 374 */     DimensionRecord dr = new DimensionRecord(this.numRows, this.numCols);
/* 375 */     this.outputFile.write((ByteData)dr);
/*     */ 
/*     */     
/* 378 */     for (int block = 0; block < numBlocks; block++) {
/*     */       
/* 380 */       DBCellRecord dbcell = new DBCellRecord(this.outputFile.getPos());
/*     */       
/* 382 */       int blockRows = Math.min(32, this.numRows - block * 32);
/* 383 */       boolean firstRow = true;
/*     */       
/*     */       int i;
/* 386 */       for (i = block * 32; i < block * 32 + blockRows; i++) {
/*     */         
/* 388 */         if (this.rows[i] != null) {
/*     */           
/* 390 */           this.rows[i].write(this.outputFile);
/* 391 */           if (firstRow) {
/*     */             
/* 393 */             dbcell.setCellOffset(this.outputFile.getPos());
/* 394 */             firstRow = false;
/*     */           } 
/*     */         } 
/*     */       } 
/*     */ 
/*     */       
/* 400 */       for (i = block * 32; i < block * 32 + blockRows; i++) {
/*     */         
/* 402 */         if (this.rows[i] != null) {
/*     */           
/* 404 */           dbcell.addCellRowPosition(this.outputFile.getPos());
/* 405 */           this.rows[i].writeCells(this.outputFile);
/*     */         } 
/*     */       } 
/*     */ 
/*     */       
/* 410 */       indexRecord.addBlockPosition(this.outputFile.getPos());
/*     */ 
/*     */ 
/*     */       
/* 414 */       dbcell.setPosition(this.outputFile.getPos());
/* 415 */       this.outputFile.write((ByteData)dbcell);
/*     */     } 
/*     */ 
/*     */     
/* 419 */     if (!this.workbookSettings.getDrawingsDisabled())
/*     */     {
/* 421 */       this.drawingWriter.write(this.outputFile);
/*     */     }
/*     */     
/* 424 */     Window2Record w2r = new Window2Record(this.settings);
/* 425 */     this.outputFile.write((ByteData)w2r);
/*     */ 
/*     */     
/* 428 */     if (this.settings.getHorizontalFreeze() != 0 || this.settings.getVerticalFreeze() != 0) {
/*     */ 
/*     */       
/* 431 */       PaneRecord pr = new PaneRecord(this.settings.getHorizontalFreeze(), this.settings.getVerticalFreeze());
/*     */       
/* 433 */       this.outputFile.write((ByteData)pr);
/*     */ 
/*     */       
/* 436 */       SelectionRecord sr = new SelectionRecord(SelectionRecord.upperLeft, 0, 0);
/*     */       
/* 438 */       this.outputFile.write((ByteData)sr);
/*     */ 
/*     */       
/* 441 */       if (this.settings.getHorizontalFreeze() != 0) {
/*     */         
/* 443 */         sr = new SelectionRecord(SelectionRecord.upperRight, this.settings.getHorizontalFreeze(), 0);
/*     */         
/* 445 */         this.outputFile.write((ByteData)sr);
/*     */       } 
/*     */ 
/*     */       
/* 449 */       if (this.settings.getVerticalFreeze() != 0) {
/*     */         
/* 451 */         sr = new SelectionRecord(SelectionRecord.lowerLeft, 0, this.settings.getVerticalFreeze());
/*     */         
/* 453 */         this.outputFile.write((ByteData)sr);
/*     */       } 
/*     */ 
/*     */       
/* 457 */       if (this.settings.getHorizontalFreeze() != 0 && this.settings.getVerticalFreeze() != 0) {
/*     */ 
/*     */         
/* 460 */         sr = new SelectionRecord(SelectionRecord.lowerRight, this.settings.getHorizontalFreeze(), this.settings.getVerticalFreeze());
/*     */ 
/*     */ 
/*     */         
/* 464 */         this.outputFile.write((ByteData)sr);
/*     */       } 
/*     */       
/* 467 */       Weird1Record w1r = new Weird1Record();
/* 468 */       this.outputFile.write((ByteData)w1r);
/*     */     
/*     */     }
/*     */     else {
/*     */ 
/*     */       
/* 474 */       SelectionRecord sr = new SelectionRecord(SelectionRecord.upperLeft, 0, 0);
/*     */       
/* 476 */       this.outputFile.write((ByteData)sr);
/*     */     } 
/*     */ 
/*     */     
/* 480 */     if (this.settings.getZoomFactor() != 100) {
/*     */       
/* 482 */       SCLRecord sclr = new SCLRecord(this.settings.getZoomFactor());
/* 483 */       this.outputFile.write((ByteData)sclr);
/*     */     } 
/*     */ 
/*     */     
/* 487 */     this.mergedCells.write(this.outputFile);
/*     */     
/* 489 */     EOFRecord eof = new EOFRecord();
/* 490 */     this.outputFile.write((ByteData)eof);
/*     */ 
/*     */ 
/*     */     
/* 494 */     this.outputFile.setData(indexRecord.getData(), indexPos + 4);
/*     */   }
/*     */ 
/*     */   
/*     */   void setHeader(HeaderRecord hr) {
/* 499 */     this.header = hr;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   final HeaderRecord getHeader() {
/* 509 */     return this.header;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   final FooterRecord getFooter() {
/* 519 */     return this.footer;
/*     */   }
/*     */ 
/*     */   
/*     */   void setFooter(FooterRecord fr) {
/* 524 */     this.footer = fr;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   void setWriteData(RowRecord[] rws, ArrayList rb, ArrayList hl, MergedCells mc, TreeSet cf) {
/* 539 */     this.rows = rws;
/* 540 */     this.rowBreaks = rb;
/* 541 */     this.hyperlinks = hl;
/* 542 */     this.mergedCells = mc;
/* 543 */     this.columnFormats = cf;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   void setDimensions(int rws, int cls) {
/* 555 */     this.numRows = rws;
/* 556 */     this.numCols = cls;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   void setSettings(SheetSettings sr) {
/* 567 */     this.settings = sr;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   WorkspaceInformationRecord getWorkspaceOptions() {
/* 577 */     return this.workspaceOptions;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   void setWorkspaceOptions(WorkspaceInformationRecord wo) {
/* 587 */     this.workspaceOptions = wo;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   void setCharts(Chart[] ch) {
/* 598 */     this.drawingWriter.setCharts(ch);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   void setDrawings(ArrayList dr) {
/* 608 */     this.drawingWriter.setDrawings(dr);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   Chart[] getCharts() {
/* 618 */     return this.drawingWriter.getCharts();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   void checkMergedBorders() {
/* 629 */     Range[] mcells = this.mergedCells.getMergedCells();
/* 630 */     ArrayList borderFormats = new ArrayList();
/* 631 */     for (int mci = 0; mci < mcells.length; mci++) {
/*     */       
/* 633 */       Range range = mcells[mci];
/* 634 */       Cell topLeft = range.getTopLeft();
/* 635 */       XFRecord tlformat = (XFRecord)topLeft.getCellFormat();
/*     */       
/* 637 */       if (tlformat != null && tlformat.hasBorders() == true && !tlformat.isRead()) {
/*     */         
/*     */         try {
/*     */ 
/*     */ 
/*     */           
/* 643 */           CellXFRecord cf1 = new CellXFRecord(tlformat);
/* 644 */           Cell bottomRight = range.getBottomRight();
/*     */           
/* 646 */           cf1.setBorder(Border.ALL, BorderLineStyle.NONE);
/* 647 */           cf1.setBorder(Border.LEFT, tlformat.getBorder(Border.LEFT));
/* 648 */           cf1.setBorder(Border.TOP, tlformat.getBorder(Border.TOP));
/*     */           
/* 650 */           if (topLeft.getRow() == bottomRight.getRow())
/*     */           {
/* 652 */             cf1.setBorder(Border.BOTTOM, tlformat.getBorder(Border.BOTTOM));
/*     */           }
/*     */           
/* 655 */           if (topLeft.getColumn() == bottomRight.getColumn())
/*     */           {
/* 657 */             cf1.setBorder(Border.RIGHT, tlformat.getBorder(Border.RIGHT));
/*     */           }
/*     */           
/* 660 */           int index = borderFormats.indexOf(cf1);
/* 661 */           if (index != -1) {
/*     */             
/* 663 */             cf1 = borderFormats.get(index);
/*     */           }
/*     */           else {
/*     */             
/* 667 */             borderFormats.add(cf1);
/*     */           } 
/* 669 */           ((WritableCell)topLeft).setCellFormat((CellFormat)cf1);
/*     */ 
/*     */           
/* 672 */           if (bottomRight.getRow() > topLeft.getRow()) {
/*     */ 
/*     */             
/* 675 */             if (bottomRight.getColumn() != topLeft.getColumn()) {
/*     */               
/* 677 */               CellXFRecord cf2 = new CellXFRecord(tlformat);
/* 678 */               cf2.setBorder(Border.ALL, BorderLineStyle.NONE);
/* 679 */               cf2.setBorder(Border.LEFT, tlformat.getBorder(Border.LEFT));
/* 680 */               cf2.setBorder(Border.BOTTOM, tlformat.getBorder(Border.BOTTOM));
/*     */               
/* 682 */               index = borderFormats.indexOf(cf2);
/* 683 */               if (index != -1) {
/*     */                 
/* 685 */                 cf2 = borderFormats.get(index);
/*     */               }
/*     */               else {
/*     */                 
/* 689 */                 borderFormats.add(cf2);
/*     */               } 
/*     */               
/* 692 */               this.sheet.addCell((WritableCell)new Blank(topLeft.getColumn(), bottomRight.getRow(), (CellFormat)cf2));
/*     */             } 
/*     */ 
/*     */ 
/*     */ 
/*     */             
/* 698 */             for (int i = topLeft.getRow() + 1; i < bottomRight.getRow(); i++) {
/*     */               
/* 700 */               CellXFRecord cf3 = new CellXFRecord(tlformat);
/* 701 */               cf3.setBorder(Border.ALL, BorderLineStyle.NONE);
/* 702 */               cf3.setBorder(Border.LEFT, tlformat.getBorder(Border.LEFT));
/*     */               
/* 704 */               if (topLeft.getColumn() == bottomRight.getColumn())
/*     */               {
/* 706 */                 cf3.setBorder(Border.RIGHT, tlformat.getBorder(Border.RIGHT));
/*     */               }
/*     */               
/* 709 */               index = borderFormats.indexOf(cf3);
/* 710 */               if (index != -1) {
/*     */                 
/* 712 */                 cf3 = borderFormats.get(index);
/*     */               }
/*     */               else {
/*     */                 
/* 716 */                 borderFormats.add(cf3);
/*     */               } 
/*     */               
/* 719 */               this.sheet.addCell((WritableCell)new Blank(topLeft.getColumn(), i, (CellFormat)cf3));
/*     */             } 
/*     */           } 
/*     */ 
/*     */           
/* 724 */           if (bottomRight.getColumn() > topLeft.getColumn()) {
/*     */             
/* 726 */             if (bottomRight.getRow() != topLeft.getRow()) {
/*     */ 
/*     */               
/* 729 */               CellXFRecord cf6 = new CellXFRecord(tlformat);
/* 730 */               cf6.setBorder(Border.ALL, BorderLineStyle.NONE);
/* 731 */               cf6.setBorder(Border.RIGHT, tlformat.getBorder(Border.RIGHT));
/* 732 */               cf6.setBorder(Border.TOP, tlformat.getBorder(Border.TOP));
/* 733 */               index = borderFormats.indexOf(cf6);
/* 734 */               if (index != -1) {
/*     */                 
/* 736 */                 cf6 = borderFormats.get(index);
/*     */               }
/*     */               else {
/*     */                 
/* 740 */                 borderFormats.add(cf6);
/*     */               } 
/*     */               
/* 743 */               this.sheet.addCell((WritableCell)new Blank(bottomRight.getColumn(), topLeft.getRow(), (CellFormat)cf6));
/*     */             } 
/*     */ 
/*     */ 
/*     */             
/* 748 */             int i = topLeft.getRow() + 1;
/* 749 */             for (; i < bottomRight.getRow(); i++) {
/*     */               
/* 751 */               CellXFRecord cf7 = new CellXFRecord(tlformat);
/* 752 */               cf7.setBorder(Border.ALL, BorderLineStyle.NONE);
/* 753 */               cf7.setBorder(Border.RIGHT, tlformat.getBorder(Border.RIGHT));
/*     */               
/* 755 */               index = borderFormats.indexOf(cf7);
/* 756 */               if (index != -1) {
/*     */                 
/* 758 */                 cf7 = borderFormats.get(index);
/*     */               }
/*     */               else {
/*     */                 
/* 762 */                 borderFormats.add(cf7);
/*     */               } 
/*     */               
/* 765 */               this.sheet.addCell((WritableCell)new Blank(bottomRight.getColumn(), i, (CellFormat)cf7));
/*     */             } 
/*     */ 
/*     */             
/* 769 */             i = topLeft.getColumn() + 1;
/* 770 */             for (; i < bottomRight.getColumn(); i++) {
/*     */               
/* 772 */               CellXFRecord cf8 = new CellXFRecord(tlformat);
/* 773 */               cf8.setBorder(Border.ALL, BorderLineStyle.NONE);
/* 774 */               cf8.setBorder(Border.TOP, tlformat.getBorder(Border.TOP));
/*     */               
/* 776 */               if (topLeft.getRow() == bottomRight.getRow())
/*     */               {
/* 778 */                 cf8.setBorder(Border.BOTTOM, tlformat.getBorder(Border.BOTTOM));
/*     */               }
/*     */ 
/*     */               
/* 782 */               index = borderFormats.indexOf(cf8);
/* 783 */               if (index != -1) {
/*     */                 
/* 785 */                 cf8 = borderFormats.get(index);
/*     */               }
/*     */               else {
/*     */                 
/* 789 */                 borderFormats.add(cf8);
/*     */               } 
/*     */               
/* 792 */               this.sheet.addCell((WritableCell)new Blank(i, topLeft.getRow(), (CellFormat)cf8));
/*     */             } 
/*     */           } 
/*     */ 
/*     */           
/* 797 */           if (bottomRight.getColumn() > topLeft.getColumn() || bottomRight.getRow() > topLeft.getRow()) {
/*     */ 
/*     */ 
/*     */             
/* 801 */             CellXFRecord cf4 = new CellXFRecord(tlformat);
/* 802 */             cf4.setBorder(Border.ALL, BorderLineStyle.NONE);
/* 803 */             cf4.setBorder(Border.RIGHT, tlformat.getBorder(Border.RIGHT));
/* 804 */             cf4.setBorder(Border.BOTTOM, tlformat.getBorder(Border.BOTTOM));
/*     */             
/* 806 */             if (bottomRight.getRow() == topLeft.getRow())
/*     */             {
/* 808 */               cf4.setBorder(Border.TOP, tlformat.getBorder(Border.TOP));
/*     */             }
/*     */             
/* 811 */             if (bottomRight.getColumn() == topLeft.getColumn())
/*     */             {
/* 813 */               cf4.setBorder(Border.LEFT, tlformat.getBorder(Border.LEFT));
/*     */             }
/*     */             
/* 816 */             index = borderFormats.indexOf(cf4);
/* 817 */             if (index != -1) {
/*     */               
/* 819 */               cf4 = borderFormats.get(index);
/*     */             }
/*     */             else {
/*     */               
/* 823 */               borderFormats.add(cf4);
/*     */             } 
/*     */             
/* 826 */             this.sheet.addCell((WritableCell)new Blank(bottomRight.getColumn(), bottomRight.getRow(), (CellFormat)cf4));
/*     */ 
/*     */ 
/*     */ 
/*     */             
/* 831 */             int i = topLeft.getColumn() + 1;
/* 832 */             for (; i < bottomRight.getColumn(); i++)
/*     */             {
/* 834 */               CellXFRecord cf5 = new CellXFRecord(tlformat);
/* 835 */               cf5.setBorder(Border.ALL, BorderLineStyle.NONE);
/* 836 */               cf5.setBorder(Border.BOTTOM, tlformat.getBorder(Border.BOTTOM));
/*     */               
/* 838 */               if (topLeft.getRow() == bottomRight.getRow())
/*     */               {
/* 840 */                 cf5.setBorder(Border.TOP, tlformat.getBorder(Border.TOP));
/*     */               }
/*     */               
/* 843 */               index = borderFormats.indexOf(cf5);
/* 844 */               if (index != -1) {
/*     */                 
/* 846 */                 cf5 = borderFormats.get(index);
/*     */               }
/*     */               else {
/*     */                 
/* 850 */                 borderFormats.add(cf5);
/*     */               } 
/*     */               
/* 853 */               this.sheet.addCell((WritableCell)new Blank(i, bottomRight.getRow(), (CellFormat)cf5));
/*     */             }
/*     */           
/*     */           } 
/* 857 */         } catch (WriteException e) {
/*     */ 
/*     */           
/* 860 */           logger.warn(e.toString());
/*     */         } 
/*     */       }
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private Cell[] getColumn(int col) {
/* 874 */     boolean found = false;
/* 875 */     int row = this.numRows - 1;
/*     */     
/* 877 */     while (row >= 0 && !found) {
/*     */       
/* 879 */       if (this.rows[row] != null && this.rows[row].getCell(col) != null) {
/*     */ 
/*     */         
/* 882 */         found = true;
/*     */         
/*     */         continue;
/*     */       } 
/* 886 */       row--;
/*     */     } 
/*     */ 
/*     */ 
/*     */     
/* 891 */     Cell[] cells = new Cell[row + 1];
/*     */     
/* 893 */     for (int i = 0; i <= row; i++)
/*     */     {
/* 895 */       cells[i] = (this.rows[i] != null) ? (Cell)this.rows[i].getCell(col) : null;
/*     */     }
/*     */     
/* 898 */     return cells;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   void setChartOnly() {
/* 906 */     this.chartOnly = true;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   void setPLS(PLSRecord pls) {
/* 916 */     this.plsRecord = pls;
/*     */   }
/*     */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\lib\jxl.jar!\jxl\write\biff\SheetWriter.class
 * Java compiler version: 2 (46.0)
 * JD-Core Version:       1.1.3
 */