/*     */ package oracle.jdbc.connector;
/*     */ 
/*     */ import java.sql.Connection;
/*     */ import java.sql.SQLException;
/*     */ import javax.resource.ResourceException;
/*     */ import javax.resource.spi.EISSystemException;
/*     */ import javax.resource.spi.IllegalStateException;
/*     */ import javax.resource.spi.LocalTransaction;
/*     */ import javax.resource.spi.LocalTransactionException;
/*     */ import oracle.jdbc.internal.OracleConnection;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class OracleLocalTransaction
/*     */   implements LocalTransaction
/*     */ {
/*  33 */   private OracleManagedConnection managedConnection = null;
/*  34 */   private Connection connection = null;
/*     */ 
/*     */ 
/*     */   
/*     */   boolean isBeginCalled = false;
/*     */ 
/*     */ 
/*     */   
/*     */   private static final String RAERR_LTXN_COMMIT = "commit without begin";
/*     */ 
/*     */   
/*     */   private static final String RAERR_LTXN_ROLLBACK = "rollback without begin";
/*     */ 
/*     */ 
/*     */   
/*     */   OracleLocalTransaction(OracleManagedConnection paramOracleManagedConnection) throws ResourceException {
/*  50 */     this.managedConnection = paramOracleManagedConnection;
/*  51 */     this.connection = paramOracleManagedConnection.getPhysicalConnection();
/*  52 */     this.isBeginCalled = false;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void begin() throws ResourceException {
/*     */     try {
/*  78 */       if (((OracleConnection)this.connection).getTxnMode() == 1) {
/*     */ 
/*     */         
/*  81 */         IllegalStateException illegalStateException = new IllegalStateException("Could not start a new transaction inside an active transaction");
/*     */ 
/*     */         
/*  84 */         throw illegalStateException;
/*     */       } 
/*     */       
/*  87 */       if (this.connection.getAutoCommit()) {
/*  88 */         this.connection.setAutoCommit(false);
/*     */       }
/*  90 */       this.isBeginCalled = true;
/*     */ 
/*     */ 
/*     */     
/*     */     }
/*  95 */     catch (SQLException sQLException) {
/*     */       
/*  97 */       EISSystemException eISSystemException = new EISSystemException("SQLException: " + sQLException.getMessage());
/*     */ 
/*     */       
/* 100 */       eISSystemException.setLinkedException(sQLException);
/*     */       
/* 102 */       throw eISSystemException;
/*     */     } 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 108 */     this.managedConnection.eventOccurred(2);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void commit() throws ResourceException {
/* 129 */     if (!this.isBeginCalled) {
/* 130 */       throw new LocalTransactionException("begin() must be called before commit()", "commit without begin");
/*     */     }
/*     */ 
/*     */     
/*     */     try {
/* 135 */       this.connection.commit();
/*     */ 
/*     */ 
/*     */     
/*     */     }
/* 140 */     catch (SQLException sQLException) {
/*     */       
/* 142 */       EISSystemException eISSystemException = new EISSystemException("SQLException: " + sQLException.getMessage());
/*     */ 
/*     */       
/* 145 */       eISSystemException.setLinkedException(sQLException);
/*     */       
/* 147 */       throw eISSystemException;
/*     */     } 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 153 */     this.isBeginCalled = false;
/*     */     
/* 155 */     this.managedConnection.eventOccurred(3);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void rollback() throws ResourceException {
/* 176 */     if (!this.isBeginCalled) {
/* 177 */       throw new LocalTransactionException("begin() must be called before rollback()", "rollback without begin");
/*     */     }
/*     */ 
/*     */     
/*     */     try {
/* 182 */       this.connection.rollback();
/*     */ 
/*     */ 
/*     */     
/*     */     }
/* 187 */     catch (SQLException sQLException) {
/*     */       
/* 189 */       EISSystemException eISSystemException = new EISSystemException("SQLException: " + sQLException.getMessage());
/*     */ 
/*     */       
/* 192 */       eISSystemException.setLinkedException(sQLException);
/*     */       
/* 194 */       throw eISSystemException;
/*     */     } 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 200 */     this.isBeginCalled = false;
/*     */     
/* 202 */     this.managedConnection.eventOccurred(4);
/*     */   }
/*     */ 
/*     */ 
/*     */   
/* 207 */   private static final String _Copyright_2004_Oracle_All_Rights_Reserved_ = null;
/*     */   public static final boolean TRACE = false;
/*     */   public static final boolean PRIVATE_TRACE = false;
/*     */   public static final String BUILD_DATE = "Sat_Feb__2_11:39:42_PST_2008";
/*     */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\lib\ojdbc14.jar!\oracle\jdbc\connector\OracleLocalTransaction.class
 * Java compiler version: 2 (46.0)
 * JD-Core Version:       1.1.3
 */