/*      */ package oracle.jdbc.driver;
/*      */ 
/*      */ import java.security.AccessController;
/*      */ import java.security.PrivilegedAction;
/*      */ import java.sql.Connection;
/*      */ import java.sql.Driver;
/*      */ import java.sql.DriverManager;
/*      */ import java.sql.DriverPropertyInfo;
/*      */ import java.sql.SQLException;
/*      */ import java.sql.Timestamp;
/*      */ import java.util.Enumeration;
/*      */ import java.util.Hashtable;
/*      */ import java.util.Properties;
/*      */ import oracle.jdbc.OracleDatabaseMetaData;
/*      */ import oracle.security.pki.OracleSecretStore;
/*      */ import oracle.security.pki.OracleWallet;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ public class OracleDriver
/*      */   implements Driver
/*      */ {
/*      */   public static final char slash_character = '/';
/*      */   public static final char at_sign_character = '@';
/*      */   public static final char left_square_bracket_character = '[';
/*      */   public static final char right_square_bracket_character = ']';
/*      */   public static final String oracle_string = "oracle";
/*      */   public static final String protocol_string = "protocol";
/*      */   public static final String user_string = "user";
/*      */   public static final String password_string = "password";
/*      */   public static final String database_string = "database";
/*      */   public static final String server_string = "server";
/*      */   public static final String access_string = "access";
/*      */   public static final String protocolFullName_string = "protocolFullName";
/*      */   public static final String logon_as_internal_str = "internal_logon";
/*      */   public static final String proxy_client_name = "PROXY_CLIENT_NAME";
/*      */   public static final String prefetch_string = "prefetch";
/*      */   public static final String row_prefetch_string = "rowPrefetch";
/*      */   public static final String default_row_prefetch_string = "defaultRowPrefetch";
/*      */   public static final String batch_string = "batch";
/*      */   public static final String execute_batch_string = "executeBatch";
/*      */   public static final String default_execute_batch_string = "defaultExecuteBatch";
/*      */   public static final String process_escapes_string = "processEscapes";
/*      */   public static final String dms_parent_name_string = "DMSName";
/*      */   public static final String dms_parent_type_string = "DMSType";
/*      */   public static final String accumulate_batch_result = "AccumulateBatchResult";
/*      */   public static final String j2ee_compliance = "oracle.jdbc.J2EE13Compliant";
/*      */   public static final String v8compatible_string = "oracle.jdbc.V8Compatible";
/*      */   public static final String permit_timestamp_date_mismatch_string = "oracle.jdbc.internal.permitBindDateDefineTimestampMismatch";
/*      */   public static final String StreamChunkSize_string = "oracle.jdbc.StreamChunkSize";
/*      */   public static final String SetFloatAndDoubleUseBinary_string = "SetFloatAndDoubleUseBinary";
/*      */   public static final String xa_trans_loose = "oracle.jdbc.XATransLoose";
/*      */   public static final String tcp_no_delay = "oracle.jdbc.TcpNoDelay";
/*      */   public static final String read_timeout = "oracle.jdbc.ReadTimeout";
/*      */   public static final String defaultnchar_string = "oracle.jdbc.defaultNChar";
/*      */   public static final String defaultncharprop_string = "defaultNChar";
/*      */   public static final String useFetchSizeWithLongColumn_prop_string = "useFetchSizeWithLongColumn";
/*      */   public static final String useFetchSizeWithLongColumn_string = "oracle.jdbc.useFetchSizeWithLongColumn";
/*      */   public static final String remarks_string = "remarks";
/*      */   public static final String report_remarks_string = "remarksReporting";
/*      */   public static final String synonyms_string = "synonyms";
/*      */   public static final String include_synonyms_string = "includeSynonyms";
/*      */   public static final String restrict_getTables_string = "restrictGetTables";
/*      */   public static final String fixed_string_string = "fixedString";
/*      */   public static final String dll_string = "oracle.jdbc.ocinativelibrary";
/*      */   public static final String nls_lang_backdoor = "oracle.jdbc.ociNlsLangBackwardCompatible";
/*      */   public static final String disable_defineColumnType_string = "disableDefineColumnType";
/*      */   public static final String convert_nchar_literals_string = "oracle.jdbc.convertNcharLiterals";
/*      */   public static final String dataSizeUnitsPropertyName = "";
/*      */   public static final String dataSizeBytes = "";
/*      */   public static final String dataSizeChars = "";
/*      */   public static final String dms_stmt_metrics_string = "oracle.jdbc.DMSStatementMetrics";
/*      */   public static final String dms_stmt_caching_metrics_string = "oracle.jdbc.DMSStatementCachingMetrics";
/*      */   public static final String set_new_password_string = "OCINewPassword";
/*      */   public static final String retain_v9_bind_behavior_string = "oracle.jdbc.RetainV9LongBindBehavior";
/*      */   public static final String no_caching_buffers = "oracle.jdbc.FreeMemoryOnEnterImplicitCache";
/*      */   public static final String secret_store_connect = "oracle.security.client.connect_string";
/*      */   public static final String secret_store_username = "oracle.security.client.username";
/*      */   public static final String secret_store_password = "oracle.security.client.password";
/*      */   public static final String secret_store_default_username = "oracle.security.client.default_username";
/*      */   public static final String secret_store_default_password = "oracle.security.client.default_password";
/*      */   public static final String wallet_location_string = "oracle.net.wallet_location";
/*  371 */   private static String walletLocation = null;
/*      */ 
/*      */ 
/*      */   
/*      */   static final int EXTENSION_TYPE_ORACLE_ERROR = -3;
/*      */ 
/*      */ 
/*      */   
/*      */   static final int EXTENSION_TYPE_GEN_ERROR = -2;
/*      */ 
/*      */ 
/*      */   
/*      */   static final int EXTENSION_TYPE_TYPE4_CLIENT = 0;
/*      */ 
/*      */ 
/*      */   
/*      */   static final int EXTENSION_TYPE_TYPE4_SERVER = 1;
/*      */ 
/*      */ 
/*      */   
/*      */   static final int EXTENSION_TYPE_TYPE2_CLIENT = 2;
/*      */ 
/*      */ 
/*      */   
/*      */   static final int EXTENSION_TYPE_TYPE2_SERVER = 3;
/*      */ 
/*      */ 
/*      */   
/*      */   private static final int NUMBER_OF_EXTENSION_TYPES = 4;
/*      */ 
/*      */ 
/*      */   
/*  403 */   private OracleDriverExtension[] driverExtensions = new OracleDriverExtension[4];
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private static final String DRIVER_PACKAGE_STRING = "driver";
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  419 */   private static final String[] driverExtensionClassNames = new String[] { "oracle.jdbc.driver.T4CDriverExtension", "oracle.jdbc.driver.T4CDriverExtension", "oracle.jdbc.driver.T2CDriverExtension", "oracle.jdbc.driver.T2SDriverExtension" };
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private static Properties driverAccess;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  438 */   protected static Connection defaultConn = null;
/*  439 */   private static OracleDriver defaultDriver = null;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   static {
/*  462 */     Timestamp timestamp = Timestamp.valueOf("2000-01-01 00:00:00.0");
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  468 */     try { if (defaultDriver == null)
/*      */       {
/*  470 */         defaultDriver = new OracleDriver();
/*      */         
/*  472 */         DriverManager.registerDriver(defaultDriver);
/*      */       }
/*      */        }
/*  475 */     catch (RuntimeException runtimeException) {  }
/*  476 */     catch (SQLException sQLException) {}
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Connection connect(String paramString, Properties paramProperties) throws SQLException {
/*      */     String str18;
/*  510 */     if (paramString.regionMatches(0, "jdbc:default:connection", 0, 23)) {
/*      */       
/*  512 */       String str = "jdbc:oracle:kprb";
/*  513 */       int k = paramString.length();
/*      */       
/*  515 */       if (k > 23) {
/*  516 */         paramString = str.concat(paramString.substring(23, paramString.length()));
/*      */       } else {
/*  518 */         paramString = str.concat(":");
/*      */       } 
/*  520 */       str = null;
/*      */     } 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  532 */     int i = oracleDriverExtensionTypeFromURL(paramString);
/*      */     
/*  534 */     if (i == -2) {
/*  535 */       return null;
/*      */     }
/*  537 */     if (i == -3) {
/*  538 */       DatabaseError.throwSqlException(67);
/*      */     }
/*  540 */     OracleDriverExtension oracleDriverExtension = null;
/*      */     
/*  542 */     oracleDriverExtension = this.driverExtensions[i];
/*      */     
/*  544 */     if (oracleDriverExtension == null) {
/*      */       
/*      */       try {
/*      */ 
/*      */         
/*  549 */         synchronized (this)
/*      */         {
/*  551 */           if (oracleDriverExtension == null)
/*      */           {
/*      */ 
/*      */ 
/*      */ 
/*      */             
/*  557 */             oracleDriverExtension = (OracleDriverExtension)Class.forName(driverExtensionClassNames[i]).newInstance();
/*      */             
/*  559 */             this.driverExtensions[i] = oracleDriverExtension;
/*      */           }
/*      */           else
/*      */           {
/*  563 */             oracleDriverExtension = this.driverExtensions[i];
/*      */           
/*      */           }
/*      */         
/*      */         }
/*      */       
/*      */       }
/*  570 */       catch (Exception exception) {
/*      */         
/*  572 */         throw new SQLException(exception.toString());
/*      */       } 
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  592 */     walletLocation = paramProperties.getProperty("oracle.net.wallet_location");
/*      */     
/*  594 */     if (walletLocation == null)
/*      */     {
/*  596 */       walletLocation = getSystemProperty("oracle.net.wallet_location", null);
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  608 */     Hashtable hashtable = parseUrl(paramString);
/*      */     
/*  610 */     if (hashtable == null)
/*      */     {
/*  612 */       return null;
/*      */     }
/*      */     
/*  615 */     String str1 = paramProperties.getProperty("user");
/*  616 */     String str2 = paramProperties.getProperty("password");
/*  617 */     String str3 = paramProperties.getProperty("database");
/*      */     
/*  619 */     if (str3 == null) {
/*  620 */       str3 = paramProperties.getProperty("server");
/*      */     }
/*  622 */     if (str1 == null) {
/*  623 */       str1 = (String)hashtable.get("user");
/*      */     }
/*  625 */     str1 = parseLoginOption(str1, paramProperties);
/*      */     
/*  627 */     if (str2 == null) {
/*  628 */       str2 = (String)hashtable.get("password");
/*      */     }
/*  630 */     if (str3 == null) {
/*  631 */       str3 = (String)hashtable.get("database");
/*      */     }
/*  633 */     String str4 = (String)hashtable.get("protocol");
/*      */     
/*  635 */     paramProperties.put("protocol", str4);
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  640 */     if (str4 == null) {
/*      */       
/*  642 */       DatabaseError.throwSqlException(40, "Protocol is not specified in URL");
/*      */ 
/*      */       
/*  645 */       return null;
/*      */     } 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  651 */     if (str4.equals("oci8") || str4.equals("oci")) {
/*  652 */       str3 = translateConnStr(str3);
/*      */     }
/*  654 */     String str5 = paramProperties.getProperty("oracle.jdbc.TcpNoDelay");
/*      */     
/*  656 */     if (str5 == null)
/*      */     {
/*  658 */       str5 = getSystemProperty("oracle.jdbc.TcpNoDelay", null);
/*      */     }
/*  660 */     if (str5 != null && str5.equalsIgnoreCase("true")) {
/*  661 */       paramProperties.put("TCP.NODELAY", "YES");
/*      */     }
/*  663 */     String str6 = paramProperties.getProperty("oracle.jdbc.ReadTimeout");
/*  664 */     if (str6 != null) {
/*  665 */       paramProperties.put("oracle.net.READ_TIMEOUT", str6);
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  677 */     int j = DriverManager.getLoginTimeout();
/*      */     
/*  679 */     if (j != 0 && paramProperties.get("oracle.net.CONNECT_TIMEOUT") == null)
/*      */     {
/*  681 */       paramProperties.put("oracle.net.CONNECT_TIMEOUT", "" + (j * 1000));
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  687 */     String str7 = paramProperties.getProperty("prefetch");
/*      */     
/*  689 */     if (str7 == null) {
/*  690 */       str7 = paramProperties.getProperty("rowPrefetch");
/*      */     }
/*  692 */     if (str7 == null) {
/*  693 */       str7 = paramProperties.getProperty("defaultRowPrefetch");
/*      */     }
/*  695 */     if (str7 != null && Integer.parseInt(str7) <= 0) {
/*  696 */       str7 = null;
/*      */     }
/*  698 */     String str8 = paramProperties.getProperty("batch");
/*      */     
/*  700 */     if (str8 == null) {
/*  701 */       str8 = paramProperties.getProperty("executeBatch");
/*      */     }
/*  703 */     if (str8 == null) {
/*  704 */       str8 = paramProperties.getProperty("defaultExecuteBatch");
/*      */     }
/*  706 */     if (str8 != null && Integer.parseInt(str8) <= 0) {
/*  707 */       str8 = null;
/*      */     }
/*      */ 
/*      */     
/*  711 */     String str9 = paramProperties.getProperty("defaultNChar");
/*      */     
/*  713 */     if (str9 == null) {
/*  714 */       str9 = getSystemProperty("oracle.jdbc.defaultNChar", null);
/*      */     }
/*  716 */     String str10 = paramProperties.getProperty("useFetchSizeWithLongColumn");
/*      */ 
/*      */     
/*  719 */     if (str10 == null)
/*      */     {
/*  721 */       str10 = getSystemProperty("oracle.jdbc.useFetchSizeWithLongColumn", null);
/*      */     }
/*      */ 
/*      */ 
/*      */     
/*  726 */     String str11 = paramProperties.getProperty("remarks");
/*      */     
/*  728 */     if (str11 == null) {
/*  729 */       str11 = paramProperties.getProperty("remarksReporting");
/*      */     }
/*      */ 
/*      */     
/*  733 */     String str12 = paramProperties.getProperty("synonyms");
/*      */     
/*  735 */     if (str12 == null) {
/*  736 */       str12 = paramProperties.getProperty("includeSynonyms");
/*      */     }
/*      */ 
/*      */     
/*  740 */     String str13 = paramProperties.getProperty("restrictGetTables");
/*      */ 
/*      */     
/*  743 */     String str14 = paramProperties.getProperty("fixedString");
/*      */ 
/*      */     
/*  746 */     String str15 = paramProperties.getProperty("AccumulateBatchResult");
/*      */     
/*  748 */     if (str15 == null) {
/*  749 */       str15 = "true";
/*      */     }
/*      */ 
/*      */     
/*  753 */     String str16 = paramProperties.getProperty("disableDefineColumnType");
/*      */ 
/*      */     
/*  756 */     if (str16 == null) {
/*  757 */       str16 = "false";
/*      */     }
/*  759 */     String str17 = paramProperties.getProperty("oracle.jdbc.convertNcharLiterals");
/*      */ 
/*      */     
/*  762 */     if (str17 == null) {
/*  763 */       str17 = getSystemProperty("oracle.jdbc.convertNcharLiterals", "false");
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  777 */     Enumeration enumeration = DriverManager.getDrivers();
/*      */ 
/*      */     
/*  780 */     while (enumeration.hasMoreElements()) {
/*      */       
/*  782 */       Driver driver = enumeration.nextElement();
/*      */       
/*  784 */       if (driver instanceof OracleDriver) {
/*      */         break;
/*      */       }
/*      */     } 
/*      */     
/*  789 */     while (enumeration.hasMoreElements()) {
/*      */       
/*  791 */       Driver driver = enumeration.nextElement();
/*      */       
/*  793 */       if (driver instanceof OracleDriver) {
/*  794 */         DriverManager.deregisterDriver(driver);
/*      */       }
/*      */     } 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  801 */     PhysicalConnection physicalConnection = (PhysicalConnection)oracleDriverExtension.getConnection(paramString, str1, str2, str3, paramProperties);
/*      */ 
/*      */ 
/*      */     
/*  805 */     if (str7 != null) {
/*  806 */       physicalConnection.setDefaultRowPrefetch(Integer.parseInt(str7));
/*      */     }
/*  808 */     if (str8 != null) {
/*  809 */       physicalConnection.setDefaultExecuteBatch(Integer.parseInt(str8));
/*      */     }
/*  811 */     if (str11 != null) {
/*  812 */       physicalConnection.setRemarksReporting(str11.equalsIgnoreCase("true"));
/*      */     }
/*  814 */     if (str12 != null) {
/*  815 */       physicalConnection.setIncludeSynonyms(str12.equalsIgnoreCase("true"));
/*      */     }
/*  817 */     if (str13 != null) {
/*  818 */       physicalConnection.setRestrictGetTables(str13.equalsIgnoreCase("true"));
/*      */     }
/*  820 */     if (str14 != null) {
/*  821 */       physicalConnection.setDefaultFixedString(str14.equalsIgnoreCase("true"));
/*      */     }
/*  823 */     if (str9 != null) {
/*  824 */       physicalConnection.setDefaultNChar(str9.equalsIgnoreCase("true"));
/*      */     }
/*  826 */     if (str10 != null) {
/*  827 */       physicalConnection.useFetchSizeWithLongColumn = str10.equalsIgnoreCase("true");
/*      */     }
/*      */ 
/*      */ 
/*      */     
/*  832 */     if (str15 != null) {
/*  833 */       physicalConnection.setAccumulateBatchResult(str15.equalsIgnoreCase("true"));
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  840 */     String str19 = getSystemProperty("oracle.jdbc.J2EE13Compliant", null);
/*      */ 
/*      */     
/*  843 */     if (str19 == null) {
/*      */       
/*  845 */       str18 = paramProperties.getProperty("oracle.jdbc.J2EE13Compliant");
/*      */       
/*  847 */       if (str18 == null)
/*      */       {
/*  849 */         str18 = "false";
/*      */       
/*      */       }
/*      */     
/*      */     }
/*      */     else {
/*      */ 
/*      */       
/*  857 */       str18 = str19;
/*      */     } 
/*  859 */     physicalConnection.setJ2EE13Compliant(str18.equalsIgnoreCase("true"));
/*      */     
/*  861 */     physicalConnection.disableDefineColumnType = str16.equalsIgnoreCase("true");
/*      */ 
/*      */     
/*  864 */     physicalConnection.convertNcharLiterals = str17.equalsIgnoreCase("true");
/*      */ 
/*      */     
/*  867 */     hashtable = null;
/*      */     
/*  869 */     physicalConnection.protocolId = i;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  874 */     return (Connection)physicalConnection;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Connection defaultConnection() throws SQLException {
/*  889 */     if (defaultConn == null || defaultConn.isClosed())
/*      */     {
/*  891 */       synchronized (OracleDriver.class) {
/*      */         
/*  893 */         if (defaultConn == null || defaultConn.isClosed())
/*      */         {
/*  895 */           defaultConn = DriverManager.getConnection("jdbc:oracle:kprb:");
/*      */         }
/*      */       } 
/*      */     }
/*      */     
/*  900 */     return defaultConn;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private int oracleDriverExtensionTypeFromURL(String paramString) {
/*  925 */     int i = paramString.indexOf(':') + 1;
/*      */     
/*  927 */     if (i == 0) {
/*  928 */       return -2;
/*      */     }
/*  930 */     int j = paramString.indexOf(':', i);
/*      */     
/*  932 */     if (j == -1) {
/*  933 */       return -2;
/*      */     }
/*  935 */     if (!paramString.regionMatches(true, i, "oracle", 0, j - i))
/*      */     {
/*  937 */       return -2;
/*      */     }
/*  939 */     j++;
/*      */     
/*  941 */     int k = paramString.indexOf(':', j);
/*      */     
/*  943 */     if (k == -1) {
/*  944 */       return -3;
/*      */     }
/*  946 */     String str = paramString.substring(j, k);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  953 */     if (str.equals("thin")) {
/*  954 */       return 0;
/*      */     }
/*  956 */     if (str.equals("oci8") || str.equals("oci")) {
/*  957 */       return 2;
/*      */     }
/*      */ 
/*      */     
/*  961 */     return -3;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public boolean acceptsURL(String paramString) {
/*  981 */     if (paramString.startsWith("jdbc:oracle:"))
/*      */     {
/*  983 */       return (oracleDriverExtensionTypeFromURL(paramString) > -2);
/*      */     }
/*      */     
/*  986 */     return false;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public DriverPropertyInfo[] getPropertyInfo(String paramString, Properties paramProperties) throws SQLException {
/*  995 */     return new DriverPropertyInfo[0];
/*      */   }
/*      */ 
/*      */   
/*      */   public int getMajorVersion() {
/* 1000 */     return OracleDatabaseMetaData.getDriverMajorVersionInfo();
/*      */   }
/*      */ 
/*      */   
/*      */   public int getMinorVersion() {
/* 1005 */     return OracleDatabaseMetaData.getDriverMinorVersionInfo();
/*      */   }
/*      */ 
/*      */   
/*      */   public boolean jdbcCompliant() {
/* 1010 */     return true;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public String processSqlEscapes(String paramString) throws SQLException {
/* 1023 */     OracleSql oracleSql = new OracleSql(null);
/*      */ 
/*      */ 
/*      */     
/* 1027 */     oracleSql.initialize(paramString);
/*      */     
/* 1029 */     return oracleSql.parse(paramString);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private String parseLoginOption(String paramString, Properties paramProperties) {
/* 1045 */     int j = 0;
/* 1046 */     String str1 = null;
/* 1047 */     String str2 = null;
/*      */ 
/*      */     
/* 1050 */     if (paramString == null) {
/* 1051 */       return null;
/*      */     }
/* 1053 */     int k = paramString.length();
/*      */     
/* 1055 */     if (k == 0) {
/* 1056 */       return null;
/*      */     }
/*      */     
/* 1059 */     int i = paramString.indexOf('[');
/* 1060 */     if (i > 0) {
/* 1061 */       j = paramString.indexOf(']');
/* 1062 */       str2 = paramString.substring(i + 1, j);
/* 1063 */       str2 = str2.trim();
/*      */       
/* 1065 */       if (str2.length() > 0) {
/* 1066 */         paramProperties.put("PROXY_CLIENT_NAME", str2);
/*      */       }
/*      */       
/* 1069 */       paramString = paramString.substring(0, i) + paramString.substring(j + 1, k);
/*      */     } 
/*      */ 
/*      */ 
/*      */     
/* 1074 */     String str3 = paramString.toLowerCase();
/*      */ 
/*      */     
/* 1077 */     i = str3.lastIndexOf(" as ");
/*      */     
/* 1079 */     if (i == -1 || i < str3.lastIndexOf("\"")) {
/* 1080 */       return paramString;
/*      */     }
/*      */ 
/*      */ 
/*      */     
/* 1085 */     str1 = paramString.substring(0, i);
/*      */     
/* 1087 */     i += 4;
/*      */ 
/*      */     
/* 1090 */     while (i < k && str3.charAt(i) == ' ') {
/* 1091 */       i++;
/*      */     }
/* 1093 */     if (i == k) {
/* 1094 */       return paramString;
/*      */     }
/* 1096 */     String str4 = str3.substring(i).trim();
/*      */     
/* 1098 */     if (str4.length() > 0) {
/* 1099 */       paramProperties.put("internal_logon", str4);
/*      */     }
/* 1101 */     return str1;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private Hashtable parseUrl(String paramString) throws SQLException {
/* 1123 */     Hashtable hashtable = new Hashtable(5);
/* 1124 */     int i = paramString.indexOf(':', paramString.indexOf(':') + 1) + 1;
/* 1125 */     int j = paramString.length();
/*      */ 
/*      */     
/* 1128 */     if (i == j) {
/* 1129 */       return hashtable;
/*      */     }
/* 1131 */     int k = paramString.indexOf(':', i);
/*      */ 
/*      */     
/* 1134 */     if (k == -1) {
/* 1135 */       return hashtable;
/*      */     }
/* 1137 */     hashtable.put("protocol", paramString.substring(i, k));
/*      */     
/* 1139 */     int m = k + 1;
/* 1140 */     int n = paramString.indexOf('/', m);
/*      */     
/* 1142 */     int i1 = paramString.indexOf('@', m);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1148 */     if (i1 > m && m > i && n == -1)
/*      */     {
/* 1150 */       return null;
/*      */     }
/*      */     
/* 1153 */     if (i1 == -1) {
/* 1154 */       i1 = j;
/*      */     }
/* 1156 */     if (n == -1) {
/* 1157 */       n = i1;
/*      */     }
/* 1159 */     if (n < i1 && n != m && i1 != m) {
/*      */       
/* 1161 */       hashtable.put("user", paramString.substring(m, n));
/* 1162 */       hashtable.put("password", paramString.substring(n + 1, i1));
/*      */     } 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1172 */     if (n <= i1 && (n == m || i1 == m))
/*      */     {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 1179 */       if (i1 < j) {
/*      */         
/* 1181 */         String str = paramString.substring(i1 + 1);
/* 1182 */         String[] arrayOfString = getSecretStoreCredentials(str);
/* 1183 */         if (arrayOfString[0] != null || arrayOfString[1] != null) {
/*      */           
/* 1185 */           hashtable.put("user", arrayOfString[0]);
/* 1186 */           hashtable.put("password", arrayOfString[1]);
/*      */         } 
/*      */       } 
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1194 */     if (i1 < j) {
/* 1195 */       hashtable.put("database", paramString.substring(i1 + 1));
/*      */     }
/*      */ 
/*      */ 
/*      */     
/* 1200 */     return hashtable;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private String[] getSecretStoreCredentials(String paramString) throws SQLException {
/* 1229 */     String[] arrayOfString = new String[2];
/* 1230 */     arrayOfString[0] = null;
/* 1231 */     arrayOfString[1] = null;
/*      */     
/* 1233 */     if (walletLocation != null) {
/*      */       
/*      */       try {
/*      */         
/* 1237 */         OracleWallet oracleWallet = new OracleWallet();
/* 1238 */         if (oracleWallet.exists(walletLocation)) {
/*      */           
/* 1240 */           oracleWallet.open(walletLocation, null);
/* 1241 */           OracleSecretStore oracleSecretStore = oracleWallet.getSecretStore();
/*      */ 
/*      */ 
/*      */           
/* 1245 */           if (oracleSecretStore.containsAlias("oracle.security.client.default_username")) {
/* 1246 */             arrayOfString[0] = new String(oracleSecretStore.getSecret("oracle.security.client.default_username"));
/*      */           }
/* 1248 */           if (oracleSecretStore.containsAlias("oracle.security.client.default_password")) {
/* 1249 */             arrayOfString[1] = new String(oracleSecretStore.getSecret("oracle.security.client.default_password"));
/*      */           }
/*      */           
/* 1252 */           Enumeration enumeration = oracleWallet.getSecretStore().internalAliases();
/*      */           
/* 1254 */           String str = null;
/* 1255 */           while (enumeration.hasMoreElements()) {
/*      */             
/* 1257 */             str = enumeration.nextElement();
/* 1258 */             if (str.startsWith("oracle.security.client.connect_string"))
/*      */             {
/* 1260 */               if (paramString.equalsIgnoreCase(new String(oracleSecretStore.getSecret(str)))) {
/*      */ 
/*      */                 
/* 1263 */                 String str1 = str.substring("oracle.security.client.connect_string".length());
/* 1264 */                 arrayOfString[0] = new String(oracleSecretStore.getSecret("oracle.security.client.username" + str1));
/*      */                 
/* 1266 */                 arrayOfString[1] = new String(oracleSecretStore.getSecret("oracle.security.client.password" + str1));
/*      */ 
/*      */                 
/*      */                 break;
/*      */               } 
/*      */             }
/*      */           } 
/*      */         } 
/* 1274 */       } catch (NoClassDefFoundError noClassDefFoundError) {
/*      */ 
/*      */ 
/*      */         
/* 1278 */         DatabaseError.throwSqlException(167);
/*      */       
/*      */       }
/* 1281 */       catch (Exception exception) {
/*      */         
/* 1283 */         if (exception instanceof RuntimeException) throw (RuntimeException)exception;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */         
/* 1295 */         DatabaseError.throwSqlException(168);
/*      */       } 
/*      */     }
/*      */ 
/*      */ 
/*      */     
/* 1301 */     return arrayOfString;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public static String getCompileTime() {
/* 1316 */     return "Sat_Feb__2_11:39:36_PST_2008";
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private String translateConnStr(String paramString) throws SQLException {
/* 1335 */     int i = 0;
/* 1336 */     int j = 0;
/*      */     
/* 1338 */     if (paramString == null) {
/* 1339 */       return paramString;
/*      */     }
/*      */ 
/*      */ 
/*      */     
/* 1344 */     if ((i = paramString.indexOf(':')) == -1 || (j = paramString.indexOf(':', i + 1)) == -1)
/*      */     {
/*      */       
/* 1347 */       return paramString;
/*      */     }
/*      */ 
/*      */     
/* 1351 */     if (paramString.indexOf(':', j + 1) != -1)
/*      */     {
/* 1353 */       DatabaseError.throwSqlException(67, paramString);
/*      */     }
/*      */     
/* 1356 */     String str1 = paramString.substring(0, i);
/* 1357 */     String str2 = paramString.substring(i + 1, j);
/* 1358 */     String str3 = paramString.substring(j + 1, paramString.length());
/*      */     
/* 1360 */     return "(DESCRIPTION=(ADDRESS=(PROTOCOL=tcp)(HOST=" + str1 + ")(PORT=" + str2 + "))(CONNECT_DATA=(SID=" + str3 + ")))";
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected static String getSystemPropertyUserName() {
/* 1375 */     return getSystemProperty("user.name", null);
/*      */   }
/*      */ 
/*      */   
/*      */   protected static String getSystemPropertyV8Compatible() {
/* 1380 */     return getSystemProperty("oracle.jdbc.V8Compatible", null);
/*      */   }
/*      */ 
/*      */   
/*      */   protected static String getSystemPropertyPollInterval() {
/* 1385 */     return getSystemProperty("oracle.jdbc.TimeoutPollInterval", "1000");
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public static String getSystemPropertyFastConnectionFailover(String paramString) {
/* 1391 */     return getSystemProperty("oracle.jdbc.FastConnectionFailover", paramString);
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public static String getSystemPropertyJserverVersion() {
/* 1397 */     return getSystemProperty("oracle.jserver.version", null);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private static String getSystemProperty(String paramString) {
/* 1410 */     return getSystemProperty(paramString, null);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private static String getSystemProperty(String paramString1, String paramString2) {
/* 1418 */     if (paramString1 != null) {
/*      */       
/* 1420 */       String str1 = paramString1;
/* 1421 */       String str2 = paramString2;
/* 1422 */       String[] arrayOfString = { paramString2 };
/* 1423 */       AccessController.doPrivileged(new PrivilegedAction(arrayOfString, str1, str2) {
/*      */             private final String[] val$rets;
/*      */             
/*      */             public Object run() {
/* 1427 */               this.val$rets[0] = System.getProperty(this.val$fstr, this.val$fdefaultValue);
/* 1428 */               return null;
/*      */             } private final String val$fstr; private final String val$fdefaultValue;
/*      */           });
/* 1431 */       return arrayOfString[0];
/*      */     } 
/*      */ 
/*      */ 
/*      */     
/* 1436 */     return paramString2;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 1445 */   private static final String _Copyright_2004_Oracle_All_Rights_Reserved_ = null;
/*      */   public static final boolean TRACE = false;
/*      */   public static final boolean PRIVATE_TRACE = false;
/*      */   public static final String BUILD_DATE = "Sat_Feb__2_11:39:36_PST_2008";
/*      */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\lib\ojdbc14.jar!\oracle\jdbc\driver\OracleDriver.class
 * Java compiler version: 2 (46.0)
 * JD-Core Version:       1.1.3
 */