/*      */ package oracle.jdbc.driver;
/*      */ 
/*      */ import java.io.IOException;
/*      */ import java.io.InputStream;
/*      */ import java.io.Reader;
/*      */ import java.math.BigDecimal;
/*      */ import java.net.URL;
/*      */ import java.sql.Array;
/*      */ import java.sql.Blob;
/*      */ import java.sql.Clob;
/*      */ import java.sql.Date;
/*      */ import java.sql.Ref;
/*      */ import java.sql.ResultSet;
/*      */ import java.sql.ResultSetMetaData;
/*      */ import java.sql.SQLException;
/*      */ import java.sql.Statement;
/*      */ import java.sql.Time;
/*      */ import java.sql.Timestamp;
/*      */ import java.util.Calendar;
/*      */ import java.util.Map;
/*      */ import oracle.sql.ARRAY;
/*      */ import oracle.sql.BFILE;
/*      */ import oracle.sql.BLOB;
/*      */ import oracle.sql.CHAR;
/*      */ import oracle.sql.CLOB;
/*      */ import oracle.sql.CustomDatum;
/*      */ import oracle.sql.CustomDatumFactory;
/*      */ import oracle.sql.DATE;
/*      */ import oracle.sql.Datum;
/*      */ import oracle.sql.INTERVALDS;
/*      */ import oracle.sql.INTERVALYM;
/*      */ import oracle.sql.NUMBER;
/*      */ import oracle.sql.OPAQUE;
/*      */ import oracle.sql.ORAData;
/*      */ import oracle.sql.ORADataFactory;
/*      */ import oracle.sql.RAW;
/*      */ import oracle.sql.REF;
/*      */ import oracle.sql.ROWID;
/*      */ import oracle.sql.STRUCT;
/*      */ import oracle.sql.TIMESTAMP;
/*      */ import oracle.sql.TIMESTAMPLTZ;
/*      */ import oracle.sql.TIMESTAMPTZ;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ class OracleResultSetImpl
/*      */   extends BaseResultSet
/*      */ {
/*      */   PhysicalConnection connection;
/*      */   OracleStatement statement;
/*      */   boolean closed;
/*      */   boolean explicitly_closed;
/*      */   boolean m_emptyRset;
/*      */   
/*      */   OracleResultSetImpl(PhysicalConnection paramPhysicalConnection, OracleStatement paramOracleStatement) throws SQLException {
/*   65 */     this.connection = paramPhysicalConnection;
/*   66 */     this.statement = paramOracleStatement;
/*   67 */     this.close_statement_on_close = false;
/*   68 */     this.closed = false;
/*   69 */     this.explicitly_closed = false;
/*   70 */     this.m_emptyRset = false;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void close() throws SQLException {
/*   86 */     internal_close(false);
/*      */ 
/*      */     
/*   89 */     if (this.close_statement_on_close) {
/*      */       
/*      */       try {
/*      */ 
/*      */ 
/*      */ 
/*      */         
/*   96 */         this.statement.close();
/*      */       }
/*   98 */       catch (SQLException sQLException) {}
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  105 */     this.explicitly_closed = true;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized boolean wasNull() throws SQLException {
/*  114 */     return this.statement.wasNullValue();
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized ResultSetMetaData getMetaData() throws SQLException {
/*  123 */     if (this.explicitly_closed) {
/*  124 */       DatabaseError.throwSqlException(10, "getMetaData");
/*      */     }
/*      */     
/*  127 */     if (this.statement.closed) {
/*  128 */       DatabaseError.throwSqlException(9, "getMetaData");
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  134 */     if (!this.statement.isOpen) {
/*  135 */       DatabaseError.throwSqlException(144, "getMetaData");
/*      */     }
/*      */     
/*  138 */     return (ResultSetMetaData)new OracleResultSetMetaData(this.connection, this.statement);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized Statement getStatement() throws SQLException {
/*  148 */     return (Statement)this.statement;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized boolean next() throws SQLException {
/*  169 */     boolean bool = true;
/*      */ 
/*      */     
/*  172 */     PhysicalConnection physicalConnection = this.statement.connection;
/*      */     
/*  174 */     if (this.explicitly_closed) {
/*  175 */       DatabaseError.throwSqlException(10, "next");
/*      */     }
/*      */ 
/*      */ 
/*      */     
/*  180 */     if (physicalConnection == null || physicalConnection.lifecycle != 1) {
/*  181 */       DatabaseError.throwSqlException(8, "next");
/*      */     }
/*      */ 
/*      */ 
/*      */     
/*  186 */     if (this.statement.closed) {
/*  187 */       DatabaseError.throwSqlException(9, "next");
/*      */     }
/*      */     
/*  190 */     if (this.statement.sqlKind == 1 || this.statement.sqlKind == 4)
/*      */     {
/*  192 */       DatabaseError.throwSqlException(166, "next");
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  198 */     if (this.closed) {
/*  199 */       return false;
/*      */     }
/*  201 */     this.statement.currentRow++;
/*  202 */     this.statement.totalRowsVisited++;
/*      */     
/*  204 */     if (this.statement.maxRows != 0 && this.statement.totalRowsVisited > this.statement.maxRows) {
/*      */ 
/*      */       
/*  207 */       internal_close(false);
/*      */       
/*  209 */       return false;
/*      */     } 
/*      */     
/*  212 */     if (this.statement.currentRow >= this.statement.validRows) {
/*  213 */       bool = close_or_fetch_from_next(false);
/*      */     }
/*  215 */     if (bool && physicalConnection.useFetchSizeWithLongColumn) {
/*  216 */       this.statement.reopenStreams();
/*      */     }
/*  218 */     return bool;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private boolean close_or_fetch_from_next(boolean paramBoolean) throws SQLException {
/*  227 */     if (paramBoolean) {
/*      */       
/*  229 */       internal_close(false);
/*      */       
/*  231 */       return false;
/*      */     } 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  238 */     if (this.statement.gotLastBatch) {
/*      */       
/*  240 */       internal_close(false);
/*      */       
/*  242 */       return false;
/*      */     } 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  249 */     this.statement.check_row_prefetch_changed();
/*      */     
/*  251 */     PhysicalConnection physicalConnection = this.statement.connection;
/*      */     
/*  253 */     if (physicalConnection.protocolId == 3) {
/*  254 */       this.sqlWarning = null;
/*      */     }
/*      */     else {
/*      */       
/*  258 */       if (this.statement.streamList != null)
/*      */       {
/*      */ 
/*      */         
/*  262 */         while (this.statement.nextStream != null) {
/*      */ 
/*      */           
/*      */           try {
/*  266 */             this.statement.nextStream.close();
/*      */           }
/*  268 */           catch (IOException iOException) {
/*      */             
/*  270 */             DatabaseError.throwSqlException(iOException);
/*      */           } 
/*      */           
/*  273 */           this.statement.nextStream = this.statement.nextStream.nextStream;
/*      */         } 
/*      */       }
/*      */       
/*  277 */       clearWarnings();
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*  287 */       physicalConnection.registerHeartbeat();
/*  288 */       physicalConnection.needLine();
/*      */     } 
/*      */ 
/*      */     
/*  292 */     synchronized (physicalConnection) {
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*  297 */       this.statement.fetch();
/*      */     } 
/*      */     
/*  300 */     if (this.statement.validRows == 0) {
/*      */       
/*  302 */       internal_close(false);
/*      */       
/*  304 */       return false;
/*      */     } 
/*      */ 
/*      */     
/*  308 */     this.statement.currentRow = 0;
/*      */     
/*  310 */     this.statement.checkValidRowsStatus();
/*      */     
/*  312 */     return true;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public boolean isBeforeFirst() throws SQLException {
/*  327 */     return (!isEmptyResultSet() && this.statement.currentRow == -1 && !this.closed);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public boolean isAfterLast() throws SQLException {
/*  337 */     return (!isEmptyResultSet() && this.closed);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public boolean isFirst() throws SQLException {
/*  346 */     return (getRow() == 1);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public boolean isLast() throws SQLException {
/*  355 */     DatabaseError.throwSqlException(75, "isLast");
/*      */ 
/*      */     
/*  358 */     return false;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public int getRow() throws SQLException {
/*  367 */     return this.statement.totalRowsVisited;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized String getString(int paramInt) throws SQLException {
/*  384 */     if (paramInt <= 0 || paramInt > this.statement.numberOfDefinePositions) {
/*  385 */       DatabaseError.throwSqlException(3);
/*      */     }
/*  387 */     if (this.closed) {
/*  388 */       DatabaseError.throwSqlException(11);
/*      */     }
/*  390 */     int i = this.statement.currentRow;
/*      */     
/*  392 */     if (i < 0) {
/*  393 */       DatabaseError.throwSqlException(14);
/*      */     }
/*  395 */     this.statement.lastIndex = paramInt;
/*      */     
/*  397 */     if (this.statement.streamList != null)
/*      */     {
/*  399 */       this.statement.closeUsedStreams(paramInt);
/*      */     }
/*      */ 
/*      */     
/*  403 */     return this.statement.accessors[paramInt - 1].getString(i);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized boolean getBoolean(int paramInt) throws SQLException {
/*  416 */     if (paramInt <= 0 || paramInt > this.statement.numberOfDefinePositions) {
/*  417 */       DatabaseError.throwSqlException(3);
/*      */     }
/*  419 */     if (this.closed) {
/*  420 */       DatabaseError.throwSqlException(11);
/*      */     }
/*  422 */     int i = this.statement.currentRow;
/*      */     
/*  424 */     if (i < 0) {
/*  425 */       DatabaseError.throwSqlException(14);
/*      */     }
/*  427 */     this.statement.lastIndex = paramInt;
/*      */     
/*  429 */     if (this.statement.streamList != null)
/*      */     {
/*  431 */       this.statement.closeUsedStreams(paramInt);
/*      */     }
/*      */ 
/*      */     
/*  435 */     return this.statement.accessors[paramInt - 1].getBoolean(i);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized byte getByte(int paramInt) throws SQLException {
/*  445 */     if (paramInt <= 0 || paramInt > this.statement.numberOfDefinePositions) {
/*  446 */       DatabaseError.throwSqlException(3);
/*      */     }
/*  448 */     if (this.closed) {
/*  449 */       DatabaseError.throwSqlException(11);
/*      */     }
/*  451 */     int i = this.statement.currentRow;
/*      */     
/*  453 */     if (i < 0) {
/*  454 */       DatabaseError.throwSqlException(14);
/*      */     }
/*  456 */     this.statement.lastIndex = paramInt;
/*      */     
/*  458 */     if (this.statement.streamList != null)
/*      */     {
/*  460 */       this.statement.closeUsedStreams(paramInt);
/*      */     }
/*      */ 
/*      */     
/*  464 */     return this.statement.accessors[paramInt - 1].getByte(i);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized short getShort(int paramInt) throws SQLException {
/*  474 */     if (paramInt <= 0 || paramInt > this.statement.numberOfDefinePositions) {
/*  475 */       DatabaseError.throwSqlException(3);
/*      */     }
/*  477 */     if (this.closed) {
/*  478 */       DatabaseError.throwSqlException(11);
/*      */     }
/*  480 */     int i = this.statement.currentRow;
/*      */     
/*  482 */     if (i < 0) {
/*  483 */       DatabaseError.throwSqlException(14);
/*      */     }
/*  485 */     this.statement.lastIndex = paramInt;
/*      */     
/*  487 */     if (this.statement.streamList != null)
/*      */     {
/*  489 */       this.statement.closeUsedStreams(paramInt);
/*      */     }
/*      */ 
/*      */     
/*  493 */     return this.statement.accessors[paramInt - 1].getShort(i);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized int getInt(int paramInt) throws SQLException {
/*  508 */     if (paramInt <= 0 || paramInt > this.statement.numberOfDefinePositions) {
/*  509 */       DatabaseError.throwSqlException(3);
/*      */     }
/*  511 */     if (this.closed) {
/*  512 */       DatabaseError.throwSqlException(11);
/*      */     }
/*  514 */     int i = this.statement.currentRow;
/*      */     
/*  516 */     if (i < 0) {
/*  517 */       DatabaseError.throwSqlException(14);
/*      */     }
/*  519 */     this.statement.lastIndex = paramInt;
/*      */     
/*  521 */     if (this.statement.streamList != null)
/*      */     {
/*  523 */       this.statement.closeUsedStreams(paramInt);
/*      */     }
/*      */ 
/*      */     
/*  527 */     return this.statement.accessors[paramInt - 1].getInt(i);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized long getLong(int paramInt) throws SQLException {
/*  539 */     if (paramInt <= 0 || paramInt > this.statement.numberOfDefinePositions) {
/*  540 */       DatabaseError.throwSqlException(3);
/*      */     }
/*  542 */     if (this.closed) {
/*  543 */       DatabaseError.throwSqlException(11);
/*      */     }
/*  545 */     int i = this.statement.currentRow;
/*      */     
/*  547 */     if (i < 0) {
/*  548 */       DatabaseError.throwSqlException(14);
/*      */     }
/*  550 */     this.statement.lastIndex = paramInt;
/*      */     
/*  552 */     if (this.statement.streamList != null)
/*      */     {
/*  554 */       this.statement.closeUsedStreams(paramInt);
/*      */     }
/*      */ 
/*      */     
/*  558 */     return this.statement.accessors[paramInt - 1].getLong(i);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized float getFloat(int paramInt) throws SQLException {
/*  568 */     if (paramInt <= 0 || paramInt > this.statement.numberOfDefinePositions) {
/*  569 */       DatabaseError.throwSqlException(3);
/*      */     }
/*  571 */     if (this.closed) {
/*  572 */       DatabaseError.throwSqlException(11);
/*      */     }
/*  574 */     int i = this.statement.currentRow;
/*      */     
/*  576 */     if (i < 0) {
/*  577 */       DatabaseError.throwSqlException(14);
/*      */     }
/*  579 */     this.statement.lastIndex = paramInt;
/*      */     
/*  581 */     if (this.statement.streamList != null)
/*      */     {
/*  583 */       this.statement.closeUsedStreams(paramInt);
/*      */     }
/*      */ 
/*      */     
/*  587 */     return this.statement.accessors[paramInt - 1].getFloat(i);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized double getDouble(int paramInt) throws SQLException {
/*  597 */     if (paramInt <= 0 || paramInt > this.statement.numberOfDefinePositions) {
/*  598 */       DatabaseError.throwSqlException(3);
/*      */     }
/*  600 */     if (this.closed) {
/*  601 */       DatabaseError.throwSqlException(11);
/*      */     }
/*  603 */     int i = this.statement.currentRow;
/*      */     
/*  605 */     if (i < 0) {
/*  606 */       DatabaseError.throwSqlException(14);
/*      */     }
/*  608 */     this.statement.lastIndex = paramInt;
/*      */     
/*  610 */     if (this.statement.streamList != null)
/*      */     {
/*  612 */       this.statement.closeUsedStreams(paramInt);
/*      */     }
/*      */ 
/*      */     
/*  616 */     return this.statement.accessors[paramInt - 1].getDouble(i);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized BigDecimal getBigDecimal(int paramInt1, int paramInt2) throws SQLException {
/*  627 */     if (paramInt1 <= 0 || paramInt1 > this.statement.numberOfDefinePositions) {
/*  628 */       DatabaseError.throwSqlException(3);
/*      */     }
/*  630 */     if (this.closed) {
/*  631 */       DatabaseError.throwSqlException(11);
/*      */     }
/*  633 */     int i = this.statement.currentRow;
/*      */     
/*  635 */     if (i < 0) {
/*  636 */       DatabaseError.throwSqlException(14);
/*      */     }
/*  638 */     this.statement.lastIndex = paramInt1;
/*      */     
/*  640 */     if (this.statement.streamList != null)
/*      */     {
/*  642 */       this.statement.closeUsedStreams(paramInt1);
/*      */     }
/*      */ 
/*      */     
/*  646 */     return this.statement.accessors[paramInt1 - 1].getBigDecimal(this.statement.currentRow, paramInt2);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   synchronized byte[] privateGetBytes(int paramInt) throws SQLException {
/*  666 */     if (paramInt <= 0 || paramInt > this.statement.numberOfDefinePositions) {
/*  667 */       DatabaseError.throwSqlException(3);
/*      */     }
/*  669 */     if (this.closed) {
/*  670 */       DatabaseError.throwSqlException(11);
/*      */     }
/*  672 */     int i = this.statement.currentRow;
/*      */     
/*  674 */     if (i < 0) {
/*  675 */       DatabaseError.throwSqlException(14);
/*      */     }
/*  677 */     this.statement.lastIndex = paramInt;
/*      */     
/*  679 */     if (this.statement.streamList != null)
/*      */     {
/*  681 */       this.statement.closeUsedStreams(paramInt);
/*      */     }
/*      */ 
/*      */     
/*  685 */     return this.statement.accessors[paramInt - 1].privateGetBytes(i);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized byte[] getBytes(int paramInt) throws SQLException {
/*  695 */     if (paramInt <= 0 || paramInt > this.statement.numberOfDefinePositions) {
/*  696 */       DatabaseError.throwSqlException(3);
/*      */     }
/*  698 */     if (this.closed) {
/*  699 */       DatabaseError.throwSqlException(11);
/*      */     }
/*  701 */     int i = this.statement.currentRow;
/*      */     
/*  703 */     if (i < 0) {
/*  704 */       DatabaseError.throwSqlException(14);
/*      */     }
/*  706 */     this.statement.lastIndex = paramInt;
/*      */     
/*  708 */     if (this.statement.streamList != null)
/*      */     {
/*  710 */       this.statement.closeUsedStreams(paramInt);
/*      */     }
/*      */ 
/*      */     
/*  714 */     return this.statement.accessors[paramInt - 1].getBytes(i);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized Date getDate(int paramInt) throws SQLException {
/*  724 */     if (paramInt <= 0 || paramInt > this.statement.numberOfDefinePositions) {
/*  725 */       DatabaseError.throwSqlException(3);
/*      */     }
/*  727 */     if (this.closed) {
/*  728 */       DatabaseError.throwSqlException(11);
/*      */     }
/*  730 */     int i = this.statement.currentRow;
/*      */     
/*  732 */     if (i < 0) {
/*  733 */       DatabaseError.throwSqlException(14);
/*      */     }
/*  735 */     this.statement.lastIndex = paramInt;
/*      */     
/*  737 */     if (this.statement.streamList != null)
/*      */     {
/*  739 */       this.statement.closeUsedStreams(paramInt);
/*      */     }
/*      */ 
/*      */     
/*  743 */     return this.statement.accessors[paramInt - 1].getDate(i);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized Time getTime(int paramInt) throws SQLException {
/*  753 */     if (paramInt <= 0 || paramInt > this.statement.numberOfDefinePositions) {
/*  754 */       DatabaseError.throwSqlException(3);
/*      */     }
/*  756 */     if (this.closed) {
/*  757 */       DatabaseError.throwSqlException(11);
/*      */     }
/*  759 */     int i = this.statement.currentRow;
/*      */     
/*  761 */     if (i < 0) {
/*  762 */       DatabaseError.throwSqlException(14);
/*      */     }
/*  764 */     this.statement.lastIndex = paramInt;
/*      */     
/*  766 */     if (this.statement.streamList != null)
/*      */     {
/*  768 */       this.statement.closeUsedStreams(paramInt);
/*      */     }
/*      */ 
/*      */     
/*  772 */     return this.statement.accessors[paramInt - 1].getTime(i);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized Timestamp getTimestamp(int paramInt) throws SQLException {
/*  783 */     if (paramInt <= 0 || paramInt > this.statement.numberOfDefinePositions) {
/*  784 */       DatabaseError.throwSqlException(3);
/*      */     }
/*  786 */     if (this.closed) {
/*  787 */       DatabaseError.throwSqlException(11);
/*      */     }
/*  789 */     int i = this.statement.currentRow;
/*      */     
/*  791 */     if (i < 0) {
/*  792 */       DatabaseError.throwSqlException(14);
/*      */     }
/*  794 */     this.statement.lastIndex = paramInt;
/*      */     
/*  796 */     if (this.statement.streamList != null)
/*      */     {
/*  798 */       this.statement.closeUsedStreams(paramInt);
/*      */     }
/*      */ 
/*      */     
/*  802 */     return this.statement.accessors[paramInt - 1].getTimestamp(i);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized InputStream getAsciiStream(int paramInt) throws SQLException {
/*  813 */     if (paramInt <= 0 || paramInt > this.statement.numberOfDefinePositions) {
/*  814 */       DatabaseError.throwSqlException(3);
/*      */     }
/*  816 */     if (this.closed) {
/*  817 */       DatabaseError.throwSqlException(11);
/*      */     }
/*  819 */     int i = this.statement.currentRow;
/*      */     
/*  821 */     if (i < 0) {
/*  822 */       DatabaseError.throwSqlException(14);
/*      */     }
/*  824 */     this.statement.lastIndex = paramInt;
/*      */     
/*  826 */     if (this.statement.streamList != null)
/*      */     {
/*  828 */       this.statement.closeUsedStreams(paramInt);
/*      */     }
/*      */ 
/*      */     
/*  832 */     return this.statement.accessors[paramInt - 1].getAsciiStream(i);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized InputStream getUnicodeStream(int paramInt) throws SQLException {
/*  843 */     if (paramInt <= 0 || paramInt > this.statement.numberOfDefinePositions) {
/*  844 */       DatabaseError.throwSqlException(3);
/*      */     }
/*  846 */     if (this.closed) {
/*  847 */       DatabaseError.throwSqlException(11);
/*      */     }
/*  849 */     int i = this.statement.currentRow;
/*      */     
/*  851 */     if (i < 0) {
/*  852 */       DatabaseError.throwSqlException(14);
/*      */     }
/*  854 */     this.statement.lastIndex = paramInt;
/*      */     
/*  856 */     if (this.statement.streamList != null)
/*      */     {
/*  858 */       this.statement.closeUsedStreams(paramInt);
/*      */     }
/*      */ 
/*      */     
/*  862 */     return this.statement.accessors[paramInt - 1].getUnicodeStream(i);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized InputStream getBinaryStream(int paramInt) throws SQLException {
/*  873 */     if (paramInt <= 0 || paramInt > this.statement.numberOfDefinePositions) {
/*  874 */       DatabaseError.throwSqlException(3);
/*      */     }
/*  876 */     if (this.closed) {
/*  877 */       DatabaseError.throwSqlException(11);
/*      */     }
/*  879 */     int i = this.statement.currentRow;
/*      */     
/*  881 */     if (i < 0) {
/*  882 */       DatabaseError.throwSqlException(14);
/*      */     }
/*  884 */     this.statement.lastIndex = paramInt;
/*      */     
/*  886 */     if (this.statement.streamList != null)
/*      */     {
/*  888 */       this.statement.closeUsedStreams(paramInt);
/*      */     }
/*      */ 
/*      */     
/*  892 */     return this.statement.accessors[paramInt - 1].getBinaryStream(i);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized Object getObject(int paramInt) throws SQLException {
/*  902 */     if (paramInt <= 0 || paramInt > this.statement.numberOfDefinePositions) {
/*  903 */       DatabaseError.throwSqlException(3);
/*      */     }
/*  905 */     if (this.closed) {
/*  906 */       DatabaseError.throwSqlException(11);
/*      */     }
/*  908 */     int i = this.statement.currentRow;
/*      */     
/*  910 */     if (i < 0) {
/*  911 */       DatabaseError.throwSqlException(14);
/*      */     }
/*  913 */     this.statement.lastIndex = paramInt;
/*      */     
/*  915 */     if (this.statement.streamList != null)
/*      */     {
/*  917 */       this.statement.closeUsedStreams(paramInt);
/*      */     }
/*      */ 
/*      */     
/*  921 */     return this.statement.accessors[paramInt - 1].getObject(i);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized ResultSet getCursor(int paramInt) throws SQLException {
/*  932 */     if (paramInt <= 0 || paramInt > this.statement.numberOfDefinePositions) {
/*  933 */       DatabaseError.throwSqlException(3);
/*      */     }
/*  935 */     if (this.closed) {
/*  936 */       DatabaseError.throwSqlException(11);
/*      */     }
/*  938 */     int i = this.statement.currentRow;
/*      */     
/*  940 */     if (i < 0) {
/*  941 */       DatabaseError.throwSqlException(14);
/*      */     }
/*  943 */     this.statement.lastIndex = paramInt;
/*      */     
/*  945 */     if (this.statement.streamList != null)
/*      */     {
/*  947 */       this.statement.closeUsedStreams(paramInt);
/*      */     }
/*      */ 
/*      */     
/*  951 */     return this.statement.accessors[paramInt - 1].getCursor(i);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized Datum getOracleObject(int paramInt) throws SQLException {
/*  962 */     if (paramInt <= 0 || paramInt > this.statement.numberOfDefinePositions) {
/*  963 */       DatabaseError.throwSqlException(3);
/*      */     }
/*  965 */     if (this.closed) {
/*  966 */       DatabaseError.throwSqlException(11);
/*      */     }
/*  968 */     int i = this.statement.currentRow;
/*      */     
/*  970 */     if (i < 0) {
/*  971 */       DatabaseError.throwSqlException(14);
/*      */     }
/*  973 */     this.statement.lastIndex = paramInt;
/*      */     
/*  975 */     if (this.statement.streamList != null)
/*      */     {
/*  977 */       this.statement.closeUsedStreams(paramInt);
/*      */     }
/*      */ 
/*      */     
/*  981 */     return this.statement.accessors[paramInt - 1].getOracleObject(i);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized ROWID getROWID(int paramInt) throws SQLException {
/*  992 */     if (paramInt <= 0 || paramInt > this.statement.numberOfDefinePositions) {
/*  993 */       DatabaseError.throwSqlException(3);
/*      */     }
/*  995 */     if (this.closed) {
/*  996 */       DatabaseError.throwSqlException(11);
/*      */     }
/*  998 */     int i = this.statement.currentRow;
/*      */     
/* 1000 */     if (i < 0) {
/* 1001 */       DatabaseError.throwSqlException(14);
/*      */     }
/* 1003 */     this.statement.lastIndex = paramInt;
/*      */     
/* 1005 */     if (this.statement.streamList != null)
/*      */     {
/* 1007 */       this.statement.closeUsedStreams(paramInt);
/*      */     }
/*      */ 
/*      */     
/* 1011 */     return this.statement.accessors[paramInt - 1].getROWID(i);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized NUMBER getNUMBER(int paramInt) throws SQLException {
/* 1022 */     if (paramInt <= 0 || paramInt > this.statement.numberOfDefinePositions) {
/* 1023 */       DatabaseError.throwSqlException(3);
/*      */     }
/* 1025 */     if (this.closed) {
/* 1026 */       DatabaseError.throwSqlException(11);
/*      */     }
/* 1028 */     int i = this.statement.currentRow;
/*      */     
/* 1030 */     if (i < 0) {
/* 1031 */       DatabaseError.throwSqlException(14);
/*      */     }
/* 1033 */     this.statement.lastIndex = paramInt;
/*      */     
/* 1035 */     if (this.statement.streamList != null)
/*      */     {
/* 1037 */       this.statement.closeUsedStreams(paramInt);
/*      */     }
/*      */ 
/*      */     
/* 1041 */     return this.statement.accessors[paramInt - 1].getNUMBER(i);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized DATE getDATE(int paramInt) throws SQLException {
/* 1052 */     if (paramInt <= 0 || paramInt > this.statement.numberOfDefinePositions) {
/* 1053 */       DatabaseError.throwSqlException(3);
/*      */     }
/* 1055 */     if (this.closed) {
/* 1056 */       DatabaseError.throwSqlException(11);
/*      */     }
/* 1058 */     int i = this.statement.currentRow;
/*      */     
/* 1060 */     if (i < 0) {
/* 1061 */       DatabaseError.throwSqlException(14);
/*      */     }
/* 1063 */     this.statement.lastIndex = paramInt;
/*      */     
/* 1065 */     if (this.statement.streamList != null)
/*      */     {
/* 1067 */       this.statement.closeUsedStreams(paramInt);
/*      */     }
/*      */ 
/*      */     
/* 1071 */     return this.statement.accessors[paramInt - 1].getDATE(i);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized ARRAY getARRAY(int paramInt) throws SQLException {
/* 1082 */     if (paramInt <= 0 || paramInt > this.statement.numberOfDefinePositions) {
/* 1083 */       DatabaseError.throwSqlException(3);
/*      */     }
/* 1085 */     if (this.closed) {
/* 1086 */       DatabaseError.throwSqlException(11);
/*      */     }
/* 1088 */     int i = this.statement.currentRow;
/*      */     
/* 1090 */     if (i < 0) {
/* 1091 */       DatabaseError.throwSqlException(14);
/*      */     }
/* 1093 */     this.statement.lastIndex = paramInt;
/*      */     
/* 1095 */     if (this.statement.streamList != null)
/*      */     {
/* 1097 */       this.statement.closeUsedStreams(paramInt);
/*      */     }
/*      */ 
/*      */     
/* 1101 */     return this.statement.accessors[paramInt - 1].getARRAY(i);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized STRUCT getSTRUCT(int paramInt) throws SQLException {
/* 1112 */     if (paramInt <= 0 || paramInt > this.statement.numberOfDefinePositions) {
/* 1113 */       DatabaseError.throwSqlException(3);
/*      */     }
/* 1115 */     if (this.closed) {
/* 1116 */       DatabaseError.throwSqlException(11);
/*      */     }
/* 1118 */     int i = this.statement.currentRow;
/*      */     
/* 1120 */     if (i < 0) {
/* 1121 */       DatabaseError.throwSqlException(14);
/*      */     }
/* 1123 */     this.statement.lastIndex = paramInt;
/*      */     
/* 1125 */     if (this.statement.streamList != null)
/*      */     {
/* 1127 */       this.statement.closeUsedStreams(paramInt);
/*      */     }
/*      */ 
/*      */     
/* 1131 */     return this.statement.accessors[paramInt - 1].getSTRUCT(i);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized OPAQUE getOPAQUE(int paramInt) throws SQLException {
/* 1142 */     if (paramInt <= 0 || paramInt > this.statement.numberOfDefinePositions) {
/* 1143 */       DatabaseError.throwSqlException(3);
/*      */     }
/* 1145 */     if (this.closed) {
/* 1146 */       DatabaseError.throwSqlException(11);
/*      */     }
/* 1148 */     int i = this.statement.currentRow;
/*      */     
/* 1150 */     if (i < 0) {
/* 1151 */       DatabaseError.throwSqlException(14);
/*      */     }
/* 1153 */     this.statement.lastIndex = paramInt;
/*      */     
/* 1155 */     if (this.statement.streamList != null)
/*      */     {
/* 1157 */       this.statement.closeUsedStreams(paramInt);
/*      */     }
/*      */ 
/*      */     
/* 1161 */     return this.statement.accessors[paramInt - 1].getOPAQUE(i);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized REF getREF(int paramInt) throws SQLException {
/* 1172 */     if (paramInt <= 0 || paramInt > this.statement.numberOfDefinePositions) {
/* 1173 */       DatabaseError.throwSqlException(3);
/*      */     }
/* 1175 */     if (this.closed) {
/* 1176 */       DatabaseError.throwSqlException(11);
/*      */     }
/* 1178 */     int i = this.statement.currentRow;
/*      */     
/* 1180 */     if (i < 0) {
/* 1181 */       DatabaseError.throwSqlException(14);
/*      */     }
/* 1183 */     this.statement.lastIndex = paramInt;
/*      */     
/* 1185 */     if (this.statement.streamList != null)
/*      */     {
/* 1187 */       this.statement.closeUsedStreams(paramInt);
/*      */     }
/*      */ 
/*      */     
/* 1191 */     return this.statement.accessors[paramInt - 1].getREF(i);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized CHAR getCHAR(int paramInt) throws SQLException {
/* 1202 */     if (paramInt <= 0 || paramInt > this.statement.numberOfDefinePositions) {
/* 1203 */       DatabaseError.throwSqlException(3);
/*      */     }
/* 1205 */     if (this.closed) {
/* 1206 */       DatabaseError.throwSqlException(11);
/*      */     }
/* 1208 */     int i = this.statement.currentRow;
/*      */     
/* 1210 */     if (i < 0) {
/* 1211 */       DatabaseError.throwSqlException(14);
/*      */     }
/* 1213 */     this.statement.lastIndex = paramInt;
/*      */     
/* 1215 */     if (this.statement.streamList != null)
/*      */     {
/* 1217 */       this.statement.closeUsedStreams(paramInt);
/*      */     }
/*      */ 
/*      */     
/* 1221 */     return this.statement.accessors[paramInt - 1].getCHAR(i);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized RAW getRAW(int paramInt) throws SQLException {
/* 1232 */     if (paramInt <= 0 || paramInt > this.statement.numberOfDefinePositions) {
/* 1233 */       DatabaseError.throwSqlException(3);
/*      */     }
/* 1235 */     if (this.closed) {
/* 1236 */       DatabaseError.throwSqlException(11);
/*      */     }
/* 1238 */     int i = this.statement.currentRow;
/*      */     
/* 1240 */     if (i < 0) {
/* 1241 */       DatabaseError.throwSqlException(14);
/*      */     }
/* 1243 */     this.statement.lastIndex = paramInt;
/*      */     
/* 1245 */     if (this.statement.streamList != null)
/*      */     {
/* 1247 */       this.statement.closeUsedStreams(paramInt);
/*      */     }
/*      */ 
/*      */     
/* 1251 */     return this.statement.accessors[paramInt - 1].getRAW(i);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized BLOB getBLOB(int paramInt) throws SQLException {
/* 1262 */     if (paramInt <= 0 || paramInt > this.statement.numberOfDefinePositions) {
/* 1263 */       DatabaseError.throwSqlException(3);
/*      */     }
/* 1265 */     if (this.closed) {
/* 1266 */       DatabaseError.throwSqlException(11);
/*      */     }
/* 1268 */     int i = this.statement.currentRow;
/*      */     
/* 1270 */     if (i < 0) {
/* 1271 */       DatabaseError.throwSqlException(14);
/*      */     }
/* 1273 */     this.statement.lastIndex = paramInt;
/*      */     
/* 1275 */     if (this.statement.streamList != null)
/*      */     {
/* 1277 */       this.statement.closeUsedStreams(paramInt);
/*      */     }
/*      */ 
/*      */     
/* 1281 */     return this.statement.accessors[paramInt - 1].getBLOB(i);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized CLOB getCLOB(int paramInt) throws SQLException {
/* 1292 */     if (paramInt <= 0 || paramInt > this.statement.numberOfDefinePositions) {
/* 1293 */       DatabaseError.throwSqlException(3);
/*      */     }
/* 1295 */     if (this.closed) {
/* 1296 */       DatabaseError.throwSqlException(11);
/*      */     }
/* 1298 */     int i = this.statement.currentRow;
/*      */     
/* 1300 */     if (i < 0) {
/* 1301 */       DatabaseError.throwSqlException(14);
/*      */     }
/* 1303 */     this.statement.lastIndex = paramInt;
/*      */     
/* 1305 */     if (this.statement.streamList != null)
/*      */     {
/* 1307 */       this.statement.closeUsedStreams(paramInt);
/*      */     }
/*      */ 
/*      */     
/* 1311 */     return this.statement.accessors[paramInt - 1].getCLOB(i);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized BFILE getBFILE(int paramInt) throws SQLException {
/* 1322 */     if (paramInt <= 0 || paramInt > this.statement.numberOfDefinePositions) {
/* 1323 */       DatabaseError.throwSqlException(3);
/*      */     }
/* 1325 */     if (this.closed) {
/* 1326 */       DatabaseError.throwSqlException(11);
/*      */     }
/* 1328 */     int i = this.statement.currentRow;
/*      */     
/* 1330 */     if (i < 0) {
/* 1331 */       DatabaseError.throwSqlException(14);
/*      */     }
/* 1333 */     this.statement.lastIndex = paramInt;
/*      */     
/* 1335 */     if (this.statement.streamList != null)
/*      */     {
/* 1337 */       this.statement.closeUsedStreams(paramInt);
/*      */     }
/*      */ 
/*      */     
/* 1341 */     return this.statement.accessors[paramInt - 1].getBFILE(i);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized BFILE getBfile(int paramInt) throws SQLException {
/* 1352 */     return getBFILE(paramInt);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized CustomDatum getCustomDatum(int paramInt, CustomDatumFactory paramCustomDatumFactory) throws SQLException {
/* 1364 */     if (paramInt <= 0 || paramInt > this.statement.numberOfDefinePositions) {
/* 1365 */       DatabaseError.throwSqlException(3);
/*      */     }
/* 1367 */     if (this.closed) {
/* 1368 */       DatabaseError.throwSqlException(11);
/*      */     }
/* 1370 */     int i = this.statement.currentRow;
/*      */     
/* 1372 */     if (i < 0) {
/* 1373 */       DatabaseError.throwSqlException(14);
/*      */     }
/* 1375 */     this.statement.lastIndex = paramInt;
/*      */     
/* 1377 */     if (this.statement.streamList != null)
/*      */     {
/* 1379 */       this.statement.closeUsedStreams(paramInt);
/*      */     }
/*      */ 
/*      */     
/* 1383 */     return this.statement.accessors[paramInt - 1].getCustomDatum(this.statement.currentRow, paramCustomDatumFactory);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized ORAData getORAData(int paramInt, ORADataFactory paramORADataFactory) throws SQLException {
/* 1395 */     if (paramInt <= 0 || paramInt > this.statement.numberOfDefinePositions) {
/* 1396 */       DatabaseError.throwSqlException(3);
/*      */     }
/* 1398 */     if (this.closed) {
/* 1399 */       DatabaseError.throwSqlException(11);
/*      */     }
/* 1401 */     int i = this.statement.currentRow;
/*      */     
/* 1403 */     if (i < 0) {
/* 1404 */       DatabaseError.throwSqlException(14);
/*      */     }
/* 1406 */     this.statement.lastIndex = paramInt;
/*      */     
/* 1408 */     if (this.statement.streamList != null)
/*      */     {
/* 1410 */       this.statement.closeUsedStreams(paramInt);
/*      */     }
/*      */ 
/*      */     
/* 1414 */     return this.statement.accessors[paramInt - 1].getORAData(this.statement.currentRow, paramORADataFactory);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized Object getObject(int paramInt, Map paramMap) throws SQLException {
/* 1427 */     if (paramInt <= 0 || paramInt > this.statement.numberOfDefinePositions) {
/* 1428 */       DatabaseError.throwSqlException(3);
/*      */     }
/* 1430 */     if (this.closed) {
/* 1431 */       DatabaseError.throwSqlException(11);
/*      */     }
/* 1433 */     int i = this.statement.currentRow;
/*      */     
/* 1435 */     if (i < 0) {
/* 1436 */       DatabaseError.throwSqlException(14);
/*      */     }
/* 1438 */     this.statement.lastIndex = paramInt;
/*      */     
/* 1440 */     if (this.statement.streamList != null)
/*      */     {
/* 1442 */       this.statement.closeUsedStreams(paramInt);
/*      */     }
/*      */ 
/*      */     
/* 1446 */     return this.statement.accessors[paramInt - 1].getObject(this.statement.currentRow, paramMap);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized Ref getRef(int paramInt) throws SQLException {
/* 1457 */     return (Ref)getREF(paramInt);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized Blob getBlob(int paramInt) throws SQLException {
/* 1467 */     return (Blob)getBLOB(paramInt);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized Clob getClob(int paramInt) throws SQLException {
/* 1477 */     return (Clob)getCLOB(paramInt);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized Array getArray(int paramInt) throws SQLException {
/* 1488 */     return (Array)getARRAY(paramInt);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized Reader getCharacterStream(int paramInt) throws SQLException {
/* 1500 */     if (paramInt <= 0 || paramInt > this.statement.numberOfDefinePositions) {
/* 1501 */       DatabaseError.throwSqlException(3);
/*      */     }
/* 1503 */     if (this.closed) {
/* 1504 */       DatabaseError.throwSqlException(11);
/*      */     }
/* 1506 */     int i = this.statement.currentRow;
/*      */     
/* 1508 */     if (i < 0) {
/* 1509 */       DatabaseError.throwSqlException(14);
/*      */     }
/* 1511 */     this.statement.lastIndex = paramInt;
/*      */     
/* 1513 */     if (this.statement.streamList != null)
/*      */     {
/* 1515 */       this.statement.closeUsedStreams(paramInt);
/*      */     }
/*      */ 
/*      */     
/* 1519 */     return this.statement.accessors[paramInt - 1].getCharacterStream(i);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public BigDecimal getBigDecimal(int paramInt) throws SQLException {
/* 1530 */     if (paramInt <= 0 || paramInt > this.statement.numberOfDefinePositions) {
/* 1531 */       DatabaseError.throwSqlException(3);
/*      */     }
/* 1533 */     if (this.closed) {
/* 1534 */       DatabaseError.throwSqlException(11);
/*      */     }
/* 1536 */     int i = this.statement.currentRow;
/*      */     
/* 1538 */     if (i < 0) {
/* 1539 */       DatabaseError.throwSqlException(14);
/*      */     }
/* 1541 */     this.statement.lastIndex = paramInt;
/*      */     
/* 1543 */     if (this.statement.streamList != null)
/*      */     {
/* 1545 */       this.statement.closeUsedStreams(paramInt);
/*      */     }
/*      */ 
/*      */     
/* 1549 */     return this.statement.accessors[paramInt - 1].getBigDecimal(i);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Date getDate(int paramInt, Calendar paramCalendar) throws SQLException {
/* 1561 */     if (paramInt <= 0 || paramInt > this.statement.numberOfDefinePositions) {
/* 1562 */       DatabaseError.throwSqlException(3);
/*      */     }
/* 1564 */     if (this.closed) {
/* 1565 */       DatabaseError.throwSqlException(11);
/*      */     }
/* 1567 */     int i = this.statement.currentRow;
/*      */     
/* 1569 */     if (i < 0) {
/* 1570 */       DatabaseError.throwSqlException(14);
/*      */     }
/* 1572 */     this.statement.lastIndex = paramInt;
/*      */     
/* 1574 */     if (this.statement.streamList != null)
/*      */     {
/* 1576 */       this.statement.closeUsedStreams(paramInt);
/*      */     }
/*      */ 
/*      */     
/* 1580 */     return this.statement.accessors[paramInt - 1].getDate(this.statement.currentRow, paramCalendar);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Time getTime(int paramInt, Calendar paramCalendar) throws SQLException {
/* 1593 */     if (paramInt <= 0 || paramInt > this.statement.numberOfDefinePositions) {
/* 1594 */       DatabaseError.throwSqlException(3);
/*      */     }
/* 1596 */     if (this.closed) {
/* 1597 */       DatabaseError.throwSqlException(11);
/*      */     }
/* 1599 */     int i = this.statement.currentRow;
/*      */     
/* 1601 */     if (i < 0) {
/* 1602 */       DatabaseError.throwSqlException(14);
/*      */     }
/* 1604 */     this.statement.lastIndex = paramInt;
/*      */     
/* 1606 */     if (this.statement.streamList != null)
/*      */     {
/* 1608 */       this.statement.closeUsedStreams(paramInt);
/*      */     }
/*      */ 
/*      */     
/* 1612 */     return this.statement.accessors[paramInt - 1].getTime(this.statement.currentRow, paramCalendar);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Timestamp getTimestamp(int paramInt, Calendar paramCalendar) throws SQLException {
/* 1625 */     if (paramInt <= 0 || paramInt > this.statement.numberOfDefinePositions) {
/* 1626 */       DatabaseError.throwSqlException(3);
/*      */     }
/* 1628 */     if (this.closed) {
/* 1629 */       DatabaseError.throwSqlException(11);
/*      */     }
/* 1631 */     int i = this.statement.currentRow;
/*      */     
/* 1633 */     if (i < 0) {
/* 1634 */       DatabaseError.throwSqlException(14);
/*      */     }
/* 1636 */     this.statement.lastIndex = paramInt;
/*      */     
/* 1638 */     if (this.statement.streamList != null)
/*      */     {
/* 1640 */       this.statement.closeUsedStreams(paramInt);
/*      */     }
/*      */ 
/*      */     
/* 1644 */     return this.statement.accessors[paramInt - 1].getTimestamp(this.statement.currentRow, paramCalendar);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public INTERVALYM getINTERVALYM(int paramInt) throws SQLException {
/* 1656 */     if (paramInt <= 0 || paramInt > this.statement.numberOfDefinePositions) {
/* 1657 */       DatabaseError.throwSqlException(3);
/*      */     }
/* 1659 */     if (this.closed) {
/* 1660 */       DatabaseError.throwSqlException(11);
/*      */     }
/* 1662 */     int i = this.statement.currentRow;
/*      */     
/* 1664 */     if (i < 0) {
/* 1665 */       DatabaseError.throwSqlException(14);
/*      */     }
/* 1667 */     this.statement.lastIndex = paramInt;
/*      */     
/* 1669 */     if (this.statement.streamList != null)
/*      */     {
/* 1671 */       this.statement.closeUsedStreams(paramInt);
/*      */     }
/*      */ 
/*      */     
/* 1675 */     return this.statement.accessors[paramInt - 1].getINTERVALYM(i);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public INTERVALDS getINTERVALDS(int paramInt) throws SQLException {
/* 1697 */     if (paramInt <= 0 || paramInt > this.statement.numberOfDefinePositions) {
/* 1698 */       DatabaseError.throwSqlException(3);
/*      */     }
/* 1700 */     if (this.closed) {
/* 1701 */       DatabaseError.throwSqlException(11);
/*      */     }
/* 1703 */     int i = this.statement.currentRow;
/*      */     
/* 1705 */     if (i < 0) {
/* 1706 */       DatabaseError.throwSqlException(14);
/*      */     }
/* 1708 */     this.statement.lastIndex = paramInt;
/*      */     
/* 1710 */     if (this.statement.streamList != null)
/*      */     {
/* 1712 */       this.statement.closeUsedStreams(paramInt);
/*      */     }
/*      */ 
/*      */     
/* 1716 */     return this.statement.accessors[paramInt - 1].getINTERVALDS(i);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public TIMESTAMP getTIMESTAMP(int paramInt) throws SQLException {
/* 1727 */     if (paramInt <= 0 || paramInt > this.statement.numberOfDefinePositions) {
/* 1728 */       DatabaseError.throwSqlException(3);
/*      */     }
/* 1730 */     if (this.closed) {
/* 1731 */       DatabaseError.throwSqlException(11);
/*      */     }
/* 1733 */     int i = this.statement.currentRow;
/*      */     
/* 1735 */     if (i < 0) {
/* 1736 */       DatabaseError.throwSqlException(14);
/*      */     }
/* 1738 */     this.statement.lastIndex = paramInt;
/*      */     
/* 1740 */     if (this.statement.streamList != null)
/*      */     {
/* 1742 */       this.statement.closeUsedStreams(paramInt);
/*      */     }
/*      */ 
/*      */     
/* 1746 */     return this.statement.accessors[paramInt - 1].getTIMESTAMP(i);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public TIMESTAMPTZ getTIMESTAMPTZ(int paramInt) throws SQLException {
/* 1756 */     if (paramInt <= 0 || paramInt > this.statement.numberOfDefinePositions) {
/* 1757 */       DatabaseError.throwSqlException(3);
/*      */     }
/* 1759 */     if (this.closed) {
/* 1760 */       DatabaseError.throwSqlException(11);
/*      */     }
/* 1762 */     int i = this.statement.currentRow;
/*      */     
/* 1764 */     if (i < 0) {
/* 1765 */       DatabaseError.throwSqlException(14);
/*      */     }
/* 1767 */     this.statement.lastIndex = paramInt;
/*      */     
/* 1769 */     if (this.statement.streamList != null)
/*      */     {
/* 1771 */       this.statement.closeUsedStreams(paramInt);
/*      */     }
/*      */ 
/*      */     
/* 1775 */     return this.statement.accessors[paramInt - 1].getTIMESTAMPTZ(i);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public TIMESTAMPLTZ getTIMESTAMPLTZ(int paramInt) throws SQLException {
/* 1785 */     if (paramInt <= 0 || paramInt > this.statement.numberOfDefinePositions) {
/* 1786 */       DatabaseError.throwSqlException(3);
/*      */     }
/* 1788 */     if (this.closed) {
/* 1789 */       DatabaseError.throwSqlException(11);
/*      */     }
/* 1791 */     int i = this.statement.currentRow;
/*      */     
/* 1793 */     if (i < 0) {
/* 1794 */       DatabaseError.throwSqlException(14);
/*      */     }
/* 1796 */     this.statement.lastIndex = paramInt;
/*      */     
/* 1798 */     if (this.statement.streamList != null)
/*      */     {
/* 1800 */       this.statement.closeUsedStreams(paramInt);
/*      */     }
/*      */ 
/*      */     
/* 1804 */     return this.statement.accessors[paramInt - 1].getTIMESTAMPLTZ(i);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized URL getURL(int paramInt) throws SQLException {
/* 1815 */     if (paramInt <= 0 || paramInt > this.statement.numberOfDefinePositions) {
/* 1816 */       DatabaseError.throwSqlException(3);
/*      */     }
/* 1818 */     if (this.closed) {
/* 1819 */       DatabaseError.throwSqlException(11);
/*      */     }
/* 1821 */     int i = this.statement.currentRow;
/*      */     
/* 1823 */     if (i < 0) {
/* 1824 */       DatabaseError.throwSqlException(14);
/*      */     }
/* 1826 */     this.statement.lastIndex = paramInt;
/*      */     
/* 1828 */     if (this.statement.streamList != null)
/*      */     {
/* 1830 */       this.statement.closeUsedStreams(paramInt);
/*      */     }
/*      */ 
/*      */     
/* 1834 */     return this.statement.accessors[paramInt - 1].getURL(i);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void setFetchSize(int paramInt) throws SQLException {
/* 1848 */     this.statement.setPrefetchInternal(paramInt, false, false);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public int getFetchSize() throws SQLException {
/* 1858 */     return this.statement.getPrefetchInternal(false);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   void internal_close(boolean paramBoolean) throws SQLException {
/* 1871 */     if (this.closed) {
/*      */       return;
/*      */     }
/* 1874 */     this.closed = true;
/*      */     
/* 1876 */     if (this.statement.gotLastBatch && this.statement.validRows == 0) {
/* 1877 */       this.m_emptyRset = true;
/*      */     }
/* 1879 */     PhysicalConnection physicalConnection = this.statement.connection;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     try {
/* 1894 */       physicalConnection.registerHeartbeat();
/* 1895 */       physicalConnection.needLine();
/*      */       
/* 1897 */       synchronized (physicalConnection)
/*      */       {
/*      */ 
/*      */ 
/*      */         
/* 1902 */         this.statement.closeQuery();
/*      */       }
/*      */     
/* 1905 */     } catch (SQLException sQLException) {}
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1913 */     this.statement.endOfResultSet(paramBoolean);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized int findColumn(String paramString) throws SQLException {
/* 1926 */     return this.statement.getColumnIndex(paramString);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   boolean isEmptyResultSet() {
/* 1935 */     return (this.m_emptyRset || (!this.m_emptyRset && this.statement.gotLastBatch && this.statement.validRows == 0));
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   int getValidRows() {
/* 1946 */     return this.statement.validRows;
/*      */   }
/*      */ 
/*      */ 
/*      */   
/* 1951 */   private static final String _Copyright_2004_Oracle_All_Rights_Reserved_ = null;
/*      */   public static final boolean TRACE = false;
/*      */   public static final boolean PRIVATE_TRACE = false;
/*      */   public static final String BUILD_DATE = "Sat_Feb__2_11:39:36_PST_2008";
/*      */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\lib\ojdbc14.jar!\oracle\jdbc\driver\OracleResultSetImpl.class
 * Java compiler version: 2 (46.0)
 * JD-Core Version:       1.1.3
 */