/*      */ package oracle.jdbc.driver;
/*      */ 
/*      */ import java.io.InputStream;
/*      */ import java.io.OutputStream;
/*      */ import java.io.Reader;
/*      */ import java.io.Writer;
/*      */ import java.security.AccessController;
/*      */ import java.security.PrivilegedAction;
/*      */ import java.sql.Connection;
/*      */ import java.sql.SQLException;
/*      */ import java.sql.SQLWarning;
/*      */ import java.util.Locale;
/*      */ import java.util.NoSuchElementException;
/*      */ import java.util.Properties;
/*      */ import java.util.StringTokenizer;
/*      */ import oracle.jdbc.OracleConnection;
/*      */ import oracle.jdbc.OracleOCIFailover;
/*      */ import oracle.jdbc.internal.OracleConnection;
/*      */ import oracle.jdbc.oracore.OracleTypeADT;
/*      */ import oracle.jdbc.oracore.OracleTypeCLOB;
/*      */ import oracle.jdbc.pool.OracleOCIConnectionPool;
/*      */ import oracle.jdbc.pool.OraclePooledConnection;
/*      */ import oracle.sql.BFILE;
/*      */ import oracle.sql.BLOB;
/*      */ import oracle.sql.BfileDBAccess;
/*      */ import oracle.sql.BlobDBAccess;
/*      */ import oracle.sql.CLOB;
/*      */ import oracle.sql.ClobDBAccess;
/*      */ import oracle.sql.LobPlsqlUtil;
/*      */ import oracle.sql.SQLName;
/*      */ import oracle.sql.converter.CharacterSetMetaData;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ public class T2CConnection
/*      */   extends PhysicalConnection
/*      */   implements BfileDBAccess, BlobDBAccess, ClobDBAccess
/*      */ {
/*   48 */   short[] queryMetaData1 = null;
/*   49 */   byte[] queryMetaData2 = null;
/*   50 */   int queryMetaData1Offset = 0;
/*   51 */   int queryMetaData2Offset = 0;
/*      */   private String password;
/*   53 */   int fatalErrorNumber = 0;
/*   54 */   String fatalErrorMessage = null;
/*      */   
/*      */   static final int QMD_dbtype = 0;
/*      */   
/*      */   static final int QMD_dbsize = 1;
/*      */   
/*      */   static final int QMD_nullok = 2;
/*      */   
/*      */   static final int QMD_precision = 3;
/*      */   
/*      */   static final int QMD_scale = 4;
/*      */   
/*      */   static final int QMD_formOfUse = 5;
/*      */   
/*      */   static final int QMD_columnNameLength = 6;
/*      */   
/*      */   static final int QMD_tdo0 = 7;
/*      */   
/*      */   static final int QMD_tdo1 = 8;
/*      */   
/*      */   static final int QMD_tdo2 = 9;
/*      */   
/*      */   static final int QMD_tdo3 = 10;
/*      */   
/*      */   static final int QMD_charLength = 11;
/*      */   
/*      */   static final int QMD_typeNameLength = 12;
/*      */   static final int T2C_LOCATOR_MAX_LEN = 16;
/*      */   static final int T2C_LINEARIZED_LOCATOR_MAX_LEN = 4000;
/*      */   static final int T2C_LINEARIZED_BFILE_LOCATOR_MAX_LEN = 530;
/*      */   static final int METADATA1_INDICES_PER_COLUMN = 13;
/*      */   protected static final int SIZEOF_QUERYMETADATA2 = 8;
/*   86 */   int queryMetaData1Size = 100;
/*   87 */   int queryMetaData2Size = 800;
/*      */   
/*      */   long m_nativeState;
/*      */   
/*      */   short m_clientCharacterSet;
/*      */   
/*      */   byte byteAlign;
/*      */   
/*      */   private static final int EOJ_SUCCESS = 0;
/*      */   
/*      */   private static final int EOJ_ERROR = -1;
/*      */   
/*      */   private static final int EOJ_WARNING = 1;
/*      */   
/*      */   private static final String OCILIBRARY = "ocijdbc10";
/*      */   
/*  103 */   private int logon_mode = 0;
/*      */   
/*      */   static final int LOGON_MODE_DEFAULT = 0;
/*      */   
/*      */   static final int LOGON_MODE_SYSDBA = 2;
/*      */   
/*      */   static final int LOGON_MODE_SYSOPER = 4;
/*      */   
/*      */   static final int LOGON_MODE_CONNECTION_POOL = 5;
/*      */   
/*      */   static final int LOGON_MODE_CONNPOOL_CONNECTION = 6;
/*      */   
/*      */   static final int LOGON_MODE_CONNPOOL_PROXY_CONNECTION = 7;
/*      */   
/*      */   static final int LOGON_MODE_CONNPOOL_ALIASED_CONNECTION = 8;
/*      */   static final int T2C_PROXYTYPE_NONE = 0;
/*      */   static final int T2C_PROXYTYPE_USER_NAME = 1;
/*      */   static final int T2C_PROXYTYPE_DISTINGUISHED_NAME = 2;
/*      */   static final int T2C_PROXYTYPE_CERTIFICATE = 3;
/*      */   private static boolean isLibraryLoaded;
/*  123 */   OracleOCIFailover appCallback = null;
/*  124 */   Object appCallbackObject = null;
/*      */ 
/*      */   
/*      */   private Properties nativeInfo;
/*      */ 
/*      */ 
/*      */   
/*      */   protected T2CConnection(String paramString1, String paramString2, String paramString3, String paramString4, Properties paramProperties, OracleDriverExtension paramOracleDriverExtension) throws SQLException {
/*  132 */     super(paramString1, paramString2, paramString3, paramString4, paramProperties, paramOracleDriverExtension);
/*      */     
/*  134 */     initialize();
/*      */   }
/*      */ 
/*      */   
/*      */   final void initializePassword(String paramString) throws SQLException {
/*  139 */     this.password = paramString;
/*      */   }
/*      */ 
/*      */   
/*      */   protected void initialize() {
/*  144 */     allocQueryMetaDataBuffers();
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private void allocQueryMetaDataBuffers() {
/*  174 */     this.queryMetaData1Offset = 0;
/*  175 */     this.queryMetaData1 = new short[this.queryMetaData1Size * 13];
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  180 */     this.queryMetaData2Offset = 0;
/*  181 */     this.queryMetaData2 = new byte[this.queryMetaData2Size];
/*      */     
/*  183 */     this.namedTypeAccessorByteLen = 0;
/*  184 */     this.refTypeAccessorByteLen = 0;
/*      */   }
/*      */ 
/*      */   
/*      */   void reallocateQueryMetaData(int paramInt1, int paramInt2) {
/*  189 */     this.queryMetaData1 = null;
/*  190 */     this.queryMetaData2 = null;
/*      */     
/*  192 */     this.queryMetaData1Size = Math.max(paramInt1, this.queryMetaData1Size);
/*  193 */     this.queryMetaData2Size = Math.max(paramInt2, this.queryMetaData2Size);
/*      */     
/*  195 */     allocQueryMetaDataBuffers();
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void logon() throws SQLException {
/*  217 */     if (this.database == null) {
/*  218 */       DatabaseError.throwSqlException(64);
/*      */     }
/*  220 */     if (!isLibraryLoaded) {
/*  221 */       loadNativeLibrary(this.connectionProperties);
/*      */     }
/*      */ 
/*      */     
/*  225 */     if (this.connectionProperties.getProperty("is_connection_pooling") == "true") {
/*      */ 
/*      */       
/*  228 */       processOCIConnectionPooling();
/*      */ 
/*      */     
/*      */     }
/*      */     else {
/*      */ 
/*      */       
/*  235 */       long l1 = 0L;
/*  236 */       long l2 = 0L;
/*  237 */       long l3 = 0L;
/*      */       
/*      */       String str1, str2;
/*  240 */       if ((str1 = this.connectionProperties.getProperty("OCISvcCtxHandle")) != null && (str2 = this.connectionProperties.getProperty("OCIEnvHandle")) != null) {
/*      */ 
/*      */ 
/*      */ 
/*      */         
/*  245 */         l1 = Long.parseLong(str1);
/*  246 */         l2 = Long.parseLong(str2);
/*      */         String str7;
/*  248 */         if ((str7 = this.connectionProperties.getProperty("OCIErrHandle")) != null)
/*      */         {
/*  250 */           l3 = Long.parseLong(str7);
/*      */         }
/*      */         
/*      */         String str8;
/*      */         
/*  255 */         if ((str8 = this.connectionProperties.getProperty("JDBCDriverCharSetId")) != null) {
/*      */           
/*  257 */           this.m_clientCharacterSet = (new Integer(str8)).shortValue();
/*      */         
/*      */         }
/*      */         else {
/*      */ 
/*      */           
/*  263 */           DatabaseError.throwSqlException(89);
/*      */         } 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */         
/*  270 */         this.conversion = new DBConversion(this.m_clientCharacterSet, this.m_clientCharacterSet, this.m_clientCharacterSet);
/*      */ 
/*      */         
/*  273 */         short[] arrayOfShort1 = new short[3];
/*      */         
/*  275 */         this.sqlWarning = checkError(t2cUseConnection(this.m_nativeState, l2, l1, l3, arrayOfShort1), this.sqlWarning);
/*      */ 
/*      */ 
/*      */         
/*  279 */         this.conversion = new DBConversion(arrayOfShort1[0], this.m_clientCharacterSet, arrayOfShort1[1]);
/*  280 */         this.byteAlign = (byte)(arrayOfShort1[2] & 0xFF);
/*      */ 
/*      */         
/*      */         return;
/*      */       } 
/*      */ 
/*      */       
/*  287 */       String str3 = this.connectionProperties.getProperty("internal_logon");
/*      */ 
/*      */       
/*  290 */       if (str3 == null) {
/*  291 */         this.logon_mode = 0;
/*  292 */       } else if (str3.equalsIgnoreCase("SYSDBA")) {
/*  293 */         this.logon_mode = 2;
/*  294 */       } else if (str3.equalsIgnoreCase("SYSOPER")) {
/*  295 */         this.logon_mode = 4;
/*      */       } 
/*  297 */       String str4 = this.connectionProperties.getProperty("oracle.jdbc.ociNlsLangBackwardCompatible");
/*      */ 
/*      */       
/*  300 */       byte[] arrayOfByte1 = null;
/*  301 */       byte[] arrayOfByte2 = null;
/*  302 */       String str5 = null;
/*  303 */       byte[] arrayOfByte3 = new byte[0];
/*  304 */       if (this.connectionProperties != null)
/*      */       {
/*  306 */         str5 = (String)this.connectionProperties.get("OCINewPassword");
/*      */       }
/*      */ 
/*      */       
/*  310 */       if (str4 != null && str4.equalsIgnoreCase("true")) {
/*      */ 
/*      */ 
/*      */         
/*  314 */         this.m_clientCharacterSet = getDriverCharSetIdFromNLS_LANG(this.connectionProperties);
/*      */       
/*      */       }
/*      */       else {
/*      */         
/*  319 */         this.m_clientCharacterSet = getClientCharSetId();
/*      */       } 
/*      */       
/*  322 */       if (str5 != null) {
/*  323 */         arrayOfByte3 = DBConversion.stringToAsciiBytes(str5);
/*      */       }
/*  325 */       arrayOfByte1 = (this.user == null) ? new byte[0] : DBConversion.stringToDriverCharBytes(this.user, this.m_clientCharacterSet);
/*      */ 
/*      */ 
/*      */       
/*  329 */       arrayOfByte2 = (this.password == null) ? new byte[0] : DBConversion.stringToAsciiBytes(this.password);
/*      */ 
/*      */       
/*  332 */       byte[] arrayOfByte4 = DBConversion.stringToAsciiBytes(this.database);
/*      */       
/*  334 */       short[] arrayOfShort = new short[3];
/*  335 */       String str6 = null;
/*  336 */       byte[] arrayOfByte5 = ((str6 = CharacterSetMetaData.getNLSLanguage(Locale.getDefault())) != null) ? str6.getBytes() : null;
/*      */       
/*  338 */       byte[] arrayOfByte6 = ((str6 = CharacterSetMetaData.getNLSTerritory(Locale.getDefault())) != null) ? str6.getBytes() : null;
/*      */ 
/*      */       
/*  341 */       if (arrayOfByte5 == null) {
/*  342 */         DatabaseError.throwSqlException(176);
/*      */       }
/*      */       
/*  345 */       this.conversion = new DBConversion(this.m_clientCharacterSet, this.m_clientCharacterSet, this.m_clientCharacterSet);
/*      */ 
/*      */       
/*  348 */       if (this.m_nativeState == 0L) {
/*      */         
/*  350 */         this.sqlWarning = checkError(t2cCreateState(arrayOfByte1, arrayOfByte1.length, arrayOfByte2, arrayOfByte2.length, arrayOfByte3, arrayOfByte3.length, arrayOfByte4, arrayOfByte4.length, this.m_clientCharacterSet, this.logon_mode, arrayOfShort, arrayOfByte5, arrayOfByte6), this.sqlWarning);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*      */       }
/*      */       else {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */         
/*  364 */         this.sqlWarning = checkError(t2cLogon(this.m_nativeState, arrayOfByte1, arrayOfByte1.length, arrayOfByte2, arrayOfByte2.length, arrayOfByte3, arrayOfByte3.length, arrayOfByte4, arrayOfByte4.length, this.logon_mode, arrayOfShort, arrayOfByte5, arrayOfByte6), this.sqlWarning);
/*      */       } 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*  375 */       this.conversion = new DBConversion(arrayOfShort[0], this.m_clientCharacterSet, arrayOfShort[1]);
/*  376 */       this.byteAlign = (byte)(arrayOfShort[2] & 0xFF);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void logoff() throws SQLException {
/*      */     try {
/*  393 */       if (this.m_nativeState != 0L)
/*      */       {
/*  395 */         checkError(t2cLogoff(this.m_nativeState));
/*      */       }
/*  397 */     } catch (NullPointerException nullPointerException) {}
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void open(OracleStatement paramOracleStatement) throws SQLException {
/*  417 */     byte[] arrayOfByte = paramOracleStatement.sqlObject.getSql(paramOracleStatement.processEscapes, paramOracleStatement.convertNcharLiterals).getBytes();
/*      */ 
/*      */     
/*  420 */     checkError(t2cCreateStatement(this.m_nativeState, 0L, arrayOfByte, arrayOfByte.length, paramOracleStatement, false, paramOracleStatement.rowPrefetch));
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   void doCancel() throws SQLException {
/*  437 */     checkError(t2cCancel(this.m_nativeState));
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   void doAbort() throws SQLException {
/*  444 */     checkError(t2cAbort(this.m_nativeState));
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void doSetAutoCommit(boolean paramBoolean) throws SQLException {
/*  461 */     checkError(t2cSetAutoCommit(this.m_nativeState, paramBoolean));
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void doCommit() throws SQLException {
/*  475 */     checkError(t2cCommit(this.m_nativeState));
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void doRollback() throws SQLException {
/*  489 */     checkError(t2cRollback(this.m_nativeState));
/*      */   }
/*      */ 
/*      */   
/*      */   protected String doGetDatabaseProductVersion() throws SQLException {
/*  494 */     byte[] arrayOfByte = t2cGetProductionVersion(this.m_nativeState);
/*      */     
/*  496 */     return this.conversion.CharBytesToString(arrayOfByte, arrayOfByte.length);
/*      */   }
/*      */ 
/*      */   
/*      */   protected short doGetVersionNumber() throws SQLException {
/*  501 */     short s = 0;
/*      */ 
/*      */     
/*      */     try {
/*  505 */       String str1 = doGetDatabaseProductVersion();
/*      */       
/*  507 */       StringTokenizer stringTokenizer = new StringTokenizer(str1.trim(), " .", false);
/*  508 */       String str2 = null;
/*  509 */       byte b = 0;
/*  510 */       short s1 = 0;
/*      */       
/*  512 */       while (stringTokenizer.hasMoreTokens())
/*      */       {
/*  514 */         str2 = stringTokenizer.nextToken();
/*      */ 
/*      */         
/*      */         try {
/*  518 */           s1 = Integer.decode(str2).shortValue();
/*  519 */           s = (short)(s * 10 + s1);
/*  520 */           b++;
/*      */ 
/*      */           
/*  523 */           if (b == 4) {
/*      */             break;
/*      */           }
/*  526 */         } catch (NumberFormatException numberFormatException) {}
/*      */       
/*      */       }
/*      */ 
/*      */     
/*      */     }
/*  532 */     catch (NoSuchElementException noSuchElementException) {}
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  540 */     if (s == -1) {
/*  541 */       s = 0;
/*      */     }
/*      */ 
/*      */ 
/*      */     
/*  546 */     return s;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public ClobDBAccess createClobDBAccess() {
/*  553 */     return this;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public BlobDBAccess createBlobDBAccess() {
/*  560 */     return this;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public BfileDBAccess createBfileDBAccess() {
/*  567 */     return this;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public CLOB createClob(byte[] paramArrayOfbyte) throws SQLException {
/*  574 */     return new CLOB((OracleConnection)this, paramArrayOfbyte);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public CLOB createClob(byte[] paramArrayOfbyte, short paramShort) throws SQLException {
/*  583 */     return new CLOB((OracleConnection)this, paramArrayOfbyte, paramShort);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public BLOB createBlob(byte[] paramArrayOfbyte) throws SQLException {
/*  590 */     return new BLOB((OracleConnection)this, paramArrayOfbyte);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public BFILE createBfile(byte[] paramArrayOfbyte) throws SQLException {
/*  597 */     return new BFILE((OracleConnection)this, paramArrayOfbyte);
/*      */   }
/*      */ 
/*      */   
/*      */   protected SQLWarning checkError(int paramInt) throws SQLException {
/*  602 */     return checkError(paramInt, (SQLWarning)null);
/*      */   }
/*      */   protected SQLWarning checkError(int paramInt, SQLWarning paramSQLWarning) throws SQLException {
/*      */     T2CError t2CError;
/*      */     int i;
/*      */     byte b;
/*      */     String str1;
/*      */     String str2;
/*  610 */     switch (paramInt) {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*      */       case -1:
/*      */       case 1:
/*  618 */         t2CError = new T2CError();
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */         
/*  624 */         i = -1;
/*      */         
/*  626 */         if (this.m_nativeState != 0L) {
/*      */           
/*  628 */           i = t2cDescribeError(this.m_nativeState, t2CError, t2CError.m_errorMessage);
/*      */         
/*      */         }
/*  631 */         else if (this.fatalErrorNumber != 0) {
/*      */           
/*  633 */           String str = DatabaseError.ErrorToSQLState(this.fatalErrorNumber);
/*      */           
/*  635 */           DatabaseError.throwSqlException(this.fatalErrorMessage, str, t2CError.m_errorNumber);
/*      */         
/*      */         }
/*      */         else {
/*      */           
/*  640 */           DatabaseError.throwSqlException(8);
/*      */         } 
/*      */ 
/*      */ 
/*      */         
/*  645 */         switch (t2CError.m_errorNumber) {
/*      */           
/*      */           case 28:
/*      */           case 600:
/*      */           case 1012:
/*      */           case 1041:
/*      */           case 3113:
/*      */           case 3114:
/*  653 */             internalClose();
/*      */             break;
/*      */         } 
/*      */ 
/*      */         
/*  658 */         if (i == -1) {
/*  659 */           DatabaseError.throwSqlException(1, "Fetch error message failed!");
/*      */         }
/*      */ 
/*      */ 
/*      */         
/*  664 */         b = 0;
/*      */         
/*  666 */         while (b < t2CError.m_errorMessage.length && t2CError.m_errorMessage[b] != 0) {
/*  667 */           b++;
/*      */         }
/*  669 */         str1 = this.conversion.CharBytesToString(t2CError.m_errorMessage, b, true);
/*      */ 
/*      */         
/*  672 */         str2 = DatabaseError.ErrorToSQLState(t2CError.m_errorNumber);
/*      */         
/*  674 */         if (paramInt == -1) {
/*      */           
/*  676 */           DatabaseError.throwSqlException(str1, str2, t2CError.m_errorNumber);
/*      */           
/*      */           break;
/*      */         } 
/*      */         
/*  681 */         paramSQLWarning = DatabaseError.addSqlWarning(paramSQLWarning, str1, str2, t2CError.m_errorNumber);
/*      */         break;
/*      */     } 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  691 */     return paramSQLWarning;
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   OracleStatement RefCursorBytesToStatement(byte[] paramArrayOfbyte, OracleStatement paramOracleStatement) throws SQLException {
/*  697 */     T2CStatement t2CStatement = new T2CStatement(this, 1, this.defaultRowPrefetch, -1, -1);
/*      */     
/*  699 */     t2CStatement.needToParse = false;
/*  700 */     t2CStatement.serverCursor = true;
/*  701 */     t2CStatement.isOpen = true;
/*  702 */     t2CStatement.processEscapes = false;
/*      */     
/*  704 */     t2CStatement.prepareForNewResults(true, false);
/*  705 */     t2CStatement.sqlObject.initialize("select unknown as ref cursor from whatever");
/*      */     
/*  707 */     t2CStatement.sqlKind = 0;
/*      */     
/*  709 */     checkError(t2cCreateStatement(this.m_nativeState, paramOracleStatement.c_state, paramArrayOfbyte, paramArrayOfbyte.length, t2CStatement, true, this.defaultRowPrefetch));
/*      */ 
/*      */     
/*  712 */     paramOracleStatement.addChild(t2CStatement);
/*      */     
/*  714 */     return t2CStatement;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void getForm(OracleTypeADT paramOracleTypeADT, OracleTypeCLOB paramOracleTypeCLOB, int paramInt) throws SQLException {
/*  721 */     boolean bool = false;
/*      */     
/*  723 */     if (paramOracleTypeCLOB != null) {
/*      */       
/*  725 */       String[] arrayOfString1 = new String[1];
/*  726 */       String[] arrayOfString2 = new String[1];
/*      */       
/*  728 */       SQLName.parse(paramOracleTypeADT.getFullName(), arrayOfString1, arrayOfString2, true);
/*      */       
/*  730 */       String str = "\"" + arrayOfString1[0] + "\".\"" + arrayOfString2[0] + "\"";
/*      */ 
/*      */       
/*  733 */       byte[] arrayOfByte = this.conversion.StringToCharBytes(str);
/*      */       
/*  735 */       int i = t2cGetFormOfUse(this.m_nativeState, paramOracleTypeCLOB, arrayOfByte, arrayOfByte.length, paramInt);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*  741 */       if (i < 0) {
/*  742 */         checkError(i);
/*      */       }
/*      */ 
/*      */ 
/*      */       
/*  747 */       paramOracleTypeCLOB.setForm(i);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public long getTdoCState(String paramString1, String paramString2) throws SQLException {
/*  766 */     String str = "\"" + paramString1 + "\".\"" + paramString2 + "\"";
/*  767 */     byte[] arrayOfByte = this.conversion.StringToCharBytes(str);
/*  768 */     int[] arrayOfInt = new int[1];
/*  769 */     long l = t2cGetTDO(this.m_nativeState, arrayOfByte, arrayOfByte.length, arrayOfInt);
/*  770 */     if (l == 0L)
/*      */     {
/*      */ 
/*      */       
/*  774 */       checkError(arrayOfInt[0]);
/*      */     }
/*      */ 
/*      */     
/*  778 */     return l;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Properties getDBAccessProperties() throws SQLException {
/*  792 */     return getOCIHandles();
/*      */   }
/*      */ 
/*      */   
/*      */   public synchronized Properties getOCIHandles() throws SQLException {
/*  797 */     if (this.nativeInfo == null) {
/*      */       
/*  799 */       long[] arrayOfLong = new long[3];
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*  805 */       checkError(t2cGetHandles(this.m_nativeState, arrayOfLong));
/*      */ 
/*      */       
/*  808 */       this.nativeInfo = new Properties();
/*      */       
/*  810 */       this.nativeInfo.put("OCIEnvHandle", String.valueOf(arrayOfLong[0]));
/*  811 */       this.nativeInfo.put("OCISvcCtxHandle", String.valueOf(arrayOfLong[1]));
/*  812 */       this.nativeInfo.put("OCIErrHandle", String.valueOf(arrayOfLong[2]));
/*  813 */       this.nativeInfo.put("ClientCharSet", String.valueOf(this.m_clientCharacterSet));
/*      */     } 
/*      */     
/*  816 */     return this.nativeInfo;
/*      */   }
/*      */ 
/*      */   
/*      */   public Properties getServerSessionInfo() throws SQLException {
/*  821 */     if (this.lifecycle != 1) {
/*  822 */       DatabaseError.throwSqlException(8);
/*      */     }
/*  824 */     if (this.sessionProperties == null) {
/*  825 */       this.sessionProperties = new Properties();
/*      */     }
/*      */ 
/*      */     
/*  829 */     if (getVersionNumber() < 10200) {
/*  830 */       queryFCFProperties(this.sessionProperties);
/*      */     } else {
/*  832 */       checkError(t2cGetServerSessionInfo(this.m_nativeState, this.sessionProperties));
/*      */     } 
/*  834 */     return this.sessionProperties;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Properties getConnectionPoolInfo() throws SQLException {
/*  842 */     if (this.lifecycle != 1)
/*  843 */       DatabaseError.throwSqlException(8); 
/*  844 */     Properties properties = new Properties();
/*      */     
/*  846 */     checkError(t2cGetConnPoolInfo(this.m_nativeState, properties));
/*      */     
/*  848 */     return properties;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void setConnectionPoolInfo(int paramInt1, int paramInt2, int paramInt3, int paramInt4, int paramInt5, int paramInt6) throws SQLException {
/*  856 */     checkError(t2cSetConnPoolInfo(this.m_nativeState, paramInt1, paramInt2, paramInt3, paramInt4, paramInt5, paramInt6));
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void ociPasswordChange(String paramString1, String paramString2, String paramString3) throws SQLException {
/*  864 */     if (this.lifecycle != 1)
/*  865 */       DatabaseError.throwSqlException(8); 
/*  866 */     byte[] arrayOfByte1 = (paramString1 == null) ? new byte[0] : DBConversion.stringToDriverCharBytes(paramString1, this.m_clientCharacterSet);
/*      */ 
/*      */ 
/*      */     
/*  870 */     byte[] arrayOfByte2 = (paramString2 == null) ? new byte[0] : DBConversion.stringToAsciiBytes(paramString2);
/*      */ 
/*      */     
/*  873 */     byte[] arrayOfByte3 = (paramString3 == null) ? new byte[0] : DBConversion.stringToAsciiBytes(paramString3);
/*      */ 
/*      */     
/*  876 */     this.sqlWarning = checkError(t2cPasswordChange(this.m_nativeState, arrayOfByte1, arrayOfByte1.length, arrayOfByte2, arrayOfByte2.length, arrayOfByte3, arrayOfByte3.length), this.sqlWarning);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private void processOCIConnectionPooling() throws SQLException {
/*  885 */     if (this.lifecycle != 1)
/*  886 */       DatabaseError.throwSqlException(8); 
/*  887 */     byte[] arrayOfByte1 = null;
/*      */     
/*  889 */     byte[] arrayOfByte2 = (this.password == null) ? new byte[0] : DBConversion.stringToAsciiBytes(this.password);
/*      */ 
/*      */     
/*  892 */     byte[] arrayOfByte3 = DBConversion.stringToAsciiBytes(this.database);
/*      */     
/*  894 */     byte[] arrayOfByte4 = CharacterSetMetaData.getNLSLanguage(Locale.getDefault()).getBytes();
/*      */     
/*  896 */     byte[] arrayOfByte5 = CharacterSetMetaData.getNLSTerritory(Locale.getDefault()).getBytes();
/*      */ 
/*      */ 
/*      */     
/*  900 */     String str = this.connectionProperties.getProperty("connection_pool");
/*      */ 
/*      */     
/*  903 */     short[] arrayOfShort = new short[3];
/*      */     
/*  905 */     if (str == "connection_pool") {
/*      */       
/*  907 */       String str1 = this.connectionProperties.getProperty("oracle.jdbc.ociNlsLangBackwardCompatible");
/*      */ 
/*      */       
/*  910 */       if (str1 != null && str1.equalsIgnoreCase("true")) {
/*      */ 
/*      */ 
/*      */         
/*  914 */         this.m_clientCharacterSet = getDriverCharSetIdFromNLS_LANG(this.connectionProperties);
/*      */       
/*      */       }
/*      */       else {
/*      */         
/*  919 */         this.m_clientCharacterSet = getClientCharSetId();
/*      */       } 
/*      */       
/*  922 */       arrayOfByte1 = (this.user == null) ? new byte[0] : DBConversion.stringToDriverCharBytes(this.user, this.m_clientCharacterSet);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*  928 */       this.conversion = new DBConversion(this.m_clientCharacterSet, this.m_clientCharacterSet, this.m_clientCharacterSet);
/*      */ 
/*      */       
/*  931 */       this.logon_mode = 5;
/*      */       
/*  933 */       if (this.m_nativeState == 0L)
/*      */       {
/*  935 */         int[] arrayOfInt = new int[6];
/*      */         
/*  937 */         OracleOCIConnectionPool.readPoolConfig(this.connectionProperties, arrayOfInt);
/*      */         
/*  939 */         this.sqlWarning = checkError(t2cCreateConnPool(arrayOfByte1, arrayOfByte1.length, arrayOfByte2, arrayOfByte2.length, arrayOfByte3, arrayOfByte3.length, this.m_clientCharacterSet, this.logon_mode, arrayOfInt[0], arrayOfInt[1], arrayOfInt[2], arrayOfInt[3], arrayOfInt[4], arrayOfInt[5]), this.sqlWarning);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */         
/*  950 */         this.versionNumber = 10000;
/*      */ 
/*      */       
/*      */       }
/*      */       else
/*      */       {
/*      */         
/*  957 */         throw DatabaseError.newSqlException(0, "Internal Error: ");
/*      */       
/*      */       }
/*      */ 
/*      */     
/*      */     }
/*  963 */     else if (str == "connpool_connection") {
/*      */       
/*  965 */       this.logon_mode = 6;
/*      */       
/*  967 */       T2CConnection t2CConnection = (T2CConnection)this.connectionProperties.get("connpool_object");
/*      */ 
/*      */       
/*  970 */       this.m_clientCharacterSet = t2CConnection.m_clientCharacterSet;
/*      */       
/*  972 */       arrayOfByte1 = (this.user == null) ? new byte[0] : DBConversion.stringToDriverCharBytes(this.user, this.m_clientCharacterSet);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*  978 */       this.conversion = new DBConversion(this.m_clientCharacterSet, this.m_clientCharacterSet, this.m_clientCharacterSet);
/*      */ 
/*      */       
/*  981 */       this.sqlWarning = checkError(t2cConnPoolLogon(t2CConnection.m_nativeState, arrayOfByte1, arrayOfByte1.length, arrayOfByte2, arrayOfByte2.length, arrayOfByte3, arrayOfByte3.length, this.logon_mode, 0, 0, (String[])null, (byte[])null, 0, (byte[])null, 0, (byte[])null, 0, (byte[])null, 0, (byte[])null, 0, arrayOfShort, arrayOfByte4, arrayOfByte5), this.sqlWarning);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     }
/* 1009 */     else if (str == "connpool_alias_connection") {
/*      */       
/* 1011 */       this.logon_mode = 8;
/*      */ 
/*      */       
/* 1014 */       byte[] arrayOfByte = null;
/*      */       
/* 1016 */       arrayOfByte = (byte[])this.connectionProperties.get("connection_id");
/*      */ 
/*      */       
/* 1019 */       T2CConnection t2CConnection = (T2CConnection)this.connectionProperties.get("connpool_object");
/*      */ 
/*      */       
/* 1022 */       this.m_clientCharacterSet = t2CConnection.m_clientCharacterSet;
/*      */       
/* 1024 */       arrayOfByte1 = (this.user == null) ? new byte[0] : DBConversion.stringToDriverCharBytes(this.user, this.m_clientCharacterSet);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 1030 */       this.conversion = new DBConversion(this.m_clientCharacterSet, this.m_clientCharacterSet, this.m_clientCharacterSet);
/*      */ 
/*      */       
/* 1033 */       this.sqlWarning = checkError(t2cConnPoolLogon(t2CConnection.m_nativeState, arrayOfByte1, arrayOfByte1.length, arrayOfByte2, arrayOfByte2.length, arrayOfByte3, arrayOfByte3.length, this.logon_mode, 0, 0, (String[])null, (byte[])null, 0, (byte[])null, 0, (byte[])null, 0, (byte[])null, 0, arrayOfByte, (arrayOfByte == null) ? 0 : arrayOfByte.length, arrayOfShort, arrayOfByte4, arrayOfByte5), this.sqlWarning);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     }
/* 1061 */     else if (str == "connpool_proxy_connection") {
/*      */       
/* 1063 */       this.logon_mode = 7;
/*      */ 
/*      */       
/* 1066 */       String str1 = this.connectionProperties.getProperty("proxytype");
/*      */ 
/*      */ 
/*      */       
/* 1070 */       Integer integer = (Integer)this.connectionProperties.get("proxy_num_roles");
/*      */       
/* 1072 */       int i = integer.intValue();
/*      */       
/* 1074 */       String[] arrayOfString = null;
/*      */       
/* 1076 */       if (i > 0)
/*      */       {
/* 1078 */         arrayOfString = (String[])this.connectionProperties.get("proxy_roles");
/*      */       }
/*      */ 
/*      */       
/* 1082 */       byte[] arrayOfByte6 = null;
/* 1083 */       byte[] arrayOfByte7 = null;
/* 1084 */       byte[] arrayOfByte8 = null;
/* 1085 */       byte[] arrayOfByte9 = null;
/*      */ 
/*      */       
/* 1088 */       byte b = 0;
/*      */ 
/*      */       
/* 1091 */       if (str1 == "proxytype_user_name") {
/*      */         
/* 1093 */         b = 1;
/*      */         
/* 1095 */         String str2 = this.connectionProperties.getProperty("proxy_user_name");
/*      */ 
/*      */         
/* 1098 */         if (str2 != null) {
/* 1099 */           arrayOfByte6 = str2.getBytes();
/*      */         }
/* 1101 */         str2 = this.connectionProperties.getProperty("proxy_password");
/*      */ 
/*      */         
/* 1104 */         if (str2 != null) {
/* 1105 */           arrayOfByte7 = str2.getBytes();
/*      */         }
/* 1107 */       } else if (str1 == "proxytype_distinguished_name") {
/*      */ 
/*      */         
/* 1110 */         b = 2;
/*      */         
/* 1112 */         String str2 = this.connectionProperties.getProperty("proxy_distinguished_name");
/*      */ 
/*      */         
/* 1115 */         if (str2 != null) {
/* 1116 */           arrayOfByte8 = str2.getBytes();
/*      */         }
/* 1118 */       } else if (str1 == "proxytype_certificate") {
/*      */         
/* 1120 */         b = 3;
/*      */         
/* 1122 */         arrayOfByte9 = (byte[])this.connectionProperties.get("proxy_certificate");
/*      */ 
/*      */       
/*      */       }
/*      */       else {
/*      */ 
/*      */ 
/*      */         
/* 1130 */         DatabaseError.throwSqlException(107);
/*      */       } 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 1137 */       T2CConnection t2CConnection = (T2CConnection)this.connectionProperties.get("connpool_object");
/*      */ 
/*      */       
/* 1140 */       this.m_clientCharacterSet = t2CConnection.m_clientCharacterSet;
/*      */       
/* 1142 */       arrayOfByte1 = (this.user == null) ? new byte[0] : DBConversion.stringToDriverCharBytes(this.user, this.m_clientCharacterSet);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 1148 */       this.conversion = new DBConversion(this.m_clientCharacterSet, this.m_clientCharacterSet, this.m_clientCharacterSet);
/*      */ 
/*      */       
/* 1151 */       this.sqlWarning = checkError(t2cConnPoolLogon(t2CConnection.m_nativeState, arrayOfByte1, arrayOfByte1.length, arrayOfByte2, arrayOfByte2.length, arrayOfByte3, arrayOfByte3.length, this.logon_mode, b, i, arrayOfString, arrayOfByte6, (arrayOfByte6 == null) ? 0 : arrayOfByte6.length, arrayOfByte7, (arrayOfByte7 == null) ? 0 : arrayOfByte7.length, arrayOfByte8, (arrayOfByte8 == null) ? 0 : arrayOfByte8.length, arrayOfByte9, (arrayOfByte9 == null) ? 0 : arrayOfByte9.length, (byte[])null, 0, arrayOfShort, arrayOfByte4, arrayOfByte5), this.sqlWarning);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     }
/*      */     else {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 1175 */       DatabaseError.throwSqlException(23, "connection-pool-logon");
/*      */     } 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1181 */     this.conversion = new DBConversion(arrayOfShort[0], this.m_clientCharacterSet, arrayOfShort[1]);
/* 1182 */     this.byteAlign = (byte)(arrayOfShort[2] & 0xFF);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public boolean isDescriptorSharable(OracleConnection paramOracleConnection) throws SQLException {
/* 1196 */     T2CConnection t2CConnection = this;
/* 1197 */     PhysicalConnection physicalConnection = (PhysicalConnection)paramOracleConnection.getPhysicalConnection();
/*      */     
/* 1199 */     return (t2CConnection == physicalConnection);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private long lobLength(byte[] paramArrayOfbyte) throws SQLException {
/* 1273 */     long l = 0L;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1278 */     l = lobGetLength(this.m_nativeState, paramArrayOfbyte, paramArrayOfbyte.length);
/*      */     
/* 1280 */     checkError((int)l);
/*      */     
/* 1282 */     return l;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private int blobRead(byte[] paramArrayOfbyte1, long paramLong, int paramInt, byte[] paramArrayOfbyte2) throws SQLException {
/* 1296 */     int i = 0;
/*      */     
/* 1298 */     i = blobRead(this.m_nativeState, paramArrayOfbyte1, paramArrayOfbyte1.length, paramLong, paramInt, paramArrayOfbyte2, paramArrayOfbyte2.length);
/*      */ 
/*      */     
/* 1301 */     checkError(i);
/*      */     
/* 1303 */     return i;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private int blobWrite(byte[] paramArrayOfbyte1, long paramLong, byte[] paramArrayOfbyte2, byte[][] paramArrayOfbyte, int paramInt1, int paramInt2) throws SQLException {
/* 1319 */     int i = 0;
/*      */     
/* 1321 */     i = blobWrite(this.m_nativeState, paramArrayOfbyte1, paramArrayOfbyte1.length, paramLong, paramInt2, paramArrayOfbyte2, paramInt1, paramArrayOfbyte);
/*      */ 
/*      */     
/* 1324 */     checkError(i);
/*      */     
/* 1326 */     return i;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private int clobWrite(byte[] paramArrayOfbyte, long paramLong, char[] paramArrayOfchar, byte[][] paramArrayOfbyte1, boolean paramBoolean, int paramInt1, int paramInt2) throws SQLException {
/* 1343 */     int i = 0;
/*      */     
/* 1345 */     i = clobWrite(this.m_nativeState, paramArrayOfbyte, paramArrayOfbyte.length, paramLong, paramInt2, paramArrayOfchar, paramInt1, paramArrayOfbyte1, paramBoolean);
/*      */ 
/*      */     
/* 1348 */     checkError(i);
/*      */     
/* 1350 */     return i;
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   private int lobGetChunkSize(byte[] paramArrayOfbyte) throws SQLException {
/* 1356 */     int i = 0;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1361 */     i = lobGetChunkSize(this.m_nativeState, paramArrayOfbyte, paramArrayOfbyte.length);
/*      */     
/* 1363 */     checkError(i);
/*      */     
/* 1365 */     return i;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public long length(BFILE paramBFILE) throws SQLException {
/* 1376 */     byte[] arrayOfByte = null;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1381 */     checkTrue((this.m_nativeState != 0L), 8);
/* 1382 */     checkTrue((paramBFILE != null && (arrayOfByte = paramBFILE.getLocator()) != null), 54);
/*      */ 
/*      */     
/* 1385 */     return lobLength(arrayOfByte);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public long position(BFILE paramBFILE, byte[] paramArrayOfbyte, long paramLong) throws SQLException {
/* 1403 */     if (paramLong < 1L)
/*      */     {
/*      */ 
/*      */       
/* 1407 */       DatabaseError.throwSqlException(68, "position()");
/*      */     }
/*      */ 
/*      */     
/* 1411 */     long l = LobPlsqlUtil.hasPattern(paramBFILE, paramArrayOfbyte, paramLong);
/*      */     
/* 1413 */     l = (l == 0L) ? -1L : l;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1418 */     return l;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public long position(BFILE paramBFILE1, BFILE paramBFILE2, long paramLong) throws SQLException {
/* 1436 */     if (paramLong < 1L)
/*      */     {
/*      */ 
/*      */       
/* 1440 */       DatabaseError.throwSqlException(68, "position()");
/*      */     }
/*      */ 
/*      */     
/* 1444 */     long l = LobPlsqlUtil.isSubLob(paramBFILE1, paramBFILE2, paramLong);
/*      */     
/* 1446 */     l = (l == 0L) ? -1L : l;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1451 */     return l;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public int getBytes(BFILE paramBFILE, long paramLong, int paramInt, byte[] paramArrayOfbyte) throws SQLException {
/* 1465 */     byte[] arrayOfByte = null;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1470 */     checkTrue((this.m_nativeState != 0L), 8);
/* 1471 */     checkTrue((paramBFILE != null && (arrayOfByte = paramBFILE.getLocator()) != null), 54);
/*      */ 
/*      */     
/* 1474 */     if (paramInt <= 0 || paramArrayOfbyte == null) {
/* 1475 */       return 0;
/*      */     }
/* 1477 */     if (paramInt > paramArrayOfbyte.length) {
/* 1478 */       paramInt = paramArrayOfbyte.length;
/*      */     }
/* 1480 */     return blobRead(arrayOfByte, paramLong, paramInt, paramArrayOfbyte);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public String getName(BFILE paramBFILE) throws SQLException {
/* 1492 */     byte[] arrayOfByte = null;
/* 1493 */     String str = null;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1498 */     checkTrue((this.m_nativeState != 0L), 8);
/* 1499 */     checkTrue((paramBFILE != null && (arrayOfByte = paramBFILE.getLocator()) != null), 54);
/*      */ 
/*      */     
/* 1502 */     str = bfileGetName(this.m_nativeState, arrayOfByte, arrayOfByte.length);
/*      */     
/* 1504 */     checkError(str.length());
/*      */     
/* 1506 */     return str;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public String getDirAlias(BFILE paramBFILE) throws SQLException {
/* 1518 */     byte[] arrayOfByte = null;
/* 1519 */     String str = null;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1524 */     checkTrue((this.m_nativeState != 0L), 8);
/* 1525 */     checkTrue((paramBFILE != null && (arrayOfByte = paramBFILE.getLocator()) != null), 54);
/*      */ 
/*      */     
/* 1528 */     str = bfileGetDirAlias(this.m_nativeState, arrayOfByte, arrayOfByte.length);
/*      */     
/* 1530 */     checkError(str.length());
/*      */     
/* 1532 */     return str;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void openFile(BFILE paramBFILE) throws SQLException {
/* 1543 */     byte[] arrayOfByte = null;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1548 */     checkTrue((this.m_nativeState != 0L), 8);
/* 1549 */     checkTrue((paramBFILE != null && (arrayOfByte = paramBFILE.getLocator()) != null), 54);
/*      */ 
/*      */     
/* 1552 */     byte[][] arrayOfByte1 = new byte[1][];
/*      */     
/* 1554 */     checkError(bfileOpen(this.m_nativeState, arrayOfByte, arrayOfByte.length, arrayOfByte1));
/*      */ 
/*      */     
/* 1557 */     paramBFILE.setLocator(arrayOfByte1[0]);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public boolean isFileOpen(BFILE paramBFILE) throws SQLException {
/* 1572 */     byte[] arrayOfByte = null;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1577 */     checkTrue((this.m_nativeState != 0L), 8);
/* 1578 */     checkTrue((paramBFILE != null && (arrayOfByte = paramBFILE.getLocator()) != null), 54);
/*      */ 
/*      */     
/* 1581 */     boolean[] arrayOfBoolean = new boolean[1];
/*      */     
/* 1583 */     checkError(bfileIsOpen(this.m_nativeState, arrayOfByte, arrayOfByte.length, arrayOfBoolean));
/*      */     
/* 1585 */     return arrayOfBoolean[0];
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public boolean fileExists(BFILE paramBFILE) throws SQLException {
/* 1599 */     byte[] arrayOfByte = null;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1604 */     checkTrue((this.m_nativeState != 0L), 8);
/* 1605 */     checkTrue((paramBFILE != null && (arrayOfByte = paramBFILE.getLocator()) != null), 54);
/*      */ 
/*      */     
/* 1608 */     boolean[] arrayOfBoolean = new boolean[1];
/*      */     
/* 1610 */     checkError(bfileExists(this.m_nativeState, arrayOfByte, arrayOfByte.length, arrayOfBoolean));
/*      */     
/* 1612 */     return arrayOfBoolean[0];
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void closeFile(BFILE paramBFILE) throws SQLException {
/* 1623 */     byte[] arrayOfByte = null;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1628 */     checkTrue((this.m_nativeState != 0L), 8);
/* 1629 */     checkTrue((paramBFILE != null && (arrayOfByte = paramBFILE.getLocator()) != null), 54);
/*      */ 
/*      */     
/* 1632 */     byte[][] arrayOfByte1 = new byte[1][];
/*      */     
/* 1634 */     checkError(bfileClose(this.m_nativeState, arrayOfByte, arrayOfByte.length, arrayOfByte1));
/*      */ 
/*      */     
/* 1637 */     paramBFILE.setLocator(arrayOfByte1[0]);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void open(BFILE paramBFILE, int paramInt) throws SQLException {
/* 1650 */     byte[] arrayOfByte = null;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1655 */     checkTrue((this.m_nativeState != 0L), 8);
/* 1656 */     checkTrue((paramBFILE != null && (arrayOfByte = paramBFILE.shareBytes()) != null), 54);
/*      */ 
/*      */     
/* 1659 */     byte[][] arrayOfByte1 = new byte[1][];
/*      */     
/* 1661 */     checkError(lobOpen(this.m_nativeState, 114, arrayOfByte, arrayOfByte.length, paramInt, arrayOfByte1));
/*      */ 
/*      */     
/* 1664 */     paramBFILE.setShareBytes(arrayOfByte1[0]);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void close(BFILE paramBFILE) throws SQLException {
/* 1675 */     byte[] arrayOfByte = null;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1680 */     checkTrue((this.m_nativeState != 0L), 8);
/* 1681 */     checkTrue((paramBFILE != null && (arrayOfByte = paramBFILE.shareBytes()) != null), 54);
/*      */ 
/*      */     
/* 1684 */     byte[][] arrayOfByte1 = new byte[1][];
/*      */     
/* 1686 */     checkError(lobClose(this.m_nativeState, 114, arrayOfByte, arrayOfByte.length, arrayOfByte1));
/*      */ 
/*      */     
/* 1689 */     paramBFILE.setShareBytes(arrayOfByte1[0]);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public boolean isOpen(BFILE paramBFILE) throws SQLException {
/* 1701 */     byte[] arrayOfByte = null;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1706 */     checkTrue((this.m_nativeState != 0L), 8);
/* 1707 */     checkTrue((paramBFILE != null && (arrayOfByte = paramBFILE.shareBytes()) != null), 54);
/*      */ 
/*      */     
/* 1710 */     boolean[] arrayOfBoolean = new boolean[1];
/*      */     
/* 1712 */     checkError(lobIsOpen(this.m_nativeState, 114, arrayOfByte, arrayOfByte.length, arrayOfBoolean));
/*      */ 
/*      */     
/* 1715 */     return arrayOfBoolean[0];
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public InputStream newInputStream(BFILE paramBFILE, int paramInt, long paramLong) throws SQLException {
/* 1735 */     if (paramLong == 0L)
/*      */     {
/* 1737 */       return new OracleBlobInputStream(paramBFILE, paramInt);
/*      */     }
/*      */ 
/*      */     
/* 1741 */     return new OracleBlobInputStream(paramBFILE, paramInt, paramLong);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public InputStream newConversionInputStream(BFILE paramBFILE, int paramInt) throws SQLException {
/* 1761 */     checkTrue((paramBFILE != null && paramBFILE.shareBytes() != null), 54);
/*      */ 
/*      */     
/* 1764 */     return new OracleConversionInputStream(this.conversion, paramBFILE.getBinaryStream(), paramInt);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Reader newConversionReader(BFILE paramBFILE, int paramInt) throws SQLException {
/* 1789 */     checkTrue((paramBFILE != null && paramBFILE.shareBytes() != null), 54);
/*      */ 
/*      */     
/* 1792 */     return new OracleConversionReader(this.conversion, paramBFILE.getBinaryStream(), paramInt);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public long length(BLOB paramBLOB) throws SQLException {
/* 1809 */     byte[] arrayOfByte = null;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1814 */     checkTrue((this.m_nativeState != 0L), 8);
/* 1815 */     checkTrue((paramBLOB != null && (arrayOfByte = paramBLOB.getLocator()) != null), 54);
/*      */ 
/*      */     
/* 1818 */     return lobLength(arrayOfByte);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public long position(BLOB paramBLOB, byte[] paramArrayOfbyte, long paramLong) throws SQLException {
/* 1837 */     checkTrue((this.m_nativeState != 0L), 8);
/* 1838 */     checkTrue((paramBLOB != null && paramBLOB.shareBytes() != null), 54);
/*      */ 
/*      */     
/* 1841 */     if (paramLong < 1L)
/*      */     {
/*      */ 
/*      */ 
/*      */       
/* 1846 */       DatabaseError.throwSqlException(68, "position()");
/*      */     }
/*      */ 
/*      */     
/* 1850 */     long l = LobPlsqlUtil.hasPattern(paramBLOB, paramArrayOfbyte, paramLong);
/*      */     
/* 1852 */     l = (l == 0L) ? -1L : l;
/*      */ 
/*      */ 
/*      */     
/* 1856 */     return l;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public long position(BLOB paramBLOB1, BLOB paramBLOB2, long paramLong) throws SQLException {
/* 1873 */     checkTrue((this.m_nativeState != 0L), 8);
/* 1874 */     checkTrue((paramBLOB1 != null && paramBLOB1.shareBytes() != null), 54);
/*      */     
/* 1876 */     checkTrue((paramBLOB2 != null && paramBLOB2.shareBytes() != null), 54);
/*      */ 
/*      */     
/* 1879 */     if (paramLong < 1L)
/*      */     {
/*      */ 
/*      */ 
/*      */       
/* 1884 */       DatabaseError.throwSqlException(68, "position()");
/*      */     }
/*      */ 
/*      */     
/* 1888 */     long l = LobPlsqlUtil.isSubLob(paramBLOB1, paramBLOB2, paramLong);
/*      */     
/* 1890 */     l = (l == 0L) ? -1L : l;
/*      */ 
/*      */ 
/*      */     
/* 1894 */     return l;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public int getBytes(BLOB paramBLOB, long paramLong, int paramInt, byte[] paramArrayOfbyte) throws SQLException {
/* 1909 */     byte[] arrayOfByte = null;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1914 */     checkTrue((this.m_nativeState != 0L), 8);
/* 1915 */     checkTrue((paramBLOB != null && (arrayOfByte = paramBLOB.getLocator()) != null), 54);
/*      */ 
/*      */     
/* 1918 */     if (paramInt <= 0 || paramArrayOfbyte == null) {
/* 1919 */       return 0;
/*      */     }
/* 1921 */     if (paramInt > paramArrayOfbyte.length) {
/* 1922 */       paramInt = paramArrayOfbyte.length;
/*      */     }
/* 1924 */     return blobRead(arrayOfByte, paramLong, paramInt, paramArrayOfbyte);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public int putBytes(BLOB paramBLOB, long paramLong, byte[] paramArrayOfbyte, int paramInt1, int paramInt2) throws SQLException {
/* 1941 */     checkTrue((paramLong >= 0L), 68);
/*      */     
/* 1943 */     int i = 0;
/*      */     
/* 1945 */     if (paramArrayOfbyte == null || paramArrayOfbyte.length == 0 || paramInt2 <= 0) {
/* 1946 */       i = 0;
/*      */     } else {
/*      */       
/* 1949 */       byte[] arrayOfByte = null;
/*      */       
/* 1951 */       checkTrue((this.m_nativeState != 0L), 8);
/* 1952 */       checkTrue((paramBLOB != null && (arrayOfByte = paramBLOB.getLocator()) != null), 54);
/*      */ 
/*      */       
/* 1955 */       if (paramArrayOfbyte == null) {
/* 1956 */         return 0;
/*      */       }
/* 1958 */       byte[][] arrayOfByte1 = new byte[1][];
/*      */       
/* 1960 */       i = blobWrite(arrayOfByte, paramLong, paramArrayOfbyte, arrayOfByte1, paramInt1, paramInt2);
/*      */ 
/*      */       
/* 1963 */       paramBLOB.setLocator(arrayOfByte1[0]);
/*      */     } 
/*      */     
/* 1966 */     return i;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public int getChunkSize(BLOB paramBLOB) throws SQLException {
/* 1976 */     byte[] arrayOfByte = null;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1981 */     checkTrue((this.m_nativeState != 0L), 8);
/* 1982 */     checkTrue((paramBLOB != null && (arrayOfByte = paramBLOB.getLocator()) != null), 54);
/*      */ 
/*      */     
/* 1985 */     return lobGetChunkSize(arrayOfByte);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void trim(BLOB paramBLOB, long paramLong) throws SQLException {
/* 1997 */     byte[] arrayOfByte = null;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 2002 */     checkTrue((this.m_nativeState != 0L), 8);
/* 2003 */     checkTrue((paramBLOB != null && (arrayOfByte = paramBLOB.shareBytes()) != null), 54);
/*      */ 
/*      */     
/* 2006 */     byte[][] arrayOfByte1 = new byte[1][];
/*      */     
/* 2008 */     checkError(lobTrim(this.m_nativeState, 113, paramLong, arrayOfByte, arrayOfByte.length, arrayOfByte1));
/*      */ 
/*      */     
/* 2011 */     paramBLOB.setShareBytes(arrayOfByte1[0]);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public BLOB createTemporaryBlob(Connection paramConnection, boolean paramBoolean, int paramInt) throws SQLException {
/* 2028 */     BLOB bLOB = null;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 2033 */     checkTrue((this.m_nativeState != 0L), 8);
/*      */     
/* 2035 */     bLOB = new BLOB((OracleConnection)paramConnection);
/*      */     
/* 2037 */     byte[][] arrayOfByte = new byte[1][];
/*      */     
/* 2039 */     checkError(lobCreateTemporary(this.m_nativeState, 113, paramBoolean, paramInt, (short)0, arrayOfByte));
/*      */ 
/*      */     
/* 2042 */     bLOB.setShareBytes(arrayOfByte[0]);
/*      */     
/* 2044 */     return bLOB;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void freeTemporary(BLOB paramBLOB) throws SQLException {
/* 2056 */     byte[] arrayOfByte = null;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 2061 */     checkTrue((this.m_nativeState != 0L), 8);
/* 2062 */     checkTrue((paramBLOB != null && (arrayOfByte = paramBLOB.shareBytes()) != null), 54);
/*      */ 
/*      */     
/* 2065 */     byte[][] arrayOfByte1 = new byte[1][];
/*      */     
/* 2067 */     checkError(lobFreeTemporary(this.m_nativeState, 113, arrayOfByte, arrayOfByte.length, arrayOfByte1));
/*      */ 
/*      */     
/* 2070 */     paramBLOB.setShareBytes(arrayOfByte1[0]);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public boolean isTemporary(BLOB paramBLOB) throws SQLException {
/* 2085 */     byte[] arrayOfByte = null;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 2090 */     checkTrue((paramBLOB != null && (arrayOfByte = paramBLOB.shareBytes()) != null), 54);
/*      */ 
/*      */     
/* 2093 */     boolean[] arrayOfBoolean = new boolean[1];
/*      */     
/* 2095 */     checkError(lobIsTemporary(this.m_nativeState, 113, arrayOfByte, arrayOfByte.length, arrayOfBoolean));
/*      */ 
/*      */     
/* 2098 */     return arrayOfBoolean[0];
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void open(BLOB paramBLOB, int paramInt) throws SQLException {
/* 2109 */     byte[] arrayOfByte = null;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 2114 */     checkTrue((this.m_nativeState != 0L), 8);
/* 2115 */     checkTrue((paramBLOB != null && (arrayOfByte = paramBLOB.shareBytes()) != null), 54);
/*      */ 
/*      */     
/* 2118 */     byte[][] arrayOfByte1 = new byte[1][];
/*      */     
/* 2120 */     checkError(lobOpen(this.m_nativeState, 113, arrayOfByte, arrayOfByte.length, paramInt, arrayOfByte1));
/*      */ 
/*      */     
/* 2123 */     paramBLOB.setShareBytes(arrayOfByte1[0]);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void close(BLOB paramBLOB) throws SQLException {
/* 2134 */     byte[] arrayOfByte = null;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 2139 */     checkTrue((this.m_nativeState != 0L), 8);
/* 2140 */     checkTrue((paramBLOB != null && (arrayOfByte = paramBLOB.shareBytes()) != null), 54);
/*      */ 
/*      */     
/* 2143 */     byte[][] arrayOfByte1 = new byte[1][];
/*      */     
/* 2145 */     checkError(lobClose(this.m_nativeState, 113, arrayOfByte, arrayOfByte.length, arrayOfByte1));
/*      */ 
/*      */     
/* 2148 */     paramBLOB.setShareBytes(arrayOfByte1[0]);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public boolean isOpen(BLOB paramBLOB) throws SQLException {
/* 2160 */     byte[] arrayOfByte = null;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 2165 */     checkTrue((this.m_nativeState != 0L), 8);
/* 2166 */     checkTrue((paramBLOB != null && (arrayOfByte = paramBLOB.shareBytes()) != null), 54);
/*      */ 
/*      */     
/* 2169 */     boolean[] arrayOfBoolean = new boolean[1];
/*      */     
/* 2171 */     checkError(lobIsOpen(this.m_nativeState, 113, arrayOfByte, arrayOfByte.length, arrayOfBoolean));
/*      */ 
/*      */     
/* 2174 */     return arrayOfBoolean[0];
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public InputStream newInputStream(BLOB paramBLOB, int paramInt, long paramLong) throws SQLException {
/* 2193 */     if (paramLong == 0L)
/*      */     {
/* 2195 */       return new OracleBlobInputStream(paramBLOB, paramInt);
/*      */     }
/*      */ 
/*      */     
/* 2199 */     return new OracleBlobInputStream(paramBLOB, paramInt, paramLong);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public OutputStream newOutputStream(BLOB paramBLOB, int paramInt, long paramLong) throws SQLException {
/* 2219 */     if (paramLong == 0L)
/*      */     {
/* 2221 */       return new OracleBlobOutputStream(paramBLOB, paramInt);
/*      */     }
/*      */ 
/*      */     
/* 2225 */     return new OracleBlobOutputStream(paramBLOB, paramInt, paramLong);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public InputStream newConversionInputStream(BLOB paramBLOB, int paramInt) throws SQLException {
/* 2246 */     checkTrue((paramBLOB != null && paramBLOB.shareBytes() != null), 54);
/*      */ 
/*      */     
/* 2249 */     return new OracleConversionInputStream(this.conversion, paramBLOB.getBinaryStream(), paramInt);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Reader newConversionReader(BLOB paramBLOB, int paramInt) throws SQLException {
/* 2273 */     checkTrue((paramBLOB != null && paramBLOB.shareBytes() != null), 54);
/*      */ 
/*      */     
/* 2276 */     return new OracleConversionReader(this.conversion, paramBLOB.getBinaryStream(), paramInt);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public long length(CLOB paramCLOB) throws SQLException {
/* 2297 */     byte[] arrayOfByte = null;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 2302 */     checkTrue((this.m_nativeState != 0L), 8);
/* 2303 */     checkTrue((paramCLOB != null && (arrayOfByte = paramCLOB.getLocator()) != null), 54);
/*      */ 
/*      */     
/* 2306 */     return lobLength(arrayOfByte);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public long position(CLOB paramCLOB, String paramString, long paramLong) throws SQLException {
/* 2324 */     if (paramString == null) {
/* 2325 */       throw new SQLException("pattern cannot be null.");
/*      */     }
/* 2327 */     checkTrue((this.m_nativeState != 0L), 8);
/* 2328 */     checkTrue((paramCLOB != null && paramCLOB.shareBytes() != null), 54);
/*      */ 
/*      */     
/* 2331 */     if (paramLong < 1L)
/*      */     {
/*      */ 
/*      */ 
/*      */       
/* 2336 */       DatabaseError.throwSqlException(68, "position()");
/*      */     }
/*      */ 
/*      */     
/* 2340 */     char[] arrayOfChar = new char[paramString.length()];
/*      */     
/* 2342 */     paramString.getChars(0, arrayOfChar.length, arrayOfChar, 0);
/*      */     
/* 2344 */     long l = LobPlsqlUtil.hasPattern(paramCLOB, arrayOfChar, paramLong);
/*      */     
/* 2346 */     l = (l == 0L) ? -1L : l;
/*      */ 
/*      */ 
/*      */     
/* 2350 */     return l;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public long position(CLOB paramCLOB1, CLOB paramCLOB2, long paramLong) throws SQLException {
/* 2367 */     checkTrue((this.m_nativeState != 0L), 8);
/* 2368 */     checkTrue((paramCLOB1 != null && paramCLOB1.shareBytes() != null), 54);
/*      */     
/* 2370 */     checkTrue((paramCLOB2 != null && paramCLOB2.shareBytes() != null), 54);
/*      */ 
/*      */     
/* 2373 */     if (paramLong < 1L)
/*      */     {
/*      */ 
/*      */ 
/*      */       
/* 2378 */       DatabaseError.throwSqlException(68, "position()");
/*      */     }
/*      */ 
/*      */     
/* 2382 */     long l = LobPlsqlUtil.isSubLob(paramCLOB1, paramCLOB2, paramLong);
/*      */     
/* 2384 */     l = (l == 0L) ? -1L : l;
/*      */ 
/*      */ 
/*      */     
/* 2388 */     return l;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public int getChars(CLOB paramCLOB, long paramLong, int paramInt, char[] paramArrayOfchar) throws SQLException {
/* 2403 */     byte[] arrayOfByte = null;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 2408 */     checkTrue((this.m_nativeState != 0L), 8);
/* 2409 */     checkTrue((paramCLOB != null && (arrayOfByte = paramCLOB.getLocator()) != null), 54);
/*      */ 
/*      */     
/* 2412 */     if (paramInt <= 0 || paramArrayOfchar == null) {
/* 2413 */       return 0;
/*      */     }
/* 2415 */     if (paramInt > paramArrayOfchar.length) {
/* 2416 */       paramInt = paramArrayOfchar.length;
/*      */     }
/* 2418 */     int i = 0;
/*      */     
/* 2420 */     i = clobRead(this.m_nativeState, arrayOfByte, arrayOfByte.length, paramLong, paramInt, paramArrayOfchar, paramArrayOfchar.length, paramCLOB.isNCLOB());
/*      */ 
/*      */     
/* 2423 */     checkError(i);
/*      */     
/* 2425 */     return i;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public int putChars(CLOB paramCLOB, long paramLong, char[] paramArrayOfchar, int paramInt1, int paramInt2) throws SQLException {
/* 2444 */     byte[] arrayOfByte = null;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 2449 */     checkTrue((this.m_nativeState != 0L), 8);
/* 2450 */     checkTrue((paramLong >= 0L), 68);
/*      */     
/* 2452 */     checkTrue((paramCLOB != null && (arrayOfByte = paramCLOB.getLocator()) != null), 54);
/*      */ 
/*      */     
/* 2455 */     if (paramArrayOfchar == null) {
/* 2456 */       return 0;
/*      */     }
/* 2458 */     byte[][] arrayOfByte1 = new byte[1][];
/* 2459 */     int i = clobWrite(arrayOfByte, paramLong, paramArrayOfchar, arrayOfByte1, paramCLOB.isNCLOB(), paramInt1, paramInt2);
/*      */ 
/*      */     
/* 2462 */     paramCLOB.setLocator(arrayOfByte1[0]);
/*      */     
/* 2464 */     return i;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public int getChunkSize(CLOB paramCLOB) throws SQLException {
/* 2474 */     byte[] arrayOfByte = null;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 2479 */     checkTrue((this.m_nativeState != 0L), 8);
/* 2480 */     checkTrue((paramCLOB != null && (arrayOfByte = paramCLOB.getLocator()) != null), 54);
/*      */ 
/*      */     
/* 2483 */     return lobGetChunkSize(arrayOfByte);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void trim(CLOB paramCLOB, long paramLong) throws SQLException {
/* 2495 */     byte[] arrayOfByte = null;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 2500 */     checkTrue((this.m_nativeState != 0L), 8);
/* 2501 */     checkTrue((paramCLOB != null && (arrayOfByte = paramCLOB.shareBytes()) != null), 54);
/*      */ 
/*      */     
/* 2504 */     byte[][] arrayOfByte1 = new byte[1][];
/*      */     
/* 2506 */     checkError(lobTrim(this.m_nativeState, 112, paramLong, arrayOfByte, arrayOfByte.length, arrayOfByte1));
/*      */ 
/*      */     
/* 2509 */     paramCLOB.setShareBytes(arrayOfByte1[0]);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public CLOB createTemporaryClob(Connection paramConnection, boolean paramBoolean, int paramInt, short paramShort) throws SQLException {
/* 2527 */     CLOB cLOB = null;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 2532 */     checkTrue((this.m_nativeState != 0L), 8);
/*      */     
/* 2534 */     cLOB = new CLOB((OracleConnection)paramConnection);
/*      */     
/* 2536 */     byte[][] arrayOfByte = new byte[1][];
/*      */     
/* 2538 */     checkError(lobCreateTemporary(this.m_nativeState, 112, paramBoolean, paramInt, paramShort, arrayOfByte));
/*      */ 
/*      */     
/* 2541 */     cLOB.setShareBytes(arrayOfByte[0]);
/*      */     
/* 2543 */     return cLOB;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void freeTemporary(CLOB paramCLOB) throws SQLException {
/* 2555 */     byte[] arrayOfByte = null;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 2560 */     checkTrue((this.m_nativeState != 0L), 8);
/* 2561 */     checkTrue((paramCLOB != null && (arrayOfByte = paramCLOB.shareBytes()) != null), 54);
/*      */ 
/*      */     
/* 2564 */     byte[][] arrayOfByte1 = new byte[1][];
/*      */     
/* 2566 */     checkError(lobFreeTemporary(this.m_nativeState, 112, arrayOfByte, arrayOfByte.length, arrayOfByte1));
/*      */ 
/*      */     
/* 2569 */     paramCLOB.setShareBytes(arrayOfByte1[0]);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public boolean isTemporary(CLOB paramCLOB) throws SQLException {
/* 2585 */     byte[] arrayOfByte = null;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 2590 */     checkTrue((paramCLOB != null && (arrayOfByte = paramCLOB.shareBytes()) != null), 54);
/*      */ 
/*      */     
/* 2593 */     boolean[] arrayOfBoolean = new boolean[1];
/*      */     
/* 2595 */     checkError(lobIsTemporary(this.m_nativeState, 112, arrayOfByte, arrayOfByte.length, arrayOfBoolean));
/*      */ 
/*      */     
/* 2598 */     return arrayOfBoolean[0];
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void open(CLOB paramCLOB, int paramInt) throws SQLException {
/* 2609 */     byte[] arrayOfByte = null;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 2614 */     checkTrue((this.m_nativeState != 0L), 8);
/* 2615 */     checkTrue((paramCLOB != null && (arrayOfByte = paramCLOB.shareBytes()) != null), 54);
/*      */ 
/*      */     
/* 2618 */     byte[][] arrayOfByte1 = new byte[1][];
/*      */     
/* 2620 */     checkError(lobOpen(this.m_nativeState, 112, arrayOfByte, arrayOfByte.length, paramInt, arrayOfByte1));
/*      */ 
/*      */     
/* 2623 */     paramCLOB.setShareBytes(arrayOfByte1[0]);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void close(CLOB paramCLOB) throws SQLException {
/* 2634 */     byte[] arrayOfByte = null;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 2639 */     checkTrue((this.m_nativeState != 0L), 8);
/* 2640 */     checkTrue((paramCLOB != null && (arrayOfByte = paramCLOB.shareBytes()) != null), 54);
/*      */ 
/*      */     
/* 2643 */     byte[][] arrayOfByte1 = new byte[1][];
/*      */     
/* 2645 */     checkError(lobClose(this.m_nativeState, 112, arrayOfByte, arrayOfByte.length, arrayOfByte1));
/*      */ 
/*      */     
/* 2648 */     paramCLOB.setShareBytes(arrayOfByte1[0]);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public boolean isOpen(CLOB paramCLOB) throws SQLException {
/* 2660 */     byte[] arrayOfByte = null;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 2665 */     checkTrue((this.m_nativeState != 0L), 8);
/* 2666 */     checkTrue((paramCLOB != null && (arrayOfByte = paramCLOB.shareBytes()) != null), 54);
/*      */ 
/*      */     
/* 2669 */     boolean[] arrayOfBoolean = new boolean[1];
/*      */     
/* 2671 */     checkError(lobIsOpen(this.m_nativeState, 112, arrayOfByte, arrayOfByte.length, arrayOfBoolean));
/*      */ 
/*      */     
/* 2674 */     return arrayOfBoolean[0];
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public InputStream newInputStream(CLOB paramCLOB, int paramInt, long paramLong) throws SQLException {
/* 2694 */     if (paramLong == 0L)
/*      */     {
/* 2696 */       return new OracleClobInputStream(paramCLOB, paramInt);
/*      */     }
/*      */ 
/*      */     
/* 2700 */     return new OracleClobInputStream(paramCLOB, paramInt, paramLong);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public OutputStream newOutputStream(CLOB paramCLOB, int paramInt, long paramLong) throws SQLException {
/* 2720 */     if (paramLong == 0L)
/*      */     {
/* 2722 */       return new OracleClobOutputStream(paramCLOB, paramInt);
/*      */     }
/*      */ 
/*      */     
/* 2726 */     return new OracleClobOutputStream(paramCLOB, paramInt, paramLong);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Reader newReader(CLOB paramCLOB, int paramInt, long paramLong) throws SQLException {
/* 2746 */     if (paramLong == 0L)
/*      */     {
/* 2748 */       return new OracleClobReader(paramCLOB, paramInt);
/*      */     }
/*      */ 
/*      */     
/* 2752 */     return new OracleClobReader(paramCLOB, paramInt, paramLong);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Writer newWriter(CLOB paramCLOB, int paramInt, long paramLong) throws SQLException {
/* 2772 */     if (paramLong == 0L)
/*      */     {
/* 2774 */       return new OracleClobWriter(paramCLOB, paramInt);
/*      */     }
/*      */ 
/*      */     
/* 2778 */     return new OracleClobWriter(paramCLOB, paramInt, paramLong);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void registerTAFCallback(OracleOCIFailover paramOracleOCIFailover, Object paramObject) throws SQLException {
/* 2803 */     this.appCallback = paramOracleOCIFailover;
/* 2804 */     this.appCallbackObject = paramObject;
/*      */     
/* 2806 */     checkError(t2cRegisterTAFCallback(this.m_nativeState));
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   synchronized int callTAFCallbackMethod(int paramInt1, int paramInt2) {
/* 2814 */     int i = 0;
/*      */ 
/*      */     
/* 2817 */     if (this.appCallback != null) {
/* 2818 */       i = this.appCallback.callbackFn((Connection)this, this.appCallbackObject, paramInt1, paramInt2);
/*      */     }
/* 2820 */     return i;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public int getHeapAllocSize() throws SQLException {
/* 2834 */     if (this.lifecycle != 1) {
/* 2835 */       DatabaseError.throwSqlException(8);
/*      */     }
/*      */ 
/*      */     
/* 2839 */     int i = t2cGetHeapAllocSize(this.m_nativeState);
/*      */     
/* 2841 */     if (i < 0) {
/*      */       
/* 2843 */       if (i == -999) {
/* 2844 */         DatabaseError.throwSqlException(23);
/*      */       }
/*      */ 
/*      */       
/* 2848 */       DatabaseError.throwSqlException(89);
/*      */     } 
/*      */     
/* 2851 */     return i;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public int getOCIEnvHeapAllocSize() throws SQLException {
/* 2866 */     if (this.lifecycle != 1) {
/* 2867 */       DatabaseError.throwSqlException(8);
/*      */     }
/*      */ 
/*      */     
/* 2871 */     int i = t2cGetOciEnvHeapAllocSize(this.m_nativeState);
/*      */     
/* 2873 */     if (i < 0) {
/*      */       
/* 2875 */       if (i == -999) {
/* 2876 */         DatabaseError.throwSqlException(23);
/*      */       } else {
/* 2878 */         checkError(i);
/*      */       } 
/*      */       
/* 2881 */       DatabaseError.throwSqlException(89);
/*      */     } 
/*      */     
/* 2884 */     return i;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public static final short getClientCharSetId() {
/* 2893 */     return 871;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public static short getDriverCharSetIdFromNLS_LANG(Properties paramProperties) throws SQLException {
/* 2909 */     if (!isLibraryLoaded) {
/* 2910 */       loadNativeLibrary(paramProperties);
/*      */     }
/*      */ 
/*      */ 
/*      */     
/* 2915 */     short s = t2cGetDriverCharSetFromNlsLang();
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 2920 */     if (s < 0) {
/* 2921 */       DatabaseError.throwSqlException(8);
/*      */     }
/*      */ 
/*      */ 
/*      */     
/* 2926 */     return s;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   void doProxySession(int paramInt, Properties paramProperties) throws SQLException {
/*      */     String str1, str2;
/*      */     Object object;
/* 2937 */     byte[][] arrayOfByte = (byte[][])null;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 2943 */     int i = 0;
/*      */     
/* 2945 */     this.savedUser = this.user;
/* 2946 */     this.user = null;
/*      */     
/* 2948 */     byte[] arrayOfByte4 = new byte[0], arrayOfByte3 = arrayOfByte4, arrayOfByte2 = arrayOfByte3, arrayOfByte1 = arrayOfByte2;
/*      */     
/* 2950 */     switch (paramInt) {
/*      */       
/*      */       case 1:
/* 2953 */         this.user = paramProperties.getProperty("PROXY_USER_NAME");
/* 2954 */         str1 = paramProperties.getProperty("PROXY_USER_PASSWORD");
/* 2955 */         if (this.user != null) {
/* 2956 */           arrayOfByte1 = DBConversion.stringToDriverCharBytes(this.user, this.m_clientCharacterSet);
/*      */         }
/* 2958 */         if (str1 != null)
/* 2959 */           arrayOfByte2 = DBConversion.stringToAsciiBytes(str1); 
/*      */         break;
/*      */       case 2:
/* 2962 */         str2 = paramProperties.getProperty("PROXY_DISTINGUISHED_NAME");
/* 2963 */         if (str2 != null) {
/* 2964 */           arrayOfByte3 = DBConversion.stringToDriverCharBytes(str2, this.m_clientCharacterSet);
/*      */         }
/*      */         break;
/*      */       case 3:
/* 2968 */         object = paramProperties.get("PROXY_CERTIFICATE");
/* 2969 */         arrayOfByte4 = (byte[])object;
/*      */         break;
/*      */     } 
/* 2972 */     String[] arrayOfString = (String[])paramProperties.get("PROXY_ROLES");
/*      */     
/* 2974 */     if (arrayOfString != null) {
/*      */       
/* 2976 */       i = arrayOfString.length;
/* 2977 */       arrayOfByte = new byte[i][];
/* 2978 */       for (byte b = 0; b < i; b++) {
/*      */         
/* 2980 */         if (arrayOfString[b] == null) {
/* 2981 */           DatabaseError.throwSqlException(150);
/*      */         }
/* 2983 */         arrayOfByte[b] = DBConversion.stringToDriverCharBytes(arrayOfString[b], this.m_clientCharacterSet);
/*      */       } 
/*      */     } 
/*      */ 
/*      */     
/* 2988 */     this.sqlWarning = checkError(t2cDoProxySession(this.m_nativeState, paramInt, arrayOfByte1, arrayOfByte1.length, arrayOfByte2, arrayOfByte2.length, arrayOfByte3, arrayOfByte3.length, arrayOfByte4, arrayOfByte4.length, i, arrayOfByte), this.sqlWarning);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 3002 */     this.isProxy = true;
/*      */   }
/*      */ 
/*      */   
/*      */   void closeProxySession() throws SQLException {
/* 3007 */     checkError(t2cCloseProxySession(this.m_nativeState));
/* 3008 */     this.user = this.savedUser;
/*      */   }
/*      */ 
/*      */   
/*      */   protected void doDescribeTable(AutoKeyInfo paramAutoKeyInfo) throws SQLException {
/*      */     int i;
/* 3014 */     String str = paramAutoKeyInfo.getTableName();
/*      */     
/* 3016 */     byte[] arrayOfByte = DBConversion.stringToDriverCharBytes(str, this.m_clientCharacterSet);
/*      */ 
/*      */     
/* 3019 */     boolean bool = false;
/*      */ 
/*      */ 
/*      */     
/*      */     do {
/* 3024 */       i = t2cDescribeTable(this.m_nativeState, arrayOfByte, arrayOfByte.length, this.queryMetaData1, this.queryMetaData2, this.queryMetaData1Offset, this.queryMetaData2Offset, this.queryMetaData1Size, this.queryMetaData2Size);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 3034 */       if (i == -1)
/*      */       {
/* 3036 */         checkError(i);
/*      */       }
/*      */ 
/*      */       
/* 3040 */       if (i != T2CStatement.T2C_EXTEND_BUFFER)
/*      */         continue; 
/* 3042 */       bool = true;
/*      */       
/* 3044 */       reallocateQueryMetaData(this.queryMetaData1Size * 2, this.queryMetaData2Size * 2);
/*      */     
/*      */     }
/* 3047 */     while (bool);
/*      */     
/* 3049 */     processDescribeTableData(i, paramAutoKeyInfo);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private void processDescribeTableData(int paramInt, AutoKeyInfo paramAutoKeyInfo) throws SQLException {
/* 3056 */     short[] arrayOfShort = this.queryMetaData1;
/* 3057 */     byte[] arrayOfByte = this.queryMetaData2;
/* 3058 */     int i = this.queryMetaData1Offset;
/* 3059 */     int j = this.queryMetaData2Offset;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 3073 */     paramAutoKeyInfo.allocateSpaceForDescribedData(paramInt);
/*      */     
/* 3075 */     for (byte b = 0; b < paramInt; b++) {
/*      */       
/* 3077 */       short s2 = arrayOfShort[i + 0];
/* 3078 */       short s1 = arrayOfShort[i + 6];
/* 3079 */       String str1 = bytes2String(arrayOfByte, j, s1, this.conversion);
/*      */ 
/*      */       
/* 3082 */       short s3 = arrayOfShort[i + 1];
/* 3083 */       short s4 = arrayOfShort[i + 11];
/* 3084 */       boolean bool = (arrayOfShort[i + 2] != 0) ? true : false;
/* 3085 */       short s5 = arrayOfShort[i + 5];
/* 3086 */       short s6 = arrayOfShort[i + 3];
/* 3087 */       short s7 = arrayOfShort[i + 4];
/* 3088 */       short s8 = arrayOfShort[i + 12];
/*      */       
/* 3090 */       j += s1;
/* 3091 */       i += 13;
/*      */       
/* 3093 */       String str2 = null;
/* 3094 */       if (s8 > 0) {
/*      */         
/* 3096 */         str2 = bytes2String(arrayOfByte, j, s8, this.conversion);
/*      */         
/* 3098 */         j += s8;
/*      */       } 
/*      */ 
/*      */       
/* 3102 */       paramAutoKeyInfo.fillDescribedData(b, str1, s2, (s4 > 0) ? s4 : s3, bool, s5, s6, s7, str2);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   void doSetApplicationContext(String paramString1, String paramString2, String paramString3) throws SQLException {
/* 3114 */     checkError(t2cSetApplicationContext(this.m_nativeState, paramString1, paramString2, paramString3));
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   void doClearAllApplicationContext(String paramString) throws SQLException {
/* 3121 */     checkError(t2cClearAllApplicationContext(this.m_nativeState, paramString));
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private static final void loadNativeLibrary(Properties paramProperties) throws SQLException {
/* 3131 */     String str = null;
/* 3132 */     if (paramProperties != null) {
/* 3133 */       str = paramProperties.getProperty("oracle.jdbc.ocinativelibrary");
/*      */     }
/*      */ 
/*      */     
/* 3137 */     if (str == null || str.equals("ocijdbc10")) {
/*      */       
/* 3139 */       synchronized (T2CConnection.class)
/*      */       {
/* 3141 */         if (!isLibraryLoaded)
/*      */         {
/* 3143 */           AccessController.doPrivileged(new PrivilegedAction()
/*      */               {
/*      */                 public Object run()
/*      */                 {
/* 3147 */                   System.loadLibrary("ocijdbc10");
/* 3148 */                   return null;
/*      */                 }
/*      */               });
/* 3151 */           isLibraryLoaded = true;
/*      */         
/*      */         }
/*      */       
/*      */       }
/*      */     
/*      */     }
/*      */     else {
/*      */       
/* 3160 */       synchronized (T2CConnection.class) {
/*      */ 
/*      */         
/*      */         try {
/* 3164 */           System.loadLibrary(str);
/* 3165 */           isLibraryLoaded = true;
/*      */         }
/* 3167 */         catch (SecurityException securityException) {
/*      */           
/* 3169 */           if (!isLibraryLoaded) {
/*      */             
/* 3171 */             System.loadLibrary(str);
/* 3172 */             isLibraryLoaded = true;
/*      */           } 
/*      */         } 
/*      */       } 
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private final void checkTrue(boolean paramBoolean, int paramInt) throws SQLException {
/* 3185 */     if (!paramBoolean) {
/* 3186 */       DatabaseError.throwSqlException(paramInt);
/*      */     }
/*      */   }
/*      */   
/*      */   boolean useLittleEndianSetCHARBinder() throws SQLException {
/* 3191 */     return t2cPlatformIsLittleEndian(this.m_nativeState);
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public void getPropertyForPooledConnection(OraclePooledConnection paramOraclePooledConnection) throws SQLException {
/* 3197 */     getPropertyForPooledConnection(paramOraclePooledConnection, this.password);
/*      */   }
/*      */ 
/*      */   
/*      */   static final char[] getCharArray(String paramString) {
/* 3202 */     char[] arrayOfChar = null;
/*      */     
/* 3204 */     if (paramString == null) {
/*      */       
/* 3206 */       arrayOfChar = new char[0];
/*      */     }
/*      */     else {
/*      */       
/* 3210 */       arrayOfChar = new char[paramString.length()];
/*      */       
/* 3212 */       paramString.getChars(0, paramString.length(), arrayOfChar, 0);
/*      */     } 
/*      */     
/* 3215 */     return arrayOfChar;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   static String bytes2String(byte[] paramArrayOfbyte, int paramInt1, int paramInt2, DBConversion paramDBConversion) throws SQLException {
/* 3223 */     byte[] arrayOfByte = new byte[paramInt2];
/* 3224 */     System.arraycopy(paramArrayOfbyte, paramInt1, arrayOfByte, 0, paramInt2);
/*      */     
/* 3226 */     return paramDBConversion.CharBytesToString(arrayOfByte, paramInt2);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 3365 */   private static final String _Copyright_2004_Oracle_All_Rights_Reserved_ = null;
/*      */   public static final boolean TRACE = false;
/*      */   public static final boolean PRIVATE_TRACE = false;
/*      */   public static final String BUILD_DATE = "Sat_Feb__2_11:39:38_PST_2008";
/*      */   
/*      */   native int t2cAbort(long paramLong);
/*      */   
/*      */   native int blobRead(long paramLong1, byte[] paramArrayOfbyte1, int paramInt1, long paramLong2, int paramInt2, byte[] paramArrayOfbyte2, int paramInt3);
/*      */   
/*      */   native int clobRead(long paramLong1, byte[] paramArrayOfbyte, int paramInt1, long paramLong2, int paramInt2, char[] paramArrayOfchar, int paramInt3, boolean paramBoolean);
/*      */   
/*      */   native int blobWrite(long paramLong1, byte[] paramArrayOfbyte1, int paramInt1, long paramLong2, int paramInt2, byte[] paramArrayOfbyte2, int paramInt3, byte[][] paramArrayOfbyte);
/*      */   
/*      */   native int clobWrite(long paramLong1, byte[] paramArrayOfbyte, int paramInt1, long paramLong2, int paramInt2, char[] paramArrayOfchar, int paramInt3, byte[][] paramArrayOfbyte1, boolean paramBoolean);
/*      */   
/*      */   native long lobGetLength(long paramLong, byte[] paramArrayOfbyte, int paramInt);
/*      */   
/*      */   native int bfileOpen(long paramLong, byte[] paramArrayOfbyte, int paramInt, byte[][] paramArrayOfbyte1);
/*      */   
/*      */   native int bfileIsOpen(long paramLong, byte[] paramArrayOfbyte, int paramInt, boolean[] paramArrayOfboolean);
/*      */   
/*      */   native int bfileExists(long paramLong, byte[] paramArrayOfbyte, int paramInt, boolean[] paramArrayOfboolean);
/*      */   
/*      */   native String bfileGetName(long paramLong, byte[] paramArrayOfbyte, int paramInt);
/*      */   
/*      */   native String bfileGetDirAlias(long paramLong, byte[] paramArrayOfbyte, int paramInt);
/*      */   
/*      */   native int bfileClose(long paramLong, byte[] paramArrayOfbyte, int paramInt, byte[][] paramArrayOfbyte1);
/*      */   
/*      */   native int lobGetChunkSize(long paramLong, byte[] paramArrayOfbyte, int paramInt);
/*      */   
/*      */   native int lobTrim(long paramLong1, int paramInt1, long paramLong2, byte[] paramArrayOfbyte, int paramInt2, byte[][] paramArrayOfbyte1);
/*      */   
/*      */   native int lobCreateTemporary(long paramLong, int paramInt1, boolean paramBoolean, int paramInt2, short paramShort, byte[][] paramArrayOfbyte);
/*      */   
/*      */   native int lobFreeTemporary(long paramLong, int paramInt1, byte[] paramArrayOfbyte, int paramInt2, byte[][] paramArrayOfbyte1);
/*      */   
/*      */   native int lobIsTemporary(long paramLong, int paramInt1, byte[] paramArrayOfbyte, int paramInt2, boolean[] paramArrayOfboolean);
/*      */   
/*      */   native int lobOpen(long paramLong, int paramInt1, byte[] paramArrayOfbyte, int paramInt2, int paramInt3, byte[][] paramArrayOfbyte1);
/*      */   
/*      */   native int lobIsOpen(long paramLong, int paramInt1, byte[] paramArrayOfbyte, int paramInt2, boolean[] paramArrayOfboolean);
/*      */   
/*      */   native int lobClose(long paramLong, int paramInt1, byte[] paramArrayOfbyte, int paramInt2, byte[][] paramArrayOfbyte1);
/*      */   
/*      */   static native short t2cGetServerSessionInfo(long paramLong, Properties paramProperties);
/*      */   
/*      */   static native short t2cGetDriverCharSetFromNlsLang();
/*      */   
/*      */   native int t2cDescribeError(long paramLong, T2CError paramT2CError, byte[] paramArrayOfbyte);
/*      */   
/*      */   native int t2cCreateState(byte[] paramArrayOfbyte1, int paramInt1, byte[] paramArrayOfbyte2, int paramInt2, byte[] paramArrayOfbyte3, int paramInt3, byte[] paramArrayOfbyte4, int paramInt4, short paramShort, int paramInt5, short[] paramArrayOfshort, byte[] paramArrayOfbyte5, byte[] paramArrayOfbyte6);
/*      */   
/*      */   native int t2cLogon(long paramLong, byte[] paramArrayOfbyte1, int paramInt1, byte[] paramArrayOfbyte2, int paramInt2, byte[] paramArrayOfbyte3, int paramInt3, byte[] paramArrayOfbyte4, int paramInt4, int paramInt5, short[] paramArrayOfshort, byte[] paramArrayOfbyte5, byte[] paramArrayOfbyte6);
/*      */   
/*      */   private native int t2cLogoff(long paramLong);
/*      */   
/*      */   private native int t2cCancel(long paramLong);
/*      */   
/*      */   private native int t2cCreateStatement(long paramLong1, long paramLong2, byte[] paramArrayOfbyte, int paramInt1, OracleStatement paramOracleStatement, boolean paramBoolean, int paramInt2);
/*      */   
/*      */   private native int t2cSetAutoCommit(long paramLong, boolean paramBoolean);
/*      */   
/*      */   private native int t2cCommit(long paramLong);
/*      */   
/*      */   private native int t2cRollback(long paramLong);
/*      */   
/*      */   private native byte[] t2cGetProductionVersion(long paramLong);
/*      */   
/*      */   private native int t2cGetVersionNumber(long paramLong);
/*      */   
/*      */   private native int t2cGetDefaultStreamChunkSize(long paramLong);
/*      */   
/*      */   native int t2cGetFormOfUse(long paramLong, OracleTypeCLOB paramOracleTypeCLOB, byte[] paramArrayOfbyte, int paramInt1, int paramInt2);
/*      */   
/*      */   native long t2cGetTDO(long paramLong, byte[] paramArrayOfbyte, int paramInt, int[] paramArrayOfint);
/*      */   
/*      */   native int t2cCreateConnPool(byte[] paramArrayOfbyte1, int paramInt1, byte[] paramArrayOfbyte2, int paramInt2, byte[] paramArrayOfbyte3, int paramInt3, short paramShort, int paramInt4, int paramInt5, int paramInt6, int paramInt7, int paramInt8, int paramInt9, int paramInt10);
/*      */   
/*      */   native int t2cConnPoolLogon(long paramLong, byte[] paramArrayOfbyte1, int paramInt1, byte[] paramArrayOfbyte2, int paramInt2, byte[] paramArrayOfbyte3, int paramInt3, int paramInt4, int paramInt5, int paramInt6, String[] paramArrayOfString, byte[] paramArrayOfbyte4, int paramInt7, byte[] paramArrayOfbyte5, int paramInt8, byte[] paramArrayOfbyte6, int paramInt9, byte[] paramArrayOfbyte7, int paramInt10, byte[] paramArrayOfbyte8, int paramInt11, short[] paramArrayOfshort, byte[] paramArrayOfbyte9, byte[] paramArrayOfbyte10);
/*      */   
/*      */   native int t2cGetConnPoolInfo(long paramLong, Properties paramProperties);
/*      */   
/*      */   native int t2cSetConnPoolInfo(long paramLong, int paramInt1, int paramInt2, int paramInt3, int paramInt4, int paramInt5, int paramInt6);
/*      */   
/*      */   native int t2cPasswordChange(long paramLong, byte[] paramArrayOfbyte1, int paramInt1, byte[] paramArrayOfbyte2, int paramInt2, byte[] paramArrayOfbyte3, int paramInt3);
/*      */   
/*      */   protected native byte[] t2cGetConnectionId(long paramLong);
/*      */   
/*      */   native int t2cGetHandles(long paramLong, long[] paramArrayOflong);
/*      */   
/*      */   native int t2cUseConnection(long paramLong1, long paramLong2, long paramLong3, long paramLong4, short[] paramArrayOfshort);
/*      */   
/*      */   native boolean t2cPlatformIsLittleEndian(long paramLong);
/*      */   
/*      */   native int t2cRegisterTAFCallback(long paramLong);
/*      */   
/*      */   native int t2cGetHeapAllocSize(long paramLong);
/*      */   
/*      */   native int t2cGetOciEnvHeapAllocSize(long paramLong);
/*      */   
/*      */   native int t2cDoProxySession(long paramLong, int paramInt1, byte[] paramArrayOfbyte1, int paramInt2, byte[] paramArrayOfbyte2, int paramInt3, byte[] paramArrayOfbyte3, int paramInt4, byte[] paramArrayOfbyte4, int paramInt5, int paramInt6, byte[][] paramArrayOfbyte);
/*      */   
/*      */   native int t2cCloseProxySession(long paramLong);
/*      */   
/*      */   static native int t2cDescribeTable(long paramLong, byte[] paramArrayOfbyte1, int paramInt1, short[] paramArrayOfshort, byte[] paramArrayOfbyte2, int paramInt2, int paramInt3, int paramInt4, int paramInt5);
/*      */   
/*      */   native int t2cSetApplicationContext(long paramLong, String paramString1, String paramString2, String paramString3);
/*      */   
/*      */   native int t2cClearAllApplicationContext(long paramLong, String paramString);
/*      */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\lib\ojdbc14.jar!\oracle\jdbc\driver\T2CConnection.class
 * Java compiler version: 2 (46.0)
 * JD-Core Version:       1.1.3
 */