/*      */ package oracle.jdbc.pool;
/*      */ 
/*      */ import java.io.Serializable;
/*      */ import java.sql.Connection;
/*      */ import java.sql.SQLException;
/*      */ import java.sql.SQLWarning;
/*      */ import java.util.Enumeration;
/*      */ import java.util.Hashtable;
/*      */ import java.util.Properties;
/*      */ import java.util.Stack;
/*      */ import javax.naming.NamingException;
/*      */ import javax.naming.Reference;
/*      */ import javax.naming.Referenceable;
/*      */ import javax.naming.StringRefAddr;
/*      */ import javax.sql.ConnectionPoolDataSource;
/*      */ import javax.sql.PooledConnection;
/*      */ import oracle.jdbc.driver.DatabaseError;
/*      */ import oracle.jdbc.internal.OracleConnection;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ public class OracleConnectionCacheImpl
/*      */   extends OracleDataSource
/*      */   implements OracleConnectionCache, Serializable, Referenceable
/*      */ {
/*   48 */   protected ConnectionPoolDataSource cpds = null;
/*      */   
/*   50 */   protected static int _DEFAULT_MIN_LIMIT = 0;
/*      */ 
/*      */   
/*   53 */   protected static int _DEFAULT_MAX_LIMIT = Integer.MAX_VALUE;
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*   58 */   protected int _MIN_LIMIT = _DEFAULT_MIN_LIMIT;
/*   59 */   protected int _MAX_LIMIT = _DEFAULT_MAX_LIMIT;
/*      */   
/*      */   protected static final int DEFAULT_CACHE_TIMEOUT = -1;
/*      */   
/*      */   protected static final int DEFAULT_THREAD_INTERVAL = 900;
/*      */   
/*      */   public static final int ORAERROR_END_OF_FILE_ON_COCHANNEL = 3113;
/*      */   
/*      */   public static final int ORAERROR_NOT_CONNECTED_TO_ORACLE = 3114;
/*      */   
/*      */   public static final int ORAERROR_INIT_SHUTDOWN_IN_PROGRESS = 1033;
/*      */   public static final int ORAERROR_ORACLE_NOT_AVAILABLE = 1034;
/*      */   public static final int ORAERROR_IMMEDIATE_SHUTDOWN_IN_PROGRESS = 1089;
/*      */   public static final int ORAERROR_SHUTDOWN_IN_PROGRESS_NO_CONN = 1090;
/*      */   public static final int ORAERROR_NET_IO_EXCEPTION = 17002;
/*   74 */   protected long cacheTTLTimeOut = -1L;
/*   75 */   protected long cacheInactivityTimeOut = -1L;
/*   76 */   protected long cacheFixedWaitTimeOut = -1L;
/*   77 */   protected long threadInterval = 900L;
/*      */ 
/*      */   
/*   80 */   Stack cache = new Stack();
/*   81 */   Hashtable activeCache = new Hashtable(50);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*   89 */   private Object CACHE_SIZE_LOCK = new String("");
/*   90 */   protected int cacheSize = 0;
/*   91 */   protected int activeSize = 0;
/*      */   
/*      */   protected int cacheScheme;
/*      */   
/*   95 */   protected long cleanupInterval = 30L;
/*   96 */   protected int[] fatalErrorCodes = null;
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public static final long DEFAULT_FIXED_WAIT_IDLE_TIME = 30L;
/*      */ 
/*      */ 
/*      */   
/*  105 */   protected long fixedWaitIdleTime = -1L;
/*      */   
/*      */   public static final int DYNAMIC_SCHEME = 1;
/*      */   
/*      */   public static final int FIXED_WAIT_SCHEME = 2;
/*      */   
/*      */   public static final int FIXED_RETURN_NULL_SCHEME = 3;
/*  112 */   protected OracleConnectionEventListener ocel = null;
/*      */ 
/*      */   
/*  115 */   protected int stmtCacheSize = 0;
/*      */   
/*      */   protected boolean stmtClearMetaData = false;
/*      */   
/*  119 */   protected OracleConnectionCacheTimeOutThread timeOutThread = null;
/*      */ 
/*      */   
/*  122 */   SQLWarning warning = null;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public OracleConnectionCacheImpl() throws SQLException {
/*  142 */     this((ConnectionPoolDataSource)null);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public OracleConnectionCacheImpl(ConnectionPoolDataSource paramConnectionPoolDataSource) throws SQLException {
/*  170 */     this.cacheScheme = 1;
/*      */ 
/*      */     
/*  173 */     this.cpds = paramConnectionPoolDataSource;
/*      */ 
/*      */     
/*  176 */     this.ocel = new OracleConnectionEventListener(this);
/*      */ 
/*      */     
/*  179 */     this.dataSourceName = "OracleConnectionCacheImpl";
/*  180 */     this.isOracleDataSource = false;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void setConnectionPoolDataSource(ConnectionPoolDataSource paramConnectionPoolDataSource) throws SQLException {
/*  213 */     if (this.cacheSize > 0) {
/*  214 */       DatabaseError.throwSqlException(78);
/*      */     }
/*  216 */     this.cpds = paramConnectionPoolDataSource;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Connection getConnection() throws SQLException {
/*  237 */     return getConnection(this.user, this.password);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Connection getConnection(String paramString1, String paramString2) throws SQLException {
/*  257 */     Connection connection = null;
/*      */     
/*  259 */     PooledConnection pooledConnection = getPooledConnection(paramString1, paramString2);
/*      */     
/*  261 */     if (pooledConnection != null)
/*      */     {
/*      */ 
/*      */       
/*  265 */       connection = pooledConnection.getConnection();
/*      */     }
/*      */ 
/*      */     
/*  269 */     if (connection != null) {
/*  270 */       ((OracleConnection)connection).setStartTime(System.currentTimeMillis());
/*      */     }
/*  272 */     return connection;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected PooledConnection getPooledConnection(String paramString1, String paramString2) throws SQLException {
/*  282 */     PooledConnection pooledConnection = null;
/*  283 */     boolean bool1 = false;
/*  284 */     boolean bool2 = false;
/*  285 */     long l = Long.MAX_VALUE;
/*  286 */     Properties properties = null;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  291 */     synchronized (this) {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*  301 */       if (!this.cache.empty()) {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */         
/*  308 */         checkCredentials(paramString1, paramString2);
/*      */         
/*  310 */         pooledConnection = removeConnectionFromCache();
/*      */       }
/*  312 */       else if (this.cacheSize < this._MAX_LIMIT || this.cacheScheme == 1) {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */         
/*  320 */         String str1 = null;
/*  321 */         String str2 = null;
/*      */         
/*  323 */         if (this.cpds != null) {
/*      */           
/*  325 */           str1 = ((OracleConnectionPoolDataSource)this.cpds).getUser();
/*  326 */           str2 = ((OracleConnectionPoolDataSource)this.cpds).getPassword();
/*      */         } 
/*      */ 
/*      */         
/*  330 */         if (this.cacheSize > 0 && paramString1 != null && !paramString1.equalsIgnoreCase(str1))
/*      */         {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */           
/*  337 */           DatabaseError.throwSqlException(79);
/*      */         }
/*      */         
/*  340 */         if (this.cacheSize > 0 && paramString2 != null && !paramString2.equalsIgnoreCase(str2))
/*      */         {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */           
/*  347 */           DatabaseError.throwSqlException(79);
/*      */         }
/*      */ 
/*      */ 
/*      */         
/*  352 */         bool1 = true;
/*  353 */         properties = new Properties();
/*  354 */         if (this.url != null)
/*  355 */           properties.setProperty("connection_url", this.url); 
/*  356 */         if (paramString1 != null) {
/*  357 */           properties.setProperty("user", paramString1);
/*  358 */         } else if (this.cpds != null && ((OracleDataSource)this.cpds).user != null) {
/*  359 */           properties.setProperty("user", ((OracleDataSource)this.cpds).user);
/*      */         } 
/*  361 */         if (paramString2 != null) {
/*  362 */           properties.setProperty("password", paramString2);
/*  363 */         } else if (this.cpds != null && ((OracleDataSource)this.cpds).password != null) {
/*  364 */           properties.setProperty("password", ((OracleDataSource)this.cpds).password);
/*      */         } 
/*  366 */         if (this.stmtCacheSize == 0 && this.cpds != null && ((OracleDataSource)this.cpds).maxStatements != 0) {
/*      */ 
/*      */           
/*  369 */           properties.setProperty("stmt_cache_size", "" + ((OracleDataSource)this.cpds).maxStatements);
/*      */         
/*      */         }
/*      */         else {
/*      */           
/*  374 */           properties.setProperty("stmt_cache_size", "" + this.stmtCacheSize);
/*      */           
/*  376 */           properties.setProperty("stmt_cache_clear_metadata", "" + this.stmtClearMetaData);
/*      */           
/*  378 */           properties.setProperty("ImplicitStatementCachingEnabled", "" + this.implicitCachingEnabled);
/*      */           
/*  380 */           properties.setProperty("ExplicitStatementCachingEnabled", "" + this.explicitCachingEnabled);
/*      */         } 
/*      */         
/*  383 */         if (this.loginTimeout != 0) {
/*  384 */           properties.setProperty("LoginTimeout", "" + this.loginTimeout);
/*      */         }
/*  386 */         synchronized (this.CACHE_SIZE_LOCK) {
/*  387 */           this.cacheSize++;
/*      */         } 
/*  389 */         if (this.cpds == null)
/*      */         {
/*  391 */           initializeConnectionPoolDataSource();
/*      */ 
/*      */ 
/*      */         
/*      */         }
/*      */ 
/*      */ 
/*      */       
/*      */       }
/*  400 */       else if (this.cacheScheme != 3) {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */         
/*  409 */         checkCredentials(paramString1, paramString2);
/*      */ 
/*      */         
/*  412 */         l = System.currentTimeMillis();
/*  413 */         bool2 = true;
/*      */       } 
/*      */     } 
/*      */ 
/*      */ 
/*      */     
/*  419 */     if (bool1) {
/*      */ 
/*      */       
/*      */       try {
/*  423 */         pooledConnection = getNewPoolOrXAConnection(properties);
/*      */         
/*  425 */         if (pooledConnection != null)
/*  426 */           pooledConnection.addConnectionEventListener(this.ocel); 
/*  427 */       } catch (SQLException sQLException) {
/*      */         
/*  429 */         synchronized (this.CACHE_SIZE_LOCK) {
/*      */           
/*  431 */           this.cacheSize--;
/*      */         } 
/*      */ 
/*      */ 
/*      */ 
/*      */         
/*  437 */         throw sQLException;
/*      */       } 
/*      */     } else {
/*      */       
/*  441 */       if (bool2)
/*      */       {
/*  443 */         while (pooledConnection == null && this.cache.empty()) {
/*      */ 
/*      */ 
/*      */ 
/*      */           
/*  448 */           synchronized (this) {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */             
/*  456 */             if (this.cacheFixedWaitTimeOut > 0L && System.currentTimeMillis() - l > this.cacheFixedWaitTimeOut * 1000L)
/*      */             {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */               
/*  464 */               DatabaseError.throwSqlException(126);
/*      */             }
/*      */           } 
/*      */ 
/*      */ 
/*      */           
/*  470 */           synchronized (this.cache) {
/*      */ 
/*      */             
/*      */             try {
/*  474 */               this.cache.wait(((this.fixedWaitIdleTime == -1L) ? 30L : this.fixedWaitIdleTime) * 1000L);
/*      */             
/*      */             }
/*  477 */             catch (InterruptedException interruptedException) {}
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */             
/*  487 */             if (!this.cache.empty()) {
/*  488 */               pooledConnection = removeConnectionFromCache();
/*      */             }
/*      */           } 
/*      */         } 
/*      */       }
/*      */ 
/*      */       
/*  495 */       if (pooledConnection != null && this.stmtCacheSize > 0)
/*      */       {
/*      */         
/*  498 */         if (!this.explicitCachingEnabled && !this.implicitCachingEnabled) {
/*      */           
/*  500 */           ((OraclePooledConnection)pooledConnection).setStmtCacheSize(this.stmtCacheSize);
/*      */         } else {
/*      */           
/*  503 */           ((OraclePooledConnection)pooledConnection).setStatementCacheSize(this.stmtCacheSize);
/*  504 */           ((OraclePooledConnection)pooledConnection).setExplicitCachingEnabled(this.explicitCachingEnabled);
/*      */           
/*  506 */           ((OraclePooledConnection)pooledConnection).setImplicitCachingEnabled(this.implicitCachingEnabled);
/*      */         } 
/*      */       }
/*      */     } 
/*      */ 
/*      */     
/*  512 */     if (pooledConnection != null) {
/*      */       
/*  514 */       if (!bool1) {
/*      */ 
/*      */         
/*  517 */         ((OraclePooledConnection)pooledConnection).physicalConn.setDefaultRowPrefetch(10);
/*  518 */         ((OraclePooledConnection)pooledConnection).physicalConn.setDefaultExecuteBatch(1);
/*      */       } 
/*      */ 
/*      */       
/*  522 */       this.activeCache.put(pooledConnection, pooledConnection);
/*      */       
/*  524 */       synchronized (this) {
/*      */         
/*  526 */         this.activeSize = this.activeCache.size();
/*      */       } 
/*      */     } 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  536 */     return pooledConnection;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   PooledConnection getNewPoolOrXAConnection(Properties paramProperties) throws SQLException {
/*  547 */     return ((OracleConnectionPoolDataSource)this.cpds).getPooledConnection(paramProperties);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void reusePooledConnection(PooledConnection paramPooledConnection) throws SQLException {
/*  574 */     detachSingleConnection(paramPooledConnection);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  580 */     if (this.cache.size() >= this._MAX_LIMIT && this.cacheScheme == 1) {
/*      */       
/*  582 */       closeSingleConnection(paramPooledConnection, false);
/*      */     } else {
/*  584 */       putConnectionToCache(paramPooledConnection);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void closePooledConnection(PooledConnection paramPooledConnection) throws SQLException {
/*  606 */     detachSingleConnection(paramPooledConnection);
/*      */ 
/*      */     
/*  609 */     closeSingleConnection(paramPooledConnection, false);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private void detachSingleConnection(PooledConnection paramPooledConnection) {
/*  622 */     this.activeCache.remove(paramPooledConnection);
/*      */ 
/*      */     
/*  625 */     this.activeSize = this.activeCache.size();
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void closeSingleConnection(PooledConnection paramPooledConnection) throws SQLException {
/*  642 */     closeSingleConnection(paramPooledConnection, true);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   final void closeSingleConnection(PooledConnection paramPooledConnection, boolean paramBoolean) throws SQLException {
/*  652 */     if (!removeConnectionFromCache(paramPooledConnection) && paramBoolean) {
/*      */       return;
/*      */     }
/*      */ 
/*      */ 
/*      */     
/*      */     try {
/*  659 */       paramPooledConnection.removeConnectionEventListener(this.ocel);
/*  660 */       paramPooledConnection.close();
/*      */     }
/*  662 */     catch (SQLException sQLException) {
/*      */ 
/*      */ 
/*      */       
/*  666 */       this.warning = DatabaseError.addSqlWarning(this.warning, new SQLWarning(sQLException.getMessage()));
/*      */     } 
/*      */ 
/*      */     
/*  670 */     synchronized (this.CACHE_SIZE_LOCK) {
/*      */ 
/*      */ 
/*      */       
/*  674 */       this.cacheSize--;
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void close() throws SQLException {
/*  700 */     closeConnections();
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  707 */     this.cache = null;
/*  708 */     this.activeCache = null;
/*  709 */     this.ocel = null;
/*  710 */     this.cpds = null;
/*  711 */     this.timeOutThread = null;
/*      */     
/*  713 */     clearWarnings();
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void closeConnections() {
/*  730 */     Enumeration enumeration = this.activeCache.keys();
/*      */     
/*  732 */     while (enumeration.hasMoreElements()) {
/*      */ 
/*      */       
/*      */       try {
/*  736 */         OraclePooledConnection oraclePooledConnection2 = enumeration.nextElement();
/*  737 */         OraclePooledConnection oraclePooledConnection1 = (OraclePooledConnection)this.activeCache.get(oraclePooledConnection2);
/*      */         
/*  739 */         if (oraclePooledConnection1 == null) {
/*      */           continue;
/*      */         }
/*  742 */         oraclePooledConnection1.removeConnectionEventListener(this.ocel);
/*  743 */         detachSingleConnection(oraclePooledConnection1);
/*      */ 
/*      */ 
/*      */         
/*  747 */         closeSingleConnection(oraclePooledConnection1, false);
/*      */       }
/*  749 */       catch (Exception exception) {}
/*      */     } 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  759 */     while (!this.cache.empty()) {
/*      */ 
/*      */       
/*      */       try {
/*  763 */         OraclePooledConnection oraclePooledConnection = this.cache.peek();
/*  764 */         oraclePooledConnection.removeConnectionEventListener(this.ocel);
/*  765 */         closeSingleConnection(oraclePooledConnection, false);
/*      */       }
/*  767 */       catch (SQLException sQLException) {}
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void setConnectionCleanupInterval(long paramLong) throws SQLException {
/*  796 */     if (paramLong > 0L) {
/*  797 */       this.cleanupInterval = paramLong;
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public long getConnectionCleanupInterval() throws SQLException {
/*  813 */     return this.cleanupInterval;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void setConnectionErrorCodes(int[] paramArrayOfint) throws SQLException {
/*  829 */     if (paramArrayOfint != null) {
/*  830 */       paramArrayOfint = paramArrayOfint;
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public int[] getConnectionErrorCodes() throws SQLException {
/*  846 */     return this.fatalErrorCodes;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public boolean isFatalConnectionError(SQLException paramSQLException) {
/*  863 */     if (this.cleanupInterval < 0L) {
/*  864 */       return false;
/*      */     }
/*  866 */     boolean bool = false;
/*  867 */     int i = paramSQLException.getErrorCode();
/*      */ 
/*      */     
/*  870 */     if (i == 3113 || i == 3114 || i == 1033 || i == 1034 || i == 1089 || i == 1090 || i == 17002) {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*  878 */       bool = true;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     }
/*  884 */     else if (this.fatalErrorCodes != null) {
/*      */       
/*  886 */       for (byte b = 0; b < this.fatalErrorCodes.length; b++) {
/*  887 */         if (i == this.fatalErrorCodes[b]) {
/*  888 */           bool = true;
/*      */         }
/*      */       } 
/*      */     } 
/*  892 */     return bool;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void setMinLimit(int paramInt) throws SQLException {
/*  908 */     if (paramInt < 0 || paramInt > this._MAX_LIMIT) {
/*  909 */       DatabaseError.throwSqlException(68);
/*      */     }
/*  911 */     this._MIN_LIMIT = paramInt;
/*  912 */     if (this.cpds == null)
/*      */     {
/*  914 */       initializeConnectionPoolDataSource();
/*      */     }
/*      */     
/*  917 */     if (this.cacheSize < this._MIN_LIMIT) {
/*      */       
/*  919 */       Properties properties = new Properties();
/*  920 */       if (this.url != null)
/*  921 */         properties.setProperty("connection_url", this.url); 
/*  922 */       if (this.user != null)
/*  923 */         properties.setProperty("user", this.user); 
/*  924 */       if (this.password != null) {
/*  925 */         properties.setProperty("password", this.password);
/*      */       }
/*  927 */       if (this.stmtCacheSize == 0 && this.maxStatements != 0) {
/*      */         
/*  929 */         properties.setProperty("stmt_cache_size", "" + this.maxStatements);
/*      */       
/*      */       }
/*      */       else {
/*      */         
/*  934 */         properties.setProperty("stmt_cache_size", "" + this.stmtCacheSize);
/*  935 */         properties.setProperty("stmt_cache_clear_metadata", "" + this.stmtClearMetaData);
/*      */         
/*  937 */         properties.setProperty("ImplicitStatementCachingEnabled", "" + this.implicitCachingEnabled);
/*      */         
/*  939 */         properties.setProperty("ExplicitStatementCachingEnabled", "" + this.explicitCachingEnabled);
/*      */       } 
/*      */       
/*  942 */       properties.setProperty("LoginTimeout", "" + this.loginTimeout);
/*      */ 
/*      */       
/*  945 */       for (int i = this.cacheSize; i < this._MIN_LIMIT; i++) {
/*      */         
/*  947 */         PooledConnection pooledConnection = getNewPoolOrXAConnection(properties);
/*      */         
/*  949 */         if (pooledConnection != null)
/*  950 */           pooledConnection.addConnectionEventListener(this.ocel); 
/*  951 */         putConnectionToCache(pooledConnection);
/*      */       } 
/*      */       
/*  954 */       this.cacheSize = this._MIN_LIMIT;
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   void initializeConnectionPoolDataSource() throws SQLException {
/*  966 */     if (this.cpds == null) {
/*      */ 
/*      */       
/*  969 */       if (this.user == null || this.password == null) {
/*  970 */         DatabaseError.throwSqlException(79);
/*      */       }
/*  972 */       this.cpds = new OracleConnectionPoolDataSource();
/*      */       
/*  974 */       copy((OracleDataSource)this.cpds);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized int getMinLimit() {
/*  990 */     return this._MIN_LIMIT;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void setMaxLimit(int paramInt) throws SQLException {
/* 1006 */     if (paramInt < 0 || paramInt < this._MIN_LIMIT) {
/* 1007 */       DatabaseError.throwSqlException(68);
/*      */     }
/* 1009 */     this._MAX_LIMIT = paramInt;
/*      */     
/* 1011 */     if (this.cacheSize > this._MAX_LIMIT && this.cacheScheme != 1) {
/*      */       
/* 1013 */       for (int i = this._MAX_LIMIT; i < this.cacheSize; i++) {
/*      */         
/* 1015 */         if (this.cache.empty()) {
/* 1016 */           DatabaseError.throwSqlException(78);
/*      */         } else {
/*      */           
/* 1019 */           OraclePooledConnection oraclePooledConnection = (OraclePooledConnection)removeConnectionFromCache();
/*      */           
/* 1021 */           oraclePooledConnection.removeConnectionEventListener(this.ocel);
/* 1022 */           oraclePooledConnection.close();
/*      */         } 
/*      */       } 
/*      */       
/* 1026 */       this.cacheSize = this._MAX_LIMIT;
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized int getMaxLimit() {
/* 1047 */     return this._MAX_LIMIT;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized int getCacheScheme() {
/* 1063 */     return this.cacheScheme;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void setCacheScheme(int paramInt) throws SQLException {
/* 1082 */     if (paramInt == 1 || paramInt == 3 || paramInt == 2) {
/*      */ 
/*      */       
/* 1085 */       this.cacheScheme = paramInt;
/*      */       
/*      */       return;
/*      */     } 
/*      */     
/* 1090 */     DatabaseError.throwSqlException(68);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void setCacheScheme(String paramString) throws SQLException {
/* 1109 */     if (paramString.equalsIgnoreCase("DYNAMIC_SCHEME")) {
/* 1110 */       this.cacheScheme = 1;
/* 1111 */     } else if (paramString.equalsIgnoreCase("FIXED_RETURN_NULL_SCHEME")) {
/* 1112 */       this.cacheScheme = 3;
/* 1113 */     } else if (paramString.equalsIgnoreCase("FIXED_WAIT_SCHEME")) {
/* 1114 */       this.cacheScheme = 2;
/*      */     } else {
/* 1116 */       DatabaseError.throwSqlException(68);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized int getActiveSize() {
/* 1134 */     return this.activeSize;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized int getCacheSize() {
/* 1150 */     return this.cacheSize;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void setCacheTimeToLiveTimeout(long paramLong) throws SQLException {
/* 1171 */     if (this.timeOutThread == null) {
/* 1172 */       this.timeOutThread = new OracleConnectionCacheTimeOutThread(this);
/*      */     }
/*      */ 
/*      */     
/* 1176 */     if (paramLong <= 0L) {
/*      */       
/* 1178 */       this.cacheTTLTimeOut = -1L;
/* 1179 */       this.warning = DatabaseError.addSqlWarning(this.warning, 111);
/*      */     
/*      */     }
/*      */     else {
/*      */ 
/*      */       
/* 1185 */       this.cacheTTLTimeOut = paramLong;
/*      */       
/* 1187 */       checkAndStartTimeOutThread();
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void setCacheInactivityTimeout(long paramLong) throws SQLException {
/* 1209 */     if (this.timeOutThread == null) {
/* 1210 */       this.timeOutThread = new OracleConnectionCacheTimeOutThread(this);
/*      */     }
/*      */ 
/*      */     
/* 1214 */     if (paramLong <= 0L) {
/*      */       
/* 1216 */       this.cacheInactivityTimeOut = -1L;
/* 1217 */       this.warning = DatabaseError.addSqlWarning(this.warning, 124);
/*      */     
/*      */     }
/*      */     else {
/*      */ 
/*      */       
/* 1223 */       this.cacheInactivityTimeOut = paramLong;
/*      */       
/* 1225 */       checkAndStartTimeOutThread();
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void setCacheFixedWaitTimeout(long paramLong) throws SQLException {
/* 1247 */     if (paramLong <= 0L) {
/*      */       
/* 1249 */       this.cacheFixedWaitTimeOut = -1L;
/* 1250 */       this.warning = DatabaseError.addSqlWarning(this.warning, 127);
/*      */     
/*      */     }
/*      */     else {
/*      */ 
/*      */       
/* 1256 */       this.cacheFixedWaitTimeOut = paramLong;
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public long getCacheTimeToLiveTimeout() throws SQLException {
/* 1275 */     return this.cacheTTLTimeOut;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public long getCacheInactivityTimeout() throws SQLException {
/* 1293 */     return this.cacheInactivityTimeOut;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public long getCacheFixedWaitTimeout() throws SQLException {
/* 1311 */     return this.cacheFixedWaitTimeOut;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void setThreadWakeUpInterval(long paramLong) throws SQLException {
/* 1332 */     if (paramLong <= 0L) {
/*      */       
/* 1334 */       this.threadInterval = 900L;
/* 1335 */       this.warning = DatabaseError.addSqlWarning(this.warning, 112);
/*      */     
/*      */     }
/*      */     else {
/*      */ 
/*      */       
/* 1341 */       this.threadInterval = paramLong;
/*      */     } 
/*      */ 
/*      */     
/* 1345 */     if ((this.cacheTTLTimeOut > 0L && this.threadInterval > this.cacheTTLTimeOut) || (this.cacheInactivityTimeOut > 0L && this.threadInterval > this.cacheInactivityTimeOut))
/*      */     {
/*      */ 
/*      */       
/* 1349 */       this.warning = DatabaseError.addSqlWarning(this.warning, 113);
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public long getThreadWakeUpInterval() throws SQLException {
/* 1370 */     return this.threadInterval;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private void checkAndStartTimeOutThread() throws SQLException {
/*      */     try {
/* 1386 */       if (!this.timeOutThread.isAlive())
/*      */       {
/* 1388 */         this.timeOutThread.setDaemon(true);
/* 1389 */         this.timeOutThread.start();
/*      */       }
/*      */     
/* 1392 */     } catch (IllegalThreadStateException illegalThreadStateException) {}
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public SQLWarning getWarnings() throws SQLException {
/* 1411 */     return this.warning;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void clearWarnings() throws SQLException {
/* 1425 */     this.warning = null;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private final void checkCredentials(String paramString1, String paramString2) throws SQLException {
/* 1438 */     String str1 = null;
/* 1439 */     String str2 = null;
/*      */     
/* 1441 */     if (this.cpds != null) {
/*      */       
/* 1443 */       str1 = ((OracleConnectionPoolDataSource)this.cpds).getUser();
/* 1444 */       str2 = ((OracleConnectionPoolDataSource)this.cpds).getPassword();
/*      */     } 
/*      */     
/* 1447 */     if ((paramString1 != null && !paramString1.equals(str1)) || (paramString2 != null && !paramString2.equals(str2)))
/*      */     {
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 1453 */       DatabaseError.throwSqlException(79);
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized Reference getReference() throws NamingException {
/* 1468 */     Reference reference = new Reference(getClass().getName(), "oracle.jdbc.pool.OracleDataSourceFactory", null);
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1473 */     addRefProperties(reference);
/*      */     
/* 1475 */     if (this._MIN_LIMIT != _DEFAULT_MIN_LIMIT) {
/* 1476 */       reference.add(new StringRefAddr("minLimit", Integer.toString(this._MIN_LIMIT)));
/*      */     }
/* 1478 */     if (this._MAX_LIMIT != _DEFAULT_MAX_LIMIT) {
/* 1479 */       reference.add(new StringRefAddr("maxLimit", Integer.toString(this._MAX_LIMIT)));
/*      */     }
/* 1481 */     if (this.cacheScheme != 1) {
/* 1482 */       reference.add(new StringRefAddr("cacheScheme", Integer.toString(this.cacheScheme)));
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1488 */     return reference;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void setStmtCacheSize(int paramInt) throws SQLException {
/* 1515 */     setStmtCacheSize(paramInt, false);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void setStmtCacheSize(int paramInt, boolean paramBoolean) throws SQLException {
/* 1544 */     if (paramInt < 0) {
/* 1545 */       DatabaseError.throwSqlException(68);
/*      */     }
/* 1547 */     this.stmtCacheSize = paramInt;
/* 1548 */     this.stmtClearMetaData = paramBoolean;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized int getStmtCacheSize() {
/* 1564 */     return this.stmtCacheSize;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   synchronized boolean isStmtCacheEnabled() {
/* 1577 */     if (this.stmtCacheSize > 0) {
/* 1578 */       return true;
/*      */     }
/* 1580 */     return false;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private void putConnectionToCache(PooledConnection paramPooledConnection) throws SQLException {
/* 1600 */     ((OraclePooledConnection)paramPooledConnection).setLastAccessedTime(System.currentTimeMillis());
/* 1601 */     this.cache.push(paramPooledConnection);
/*      */ 
/*      */     
/* 1604 */     synchronized (this.cache) {
/*      */       
/* 1606 */       this.cache.notify();
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private PooledConnection removeConnectionFromCache() throws SQLException {
/* 1619 */     return this.cache.pop();
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private boolean removeConnectionFromCache(PooledConnection paramPooledConnection) throws SQLException {
/* 1632 */     return this.cache.removeElement(paramPooledConnection);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void setCacheFixedWaitIdleTime(long paramLong) throws SQLException {
/* 1658 */     if (this.cacheScheme == 2) {
/*      */       
/* 1660 */       if (paramLong <= 0L) {
/*      */         
/* 1662 */         DatabaseError.addSqlWarning(this.warning, 68);
/*      */ 
/*      */         
/* 1665 */         this.fixedWaitIdleTime = 30L;
/*      */       } else {
/*      */         
/* 1668 */         this.fixedWaitIdleTime = paramLong;
/*      */       } 
/*      */     } else {
/* 1671 */       DatabaseError.addSqlWarning(this.warning, new SQLWarning("Caching scheme is not FIXED_WAIT_SCHEME"));
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public long getCacheFixedWaitIdleTime() throws SQLException {
/* 1690 */     return (this.fixedWaitIdleTime == -1L) ? 30L : this.fixedWaitIdleTime;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 1701 */   private static final String _Copyright_2004_Oracle_All_Rights_Reserved_ = null;
/*      */   public static final boolean TRACE = false;
/*      */   public static final boolean PRIVATE_TRACE = false;
/*      */   public static final String BUILD_DATE = "Sat_Feb__2_11:39:40_PST_2008";
/*      */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\lib\ojdbc14.jar!\oracle\jdbc\pool\OracleConnectionCacheImpl.class
 * Java compiler version: 2 (46.0)
 * JD-Core Version:       1.1.3
 */