/*      */ package oracle.jdbc.pool;
/*      */ 
/*      */ import java.io.UnsupportedEncodingException;
/*      */ import java.security.AccessController;
/*      */ import java.security.PrivilegedActionException;
/*      */ import java.security.PrivilegedExceptionAction;
/*      */ import java.sql.SQLException;
/*      */ import java.util.Enumeration;
/*      */ import java.util.Hashtable;
/*      */ import java.util.Iterator;
/*      */ import java.util.Map;
/*      */ import java.util.Properties;
/*      */ import java.util.StringTokenizer;
/*      */ import javax.sql.ConnectionPoolDataSource;
/*      */ import oracle.jdbc.driver.DatabaseError;
/*      */ import oracle.ons.ONS;
/*      */ import oracle.ons.ONSException;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ public class OracleConnectionCacheManager
/*      */ {
/*   56 */   private static OracleConnectionCacheManager cacheManagerInstance = null;
/*      */   
/*   58 */   protected Hashtable m_connCache = null;
/*      */ 
/*      */   
/*      */   public static final int REFRESH_INVALID_CONNECTIONS = 4096;
/*      */ 
/*      */   
/*      */   public static final int REFRESH_ALL_CONNECTIONS = 8192;
/*      */   
/*      */   public static final String PHYSICAL_CONNECTION_CREATED_COUNT = "PhysicalConnectionCreatedCount";
/*      */   
/*      */   public static final String PHYSICAL_CONNECTION_CLOSED_COUNT = "PhysicalConnectionClosedCount";
/*      */   
/*      */   protected static final int FAILOVER_EVENT_TYPE_SERVICE = 256;
/*      */   
/*      */   protected static final int FAILOVER_EVENT_TYPE_HOST = 512;
/*      */   
/*      */   protected static final String EVENT_DELIMITER = "{} =";
/*      */   
/*   76 */   protected OracleFailoverEventHandlerThread failoverEventHandlerThread = null;
/*      */   
/*      */   private static boolean isONSInitializedForRemoteSubscription = false;
/*      */   
/*      */   static final int ORAERROR_END_OF_FILE_ON_COM_CHANNEL = 3113;
/*      */   
/*      */   static final int ORAERROR_NOT_CONNECTED_TO_ORACLE = 3114;
/*      */   
/*      */   static final int ORAERROR_INIT_SHUTDOWN_IN_PROGRESS = 1033;
/*      */   
/*      */   static final int ORAERROR_ORACLE_NOT_AVAILABLE = 1034;
/*      */   
/*      */   static final int ORAERROR_IMMEDIATE_SHUTDOWN_IN_PROGRESS = 1089;
/*      */   
/*      */   static final int ORAERROR_SHUTDOWN_IN_PROGRESS_NO_CONN = 1090;
/*      */   
/*      */   static final int ORAERROR_NET_IO_EXCEPTION = 17002;
/*      */   
/*   94 */   protected int[] fatalErrorCodes = null;
/*   95 */   protected int failoverEnabledCacheCount = 0;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private OracleConnectionCacheManager() {
/*  105 */     this.m_connCache = new Hashtable();
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public static synchronized OracleConnectionCacheManager getConnectionCacheManagerInstance() throws SQLException {
/*      */     try {
/*  122 */       if (cacheManagerInstance == null) {
/*  123 */         cacheManagerInstance = new OracleConnectionCacheManager();
/*      */       }
/*  125 */     } catch (RuntimeException runtimeException) {}
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  131 */     return cacheManagerInstance;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public String createCache(OracleDataSource paramOracleDataSource, Properties paramProperties) throws SQLException {
/*  151 */     String str = null;
/*      */     
/*  153 */     if (paramOracleDataSource == null || !paramOracleDataSource.getConnectionCachingEnabled())
/*      */     {
/*  155 */       DatabaseError.throwSqlException(137);
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  162 */     if (paramOracleDataSource.connCacheName != null) {
/*      */       
/*  164 */       str = paramOracleDataSource.connCacheName;
/*      */     }
/*      */     else {
/*      */       
/*  168 */       str = paramOracleDataSource.dataSourceName + "#0x" + Integer.toHexString(this.m_connCache.size());
/*      */     } 
/*      */ 
/*      */     
/*  172 */     createCache(str, paramOracleDataSource, paramProperties);
/*      */     
/*  174 */     return str;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void createCache(String paramString, OracleDataSource paramOracleDataSource, Properties paramProperties) throws SQLException {
/*  195 */     if (paramOracleDataSource == null || !paramOracleDataSource.getConnectionCachingEnabled())
/*      */     {
/*  197 */       DatabaseError.throwSqlException(137);
/*      */     }
/*      */     
/*  200 */     if (paramString == null)
/*      */     {
/*  202 */       DatabaseError.throwSqlException(138);
/*      */     }
/*      */ 
/*      */     
/*  206 */     if (this.m_connCache.containsKey(paramString))
/*      */     {
/*  208 */       DatabaseError.throwSqlException(140);
/*      */     }
/*      */     
/*  211 */     boolean bool = paramOracleDataSource.getFastConnectionFailoverEnabled();
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  219 */     if (bool && this.failoverEventHandlerThread == null) {
/*      */ 
/*      */ 
/*      */       
/*  223 */       String str = paramOracleDataSource.getONSConfiguration();
/*      */ 
/*      */ 
/*      */       
/*  227 */       if (str != null && !str.equals(""))
/*      */       {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */         
/*  235 */         synchronized (this) {
/*      */           
/*  237 */           if (!isONSInitializedForRemoteSubscription) {
/*      */ 
/*      */             
/*      */             try {
/*      */               
/*  242 */               AccessController.doPrivileged(new PrivilegedExceptionAction(this, str)
/*      */                   {
/*      */                     private final String val$onsConfigStr;
/*      */                     
/*      */                     private final OracleConnectionCacheManager this$0;
/*      */ 
/*      */                     
/*      */                     public Object run() throws ONSException {
/*  250 */                       ONS oNS = new ONS(this.val$onsConfigStr);
/*  251 */                       return null;
/*      */                     }
/*      */                   });
/*      */             }
/*  255 */             catch (PrivilegedActionException privilegedActionException) {
/*      */               
/*  257 */               DatabaseError.throwSqlException(175, privilegedActionException);
/*      */             } 
/*      */ 
/*      */             
/*  261 */             isONSInitializedForRemoteSubscription = true;
/*      */           } 
/*      */         } 
/*      */       }
/*      */       
/*  266 */       this.failoverEventHandlerThread = new OracleFailoverEventHandlerThread();
/*      */     } 
/*      */ 
/*      */     
/*  270 */     OracleImplicitConnectionCache oracleImplicitConnectionCache = new OracleImplicitConnectionCache(paramOracleDataSource, paramProperties);
/*      */ 
/*      */     
/*  273 */     oracleImplicitConnectionCache.cacheName = paramString;
/*  274 */     paramOracleDataSource.odsCache = oracleImplicitConnectionCache;
/*      */ 
/*      */     
/*  277 */     this.m_connCache.put(paramString, oracleImplicitConnectionCache);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  285 */     if (bool)
/*      */     {
/*      */ 
/*      */ 
/*      */       
/*  290 */       checkAndStartThread(this.failoverEventHandlerThread);
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void removeCache(String paramString, long paramLong) throws SQLException {
/*  318 */     OracleImplicitConnectionCache oracleImplicitConnectionCache = (paramString != null) ? (OracleImplicitConnectionCache)this.m_connCache.remove(paramString) : null;
/*      */ 
/*      */     
/*  321 */     if (oracleImplicitConnectionCache != null) {
/*      */       
/*  323 */       oracleImplicitConnectionCache.disableConnectionCache();
/*      */ 
/*      */       
/*  326 */       if (paramLong > 0L) {
/*      */         
/*      */         try {
/*      */           
/*  330 */           Thread.currentThread(); Thread.sleep(paramLong * 1000L);
/*      */         }
/*  332 */         catch (InterruptedException interruptedException) {}
/*      */       }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*  340 */       if (oracleImplicitConnectionCache.cacheEnabledDS.getFastConnectionFailoverEnabled()) {
/*  341 */         cleanupFCFThreads(oracleImplicitConnectionCache);
/*      */       }
/*      */       
/*  344 */       oracleImplicitConnectionCache.closeConnectionCache((paramLong < 0L) ? 32 : 1);
/*      */       
/*  346 */       oracleImplicitConnectionCache = null;
/*      */     }
/*      */     else {
/*      */       
/*  350 */       DatabaseError.throwSqlException(141);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void reinitializeCache(String paramString, Properties paramProperties) throws SQLException {
/*  368 */     OracleImplicitConnectionCache oracleImplicitConnectionCache = (paramString != null) ? (OracleImplicitConnectionCache)this.m_connCache.get(paramString) : null;
/*      */ 
/*      */     
/*  371 */     if (oracleImplicitConnectionCache != null) {
/*      */       
/*  373 */       disableCache(paramString);
/*  374 */       oracleImplicitConnectionCache.reinitializeCacheConnections(paramProperties);
/*  375 */       enableCache(paramString);
/*      */     }
/*      */     else {
/*      */       
/*  379 */       DatabaseError.throwSqlException(141);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public boolean existsCache(String paramString) throws SQLException {
/*  398 */     return this.m_connCache.containsKey(paramString);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void enableCache(String paramString) throws SQLException {
/*  413 */     OracleImplicitConnectionCache oracleImplicitConnectionCache = (paramString != null) ? (OracleImplicitConnectionCache)this.m_connCache.get(paramString) : null;
/*      */ 
/*      */     
/*  416 */     if (oracleImplicitConnectionCache != null) {
/*      */       
/*  418 */       oracleImplicitConnectionCache.enableConnectionCache();
/*      */     }
/*      */     else {
/*      */       
/*  422 */       DatabaseError.throwSqlException(141);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void disableCache(String paramString) throws SQLException {
/*  440 */     OracleImplicitConnectionCache oracleImplicitConnectionCache = (paramString != null) ? (OracleImplicitConnectionCache)this.m_connCache.get(paramString) : null;
/*      */ 
/*      */     
/*  443 */     if (oracleImplicitConnectionCache != null) {
/*      */       
/*  445 */       oracleImplicitConnectionCache.disableConnectionCache();
/*      */     }
/*      */     else {
/*      */       
/*  449 */       DatabaseError.throwSqlException(141);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void refreshCache(String paramString, int paramInt) throws SQLException {
/*  471 */     OracleImplicitConnectionCache oracleImplicitConnectionCache = (paramString != null) ? (OracleImplicitConnectionCache)this.m_connCache.get(paramString) : null;
/*      */ 
/*      */     
/*  474 */     if (oracleImplicitConnectionCache != null) {
/*      */       
/*  476 */       switch (paramInt) {
/*      */         
/*      */         case 4096:
/*      */         case 8192:
/*  480 */           oracleImplicitConnectionCache.refreshCacheConnections(paramInt);
/*      */           return;
/*      */       } 
/*      */       
/*  484 */       DatabaseError.throwSqlException(68);
/*      */     
/*      */     }
/*      */     else {
/*      */       
/*  489 */       DatabaseError.throwSqlException(141);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void purgeCache(String paramString, boolean paramBoolean) throws SQLException {
/*  511 */     OracleImplicitConnectionCache oracleImplicitConnectionCache = (paramString != null) ? (OracleImplicitConnectionCache)this.m_connCache.get(paramString) : null;
/*      */ 
/*      */     
/*  514 */     if (oracleImplicitConnectionCache != null) {
/*      */       
/*  516 */       oracleImplicitConnectionCache.purgeCacheConnections(paramBoolean, 1);
/*      */     
/*      */     }
/*      */     else {
/*      */       
/*  521 */       DatabaseError.throwSqlException(141);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Properties getCacheProperties(String paramString) throws SQLException {
/*  541 */     OracleImplicitConnectionCache oracleImplicitConnectionCache = (paramString != null) ? (OracleImplicitConnectionCache)this.m_connCache.get(paramString) : null;
/*      */ 
/*      */     
/*  544 */     if (oracleImplicitConnectionCache != null)
/*      */     {
/*  546 */       return oracleImplicitConnectionCache.getConnectionCacheProperties();
/*      */     }
/*      */ 
/*      */     
/*  550 */     DatabaseError.throwSqlException(141);
/*      */ 
/*      */     
/*  553 */     return null;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public String[] getCacheNameList() throws SQLException {
/*  568 */     return (String[])this.m_connCache.keySet().toArray((Object[])new String[this.m_connCache.size()]);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public int getNumberOfAvailableConnections(String paramString) throws SQLException {
/*  585 */     OracleImplicitConnectionCache oracleImplicitConnectionCache = (paramString != null) ? (OracleImplicitConnectionCache)this.m_connCache.get(paramString) : null;
/*      */ 
/*      */     
/*  588 */     if (oracleImplicitConnectionCache != null)
/*      */     {
/*  590 */       return oracleImplicitConnectionCache.cacheSize;
/*      */     }
/*      */ 
/*      */     
/*  594 */     DatabaseError.throwSqlException(141);
/*      */ 
/*      */     
/*  597 */     return 0;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public int getNumberOfActiveConnections(String paramString) throws SQLException {
/*  612 */     OracleImplicitConnectionCache oracleImplicitConnectionCache = (paramString != null) ? (OracleImplicitConnectionCache)this.m_connCache.get(paramString) : null;
/*      */ 
/*      */     
/*  615 */     if (oracleImplicitConnectionCache != null)
/*      */     {
/*  617 */       return oracleImplicitConnectionCache.getNumberOfCheckedOutConnections();
/*      */     }
/*      */ 
/*      */     
/*  621 */     DatabaseError.throwSqlException(141);
/*      */ 
/*      */     
/*  624 */     return 0;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void setConnectionPoolDataSource(String paramString, ConnectionPoolDataSource paramConnectionPoolDataSource) throws SQLException {
/*  648 */     OracleImplicitConnectionCache oracleImplicitConnectionCache = (paramString != null) ? (OracleImplicitConnectionCache)this.m_connCache.get(paramString) : null;
/*      */ 
/*      */     
/*  651 */     if (oracleImplicitConnectionCache != null) {
/*      */       
/*  653 */       if (oracleImplicitConnectionCache.cacheSize > 0)
/*      */       {
/*  655 */         DatabaseError.throwSqlException(78);
/*      */       }
/*      */       else
/*      */       {
/*  659 */         ((OracleConnectionPoolDataSource)paramConnectionPoolDataSource).makeURL();
/*  660 */         ((OracleConnectionPoolDataSource)paramConnectionPoolDataSource).setURL(((OracleConnectionPoolDataSource)paramConnectionPoolDataSource).url);
/*      */         
/*  662 */         oracleImplicitConnectionCache.connectionPoolDS = (OracleConnectionPoolDataSource)paramConnectionPoolDataSource;
/*      */       }
/*      */     
/*      */     } else {
/*      */       
/*  667 */       DatabaseError.throwSqlException(141);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void verifyAndHandleEvent(int paramInt, byte[] paramArrayOfbyte) throws SQLException {
/*  688 */     String str1 = null;
/*  689 */     String str2 = null;
/*  690 */     String str3 = null;
/*  691 */     String str4 = null;
/*  692 */     String str5 = null;
/*      */     
/*  694 */     int i = 0;
/*  695 */     StringTokenizer stringTokenizer = null;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     try {
/*  702 */       stringTokenizer = new StringTokenizer(new String(paramArrayOfbyte, "UTF-8"), "{} =", true);
/*      */     
/*      */     }
/*  705 */     catch (UnsupportedEncodingException unsupportedEncodingException) {}
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  711 */     String str6 = null;
/*  712 */     String str7 = null;
/*  713 */     String str8 = null;
/*      */ 
/*      */ 
/*      */     
/*  717 */     while (stringTokenizer.hasMoreTokens()) {
/*      */       
/*  719 */       str7 = null;
/*  720 */       str6 = stringTokenizer.nextToken();
/*  721 */       if (str6.equals("=") && stringTokenizer.hasMoreTokens()) {
/*      */         
/*  723 */         str7 = stringTokenizer.nextToken();
/*      */       }
/*      */       else {
/*      */         
/*  727 */         str8 = str6;
/*      */       } 
/*      */       
/*  730 */       if (str8.equalsIgnoreCase("version") && str7 != null && !str7.equals("1.0"))
/*      */       {
/*      */         
/*  733 */         DatabaseError.throwSqlException(146);
/*      */       }
/*      */       
/*  736 */       if (str8.equalsIgnoreCase("service") && str7 != null) {
/*  737 */         str1 = str7;
/*      */       }
/*  739 */       if (str8.equalsIgnoreCase("instance") && str7 != null && !str7.equals(" "))
/*      */       {
/*      */         
/*  742 */         str2 = str7.toLowerCase().intern();
/*      */       }
/*      */       
/*  745 */       if (str8.equalsIgnoreCase("database") && str7 != null) {
/*  746 */         str3 = str7.toLowerCase().intern();
/*      */       }
/*  748 */       if (str8.equalsIgnoreCase("host") && str7 != null) {
/*  749 */         str4 = str7.toLowerCase().intern();
/*      */       }
/*  751 */       if (str8.equalsIgnoreCase("status") && str7 != null) {
/*  752 */         str5 = str7;
/*      */       }
/*  754 */       if (str8.equalsIgnoreCase("card") && str7 != null) {
/*      */         
/*      */         try {
/*      */           
/*  758 */           i = Integer.parseInt(str7);
/*      */         }
/*  760 */         catch (NumberFormatException numberFormatException) {}
/*      */       }
/*      */     } 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  768 */     invokeFailoverProcessingThreads(paramInt, str1, str2, str3, str4, str5, i);
/*      */ 
/*      */     
/*  771 */     stringTokenizer = null;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private void invokeFailoverProcessingThreads(int paramInt1, String paramString1, String paramString2, String paramString3, String paramString4, String paramString5, int paramInt2) throws SQLException {
/*  786 */     OracleImplicitConnectionCache oracleImplicitConnectionCache = null;
/*  787 */     boolean bool1 = false;
/*  788 */     boolean bool2 = false;
/*      */     
/*  790 */     if (paramInt1 == 256) {
/*  791 */       bool1 = true;
/*      */     }
/*  793 */     if (paramInt1 == 512) {
/*  794 */       bool2 = true;
/*      */     }
/*  796 */     Iterator iterator = this.m_connCache.values().iterator();
/*      */     
/*  798 */     while (iterator.hasNext()) {
/*      */       
/*  800 */       oracleImplicitConnectionCache = iterator.next();
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*  810 */       if ((bool1 && paramString1.equalsIgnoreCase(oracleImplicitConnectionCache.dataSourceServiceName)) || bool2) {
/*      */ 
/*      */ 
/*      */         
/*  814 */         OracleFailoverWorkerThread oracleFailoverWorkerThread = new OracleFailoverWorkerThread(oracleImplicitConnectionCache, paramInt1, paramString2, paramString3, paramString4, paramString5, paramInt2);
/*      */ 
/*      */ 
/*      */         
/*  818 */         checkAndStartThread(oracleFailoverWorkerThread);
/*      */         
/*  820 */         oracleImplicitConnectionCache.failoverWorkerThread = oracleFailoverWorkerThread;
/*      */       } 
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void checkAndStartThread(Thread paramThread) throws SQLException {
/*      */     try {
/*  837 */       if (!paramThread.isAlive())
/*      */       {
/*  839 */         paramThread.setDaemon(true);
/*  840 */         paramThread.start();
/*      */       }
/*      */     
/*  843 */     } catch (IllegalThreadStateException illegalThreadStateException) {}
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected boolean failoverEnabledCacheExists() {
/*  858 */     if (this.failoverEnabledCacheCount > 0) {
/*  859 */       return true;
/*      */     }
/*  861 */     return false;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void parseRuntimeLoadBalancingEvent(String paramString, byte[] paramArrayOfbyte) throws SQLException {
/*  875 */     OracleImplicitConnectionCache oracleImplicitConnectionCache = null;
/*  876 */     Enumeration enumeration = this.m_connCache.elements();
/*      */     
/*  878 */     while (enumeration.hasMoreElements()) {
/*      */ 
/*      */       
/*      */       try {
/*  882 */         oracleImplicitConnectionCache = enumeration.nextElement();
/*  883 */         if (paramString.equalsIgnoreCase(oracleImplicitConnectionCache.dataSourceServiceName))
/*      */         {
/*  885 */           if (paramArrayOfbyte == null) {
/*  886 */             oracleImplicitConnectionCache.zapRLBInfo(); continue;
/*      */           } 
/*  888 */           retrieveServiceMetrics(oracleImplicitConnectionCache, paramArrayOfbyte);
/*      */         }
/*      */       
/*  891 */       } catch (Exception exception) {}
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private void retrieveServiceMetrics(OracleImplicitConnectionCache paramOracleImplicitConnectionCache, byte[] paramArrayOfbyte) throws SQLException {
/*  913 */     StringTokenizer stringTokenizer = null;
/*  914 */     String str1 = null;
/*  915 */     String str2 = null;
/*  916 */     int i = 0;
/*  917 */     byte b = 0;
/*  918 */     boolean bool = false;
/*      */ 
/*      */     
/*      */     try {
/*  922 */       stringTokenizer = new StringTokenizer(new String(paramArrayOfbyte, "UTF-8"), "{} =", true);
/*      */     
/*      */     }
/*  925 */     catch (UnsupportedEncodingException unsupportedEncodingException) {}
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  931 */     String str3 = null;
/*  932 */     String str4 = null;
/*  933 */     String str5 = null;
/*      */     
/*  935 */     while (stringTokenizer.hasMoreTokens()) {
/*      */       
/*  937 */       str4 = null;
/*  938 */       str3 = stringTokenizer.nextToken();
/*      */       
/*  940 */       if (str3.equals("=") && stringTokenizer.hasMoreTokens()) {
/*      */         
/*  942 */         str4 = stringTokenizer.nextToken();
/*      */       } else {
/*  944 */         if (str3.equals("}")) {
/*      */ 
/*      */           
/*  947 */           if (bool) {
/*      */             
/*  949 */             paramOracleImplicitConnectionCache.updateDatabaseInstance(str2, str1, i, b);
/*  950 */             bool = false;
/*      */           } 
/*      */           continue;
/*      */         } 
/*  954 */         if (str3.equals("{") || str3.equals(" ")) {
/*      */           continue;
/*      */         }
/*      */ 
/*      */ 
/*      */         
/*  960 */         str5 = str3;
/*  961 */         bool = true;
/*      */       } 
/*      */       
/*  964 */       if (str5.equalsIgnoreCase("version") && str4 != null)
/*      */       {
/*  966 */         if (!str4.equals("1.0"))
/*      */         {
/*  968 */           DatabaseError.throwSqlException(146);
/*      */         }
/*      */       }
/*      */       
/*  972 */       if (str5.equalsIgnoreCase("database") && str4 != null) {
/*  973 */         str2 = str4.toLowerCase().intern();
/*      */       }
/*  975 */       if (str5.equalsIgnoreCase("instance") && str4 != null) {
/*  976 */         str1 = str4.toLowerCase().intern();
/*      */       }
/*  978 */       if (str5.equalsIgnoreCase("percent") && str4 != null) {
/*      */         
/*      */         try {
/*      */           
/*  982 */           i = Integer.parseInt(str4);
/*  983 */           if (i == 0) i = 1;
/*      */         
/*  985 */         } catch (NumberFormatException numberFormatException) {}
/*      */       }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*  992 */       if (str5.equalsIgnoreCase("flag") && str4 != null) {
/*      */         
/*  994 */         if (str4.equalsIgnoreCase("good")) {
/*  995 */           b = 1; continue;
/*  996 */         }  if (str4.equalsIgnoreCase("violating")) {
/*  997 */           b = 3; continue;
/*  998 */         }  if (str4.equalsIgnoreCase("NO_DATA")) {
/*  999 */           b = 4; continue;
/* 1000 */         }  if (str4.equalsIgnoreCase("UNKNOWN")) {
/* 1001 */           b = 2; continue;
/* 1002 */         }  if (str4.equalsIgnoreCase("BLOCKED")) {
/* 1003 */           b = 5;
/*      */         }
/*      */       } 
/*      */     } 
/*      */     
/* 1008 */     paramOracleImplicitConnectionCache.processDatabaseInstances();
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void cleanupFCFThreads(OracleImplicitConnectionCache paramOracleImplicitConnectionCache) throws SQLException {
/* 1019 */     cleanupFCFWorkerThread(paramOracleImplicitConnectionCache);
/* 1020 */     paramOracleImplicitConnectionCache.cleanupRLBThreads();
/*      */ 
/*      */     
/* 1023 */     if (this.failoverEnabledCacheCount <= 0) {
/* 1024 */       cleanupFCFEventHandlerThread();
/*      */     }
/*      */     
/* 1027 */     this.failoverEnabledCacheCount--;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void cleanupFCFWorkerThread(OracleImplicitConnectionCache paramOracleImplicitConnectionCache) throws SQLException {
/* 1040 */     if (paramOracleImplicitConnectionCache.failoverWorkerThread != null) {
/*      */ 
/*      */       
/*      */       try {
/* 1044 */         if (paramOracleImplicitConnectionCache.failoverWorkerThread.isAlive()) {
/* 1045 */           paramOracleImplicitConnectionCache.failoverWorkerThread.join();
/*      */         }
/* 1047 */       } catch (InterruptedException interruptedException) {}
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 1053 */       paramOracleImplicitConnectionCache.failoverWorkerThread = null;
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void cleanupFCFEventHandlerThread() throws SQLException {
/* 1070 */     if (this.failoverEventHandlerThread != null) {
/*      */ 
/*      */       
/*      */       try {
/* 1074 */         this.failoverEventHandlerThread.interrupt();
/*      */       }
/* 1076 */       catch (Exception exception) {}
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 1082 */       this.failoverEventHandlerThread = null;
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public boolean isFatalConnectionError(SQLException paramSQLException) {
/* 1098 */     boolean bool = false;
/* 1099 */     int i = paramSQLException.getErrorCode();
/*      */ 
/*      */     
/* 1102 */     if (i == 3113 || i == 3114 || i == 1033 || i == 1034 || i == 1089 || i == 1090 || i == 17002)
/*      */     {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 1110 */       bool = true;
/*      */     }
/*      */ 
/*      */     
/* 1114 */     if (!bool && this.fatalErrorCodes != null)
/*      */     {
/* 1116 */       for (byte b = 0; b < this.fatalErrorCodes.length; b++) {
/* 1117 */         if (i == this.fatalErrorCodes[b]) {
/*      */           
/* 1119 */           bool = true;
/*      */           break;
/*      */         } 
/*      */       } 
/*      */     }
/* 1124 */     return bool;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void setConnectionErrorCodes(int[] paramArrayOfint) throws SQLException {
/* 1137 */     if (paramArrayOfint != null) {
/* 1138 */       this.fatalErrorCodes = paramArrayOfint;
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public int[] getConnectionErrorCodes() throws SQLException {
/* 1152 */     return this.fatalErrorCodes;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Map getStatistics(String paramString) throws SQLException {
/* 1169 */     Map map = null;
/* 1170 */     OracleImplicitConnectionCache oracleImplicitConnectionCache = null;
/*      */     
/* 1172 */     if (this.m_connCache != null && (oracleImplicitConnectionCache = (OracleImplicitConnectionCache)this.m_connCache.get(paramString)) != null)
/*      */     {
/* 1174 */       map = oracleImplicitConnectionCache.getStatistics();
/*      */     }
/* 1176 */     return map;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 1182 */   private static final String _Copyright_2004_Oracle_All_Rights_Reserved_ = null;
/*      */   public static final boolean TRACE = false;
/*      */   public static final boolean PRIVATE_TRACE = false;
/*      */   public static final String BUILD_DATE = "Sat_Feb__2_11:39:40_PST_2008";
/*      */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\lib\ojdbc14.jar!\oracle\jdbc\pool\OracleConnectionCacheManager.class
 * Java compiler version: 2 (46.0)
 * JD-Core Version:       1.1.3
 */