/*      */ package oracle.jdbc.pool;
/*      */ 
/*      */ import java.io.IOException;
/*      */ import java.io.ObjectInputStream;
/*      */ import java.io.ObjectOutputStream;
/*      */ import java.io.PrintWriter;
/*      */ import java.io.Serializable;
/*      */ import java.sql.Connection;
/*      */ import java.sql.SQLException;
/*      */ import java.sql.SQLWarning;
/*      */ import java.util.Enumeration;
/*      */ import java.util.Properties;
/*      */ import javax.naming.NamingException;
/*      */ import javax.naming.Reference;
/*      */ import javax.naming.Referenceable;
/*      */ import javax.naming.StringRefAddr;
/*      */ import javax.sql.DataSource;
/*      */ import oracle.jdbc.OracleConnection;
/*      */ import oracle.jdbc.driver.DatabaseError;
/*      */ import oracle.jdbc.driver.OracleDriver;
/*      */ import oracle.jdbc.driver.OracleLog;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ public class OracleDataSource
/*      */   implements DataSource, Serializable, Referenceable
/*      */ {
/*   50 */   protected PrintWriter logWriter = null;
/*   51 */   protected int loginTimeout = 0;
/*      */ 
/*      */   
/*   54 */   protected String databaseName = null;
/*   55 */   protected String serviceName = null;
/*   56 */   protected String dataSourceName = "OracleDataSource";
/*   57 */   protected String description = null;
/*   58 */   protected String networkProtocol = "tcp";
/*   59 */   protected int portNumber = 0;
/*   60 */   protected String user = null;
/*   61 */   protected String password = null;
/*   62 */   protected String serverName = null;
/*   63 */   protected String url = null;
/*   64 */   protected String driverType = null;
/*   65 */   protected String tnsEntry = null;
/*   66 */   protected int maxStatements = 0;
/*      */   
/*      */   protected boolean implicitCachingEnabled = false;
/*      */   protected boolean explicitCachingEnabled = false;
/*   70 */   protected transient OracleImplicitConnectionCache odsCache = null;
/*   71 */   protected transient OracleConnectionCacheManager cacheManager = null;
/*   72 */   protected String connCacheName = null;
/*   73 */   protected Properties connCacheProperties = null;
/*   74 */   protected Properties connectionProperties = null;
/*      */   protected boolean connCachingEnabled = false;
/*      */   protected boolean fastConnFailover = false;
/*   77 */   protected String onsConfigStr = null;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public boolean isOracleDataSource = true;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*   97 */   private static final boolean fastConnectionFailoverSysProperty = "true".equalsIgnoreCase(OracleDriver.getSystemPropertyFastConnectionFailover("false"));
/*      */   
/*      */   private boolean urlExplicit = false;
/*      */   
/*      */   private boolean useDefaultConnection = false;
/*      */   
/*  103 */   protected transient OracleDriver driver = new OracleDriver();
/*      */ 
/*      */   
/*      */   private static final String spawnNewThreadToCancelProperty = "oracle.jdbc.spawnNewThreadToCancel";
/*      */ 
/*      */ 
/*      */   
/*      */   public OracleDataSource() throws SQLException {
/*  111 */     processFastConnectionFailoverSysProperty();
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   void processFastConnectionFailoverSysProperty() {
/*  118 */     if (this.isOracleDataSource && fastConnectionFailoverSysProperty) {
/*      */ 
/*      */ 
/*      */       
/*  122 */       this.connCachingEnabled = true;
/*      */ 
/*      */       
/*  125 */       if (this.cacheManager == null) {
/*      */         
/*      */         try {
/*      */           
/*  129 */           this.cacheManager = OracleConnectionCacheManager.getConnectionCacheManagerInstance();
/*      */         
/*      */         }
/*  132 */         catch (SQLException sQLException) {}
/*      */       }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*  141 */       this.fastConnFailover = true;
/*  142 */       setSpawnNewThreadToCancel(true);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Connection getConnection() throws SQLException {
/*  157 */     String str1 = null;
/*  158 */     String str2 = null;
/*  159 */     synchronized (this) {
/*      */       
/*  161 */       str1 = this.user;
/*  162 */       str2 = this.password;
/*      */     } 
/*      */     
/*  165 */     return getConnection(str1, str2);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Connection getConnection(String paramString1, String paramString2) throws SQLException {
/*  184 */     Connection connection = null;
/*  185 */     Properties properties = null;
/*  186 */     if (this.connCachingEnabled) {
/*      */ 
/*      */       
/*  189 */       connection = getConnection(paramString1, paramString2, null);
/*      */     }
/*      */     else {
/*      */       
/*  193 */       synchronized (this) {
/*      */         
/*  195 */         makeURL();
/*      */ 
/*      */ 
/*      */ 
/*      */         
/*  200 */         properties = (this.connectionProperties == null) ? new Properties() : (Properties)this.connectionProperties.clone();
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */         
/*  208 */         if (this.url != null)
/*  209 */           properties.setProperty("connection_url", this.url); 
/*  210 */         if (paramString1 != null)
/*  211 */           properties.setProperty("user", paramString1); 
/*  212 */         if (paramString2 != null)
/*  213 */           properties.setProperty("password", paramString2); 
/*  214 */         if (this.loginTimeout != 0) {
/*  215 */           properties.setProperty("LoginTimeout", "" + this.loginTimeout);
/*      */         }
/*  217 */         if (this.maxStatements != 0) {
/*  218 */           properties.setProperty("stmt_cache_size", "" + this.maxStatements);
/*      */         }
/*      */       } 
/*  221 */       connection = getPhysicalConnection(properties);
/*  222 */       if (connection == null) {
/*  223 */         DatabaseError.throwSqlException(67);
/*      */       }
/*      */     } 
/*      */ 
/*      */ 
/*      */     
/*  229 */     return connection;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected Connection getPhysicalConnection(Properties paramProperties) throws SQLException {
/*  238 */     Connection connection = null;
/*  239 */     Properties properties = paramProperties;
/*  240 */     String str1 = paramProperties.getProperty("connection_url");
/*  241 */     String str2 = paramProperties.getProperty("user");
/*  242 */     String str3 = properties.getProperty("password");
/*  243 */     String str4 = null;
/*  244 */     boolean bool1 = false;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  250 */     synchronized (this) {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*  256 */       if (this.connectionProperties != null) {
/*      */         
/*  258 */         properties = (Properties)this.connectionProperties.clone();
/*      */         
/*  260 */         if (str2 != null) {
/*  261 */           properties.put("user", str2);
/*      */         }
/*  263 */         if (str3 != null)
/*  264 */           properties.put("password", str3); 
/*      */       } 
/*  266 */       if (str2 == null && this.user != null)
/*  267 */         properties.put("user", this.user); 
/*  268 */       if (str3 == null && this.password != null) {
/*  269 */         properties.put("password", this.password);
/*      */       }
/*  271 */       if (str1 == null) {
/*  272 */         str1 = this.url;
/*      */       }
/*  274 */       String str = paramProperties.getProperty("LoginTimeout");
/*      */       
/*  276 */       if (str != null) {
/*  277 */         properties.put("oracle.net.CONNECT_TIMEOUT", "" + (Integer.parseInt(str) * 1000));
/*      */       }
/*      */       
/*  280 */       bool1 = this.useDefaultConnection;
/*      */       
/*  282 */       if (this.driver == null) {
/*  283 */         this.driver = new OracleDriver();
/*      */       }
/*      */     } 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  291 */     if (bool1) {
/*      */       
/*  293 */       connection = this.driver.defaultConnection();
/*      */     }
/*      */     else {
/*      */       
/*  297 */       connection = this.driver.connect(str1, properties);
/*      */     } 
/*      */     
/*  300 */     if (connection == null) {
/*  301 */       DatabaseError.throwSqlException(67);
/*      */     }
/*      */ 
/*      */     
/*  305 */     str4 = paramProperties.getProperty("stmt_cache_size");
/*      */     
/*  307 */     int i = 0;
/*  308 */     if (str4 != null) {
/*  309 */       ((OracleConnection)connection).setStatementCacheSize(i = Integer.parseInt(str4));
/*      */     }
/*      */     
/*  312 */     boolean bool2 = false;
/*  313 */     str4 = paramProperties.getProperty("ExplicitStatementCachingEnabled");
/*      */     
/*  315 */     if (str4 != null) {
/*  316 */       ((OracleConnection)connection).setExplicitCachingEnabled(bool2 = str4.equals("true"));
/*      */     }
/*      */     
/*  319 */     boolean bool3 = false;
/*  320 */     str4 = paramProperties.getProperty("ImplicitStatementCachingEnabled");
/*      */     
/*  322 */     if (str4 != null)
/*      */     {
/*  324 */       ((OracleConnection)connection).setImplicitCachingEnabled(bool3 = str4.equals("true"));
/*      */     }
/*      */ 
/*      */ 
/*      */     
/*  329 */     if (i > 0 && !bool2 && !bool3) {
/*      */ 
/*      */ 
/*      */       
/*  333 */       ((OracleConnection)connection).setImplicitCachingEnabled(true);
/*  334 */       ((OracleConnection)connection).setExplicitCachingEnabled(true);
/*      */     } 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  340 */     return connection;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Connection getConnection(Properties paramProperties) throws SQLException {
/*  357 */     String str1 = null;
/*  358 */     String str2 = null;
/*  359 */     synchronized (this) {
/*      */       
/*  361 */       if (!this.connCachingEnabled)
/*      */       {
/*  363 */         DatabaseError.throwSqlException(137);
/*      */       }
/*  365 */       str1 = this.user;
/*  366 */       str2 = this.password;
/*      */     } 
/*      */     
/*  369 */     return getConnection(str1, str2, paramProperties);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Connection getConnection(String paramString1, String paramString2, Properties paramProperties) throws SQLException {
/*  392 */     if (!this.connCachingEnabled)
/*      */     {
/*  394 */       DatabaseError.throwSqlException(137);
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  401 */     if (this.odsCache == null) {
/*  402 */       cacheInitialize();
/*      */     }
/*  404 */     return this.odsCache.getConnection(paramString1, paramString2, paramProperties);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private synchronized void cacheInitialize() throws SQLException {
/*  422 */     if (this.odsCache == null)
/*      */     {
/*  424 */       if (this.connCacheName != null) {
/*  425 */         this.cacheManager.createCache(this.connCacheName, this, this.connCacheProperties);
/*      */       } else {
/*  427 */         this.connCacheName = this.cacheManager.createCache(this, this.connCacheProperties);
/*      */       } 
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void close() throws SQLException {
/*  445 */     if (this.connCachingEnabled && this.odsCache != null) {
/*      */       
/*  447 */       this.cacheManager.removeCache(this.odsCache.cacheName, 0L);
/*      */       
/*  449 */       this.odsCache = null;
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void setConnectionCachingEnabled(boolean paramBoolean) throws SQLException {
/*  467 */     if (this.isOracleDataSource) {
/*      */       
/*  469 */       if (paramBoolean)
/*      */       {
/*  471 */         this.connCachingEnabled = true;
/*      */         
/*  473 */         if (this.cacheManager == null)
/*      */         {
/*  475 */           this.cacheManager = OracleConnectionCacheManager.getConnectionCacheManagerInstance();
/*      */ 
/*      */ 
/*      */         
/*      */         }
/*      */ 
/*      */ 
/*      */       
/*      */       }
/*  484 */       else if (this.odsCache == null)
/*      */       {
/*  486 */         this.connCachingEnabled = false;
/*  487 */         this.fastConnFailover = false;
/*  488 */         setSpawnNewThreadToCancel(false);
/*  489 */         this.connCacheName = null;
/*  490 */         this.connCacheProperties = null;
/*      */ 
/*      */ 
/*      */       
/*      */       }
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     }
/*      */     else {
/*      */ 
/*      */ 
/*      */       
/*  504 */       DatabaseError.throwSqlException(137);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public boolean getConnectionCachingEnabled() throws SQLException {
/*  523 */     return this.connCachingEnabled;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void setConnectionCacheName(String paramString) throws SQLException {
/*  538 */     if (this.connCachingEnabled)
/*      */     {
/*  540 */       if (paramString == null) {
/*      */         
/*  542 */         DatabaseError.throwSqlException(138);
/*      */       }
/*      */       else {
/*      */         
/*  546 */         this.connCacheName = paramString;
/*      */       } 
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public String getConnectionCacheName() throws SQLException {
/*  566 */     if (this.connCachingEnabled && this.odsCache != null) {
/*  567 */       return this.odsCache.cacheName;
/*      */     }
/*  569 */     return this.connCacheName;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void setConnectionCacheProperties(Properties paramProperties) throws SQLException {
/*  649 */     if (this.connCachingEnabled) {
/*  650 */       this.connCacheProperties = paramProperties;
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Properties getConnectionCacheProperties() throws SQLException {
/*  667 */     if (this.connCachingEnabled && this.odsCache != null) {
/*  668 */       return this.odsCache.getConnectionCacheProperties();
/*      */     }
/*  670 */     return this.connCacheProperties;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void setFastConnectionFailoverEnabled(boolean paramBoolean) throws SQLException {
/*  695 */     if (this.connCachingEnabled) {
/*      */       
/*  697 */       if (!this.fastConnFailover) {
/*      */         
/*  699 */         this.fastConnFailover = paramBoolean;
/*  700 */         setSpawnNewThreadToCancel(paramBoolean);
/*  701 */       } else if (!paramBoolean) {
/*      */ 
/*      */ 
/*      */         
/*  705 */         DatabaseError.throwSqlException(255);
/*      */       
/*      */       }
/*      */ 
/*      */     
/*      */     }
/*      */     else {
/*      */ 
/*      */       
/*  714 */       DatabaseError.throwSqlException(137);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public boolean getFastConnectionFailoverEnabled() throws SQLException {
/*  732 */     return this.fastConnFailover;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public String getONSConfiguration() throws SQLException {
/*  748 */     return this.onsConfigStr;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void setONSConfiguration(String paramString) throws SQLException {
/*  779 */     this.onsConfigStr = paramString;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized int getLoginTimeout() {
/*  800 */     return this.loginTimeout;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void setLoginTimeout(int paramInt) {
/*  820 */     this.loginTimeout = paramInt;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void setLogWriter(PrintWriter paramPrintWriter) {
/*  846 */     this.logWriter = paramPrintWriter;
/*      */     
/*  848 */     OracleLog.setLogWriter(paramPrintWriter);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized PrintWriter getLogWriter() {
/*  873 */     return this.logWriter;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void setTNSEntryName(String paramString) {
/*  890 */     this.tnsEntry = paramString;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized String getTNSEntryName() {
/*  906 */     return this.tnsEntry;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void setDataSourceName(String paramString) {
/*  923 */     this.dataSourceName = paramString;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized String getDataSourceName() {
/*  939 */     return this.dataSourceName;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized String getDatabaseName() {
/*  953 */     return this.databaseName;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void setDatabaseName(String paramString) {
/*  968 */     this.databaseName = paramString;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void setServiceName(String paramString) {
/*  987 */     this.serviceName = paramString;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized String getServiceName() {
/* 1006 */     return this.serviceName;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void setServerName(String paramString) {
/* 1023 */     this.serverName = paramString;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized String getServerName() {
/* 1037 */     return this.serverName;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void setURL(String paramString) {
/* 1053 */     this.url = paramString;
/*      */     
/* 1055 */     if (this.url != null) {
/* 1056 */       this.urlExplicit = true;
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized String getURL() throws SQLException {
/* 1071 */     if (!this.urlExplicit) {
/* 1072 */       makeURL();
/*      */     }
/*      */ 
/*      */ 
/*      */     
/* 1077 */     return this.url;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void setUser(String paramString) {
/* 1091 */     this.user = paramString;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public String getUser() {
/* 1104 */     return this.user;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void setPassword(String paramString) {
/* 1119 */     this.password = paramString;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected String getPassword() {
/* 1128 */     return this.password;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized String getDescription() {
/* 1142 */     return this.description;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void setDescription(String paramString) {
/* 1156 */     this.description = paramString;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized String getDriverType() {
/* 1171 */     return this.driverType;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void setDriverType(String paramString) {
/* 1193 */     this.driverType = paramString;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized String getNetworkProtocol() {
/* 1208 */     return this.networkProtocol;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void setNetworkProtocol(String paramString) {
/* 1224 */     this.networkProtocol = paramString;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void setPortNumber(int paramInt) {
/* 1239 */     this.portNumber = paramInt;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized int getPortNumber() {
/* 1253 */     return this.portNumber;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized Reference getReference() throws NamingException {
/* 1265 */     Reference reference = new Reference(getClass().getName(), "oracle.jdbc.pool.OracleDataSourceFactory", null);
/*      */ 
/*      */ 
/*      */     
/* 1269 */     addRefProperties(reference);
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1274 */     return reference;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void addRefProperties(Reference paramReference) {
/* 1284 */     if (this.url != null) {
/* 1285 */       paramReference.add(new StringRefAddr("url", this.url));
/*      */     }
/* 1287 */     if (this.user != null) {
/* 1288 */       paramReference.add(new StringRefAddr("userName", this.user));
/*      */     }
/* 1290 */     if (this.password != null) {
/* 1291 */       paramReference.add(new StringRefAddr("passWord", this.password));
/*      */     }
/* 1293 */     if (this.description != null) {
/* 1294 */       paramReference.add(new StringRefAddr("description", this.description));
/*      */     }
/* 1296 */     if (this.driverType != null) {
/* 1297 */       paramReference.add(new StringRefAddr("driverType", this.driverType));
/*      */     }
/* 1299 */     if (this.serverName != null) {
/* 1300 */       paramReference.add(new StringRefAddr("serverName", this.serverName));
/*      */     }
/* 1302 */     if (this.databaseName != null) {
/* 1303 */       paramReference.add(new StringRefAddr("databaseName", this.databaseName));
/*      */     }
/* 1305 */     if (this.serviceName != null) {
/* 1306 */       paramReference.add(new StringRefAddr("serviceName", this.serviceName));
/*      */     }
/* 1308 */     if (this.networkProtocol != null) {
/* 1309 */       paramReference.add(new StringRefAddr("networkProtocol", this.networkProtocol));
/*      */     }
/* 1311 */     if (this.portNumber != 0) {
/* 1312 */       paramReference.add(new StringRefAddr("portNumber", Integer.toString(this.portNumber)));
/*      */     }
/* 1314 */     if (this.tnsEntry != null) {
/* 1315 */       paramReference.add(new StringRefAddr("tnsentryname", this.tnsEntry));
/*      */     }
/* 1317 */     if (this.maxStatements != 0) {
/* 1318 */       paramReference.add(new StringRefAddr("maxStatements", Integer.toString(this.maxStatements)));
/*      */     }
/*      */     
/* 1321 */     if (this.implicitCachingEnabled) {
/* 1322 */       paramReference.add(new StringRefAddr("implicitCachingEnabled", "true"));
/*      */     }
/* 1324 */     if (this.explicitCachingEnabled) {
/* 1325 */       paramReference.add(new StringRefAddr("explicitCachingEnabled", "true"));
/*      */     }
/*      */ 
/*      */     
/* 1329 */     if (this.connCachingEnabled) {
/* 1330 */       paramReference.add(new StringRefAddr("connectionCachingEnabled", "true"));
/*      */     }
/* 1332 */     if (this.connCacheName != null) {
/* 1333 */       paramReference.add(new StringRefAddr("connectionCacheName", this.connCacheName));
/*      */     }
/* 1335 */     if (this.connCacheProperties != null) {
/* 1336 */       paramReference.add(new StringRefAddr("connectionCacheProperties", this.connCacheProperties.toString()));
/*      */     }
/*      */     
/* 1339 */     if (this.fastConnFailover) {
/* 1340 */       paramReference.add(new StringRefAddr("fastConnectionFailoverEnabled", "true"));
/*      */     }
/* 1342 */     if (this.onsConfigStr != null) {
/* 1343 */       paramReference.add(new StringRefAddr("onsConfigStr", this.onsConfigStr));
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   void makeURL() throws SQLException {
/* 1353 */     if (this.urlExplicit) {
/*      */       return;
/*      */     }
/*      */ 
/*      */     
/* 1358 */     if (this.driverType == null || (!this.driverType.equals("oci8") && !this.driverType.equals("oci") && !this.driverType.equals("thin") && !this.driverType.equals("kprb")))
/*      */     {
/*      */       
/* 1361 */       DatabaseError.throwSqlException(67, "OracleDataSource.makeURL");
/*      */     }
/*      */ 
/*      */ 
/*      */     
/* 1366 */     if (this.driverType.equals("kprb")) {
/*      */       
/* 1368 */       this.useDefaultConnection = true;
/* 1369 */       this.url = "jdbc:oracle:kprb:@";
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*      */       return;
/*      */     } 
/*      */ 
/*      */ 
/*      */     
/* 1379 */     if ((this.driverType.equals("oci8") || this.driverType.equals("oci")) && this.networkProtocol != null && this.networkProtocol.equals("ipc")) {
/*      */ 
/*      */       
/* 1382 */       this.url = "jdbc:oracle:oci:@";
/*      */ 
/*      */ 
/*      */       
/*      */       return;
/*      */     } 
/*      */ 
/*      */ 
/*      */     
/* 1391 */     if (this.tnsEntry != null) {
/*      */       
/* 1393 */       this.url = "jdbc:oracle:" + this.driverType + ":@" + this.tnsEntry;
/*      */ 
/*      */ 
/*      */       
/*      */       return;
/*      */     } 
/*      */ 
/*      */ 
/*      */     
/* 1402 */     if (this.serviceName != null) {
/*      */       
/* 1404 */       this.url = "jdbc:oracle:" + this.driverType + ":@(DESCRIPTION=(ADDRESS=(PROTOCOL=" + this.networkProtocol + ")(PORT=" + this.portNumber + ")(HOST=" + this.serverName + "))(CONNECT_DATA=(SERVICE_NAME=" + this.serviceName + ")))";
/*      */     
/*      */     }
/*      */     else {
/*      */ 
/*      */       
/* 1410 */       this.url = "jdbc:oracle:" + this.driverType + ":@(DESCRIPTION=(ADDRESS=(PROTOCOL=" + this.networkProtocol + ")(PORT=" + this.portNumber + ")(HOST=" + this.serverName + "))(CONNECT_DATA=(SID=" + this.databaseName + ")))";
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 1417 */       DatabaseError.addSqlWarning(null, new SQLWarning("URL with SID jdbc:subprotocol:@host:port:sid will be deprecated in 10i\nPlease use URL with SERVICE_NAME as jdbc:subprotocol:@//host:port/service_name"));
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 1425 */       if (this.fastConnFailover)
/*      */       {
/* 1427 */         DatabaseError.throwSqlException(67, "OracleDataSource.makeURL");
/*      */       }
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void trace(String paramString) {
/* 1445 */     if (this.logWriter != null)
/*      */     {
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 1451 */       OracleLog.print(this, 2, 2, 32, "OracleDataSource.trace(s): logWriter is not null");
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void copy(OracleDataSource paramOracleDataSource) throws SQLException {
/* 1467 */     paramOracleDataSource.setUser(this.user);
/* 1468 */     paramOracleDataSource.setPassword(this.password);
/* 1469 */     paramOracleDataSource.setTNSEntryName(this.tnsEntry);
/* 1470 */     makeURL();
/* 1471 */     paramOracleDataSource.setURL(this.url);
/* 1472 */     paramOracleDataSource.connectionProperties = this.connectionProperties;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void setMaxStatements(int paramInt) throws SQLException {
/* 1498 */     this.maxStatements = paramInt;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public int getMaxStatements() throws SQLException {
/* 1512 */     return this.maxStatements;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void setImplicitCachingEnabled(boolean paramBoolean) throws SQLException {
/* 1532 */     this.implicitCachingEnabled = paramBoolean;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public boolean getImplicitCachingEnabled() throws SQLException {
/* 1546 */     return this.implicitCachingEnabled;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void setExplicitCachingEnabled(boolean paramBoolean) throws SQLException {
/* 1567 */     this.explicitCachingEnabled = paramBoolean;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public boolean getExplicitCachingEnabled() throws SQLException {
/* 1581 */     return this.explicitCachingEnabled;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void setConnectionProperties(Properties paramProperties) throws SQLException {
/* 1882 */     if (paramProperties == null) { this.connectionProperties = paramProperties; }
/* 1883 */     else { this.connectionProperties = (Properties)paramProperties.clone(); }
/* 1884 */      setSpawnNewThreadToCancel(this.fastConnFailover);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Properties getConnectionProperties() throws SQLException {
/* 1897 */     return filterConnectionProperties(this.connectionProperties);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public static final Properties filterConnectionProperties(Properties paramProperties) {
/* 1907 */     Properties properties = null;
/*      */ 
/*      */     
/* 1910 */     if (paramProperties != null) {
/*      */       
/* 1912 */       properties = (Properties)paramProperties.clone();
/* 1913 */       Enumeration enumeration = properties.propertyNames();
/* 1914 */       Object object = null;
/* 1915 */       while (enumeration.hasMoreElements()) {
/*      */         
/* 1917 */         String str = (String)enumeration.nextElement();
/*      */ 
/*      */ 
/*      */ 
/*      */         
/* 1922 */         if (str != null && str.matches(".*[P,p][A,a][S,s][S,s][W,w][O,o][R,r][D,d].*"))
/*      */         {
/* 1924 */           properties.remove(str);
/*      */         }
/*      */       } 
/*      */ 
/*      */       
/* 1929 */       paramProperties.remove("oracle.jdbc.spawnNewThreadToCancel");
/*      */     } 
/*      */     
/* 1932 */     return properties;
/*      */   }
/*      */ 
/*      */   
/*      */   private void setSpawnNewThreadToCancel(boolean paramBoolean) {
/* 1937 */     if (paramBoolean) {
/* 1938 */       if (this.connectionProperties == null) this.connectionProperties = new Properties(); 
/* 1939 */       this.connectionProperties.setProperty("oracle.jdbc.spawnNewThreadToCancel", "true");
/*      */     }
/* 1941 */     else if (this.connectionProperties != null) {
/* 1942 */       this.connectionProperties.remove("oracle.jdbc.spawnNewThreadToCancel");
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private void writeObject(ObjectOutputStream paramObjectOutputStream) throws IOException {
/* 1952 */     paramObjectOutputStream.defaultWriteObject();
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private void readObject(ObjectInputStream paramObjectInputStream) throws IOException, ClassNotFoundException, SQLException {
/* 1968 */     paramObjectInputStream.defaultReadObject();
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1973 */     if (this.connCachingEnabled) {
/* 1974 */       setConnectionCachingEnabled(this.connCachingEnabled);
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */   
/* 1980 */   private static final String _Copyright_2004_Oracle_All_Rights_Reserved_ = null;
/*      */   public static final boolean TRACE = false;
/*      */   public static final boolean PRIVATE_TRACE = false;
/*      */   public static final String BUILD_DATE = "Sat_Feb__2_11:39:41_PST_2008";
/*      */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\lib\ojdbc14.jar!\oracle\jdbc\pool\OracleDataSource.class
 * Java compiler version: 2 (46.0)
 * JD-Core Version:       1.1.3
 */