/*      */ package oracle.jdbc.pool;
/*      */ 
/*      */ import java.sql.Connection;
/*      */ import java.sql.SQLException;
/*      */ import java.util.HashMap;
/*      */ import java.util.Iterator;
/*      */ import java.util.LinkedList;
/*      */ import java.util.Map;
/*      */ import java.util.Properties;
/*      */ import java.util.Random;
/*      */ import java.util.Vector;
/*      */ import javax.sql.PooledConnection;
/*      */ import oracle.jdbc.OracleConnection;
/*      */ import oracle.jdbc.driver.DatabaseError;
/*      */ import oracle.jdbc.internal.OracleConnection;
/*      */ import oracle.jdbc.xa.client.OracleXADataSource;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ class OracleImplicitConnectionCache
/*      */ {
/*   49 */   protected OracleDataSource cacheEnabledDS = null;
/*   50 */   protected String cacheName = null;
/*   51 */   protected OracleConnectionPoolDataSource connectionPoolDS = null;
/*      */   
/*      */   protected boolean fastConnectionFailoverEnabled = false;
/*      */   
/*   55 */   protected String defaultUser = null;
/*   56 */   protected String defaultPassword = null;
/*      */   
/*      */   protected static final int DEFAULT_MIN_LIMIT = 0;
/*      */   
/*      */   protected static final int DEFAULT_MAX_LIMIT = 2147483647;
/*      */   
/*      */   protected static final int DEFAULT_INITIAL_LIMIT = 0;
/*      */   
/*      */   protected static final int DEFAULT_MAX_STATEMENTS_LIMIT = 0;
/*      */   
/*      */   protected static final int DEFAULT_INACTIVITY_TIMEOUT = 0;
/*      */   
/*      */   protected static final int DEFAULT_TIMETOLIVE_TIMEOUT = 0;
/*      */   
/*      */   protected static final int DEFAULT_ABANDONED_CONN_TIMEOUT = 0;
/*      */   
/*      */   protected static final int DEFAULT_CONNECTION_WAIT_TIMEOUT = 0;
/*      */   protected static final String DEFAULT_ATTRIBUTE_WEIGHT = "0";
/*      */   protected static final int DEFAULT_LOWER_THRESHOLD_LIMIT = 20;
/*      */   protected static final int DEFAULT_PROPERTY_CHECK_INTERVAL = 900;
/*      */   protected static final int CLOSE_AND_REMOVE_ALL_CONNECTIONS = 1;
/*      */   protected static final int CLOSE_AND_REMOVE_FAILOVER_CONNECTIONS = 2;
/*      */   protected static final int PROCESS_INACTIVITY_TIMEOUT = 4;
/*      */   protected static final int CLOSE_AND_REMOVE_N_CONNECTIONS = 8;
/*      */   protected static final int DISABLE_STATEMENT_CACHING = 16;
/*      */   protected static final int RESET_STATEMENT_CACHE_SIZE = 18;
/*      */   protected static final int CLOSE_AND_REMOVE_RLB_CONNECTIONS = 24;
/*      */   protected static final int ABORT_AND_CLOSE_ALL_CONNECTIONS = 32;
/*      */   public static final int REFRESH_INVALID_CONNECTIONS = 4096;
/*      */   public static final int REFRESH_ALL_CONNECTIONS = 8192;
/*      */   private static final String ATTRKEY_DELIM = "0xffff";
/*   87 */   protected int cacheMinLimit = 0;
/*   88 */   protected int cacheMaxLimit = Integer.MAX_VALUE;
/*   89 */   protected int cacheInitialLimit = 0;
/*   90 */   protected int cacheMaxStatementsLimit = 0;
/*   91 */   protected Properties cacheAttributeWeights = null;
/*   92 */   protected int cacheInactivityTimeout = 0;
/*   93 */   protected int cacheTimeToLiveTimeout = 0;
/*   94 */   protected int cacheAbandonedConnectionTimeout = 0;
/*   95 */   protected int cacheLowerThresholdLimit = 20;
/*   96 */   protected int cachePropertyCheckInterval = 900;
/*      */   protected boolean cacheClosestConnectionMatch = false;
/*      */   protected boolean cacheValidateConnection = false;
/*   99 */   protected int cacheConnectionWaitTimeout = 0;
/*      */   
/*      */   static final String MIN_LIMIT_KEY = "MinLimit";
/*      */   
/*      */   static final String MAX_LIMIT_KEY = "MaxLimit";
/*      */   
/*      */   static final String INITIAL_LIMIT_KEY = "InitialLimit";
/*      */   
/*      */   static final String MAX_STATEMENTS_LIMIT_KEY = "MaxStatementsLimit";
/*      */   
/*      */   static final String ATTRIBUTE_WEIGHTS_KEY = "AttributeWeights";
/*      */   
/*      */   static final String INACTIVITY_TIMEOUT_KEY = "InactivityTimeout";
/*      */   
/*      */   static final String TIME_TO_LIVE_TIMEOUT_KEY = "TimeToLiveTimeout";
/*      */   static final String ABANDONED_CONNECTION_TIMEOUT_KEY = "AbandonedConnectionTimeout";
/*      */   static final String LOWER_THRESHOLD_LIMIT_KEY = "LowerThresholdLimit";
/*      */   static final String PROPERTY_CHECK_INTERVAL_KEY = "PropertyCheckInterval";
/*      */   static final String VALIDATE_CONNECTION_KEY = "ValidateConnection";
/*      */   static final String CLOSEST_CONNECTION_MATCH_KEY = "ClosestConnectionMatch";
/*      */   static final String CONNECTION_WAIT_TIMEOUT_KEY = "ConnectionWaitTimeout";
/*      */   static final int INSTANCE_GOOD = 1;
/*      */   static final int INSTANCE_UNKNOWN = 2;
/*      */   static final int INSTANCE_VIOLATING = 3;
/*      */   static final int INSTANCE_NO_DATA = 4;
/*      */   static final int INSTANCE_BLOCKED = 5;
/*      */   static final int RLB_NUMBER_OF_HITS_PER_INSTANCE = 1000;
/*  126 */   int dbInstancePercentTotal = 0;
/*      */   boolean useGoodGroup = false;
/*  128 */   Vector instancesToRetireQueue = null;
/*  129 */   OracleDatabaseInstance instanceToRetire = null;
/*  130 */   int retireConnectionsCount = 0;
/*  131 */   int countTotal = 0;
/*      */   
/*  133 */   protected OracleConnectionCacheManager cacheManager = null;
/*      */   protected boolean disableConnectionRequest = false;
/*  135 */   protected OracleImplicitConnectionCacheThread timeoutThread = null;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  142 */   protected OracleRuntimeLoadBalancingEventHandlerThread runtimeLoadBalancingThread = null;
/*      */ 
/*      */   
/*  145 */   protected OracleGravitateConnectionCacheThread gravitateCacheThread = null;
/*  146 */   protected int connectionsToRemove = 0;
/*      */ 
/*      */ 
/*      */   
/*  150 */   private HashMap userMap = null;
/*  151 */   Vector checkedOutConnectionList = null;
/*      */ 
/*      */   
/*  154 */   LinkedList databaseInstancesList = null;
/*      */   
/*  156 */   int cacheSize = 0;
/*      */   
/*      */   protected static final String EVENT_DELIMITER = " ";
/*      */   
/*      */   protected boolean isEntireServiceDownProcessed = false;
/*  161 */   protected int defaultUserPreFailureSize = 0;
/*  162 */   protected String dataSourceServiceName = null;
/*  163 */   protected OracleFailoverWorkerThread failoverWorkerThread = null;
/*  164 */   protected Random rand = null;
/*  165 */   protected int downEventCount = 0;
/*  166 */   protected int upEventCount = 0;
/*  167 */   protected int pendingCreationRequests = 0;
/*      */   
/*  169 */   protected int connectionClosedCount = 0;
/*  170 */   protected int connectionCreatedCount = 0;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   OracleImplicitConnectionCache(OracleDataSource paramOracleDataSource, Properties paramProperties) throws SQLException {
/*  181 */     this.cacheEnabledDS = paramOracleDataSource;
/*      */     
/*  183 */     initializeConnectionCache();
/*  184 */     setConnectionCacheProperties(paramProperties);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  191 */     defaultUserPrePopulateCache(this.cacheInitialLimit);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private void defaultUserPrePopulateCache(int paramInt) throws SQLException {
/*  204 */     if (paramInt > 0) {
/*      */       
/*  206 */       String str1 = this.defaultUser;
/*  207 */       String str2 = this.defaultPassword;
/*      */       
/*  209 */       validateUser(str1, str2);
/*      */       
/*  211 */       OraclePooledConnection oraclePooledConnection = null;
/*      */       
/*  213 */       for (byte b = 0; b < paramInt; b++) {
/*      */         
/*  215 */         oraclePooledConnection = makeOneConnection(str1, str2);
/*  216 */         synchronized (this) {
/*      */           
/*  218 */           if (oraclePooledConnection != null) {
/*      */ 
/*      */ 
/*      */             
/*  222 */             this.cacheSize--;
/*  223 */             storeCacheConnection(null, oraclePooledConnection);
/*      */           } 
/*      */         } 
/*      */       } 
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void initializeConnectionCache() throws SQLException {
/*  239 */     this.userMap = new HashMap();
/*  240 */     this.checkedOutConnectionList = new Vector();
/*      */     
/*  242 */     if (this.cacheManager == null) {
/*  243 */       this.cacheManager = OracleConnectionCacheManager.getConnectionCacheManagerInstance();
/*      */     }
/*      */     
/*  246 */     this.defaultUser = this.cacheEnabledDS.user;
/*  247 */     this.defaultPassword = this.cacheEnabledDS.password;
/*  248 */     if (this.defaultPassword != null) {
/*  249 */       this.defaultPassword = this.defaultPassword.toUpperCase();
/*      */     }
/*  251 */     if (this.connectionPoolDS == null) {
/*      */       
/*  253 */       if (this.cacheEnabledDS instanceof OracleXADataSource) {
/*      */         
/*  255 */         this.connectionPoolDS = (OracleConnectionPoolDataSource)new OracleXADataSource();
/*      */       }
/*      */       else {
/*      */         
/*  259 */         this.connectionPoolDS = new OracleConnectionPoolDataSource();
/*      */       } 
/*      */ 
/*      */       
/*  263 */       this.cacheEnabledDS.copy(this.connectionPoolDS);
/*      */     } 
/*      */     
/*  266 */     if (this.fastConnectionFailoverEnabled = this.cacheEnabledDS.getFastConnectionFailoverEnabled()) {
/*      */ 
/*      */       
/*  269 */       this.rand = new Random(0L);
/*  270 */       this.instancesToRetireQueue = new Vector();
/*  271 */       this.cacheManager.failoverEnabledCacheCount++;
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private void validateUser(String paramString1, String paramString2) throws SQLException {
/*  286 */     if (paramString1 == null || paramString2 == null) {
/*  287 */       DatabaseError.throwSqlException(79);
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected Connection getConnection(String paramString1, String paramString2, Properties paramProperties) throws SQLException {
/*  306 */     OraclePooledConnection oraclePooledConnection = null;
/*  307 */     Connection connection = null;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     try {
/*  316 */       if (this.disableConnectionRequest)
/*      */       {
/*  318 */         DatabaseError.throwSqlException(142);
/*      */       }
/*      */ 
/*      */       
/*  322 */       validateUser(paramString1, paramString2);
/*      */ 
/*      */       
/*  325 */       if (!paramString1.startsWith("\"")) {
/*  326 */         paramString1 = paramString1.toLowerCase();
/*      */       }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*  341 */       if (getNumberOfCheckedOutConnections() < this.cacheMaxLimit) {
/*  342 */         oraclePooledConnection = getCacheConnection(paramString1, paramString2, paramProperties);
/*      */       }
/*      */       
/*  345 */       if (oraclePooledConnection == null) {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */         
/*  352 */         processConnectionCacheCallback();
/*      */         
/*  354 */         if (this.cacheSize > 0) {
/*  355 */           oraclePooledConnection = getCacheConnection(paramString1, paramString2, paramProperties);
/*      */         }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */         
/*  364 */         if (oraclePooledConnection == null && this.cacheConnectionWaitTimeout > 0) {
/*      */           
/*  366 */           long l1 = this.cacheConnectionWaitTimeout * 1000L;
/*  367 */           long l2 = System.currentTimeMillis();
/*  368 */           long l3 = 0L;
/*      */           
/*      */           do {
/*  371 */             processConnectionWaitTimeout(l1);
/*      */             
/*  373 */             if (this.cacheSize > 0) {
/*  374 */               oraclePooledConnection = getCacheConnection(paramString1, paramString2, paramProperties);
/*      */             }
/*  376 */             l3 = System.currentTimeMillis();
/*  377 */             l1 -= System.currentTimeMillis() - l2;
/*  378 */             l2 = l3;
/*      */           
/*      */           }
/*  381 */           while (oraclePooledConnection == null && l1 > 0L);
/*      */         } 
/*      */       } 
/*      */ 
/*      */       
/*  386 */       if (oraclePooledConnection != null && oraclePooledConnection.physicalConn != null) {
/*      */ 
/*      */ 
/*      */         
/*  390 */         connection = oraclePooledConnection.getConnection();
/*      */         
/*  392 */         if (connection != null) {
/*      */           
/*  394 */           if (this.cacheValidateConnection && testDatabaseConnection((OracleConnection)connection) != 0) {
/*      */ 
/*      */ 
/*      */             
/*  398 */             ((OracleConnection)connection).close(4096);
/*  399 */             DatabaseError.throwSqlException(143);
/*      */           } 
/*      */ 
/*      */           
/*  403 */           if (this.cacheAbandonedConnectionTimeout > 0) {
/*  404 */             ((OracleConnection)connection).setAbandonedTimeoutEnabled(true);
/*      */           }
/*      */           
/*  407 */           if (this.cacheTimeToLiveTimeout > 0) {
/*  408 */             ((OracleConnection)connection).setStartTime(System.currentTimeMillis());
/*      */           }
/*  410 */           synchronized (this) {
/*      */ 
/*      */ 
/*      */             
/*  414 */             this.cacheSize--;
/*  415 */             this.checkedOutConnectionList.addElement(oraclePooledConnection);
/*      */           } 
/*      */         } 
/*      */       } 
/*  419 */     } catch (SQLException sQLException) {
/*      */       
/*  421 */       synchronized (this) {
/*      */         
/*  423 */         if (oraclePooledConnection != null) {
/*      */           
/*  425 */           this.cacheSize--;
/*  426 */           abortConnection(oraclePooledConnection);
/*      */         } 
/*      */       } 
/*  429 */       throw sQLException;
/*      */     } 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  436 */     return connection;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private OraclePooledConnection getCacheConnection(String paramString1, String paramString2, Properties paramProperties) throws SQLException {
/*  452 */     OraclePooledConnection oraclePooledConnection = retrieveCacheConnection(paramString1, paramString2, paramProperties);
/*      */     
/*  454 */     if (oraclePooledConnection == null) {
/*      */       
/*  456 */       oraclePooledConnection = makeOneConnection(paramString1, paramString2);
/*      */       
/*  458 */       if (oraclePooledConnection != null && paramProperties != null && !paramProperties.isEmpty()) {
/*  459 */         setUnMatchedAttributes(paramProperties, oraclePooledConnection);
/*      */       }
/*      */     } 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  467 */     return oraclePooledConnection;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   OraclePooledConnection makeOneConnection(String paramString1, String paramString2) throws SQLException {
/*  478 */     OraclePooledConnection oraclePooledConnection = null;
/*  479 */     boolean bool = false;
/*  480 */     synchronized (this) {
/*      */ 
/*      */       
/*  483 */       if (getTotalCachedConnections() + this.pendingCreationRequests < this.cacheMaxLimit) {
/*      */ 
/*      */         
/*  486 */         this.pendingCreationRequests++;
/*  487 */         bool = true;
/*      */       } 
/*      */     } 
/*      */     
/*  491 */     if (bool) {
/*      */       
/*      */       try {
/*      */         
/*  495 */         oraclePooledConnection = makeCacheConnection(paramString1, paramString2);
/*      */ 
/*      */       
/*      */       }
/*      */       finally {
/*      */ 
/*      */ 
/*      */         
/*  503 */         synchronized (this) {
/*      */           
/*  505 */           if (oraclePooledConnection != null)
/*  506 */             this.connectionCreatedCount++; 
/*  507 */           this.pendingCreationRequests--;
/*      */         } 
/*      */       } 
/*      */     }
/*      */     
/*  512 */     return oraclePooledConnection;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected int getTotalCachedConnections() {
/*  521 */     return this.cacheSize + getNumberOfCheckedOutConnections();
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected int getNumberOfCheckedOutConnections() {
/*  530 */     return this.checkedOutConnectionList.size();
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private synchronized OraclePooledConnection retrieveCacheConnection(String paramString1, String paramString2, Properties paramProperties) throws SQLException {
/*  543 */     OraclePooledConnection oraclePooledConnection = null;
/*  544 */     OracleConnectionCacheEntry oracleConnectionCacheEntry = (OracleConnectionCacheEntry)this.userMap.get(paramString1 + paramString2.toUpperCase());
/*      */ 
/*      */     
/*  547 */     if (oracleConnectionCacheEntry != null)
/*      */     {
/*      */ 
/*      */ 
/*      */       
/*  552 */       if (paramProperties == null || (paramProperties != null && paramProperties.isEmpty())) {
/*      */         
/*  554 */         if (oracleConnectionCacheEntry.userConnList != null) {
/*  555 */           oraclePooledConnection = retrieveFromConnectionList(oracleConnectionCacheEntry.userConnList);
/*      */         }
/*  557 */       } else if (oracleConnectionCacheEntry.attrConnMap != null) {
/*      */         
/*  559 */         String str = buildAttrKey(paramProperties);
/*  560 */         Vector vector = (Vector)oracleConnectionCacheEntry.attrConnMap.get(str);
/*      */ 
/*      */         
/*  563 */         if (vector != null)
/*      */         {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */           
/*  570 */           oraclePooledConnection = retrieveFromConnectionList(vector);
/*      */         }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */         
/*  578 */         if (oraclePooledConnection == null && this.cacheClosestConnectionMatch) {
/*  579 */           oraclePooledConnection = retrieveClosestConnectionMatch(oracleConnectionCacheEntry.attrConnMap, paramProperties);
/*      */         }
/*      */ 
/*      */ 
/*      */         
/*  584 */         if (oraclePooledConnection == null && oracleConnectionCacheEntry.userConnList != null) {
/*  585 */           oraclePooledConnection = retrieveFromConnectionList(oracleConnectionCacheEntry.userConnList);
/*      */         }
/*      */       } 
/*      */     }
/*      */     
/*  590 */     if (oraclePooledConnection != null)
/*      */     {
/*  592 */       if (paramProperties != null && !paramProperties.isEmpty()) {
/*  593 */         setUnMatchedAttributes(paramProperties, oraclePooledConnection);
/*      */       }
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  600 */     return oraclePooledConnection;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private OraclePooledConnection retrieveClosestConnectionMatch(HashMap paramHashMap, Properties paramProperties) throws SQLException {
/*  613 */     OraclePooledConnection oraclePooledConnection1 = null;
/*  614 */     OraclePooledConnection oraclePooledConnection2 = null;
/*      */     
/*  616 */     int i = paramProperties.size();
/*  617 */     int j = 0;
/*  618 */     int k = 0;
/*  619 */     int m = 0;
/*  620 */     int n = 0;
/*  621 */     int i1 = 0;
/*      */     
/*  623 */     if (this.cacheAttributeWeights != null) {
/*  624 */       j = getAttributesWeightCount(paramProperties, null);
/*      */     }
/*  626 */     if (paramHashMap != null && !paramHashMap.isEmpty()) {
/*      */ 
/*      */ 
/*      */       
/*  630 */       Iterator iterator = paramHashMap.entrySet().iterator();
/*      */       
/*  632 */       while (iterator.hasNext()) {
/*      */         
/*  634 */         Map.Entry entry = iterator.next();
/*      */         
/*  636 */         Vector vector = (Vector)entry.getValue();
/*  637 */         Object[] arrayOfObject = vector.toArray();
/*  638 */         int i2 = vector.size();
/*      */         
/*  640 */         for (byte b = 0; b < i2; b++) {
/*      */           
/*  642 */           oraclePooledConnection1 = (OraclePooledConnection)arrayOfObject[b];
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */           
/*  649 */           if (oraclePooledConnection1.cachedConnectionAttributes != null && !oraclePooledConnection1.cachedConnectionAttributes.isEmpty() && oraclePooledConnection1.cachedConnectionAttributes.size() <= i)
/*      */           {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */             
/*  663 */             if (j > 0) {
/*      */               
/*  665 */               m = getAttributesWeightCount(paramProperties, oraclePooledConnection1.cachedConnectionAttributes);
/*      */ 
/*      */ 
/*      */               
/*  669 */               if (m > k)
/*      */               {
/*  671 */                 oraclePooledConnection2 = oraclePooledConnection1;
/*  672 */                 k = m;
/*      */               }
/*      */             
/*      */             } else {
/*      */               
/*  677 */               i1 = getAttributesMatchCount(paramProperties, oraclePooledConnection1.cachedConnectionAttributes);
/*      */ 
/*      */               
/*  680 */               if (i1 > n) {
/*      */                 
/*  682 */                 oraclePooledConnection2 = oraclePooledConnection1;
/*  683 */                 n = i1;
/*      */               } 
/*      */             } 
/*      */           }
/*      */         } 
/*      */       } 
/*      */     } 
/*      */     
/*  691 */     return oraclePooledConnection2;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private int getAttributesMatchCount(Properties paramProperties1, Properties paramProperties2) throws SQLException {
/*  707 */     byte b = 0;
/*  708 */     Map.Entry entry = null;
/*  709 */     Object object1 = null;
/*  710 */     Object object2 = null;
/*      */     
/*  712 */     Iterator iterator = paramProperties1.entrySet().iterator();
/*      */     
/*  714 */     while (iterator.hasNext()) {
/*      */       
/*  716 */       entry = iterator.next();
/*  717 */       object1 = entry.getKey();
/*  718 */       object2 = entry.getValue();
/*      */       
/*  720 */       if (paramProperties2.containsKey(object1) && object2.equals(paramProperties2.get(object1)))
/*      */       {
/*  722 */         b++;
/*      */       }
/*      */     } 
/*  725 */     return b;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private int getAttributesWeightCount(Properties paramProperties1, Properties paramProperties2) throws SQLException {
/*  755 */     Map.Entry entry = null;
/*  756 */     Object object1 = null;
/*  757 */     Object object2 = null;
/*  758 */     int i = 0;
/*      */     
/*  760 */     Iterator iterator = paramProperties1.entrySet().iterator();
/*      */     
/*  762 */     while (iterator.hasNext()) {
/*      */       
/*  764 */       entry = iterator.next();
/*  765 */       object1 = entry.getKey();
/*  766 */       object2 = entry.getValue();
/*      */ 
/*      */       
/*  769 */       if (paramProperties2 == null) {
/*      */         
/*  771 */         if (this.cacheAttributeWeights.containsKey(object1))
/*      */         {
/*  773 */           i += Integer.parseInt((String)this.cacheAttributeWeights.get(object1));
/*      */         }
/*      */         continue;
/*      */       } 
/*  777 */       if (paramProperties2.containsKey(object1) && object2.equals(paramProperties2.get(object1))) {
/*      */ 
/*      */         
/*  780 */         if (this.cacheAttributeWeights.containsKey(object1)) {
/*      */           
/*  782 */           i += Integer.parseInt((String)this.cacheAttributeWeights.get(object1));
/*      */ 
/*      */           
/*      */           continue;
/*      */         } 
/*      */ 
/*      */         
/*  789 */         i++;
/*      */       } 
/*      */     } 
/*      */ 
/*      */     
/*  794 */     return i;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private void setUnMatchedAttributes(Properties paramProperties, OraclePooledConnection paramOraclePooledConnection) throws SQLException {
/*  809 */     if (paramOraclePooledConnection.unMatchedCachedConnAttr == null) {
/*  810 */       paramOraclePooledConnection.unMatchedCachedConnAttr = new Properties();
/*      */     } else {
/*  812 */       paramOraclePooledConnection.unMatchedCachedConnAttr.clear();
/*      */     } 
/*  814 */     if (!this.cacheClosestConnectionMatch) {
/*      */       
/*  816 */       paramOraclePooledConnection.unMatchedCachedConnAttr.putAll(paramProperties);
/*      */     }
/*      */     else {
/*      */       
/*  820 */       Properties properties = paramOraclePooledConnection.cachedConnectionAttributes;
/*  821 */       Map.Entry entry = null;
/*  822 */       Object object1 = null;
/*  823 */       Object object2 = null;
/*      */       
/*  825 */       Iterator iterator = paramProperties.entrySet().iterator();
/*      */       
/*  827 */       while (iterator.hasNext()) {
/*      */         
/*  829 */         entry = iterator.next();
/*  830 */         object1 = entry.getKey();
/*  831 */         object2 = entry.getValue();
/*      */         
/*  833 */         if (!properties.containsKey(object1) && !object2.equals(properties.get(object1)))
/*      */         {
/*  835 */           paramOraclePooledConnection.unMatchedCachedConnAttr.put(object1, object2);
/*      */         }
/*      */       } 
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private OraclePooledConnection retrieveFromConnectionList(Vector paramVector) throws SQLException {
/*  853 */     if (paramVector.isEmpty()) {
/*  854 */       return null;
/*      */     }
/*  856 */     OraclePooledConnection oraclePooledConnection = null;
/*      */     
/*  858 */     if (this.fastConnectionFailoverEnabled) {
/*      */ 
/*      */       
/*  861 */       if (this.useGoodGroup && this.databaseInstancesList != null && this.databaseInstancesList.size() > 0) {
/*      */ 
/*      */         
/*  864 */         synchronized (this.databaseInstancesList) {
/*      */           
/*  866 */           int i = this.databaseInstancesList.size();
/*  867 */           OracleDatabaseInstance oracleDatabaseInstance = null;
/*  868 */           int j = 0;
/*      */           
/*  870 */           boolean[] arrayOfBoolean = new boolean[i];
/*  871 */           int k = this.dbInstancePercentTotal;
/*      */           byte b;
/*  873 */           label51: for (b = 0; b < i; b++) {
/*      */             
/*  875 */             int m = 0;
/*      */ 
/*      */             
/*  878 */             if (k <= 1) {
/*  879 */               j = 0;
/*      */             } else {
/*  881 */               j = this.rand.nextInt(k - 1);
/*      */             } 
/*      */             
/*  884 */             for (byte b1 = 0; b1 < i; b1++) {
/*      */               
/*  886 */               oracleDatabaseInstance = this.databaseInstancesList.get(b1);
/*      */               
/*  888 */               if (!arrayOfBoolean[b1] && oracleDatabaseInstance.flag <= 3) {
/*      */                 
/*  890 */                 m += oracleDatabaseInstance.percent;
/*      */ 
/*      */ 
/*      */ 
/*      */                 
/*  895 */                 if (j <= m) {
/*      */ 
/*      */                   
/*  898 */                   if (b == 0) oracleDatabaseInstance.attemptedConnRequestCount++;
/*      */                   
/*  900 */                   if ((oraclePooledConnection = selectConnectionFromList(paramVector, oracleDatabaseInstance)) != null) {
/*      */                     break label51;
/*      */                   }
/*      */ 
/*      */ 
/*      */                   
/*  906 */                   k -= oracleDatabaseInstance.percent;
/*  907 */                   arrayOfBoolean[b1] = true;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */                   
/*      */                   break;
/*      */                 } 
/*      */               } 
/*      */             } 
/*      */           } 
/*      */         } 
/*      */       } else {
/*  924 */         int i = paramVector.size();
/*  925 */         int j = this.rand.nextInt(i);
/*  926 */         OraclePooledConnection oraclePooledConnection1 = null;
/*      */         
/*  928 */         for (byte b = 0; b < i; b++) {
/*      */           
/*  930 */           oraclePooledConnection1 = paramVector.get((j++ + i) % i);
/*      */ 
/*      */           
/*  933 */           if (!oraclePooledConnection1.connectionMarkedDown) {
/*      */             
/*  935 */             oraclePooledConnection = oraclePooledConnection1;
/*  936 */             paramVector.remove(oraclePooledConnection);
/*      */ 
/*      */             
/*      */             break;
/*      */           } 
/*      */         } 
/*      */       } 
/*      */     } else {
/*  944 */       oraclePooledConnection = paramVector.remove(0);
/*      */     } 
/*      */     
/*  947 */     return oraclePooledConnection;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private OraclePooledConnection selectConnectionFromList(Vector paramVector, OracleDatabaseInstance paramOracleDatabaseInstance) {
/*  958 */     OraclePooledConnection oraclePooledConnection1 = null;
/*  959 */     OraclePooledConnection oraclePooledConnection2 = null;
/*      */ 
/*      */     
/*  962 */     int i = paramVector.size();
/*  963 */     for (byte b = 0; b < i; b++) {
/*      */       
/*  965 */       oraclePooledConnection2 = paramVector.get(b);
/*      */       
/*  967 */       if (!oraclePooledConnection2.connectionMarkedDown && oraclePooledConnection2.dataSourceDbUniqNameKey == paramOracleDatabaseInstance.databaseUniqName && oraclePooledConnection2.dataSourceInstanceNameKey == paramOracleDatabaseInstance.instanceName) {
/*      */ 
/*      */ 
/*      */         
/*  971 */         oraclePooledConnection1 = oraclePooledConnection2;
/*  972 */         paramVector.remove(oraclePooledConnection1);
/*      */ 
/*      */ 
/*      */         
/*      */         break;
/*      */       } 
/*      */     } 
/*      */ 
/*      */     
/*  981 */     return oraclePooledConnection1;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private void removeCacheConnection(OraclePooledConnection paramOraclePooledConnection) throws SQLException {
/*  993 */     boolean bool = false;
/*      */     
/*  995 */     OracleConnectionCacheEntry oracleConnectionCacheEntry = paramOraclePooledConnection.removeFromImplictCache(this.userMap);
/*      */ 
/*      */     
/*  998 */     if (oracleConnectionCacheEntry != null) {
/*      */       
/* 1000 */       Properties properties = paramOraclePooledConnection.cachedConnectionAttributes;
/*      */       
/* 1002 */       if (properties == null || (properties != null && properties.isEmpty())) {
/*      */         
/* 1004 */         if (oracleConnectionCacheEntry.userConnList != null) {
/* 1005 */           bool = oracleConnectionCacheEntry.userConnList.removeElement(paramOraclePooledConnection);
/*      */         }
/* 1007 */       } else if (oracleConnectionCacheEntry.attrConnMap != null) {
/*      */         
/* 1009 */         String str = buildAttrKey(properties);
/*      */         
/* 1011 */         Vector vector = (Vector)oracleConnectionCacheEntry.attrConnMap.get(str);
/*      */ 
/*      */         
/* 1014 */         if (vector != null) {
/*      */ 
/*      */ 
/*      */           
/* 1018 */           if (paramOraclePooledConnection.unMatchedCachedConnAttr != null) {
/*      */             
/* 1020 */             paramOraclePooledConnection.unMatchedCachedConnAttr.clear();
/* 1021 */             paramOraclePooledConnection.unMatchedCachedConnAttr = null;
/*      */           } 
/*      */           
/* 1024 */           if (paramOraclePooledConnection.cachedConnectionAttributes != null) {
/*      */             
/* 1026 */             paramOraclePooledConnection.cachedConnectionAttributes.clear();
/* 1027 */             paramOraclePooledConnection.cachedConnectionAttributes = null;
/*      */           } 
/*      */           
/* 1030 */           properties = null;
/* 1031 */           bool = vector.removeElement(paramOraclePooledConnection);
/*      */         } 
/*      */       } 
/*      */     } 
/*      */ 
/*      */     
/* 1037 */     if (bool)
/*      */     {
/* 1039 */       this.cacheSize--;
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void doForEveryCachedConnection(int paramInt) throws SQLException {
/* 1065 */     byte b = 0;
/*      */     
/* 1067 */     synchronized (this) {
/*      */       
/* 1069 */       if (this.userMap != null && !this.userMap.isEmpty()) {
/*      */         
/* 1071 */         Iterator iterator = this.userMap.entrySet().iterator();
/*      */         
/* 1073 */         while (iterator.hasNext()) {
/*      */           
/* 1075 */           Map.Entry entry = iterator.next();
/* 1076 */           OracleConnectionCacheEntry oracleConnectionCacheEntry = (OracleConnectionCacheEntry)entry.getValue();
/*      */ 
/*      */ 
/*      */           
/* 1080 */           if (oracleConnectionCacheEntry.userConnList != null && !oracleConnectionCacheEntry.userConnList.isEmpty()) {
/*      */             
/* 1082 */             Vector vector = oracleConnectionCacheEntry.userConnList;
/* 1083 */             Object[] arrayOfObject = vector.toArray();
/*      */             
/* 1085 */             for (byte b1 = 0; b1 < arrayOfObject.length; b1++) {
/*      */               
/* 1087 */               OraclePooledConnection oraclePooledConnection = (OraclePooledConnection)arrayOfObject[b1];
/*      */               
/* 1089 */               if (oraclePooledConnection != null && performPooledConnectionTask(oraclePooledConnection, paramInt)) {
/* 1090 */                 b++;
/*      */               }
/*      */             } 
/*      */           } 
/* 1094 */           if (oracleConnectionCacheEntry.attrConnMap != null && !oracleConnectionCacheEntry.attrConnMap.isEmpty()) {
/*      */             
/* 1096 */             Iterator iterator1 = oracleConnectionCacheEntry.attrConnMap.entrySet().iterator();
/*      */             
/* 1098 */             while (iterator1.hasNext()) {
/*      */               
/* 1100 */               Map.Entry entry1 = iterator1.next();
/*      */               
/* 1102 */               Vector vector = (Vector)entry1.getValue();
/* 1103 */               Object[] arrayOfObject = vector.toArray();
/*      */               
/* 1105 */               for (byte b1 = 0; b1 < arrayOfObject.length; b1++) {
/*      */                 
/* 1107 */                 OraclePooledConnection oraclePooledConnection = (OraclePooledConnection)arrayOfObject[b1];
/*      */                 
/* 1109 */                 if (oraclePooledConnection != null && performPooledConnectionTask(oraclePooledConnection, paramInt)) {
/* 1110 */                   b++;
/*      */                 }
/*      */               } 
/*      */             } 
/* 1114 */             if (paramInt == 1 || paramInt == 32)
/*      */             {
/* 1116 */               oracleConnectionCacheEntry.attrConnMap.clear();
/*      */             }
/*      */           } 
/*      */         } 
/*      */         
/* 1121 */         if (paramInt == 1 || paramInt == 32) {
/*      */ 
/*      */           
/* 1124 */           this.userMap.clear();
/*      */           
/* 1126 */           this.cacheSize = 0;
/*      */         } 
/*      */       } 
/*      */     } 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1136 */     if (b > 0)
/*      */     {
/*      */       
/* 1139 */       defaultUserPrePopulateCache(b);
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private boolean performPooledConnectionTask(OraclePooledConnection paramOraclePooledConnection, int paramInt) throws SQLException {
/*      */     Connection connection;
/* 1160 */     boolean bool = false;
/*      */     
/* 1162 */     switch (paramInt) {
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*      */       case 2:
/* 1168 */         if (paramOraclePooledConnection.connectionMarkedDown) {
/*      */ 
/*      */ 
/*      */           
/* 1172 */           paramOraclePooledConnection.needToAbort = true;
/* 1173 */           closeAndRemovePooledConnection(paramOraclePooledConnection);
/*      */         } 
/*      */         break;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*      */       case 8:
/* 1182 */         if (this.connectionsToRemove > 0) {
/*      */           
/* 1184 */           closeAndRemovePooledConnection(paramOraclePooledConnection);
/*      */           
/* 1186 */           this.connectionsToRemove--;
/*      */         } 
/*      */         break;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*      */       case 24:
/* 1195 */         if (this.retireConnectionsCount > 0)
/*      */         {
/* 1197 */           if (this.instanceToRetire.databaseUniqName == paramOraclePooledConnection.dataSourceDbUniqNameKey && this.instanceToRetire.instanceName == paramOraclePooledConnection.dataSourceInstanceNameKey) {
/*      */ 
/*      */             
/* 1200 */             closeAndRemovePooledConnection(paramOraclePooledConnection);
/* 1201 */             this.retireConnectionsCount--;
/*      */             
/* 1203 */             if (getTotalCachedConnections() < this.cacheMinLimit) {
/* 1204 */               bool = true;
/*      */             }
/*      */           } 
/*      */         }
/*      */         break;
/*      */ 
/*      */ 
/*      */       
/*      */       case 4096:
/* 1213 */         connection = paramOraclePooledConnection.getLogicalHandle();
/*      */         
/* 1215 */         if (connection != null || (connection = paramOraclePooledConnection.getPhysicalHandle()) != null)
/*      */         {
/*      */           
/* 1218 */           if (testDatabaseConnection((OracleConnection)connection) != 0) {
/*      */ 
/*      */             
/* 1221 */             closeAndRemovePooledConnection(paramOraclePooledConnection);
/*      */             
/* 1223 */             bool = true;
/*      */           } 
/*      */         }
/*      */         break;
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*      */       case 8192:
/* 1232 */         closeAndRemovePooledConnection(paramOraclePooledConnection);
/*      */         
/* 1234 */         bool = true;
/*      */         break;
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*      */       case 1:
/* 1241 */         closeAndRemovePooledConnection(paramOraclePooledConnection);
/*      */         break;
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*      */       case 4:
/* 1248 */         processInactivityTimeout(paramOraclePooledConnection);
/*      */         break;
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*      */       case 16:
/* 1255 */         setStatementCaching(paramOraclePooledConnection, this.cacheMaxStatementsLimit, false);
/*      */         break;
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*      */       case 18:
/* 1262 */         setStatementCaching(paramOraclePooledConnection, this.cacheMaxStatementsLimit, true);
/*      */         break;
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*      */       case 32:
/* 1269 */         abortConnection(paramOraclePooledConnection);
/* 1270 */         closeAndRemovePooledConnection(paramOraclePooledConnection);
/*      */         break;
/*      */     } 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1278 */     return bool;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected synchronized void doForEveryCheckedOutConnection(int paramInt) throws SQLException {
/*      */     byte b;
/* 1295 */     int i = this.checkedOutConnectionList.size();
/*      */ 
/*      */     
/* 1298 */     switch (paramInt) {
/*      */       
/*      */       case 1:
/* 1301 */         for (b = 0; b < i; b++)
/*      */         {
/* 1303 */           closeCheckedOutConnection(this.checkedOutConnectionList.get(b), false);
/*      */         }
/*      */ 
/*      */         
/* 1307 */         this.checkedOutConnectionList.removeAllElements();
/*      */         break;
/*      */       
/*      */       case 24:
/* 1311 */         for (b = 0; b < i && this.retireConnectionsCount > 0; b++) {
/*      */           
/* 1313 */           OraclePooledConnection oraclePooledConnection = this.checkedOutConnectionList.get(b);
/* 1314 */           if (this.instanceToRetire.databaseUniqName == oraclePooledConnection.dataSourceDbUniqNameKey && this.instanceToRetire.instanceName == oraclePooledConnection.dataSourceInstanceNameKey) {
/*      */ 
/*      */             
/* 1317 */             oraclePooledConnection.closeOption = 4096;
/*      */ 
/*      */             
/* 1320 */             this.retireConnectionsCount -= 2;
/*      */           } 
/*      */         } 
/*      */         break;
/*      */       
/*      */       case 32:
/* 1326 */         for (b = 0; b < i; b++) {
/*      */           
/* 1328 */           OraclePooledConnection oraclePooledConnection = null;
/* 1329 */           abortConnection(oraclePooledConnection = this.checkedOutConnectionList.get(b));
/* 1330 */           closeCheckedOutConnection(oraclePooledConnection, false);
/*      */         } 
/*      */ 
/*      */         
/* 1334 */         this.checkedOutConnectionList.removeAllElements();
/*      */         break;
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void closeCheckedOutConnection(OraclePooledConnection paramOraclePooledConnection, boolean paramBoolean) throws SQLException {
/* 1356 */     if (paramOraclePooledConnection != null) {
/*      */       
/* 1358 */       OracleConnection oracleConnection = (OracleConnection)paramOraclePooledConnection.getLogicalHandle();
/*      */ 
/*      */ 
/*      */       
/*      */       try {
/* 1363 */         if (!oracleConnection.getAutoCommit() && !paramOraclePooledConnection.needToAbort) {
/* 1364 */           oracleConnection.rollback();
/*      */         }
/* 1366 */       } catch (SQLException sQLException) {}
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 1372 */       if (paramBoolean) {
/*      */ 
/*      */         
/*      */         try {
/*      */           
/* 1377 */           oracleConnection.cleanupAndClose(true);
/*      */         }
/* 1379 */         catch (SQLException sQLException) {}
/*      */ 
/*      */       
/*      */       }
/*      */       else {
/*      */ 
/*      */ 
/*      */         
/* 1387 */         actualPooledConnectionClose(paramOraclePooledConnection);
/*      */       } 
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private synchronized void storeCacheConnection(Properties paramProperties, OraclePooledConnection paramOraclePooledConnection) throws SQLException {
/* 1407 */     boolean bool = false;
/*      */     
/* 1409 */     if (paramOraclePooledConnection == null || paramOraclePooledConnection.physicalConn == null) {
/*      */       return;
/*      */     }
/*      */ 
/*      */     
/* 1414 */     if (this.cacheInactivityTimeout > 0)
/*      */     {
/* 1416 */       paramOraclePooledConnection.setLastAccessedTime(System.currentTimeMillis());
/*      */     }
/*      */     
/* 1419 */     if (paramOraclePooledConnection.unMatchedCachedConnAttr != null) {
/*      */       
/* 1421 */       paramOraclePooledConnection.unMatchedCachedConnAttr.clear();
/* 1422 */       paramOraclePooledConnection.unMatchedCachedConnAttr = null;
/*      */     } 
/*      */     
/* 1425 */     OracleConnectionCacheEntry oracleConnectionCacheEntry = paramOraclePooledConnection.removeFromImplictCache(this.userMap);
/*      */ 
/*      */     
/* 1428 */     if (oracleConnectionCacheEntry != null) {
/*      */       
/* 1430 */       if (paramProperties == null || (paramProperties != null && paramProperties.isEmpty())) {
/*      */         
/* 1432 */         if (oracleConnectionCacheEntry.userConnList == null) {
/* 1433 */           oracleConnectionCacheEntry.userConnList = new Vector();
/*      */         }
/* 1435 */         bool = oracleConnectionCacheEntry.userConnList.add(paramOraclePooledConnection);
/*      */       
/*      */       }
/*      */       else {
/*      */ 
/*      */         
/* 1441 */         paramOraclePooledConnection.cachedConnectionAttributes = paramProperties;
/*      */         
/* 1443 */         if (oracleConnectionCacheEntry.attrConnMap == null) {
/* 1444 */           oracleConnectionCacheEntry.attrConnMap = new HashMap();
/*      */         }
/* 1446 */         String str = buildAttrKey(paramProperties);
/* 1447 */         Vector vector = (Vector)oracleConnectionCacheEntry.attrConnMap.get(str);
/*      */ 
/*      */         
/* 1450 */         if (vector != null)
/*      */         {
/* 1452 */           bool = vector.add(paramOraclePooledConnection);
/*      */         }
/*      */         else
/*      */         {
/* 1456 */           vector = new Vector();
/*      */           
/* 1458 */           bool = vector.add(paramOraclePooledConnection);
/* 1459 */           oracleConnectionCacheEntry.attrConnMap.put(str, vector);
/*      */         }
/*      */       
/*      */       } 
/*      */     } else {
/*      */       
/* 1465 */       oracleConnectionCacheEntry = new OracleConnectionCacheEntry();
/*      */       
/* 1467 */       paramOraclePooledConnection.addToImplicitCache(this.userMap, oracleConnectionCacheEntry);
/*      */       
/* 1469 */       if (paramProperties == null || (paramProperties != null && paramProperties.isEmpty())) {
/*      */         
/* 1471 */         Vector vector = new Vector();
/*      */         
/* 1473 */         bool = vector.add(paramOraclePooledConnection);
/*      */         
/* 1475 */         oracleConnectionCacheEntry.userConnList = vector;
/*      */       }
/*      */       else {
/*      */         
/* 1479 */         String str = buildAttrKey(paramProperties);
/*      */ 
/*      */         
/* 1482 */         paramOraclePooledConnection.cachedConnectionAttributes = paramProperties;
/*      */         
/* 1484 */         HashMap hashMap = new HashMap();
/* 1485 */         Vector vector = new Vector();
/*      */         
/* 1487 */         bool = vector.add(paramOraclePooledConnection);
/* 1488 */         hashMap.put(str, vector);
/*      */         
/* 1490 */         oracleConnectionCacheEntry.attrConnMap = hashMap;
/*      */       } 
/*      */     } 
/*      */ 
/*      */     
/* 1495 */     if (bool) {
/* 1496 */       this.cacheSize++;
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1507 */     if (this.cacheConnectionWaitTimeout > 0)
/*      */     {
/* 1509 */       notifyAll();
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private String buildAttrKey(Properties paramProperties) throws SQLException {
/* 1527 */     int i = paramProperties.keySet().size();
/* 1528 */     Object[] arrayOfObject = paramProperties.keySet().toArray();
/* 1529 */     boolean bool = true;
/* 1530 */     StringBuffer stringBuffer = new StringBuffer();
/*      */ 
/*      */     
/* 1533 */     while (bool) {
/*      */       
/* 1535 */       bool = false;
/*      */       
/* 1537 */       for (byte b1 = 0; b1 < i - 1; b1++) {
/*      */         
/* 1539 */         if (((String)arrayOfObject[b1]).compareTo((String)arrayOfObject[b1 + 1]) > 0) {
/*      */           
/* 1541 */           bool = true;
/*      */           
/* 1543 */           Object object = arrayOfObject[b1];
/*      */           
/* 1545 */           arrayOfObject[b1] = arrayOfObject[b1 + 1];
/* 1546 */           arrayOfObject[b1 + 1] = object;
/*      */         } 
/*      */       } 
/*      */     } 
/*      */ 
/*      */     
/* 1552 */     for (byte b = 0; b < i; b++) {
/* 1553 */       stringBuffer.append(arrayOfObject[b] + "0xffff" + paramProperties.get(arrayOfObject[b]));
/*      */     }
/*      */ 
/*      */ 
/*      */     
/* 1558 */     return stringBuffer.toString();
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected OraclePooledConnection makeCacheConnection(String paramString1, String paramString2) throws SQLException {
/* 1572 */     OraclePooledConnection oraclePooledConnection = (OraclePooledConnection)this.connectionPoolDS.getPooledConnection(paramString1, paramString2);
/*      */ 
/*      */ 
/*      */     
/* 1576 */     if (oraclePooledConnection != null) {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 1584 */       if (this.cacheMaxStatementsLimit > 0) {
/* 1585 */         setStatementCaching(oraclePooledConnection, this.cacheMaxStatementsLimit, true);
/*      */       }
/*      */       
/* 1588 */       oraclePooledConnection.registerImplicitCacheConnectionEventListener(new OracleConnectionCacheEventListener(this));
/*      */ 
/*      */       
/* 1591 */       oraclePooledConnection.cachedConnectionAttributes = new Properties();
/*      */ 
/*      */       
/* 1594 */       if (this.fastConnectionFailoverEnabled)
/*      */       {
/* 1596 */         initFailoverParameters(oraclePooledConnection);
/*      */       }
/*      */ 
/*      */       
/* 1600 */       synchronized (this) {
/*      */         
/* 1602 */         this.cacheSize++;
/*      */ 
/*      */ 
/*      */ 
/*      */         
/* 1607 */         if (this.fastConnectionFailoverEnabled && this.runtimeLoadBalancingThread == null) {
/*      */ 
/*      */           
/* 1610 */           this.runtimeLoadBalancingThread = new OracleRuntimeLoadBalancingEventHandlerThread(this.dataSourceServiceName);
/*      */           
/* 1612 */           this.cacheManager.checkAndStartThread(this.runtimeLoadBalancingThread);
/*      */         } 
/*      */       } 
/*      */     } 
/*      */ 
/*      */     
/* 1618 */     return oraclePooledConnection;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private void setStatementCaching(OraclePooledConnection paramOraclePooledConnection, int paramInt, boolean paramBoolean) throws SQLException {
/* 1626 */     if (paramInt > 0) {
/* 1627 */       paramOraclePooledConnection.setStatementCacheSize(paramInt);
/*      */     }
/* 1629 */     paramOraclePooledConnection.setImplicitCachingEnabled(paramBoolean);
/* 1630 */     paramOraclePooledConnection.setExplicitCachingEnabled(paramBoolean);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected synchronized void reusePooledConnection(PooledConnection paramPooledConnection) throws SQLException {
/* 1651 */     OraclePooledConnection oraclePooledConnection = (OraclePooledConnection)paramPooledConnection;
/* 1652 */     if (oraclePooledConnection != null && oraclePooledConnection.physicalConn != null) {
/*      */       
/* 1654 */       storeCacheConnection(oraclePooledConnection.cachedConnectionAttributes, oraclePooledConnection);
/*      */ 
/*      */       
/* 1657 */       this.checkedOutConnectionList.removeElement(oraclePooledConnection);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void closePooledConnection(PooledConnection paramPooledConnection) throws SQLException {
/* 1681 */     if (paramPooledConnection != null) {
/*      */       
/* 1683 */       actualPooledConnectionClose((OraclePooledConnection)paramPooledConnection);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 1689 */       if (((OraclePooledConnection)paramPooledConnection).closeOption == 4096) {
/* 1690 */         this.checkedOutConnectionList.removeElement(paramPooledConnection);
/*      */       }
/* 1692 */       paramPooledConnection = null;
/*      */       
/* 1694 */       if (getTotalCachedConnections() < this.cacheMinLimit) {
/* 1695 */         defaultUserPrePopulateCache(1);
/*      */       }
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void refreshCacheConnections(int paramInt) throws SQLException {
/* 1713 */     doForEveryCachedConnection(paramInt);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void reinitializeCacheConnections(Properties paramProperties) throws SQLException {
/* 1732 */     int i = 0;
/*      */     
/* 1734 */     synchronized (this) {
/*      */       
/* 1736 */       this.defaultUser = this.cacheEnabledDS.user;
/* 1737 */       this.defaultPassword = this.cacheEnabledDS.password;
/* 1738 */       if (this.defaultPassword != null)
/* 1739 */         this.defaultPassword = this.defaultPassword.toUpperCase(); 
/* 1740 */       this.fastConnectionFailoverEnabled = this.cacheEnabledDS.getFastConnectionFailoverEnabled();
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 1748 */       cleanupTimeoutThread();
/*      */ 
/*      */ 
/*      */       
/* 1752 */       doForEveryCheckedOutConnection(1);
/*      */ 
/*      */       
/* 1755 */       int j = this.cacheInitialLimit;
/* 1756 */       int k = this.cacheMaxLimit;
/* 1757 */       int m = this.cacheMaxStatementsLimit;
/*      */ 
/*      */       
/* 1760 */       setConnectionCacheProperties(paramProperties);
/*      */       
/* 1762 */       if (this.cacheInitialLimit > j) {
/* 1763 */         i = this.cacheInitialLimit - j;
/*      */       }
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 1769 */       if (k != Integer.MAX_VALUE)
/*      */       {
/* 1771 */         if (this.cacheMaxLimit < k && this.cacheSize > this.cacheMaxLimit) {
/*      */           
/* 1773 */           this.connectionsToRemove = this.cacheSize - this.cacheMaxLimit;
/*      */           
/* 1775 */           doForEveryCachedConnection(8);
/*      */           
/* 1777 */           this.connectionsToRemove = 0;
/*      */         } 
/*      */       }
/*      */ 
/*      */ 
/*      */       
/* 1783 */       if (this.cacheMaxStatementsLimit != m)
/*      */       {
/* 1785 */         if (this.cacheMaxStatementsLimit == 0) {
/* 1786 */           doForEveryCachedConnection(16);
/*      */         } else {
/* 1788 */           doForEveryCachedConnection(18);
/*      */         } 
/*      */       }
/*      */     } 
/*      */ 
/*      */ 
/*      */     
/* 1795 */     if (i > 0)
/*      */     {
/* 1797 */       defaultUserPrePopulateCache(i);
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected synchronized void setConnectionCacheProperties(Properties paramProperties) throws SQLException {
/*      */     try {
/* 1824 */       if (paramProperties != null) {
/*      */         
/* 1826 */         String str = null;
/*      */ 
/*      */         
/* 1829 */         if ((str = paramProperties.getProperty("MinLimit")) != null)
/*      */         {
/* 1831 */           if ((this.cacheMinLimit = Integer.parseInt(str)) < 0) {
/* 1832 */             this.cacheMinLimit = 0;
/*      */           }
/*      */         }
/*      */         
/* 1836 */         if ((str = paramProperties.getProperty("MaxLimit")) != null)
/*      */         {
/* 1838 */           if ((this.cacheMaxLimit = Integer.parseInt(str)) < 0) {
/* 1839 */             this.cacheMaxLimit = Integer.MAX_VALUE;
/*      */           }
/*      */         }
/*      */         
/* 1843 */         if (this.cacheMaxLimit < this.cacheMinLimit) {
/* 1844 */           this.cacheMinLimit = this.cacheMaxLimit;
/*      */         }
/*      */         
/* 1847 */         if ((str = paramProperties.getProperty("InitialLimit")) != null)
/*      */         {
/* 1849 */           if ((this.cacheInitialLimit = Integer.parseInt(str)) < 0) {
/* 1850 */             this.cacheInitialLimit = 0;
/*      */           }
/*      */         }
/* 1853 */         if (this.cacheInitialLimit > this.cacheMaxLimit) {
/* 1854 */           this.cacheInitialLimit = this.cacheMaxLimit;
/*      */         }
/*      */         
/* 1857 */         if ((str = paramProperties.getProperty("MaxStatementsLimit")) != null)
/*      */         {
/* 1859 */           if ((this.cacheMaxStatementsLimit = Integer.parseInt(str)) < 0) {
/* 1860 */             this.cacheMaxStatementsLimit = 0;
/*      */           }
/*      */         }
/*      */         
/* 1864 */         Properties properties = (Properties)paramProperties.get("AttributeWeights");
/*      */ 
/*      */         
/* 1867 */         if (properties != null) {
/*      */           
/* 1869 */           Map.Entry entry = null;
/* 1870 */           int i = 0;
/* 1871 */           Object object = null;
/*      */           
/* 1873 */           Iterator iterator = properties.entrySet().iterator();
/*      */           
/* 1875 */           while (iterator.hasNext()) {
/*      */             
/* 1877 */             entry = iterator.next();
/* 1878 */             object = entry.getKey();
/*      */             
/* 1880 */             if ((str = (String)properties.get(object)) != null)
/*      */             {
/* 1882 */               if ((i = Integer.parseInt(str)) < 0) {
/* 1883 */                 properties.put(object, "0");
/*      */               }
/*      */             }
/*      */           } 
/* 1887 */           if (this.cacheAttributeWeights == null) {
/* 1888 */             this.cacheAttributeWeights = new Properties();
/*      */           }
/* 1890 */           this.cacheAttributeWeights.putAll(properties);
/*      */         } 
/*      */ 
/*      */         
/* 1894 */         if ((str = paramProperties.getProperty("InactivityTimeout")) != null)
/*      */         {
/* 1896 */           if ((this.cacheInactivityTimeout = Integer.parseInt(str)) < 0) {
/* 1897 */             this.cacheInactivityTimeout = 0;
/*      */           }
/*      */         }
/*      */         
/* 1901 */         if ((str = paramProperties.getProperty("TimeToLiveTimeout")) != null)
/*      */         {
/* 1903 */           if ((this.cacheTimeToLiveTimeout = Integer.parseInt(str)) < 0) {
/* 1904 */             this.cacheTimeToLiveTimeout = 0;
/*      */           }
/*      */         }
/*      */         
/* 1908 */         if ((str = paramProperties.getProperty("AbandonedConnectionTimeout")) != null)
/*      */         {
/* 1910 */           if ((this.cacheAbandonedConnectionTimeout = Integer.parseInt(str)) < 0) {
/* 1911 */             this.cacheAbandonedConnectionTimeout = 0;
/*      */           }
/*      */         }
/*      */         
/* 1915 */         if ((str = paramProperties.getProperty("LowerThresholdLimit")) != null) {
/*      */           
/* 1917 */           this.cacheLowerThresholdLimit = Integer.parseInt(str);
/*      */           
/* 1919 */           if (this.cacheLowerThresholdLimit < 0 || this.cacheLowerThresholdLimit > 100)
/*      */           {
/* 1921 */             this.cacheLowerThresholdLimit = 20;
/*      */           }
/*      */         } 
/*      */         
/* 1925 */         if ((str = paramProperties.getProperty("PropertyCheckInterval")) != null)
/*      */         {
/* 1927 */           if ((this.cachePropertyCheckInterval = Integer.parseInt(str)) < 0) {
/* 1928 */             this.cachePropertyCheckInterval = 900;
/*      */           }
/*      */         }
/*      */         
/* 1932 */         if ((str = paramProperties.getProperty("ValidateConnection")) != null) {
/* 1933 */           this.cacheValidateConnection = Boolean.valueOf(str).booleanValue();
/*      */         }
/*      */ 
/*      */         
/* 1937 */         if ((str = paramProperties.getProperty("ClosestConnectionMatch")) != null)
/*      */         {
/* 1939 */           this.cacheClosestConnectionMatch = Boolean.valueOf(str).booleanValue();
/*      */         }
/*      */ 
/*      */         
/* 1943 */         if ((str = paramProperties.getProperty("ConnectionWaitTimeout")) != null)
/*      */         {
/* 1945 */           if ((this.cacheConnectionWaitTimeout = Integer.parseInt(str)) < 0) {
/* 1946 */             this.cacheConnectionWaitTimeout = 0;
/*      */           }
/*      */         }
/*      */       }
/*      */       else {
/*      */         
/* 1952 */         this.cacheMinLimit = 0;
/* 1953 */         this.cacheMaxLimit = Integer.MAX_VALUE;
/* 1954 */         this.cacheInitialLimit = 0;
/* 1955 */         this.cacheMaxStatementsLimit = 0;
/* 1956 */         this.cacheAttributeWeights = null;
/* 1957 */         this.cacheInactivityTimeout = 0;
/* 1958 */         this.cacheTimeToLiveTimeout = 0;
/* 1959 */         this.cacheAbandonedConnectionTimeout = 0;
/* 1960 */         this.cacheLowerThresholdLimit = 20;
/* 1961 */         this.cachePropertyCheckInterval = 900;
/* 1962 */         this.cacheClosestConnectionMatch = false;
/* 1963 */         this.cacheValidateConnection = false;
/* 1964 */         this.cacheConnectionWaitTimeout = 0;
/*      */       } 
/*      */ 
/*      */       
/* 1968 */       if (this.cacheInactivityTimeout > 0 || this.cacheTimeToLiveTimeout > 0 || this.cacheAbandonedConnectionTimeout > 0)
/*      */       {
/*      */         
/* 1971 */         if (this.timeoutThread == null) {
/* 1972 */           this.timeoutThread = new OracleImplicitConnectionCacheThread(this);
/*      */         }
/* 1974 */         this.cacheManager.checkAndStartThread(this.timeoutThread);
/*      */       }
/*      */     
/* 1977 */     } catch (NumberFormatException numberFormatException) {
/*      */       
/* 1979 */       DatabaseError.throwSqlException(139);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected Properties getConnectionCacheProperties() throws SQLException {
/* 1992 */     Properties properties = new Properties();
/*      */     
/* 1994 */     properties.setProperty("MinLimit", String.valueOf(this.cacheMinLimit));
/* 1995 */     properties.setProperty("MaxLimit", String.valueOf(this.cacheMaxLimit));
/* 1996 */     properties.setProperty("InitialLimit", String.valueOf(this.cacheInitialLimit));
/* 1997 */     properties.setProperty("MaxStatementsLimit", String.valueOf(this.cacheMaxStatementsLimit));
/*      */ 
/*      */     
/* 2000 */     if (this.cacheAttributeWeights != null) {
/* 2001 */       properties.put("AttributeWeights", this.cacheAttributeWeights);
/*      */     } else {
/* 2003 */       properties.setProperty("AttributeWeights", "NULL");
/*      */     } 
/* 2005 */     properties.setProperty("InactivityTimeout", String.valueOf(this.cacheInactivityTimeout));
/*      */     
/* 2007 */     properties.setProperty("TimeToLiveTimeout", String.valueOf(this.cacheTimeToLiveTimeout));
/*      */     
/* 2009 */     properties.setProperty("AbandonedConnectionTimeout", String.valueOf(this.cacheAbandonedConnectionTimeout));
/*      */     
/* 2011 */     properties.setProperty("LowerThresholdLimit", String.valueOf(this.cacheLowerThresholdLimit));
/*      */     
/* 2013 */     properties.setProperty("PropertyCheckInterval", String.valueOf(this.cachePropertyCheckInterval));
/*      */     
/* 2015 */     properties.setProperty("ConnectionWaitTimeout", String.valueOf(this.cacheConnectionWaitTimeout));
/*      */     
/* 2017 */     properties.setProperty("ValidateConnection", String.valueOf(this.cacheValidateConnection));
/*      */     
/* 2019 */     properties.setProperty("ClosestConnectionMatch", String.valueOf(this.cacheClosestConnectionMatch));
/*      */ 
/*      */     
/* 2022 */     return properties;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected int testDatabaseConnection(OracleConnection paramOracleConnection) throws SQLException {
/* 2035 */     return paramOracleConnection.pingDatabase(0);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected synchronized void closeConnectionCache(int paramInt) throws SQLException {
/* 2052 */     cleanupTimeoutThread();
/*      */ 
/*      */ 
/*      */     
/* 2056 */     purgeCacheConnections(true, paramInt);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 2063 */     this.connectionPoolDS = null;
/* 2064 */     this.cacheEnabledDS = null;
/* 2065 */     this.checkedOutConnectionList = null;
/* 2066 */     this.userMap = null;
/* 2067 */     this.cacheManager = null;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected synchronized void disableConnectionCache() throws SQLException {
/* 2079 */     this.disableConnectionRequest = true;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected synchronized void enableConnectionCache() throws SQLException {
/* 2093 */     this.disableConnectionRequest = false;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void initFailoverParameters(OraclePooledConnection paramOraclePooledConnection) throws SQLException {
/* 2108 */     String str1 = null;
/* 2109 */     String str2 = null;
/* 2110 */     String str3 = null;
/*      */     
/* 2112 */     Properties properties = ((OracleConnection)paramOraclePooledConnection.getPhysicalHandle()).getServerSessionInfo();
/*      */     
/* 2114 */     str3 = properties.getProperty("INSTANCE_NAME");
/* 2115 */     if (str3 != null) {
/* 2116 */       str1 = paramOraclePooledConnection.dataSourceInstanceNameKey = str3.trim().toLowerCase().intern();
/*      */     }
/*      */ 
/*      */ 
/*      */     
/* 2121 */     str3 = properties.getProperty("SERVER_HOST");
/* 2122 */     if (str3 != null) {
/* 2123 */       paramOraclePooledConnection.dataSourceHostNameKey = str3.trim().toLowerCase().intern();
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 2129 */     str3 = properties.getProperty("SERVICE_NAME");
/* 2130 */     if (str3 != null) {
/* 2131 */       this.dataSourceServiceName = str3.trim();
/*      */     }
/*      */ 
/*      */ 
/*      */     
/* 2136 */     str3 = properties.getProperty("DATABASE_NAME");
/* 2137 */     if (str3 != null) {
/* 2138 */       str2 = paramOraclePooledConnection.dataSourceDbUniqNameKey = str3.trim().toLowerCase().intern();
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 2146 */     if (this.databaseInstancesList == null) {
/* 2147 */       this.databaseInstancesList = new LinkedList();
/*      */     }
/* 2149 */     int i = this.databaseInstancesList.size();
/* 2150 */     synchronized (this.databaseInstancesList) {
/*      */       
/* 2152 */       OracleDatabaseInstance oracleDatabaseInstance = null;
/* 2153 */       boolean bool = false;
/*      */       
/* 2155 */       for (byte b = 0; b < i; b++) {
/*      */         
/* 2157 */         oracleDatabaseInstance = this.databaseInstancesList.get(b);
/* 2158 */         if (oracleDatabaseInstance.databaseUniqName == str2 && oracleDatabaseInstance.instanceName == str1) {
/*      */ 
/*      */           
/* 2161 */           oracleDatabaseInstance.numberOfConnectionsCount++;
/* 2162 */           bool = true;
/*      */           
/*      */           break;
/*      */         } 
/*      */       } 
/* 2167 */       if (!bool) {
/*      */         
/* 2169 */         OracleDatabaseInstance oracleDatabaseInstance1 = new OracleDatabaseInstance(str2, str1);
/*      */ 
/*      */         
/* 2172 */         oracleDatabaseInstance1.numberOfConnectionsCount++;
/* 2173 */         this.databaseInstancesList.add(oracleDatabaseInstance1);
/*      */       } 
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void processFailoverEvent(int paramInt1, String paramString1, String paramString2, String paramString3, String paramString4, int paramInt2) {
/* 2200 */     if (paramInt1 == 256) {
/*      */       
/* 2202 */       if (paramString4.equalsIgnoreCase("down") || paramString4.equalsIgnoreCase("not_restarting") || paramString4.equalsIgnoreCase("restart_failed"))
/*      */       {
/*      */ 
/*      */         
/* 2206 */         this.downEventCount++;
/*      */         
/* 2208 */         markDownLostConnections(true, false, paramString1, paramString2, paramString3, paramString4);
/*      */         
/* 2210 */         cleanupFailoverConnections(true, false, paramString1, paramString2, paramString3, paramString4);
/*      */       
/*      */       }
/* 2213 */       else if (paramString4.equalsIgnoreCase("up"))
/*      */       {
/*      */ 
/*      */         
/* 2217 */         if (this.downEventCount > 0) {
/* 2218 */           this.upEventCount++;
/*      */         }
/*      */         
/*      */         try {
/* 2222 */           processUpEvent(paramInt2);
/*      */         }
/* 2224 */         catch (Exception exception) {}
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */         
/* 2231 */         this.isEntireServiceDownProcessed = false;
/*      */       }
/*      */     
/* 2234 */     } else if (paramInt1 == 512 && paramString4.equalsIgnoreCase("nodedown")) {
/*      */ 
/*      */       
/* 2237 */       markDownLostConnections(false, true, paramString1, paramString2, paramString3, paramString4);
/*      */       
/* 2239 */       cleanupFailoverConnections(false, true, paramString1, paramString2, paramString3, paramString4);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   void processUpEvent(int paramInt) throws SQLException {
/* 2318 */     int i = 0;
/* 2319 */     int j = 0;
/* 2320 */     int k = getTotalCachedConnections();
/* 2321 */     boolean bool = false;
/*      */     
/* 2323 */     synchronized (this) {
/*      */ 
/*      */       
/* 2326 */       if (paramInt <= 1) {
/* 2327 */         paramInt = 2;
/*      */       }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 2334 */       if (this.downEventCount == 0 && this.upEventCount == 0 && getNumberOfDefaultUserConnections() > 0) {
/*      */ 
/*      */ 
/*      */         
/* 2338 */         i = (int)(this.cacheSize * 0.25D);
/*      */       }
/*      */       else {
/*      */         
/* 2342 */         i = this.defaultUserPreFailureSize;
/*      */       } 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 2354 */       if (i <= 0) {
/*      */         
/* 2356 */         if (getNumberOfDefaultUserConnections() > 0)
/*      */         {
/* 2358 */           j = (int)(this.cacheSize * 0.25D);
/* 2359 */           bool = true;
/*      */         }
/*      */         else
/*      */         {
/*      */           return;
/*      */         }
/*      */       
/*      */       } else {
/*      */         
/* 2368 */         j = i / paramInt;
/*      */ 
/*      */ 
/*      */         
/* 2372 */         if (j + k > this.cacheMaxLimit) {
/* 2373 */           bool = true;
/*      */         }
/*      */       } 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 2389 */       if (this.downEventCount == this.upEventCount) {
/*      */         
/* 2391 */         this.defaultUserPreFailureSize = 0;
/* 2392 */         this.downEventCount = 0;
/* 2393 */         this.upEventCount = 0;
/*      */       } 
/*      */     } 
/*      */ 
/*      */     
/* 2398 */     if (j > 0) {
/* 2399 */       loadBalanceConnections(j, bool);
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private void loadBalanceConnections(int paramInt, boolean paramBoolean) throws SQLException {
/* 2411 */     if (paramBoolean) {
/*      */       
/* 2413 */       this.connectionsToRemove = paramInt;
/*      */       
/* 2415 */       doForEveryCachedConnection(8);
/*      */       
/* 2417 */       this.connectionsToRemove = 0;
/*      */     } 
/*      */ 
/*      */     
/* 2421 */     if (paramInt <= 10) {
/*      */ 
/*      */       
/*      */       try {
/* 2425 */         defaultUserPrePopulateCache(paramInt);
/*      */       }
/* 2427 */       catch (Exception exception) {}
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     }
/*      */     else {
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 2438 */       int i = (int)(paramInt * 0.25D);
/*      */       
/* 2440 */       for (byte b = 0; b < 4; b++) {
/*      */ 
/*      */         
/*      */         try {
/* 2444 */           defaultUserPrePopulateCache(i);
/*      */         }
/* 2446 */         catch (Exception exception) {}
/*      */       } 
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private int getNumberOfDefaultUserConnections() {
/* 2463 */     int i = 0;
/*      */     
/* 2465 */     if (this.userMap != null && !this.userMap.isEmpty()) {
/*      */       
/* 2467 */       OracleConnectionCacheEntry oracleConnectionCacheEntry = (OracleConnectionCacheEntry)this.userMap.get(this.defaultUser + this.defaultPassword.toUpperCase());
/*      */ 
/*      */ 
/*      */       
/* 2471 */       if (oracleConnectionCacheEntry != null && oracleConnectionCacheEntry.userConnList != null && !oracleConnectionCacheEntry.userConnList.isEmpty())
/*      */       {
/*      */         
/* 2474 */         i = oracleConnectionCacheEntry.userConnList.size();
/*      */       }
/*      */     } 
/*      */     
/* 2478 */     return i;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   synchronized void markDownLostConnections(boolean paramBoolean1, boolean paramBoolean2, String paramString1, String paramString2, String paramString3, String paramString4) {
/* 2499 */     if (!this.isEntireServiceDownProcessed) {
/*      */       
/* 2501 */       if (this.userMap != null && !this.userMap.isEmpty()) {
/*      */ 
/*      */ 
/*      */         
/* 2505 */         Iterator iterator = this.userMap.entrySet().iterator();
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */         
/* 2513 */         while (iterator.hasNext()) {
/*      */           
/* 2515 */           boolean bool = false;
/*      */           
/* 2517 */           Map.Entry entry = iterator.next();
/* 2518 */           String str = null;
/* 2519 */           if (this.defaultUser != null && this.defaultPassword != null) {
/* 2520 */             str = this.defaultUser + this.defaultPassword;
/*      */           }
/*      */           
/* 2523 */           if (str != null && str.equalsIgnoreCase((String)entry.getKey()))
/*      */           {
/* 2525 */             bool = true;
/*      */           }
/* 2527 */           OracleConnectionCacheEntry oracleConnectionCacheEntry = (OracleConnectionCacheEntry)entry.getValue();
/*      */ 
/*      */ 
/*      */           
/* 2531 */           if (oracleConnectionCacheEntry != null && oracleConnectionCacheEntry.userConnList != null && !oracleConnectionCacheEntry.userConnList.isEmpty()) {
/*      */ 
/*      */             
/* 2534 */             boolean bool1 = false;
/* 2535 */             Iterator iterator1 = oracleConnectionCacheEntry.userConnList.iterator();
/*      */             
/* 2537 */             while (iterator1.hasNext()) {
/*      */               
/* 2539 */               OraclePooledConnection oraclePooledConnection = iterator1.next();
/*      */               
/* 2541 */               if (paramBoolean1) {
/* 2542 */                 bool1 = markDownConnectionsForServiceEvent(paramString1, paramString2, oraclePooledConnection);
/*      */               }
/* 2544 */               else if (paramBoolean2) {
/* 2545 */                 bool1 = markDownConnectionsForHostEvent(paramString3, oraclePooledConnection);
/*      */               } 
/*      */ 
/*      */               
/* 2549 */               if (bool1 && bool) {
/* 2550 */                 this.defaultUserPreFailureSize++;
/*      */               }
/*      */             } 
/*      */           } 
/*      */           
/* 2555 */           if (oracleConnectionCacheEntry != null && oracleConnectionCacheEntry.attrConnMap != null && !oracleConnectionCacheEntry.attrConnMap.isEmpty()) {
/*      */ 
/*      */             
/* 2558 */             Iterator iterator1 = oracleConnectionCacheEntry.attrConnMap.entrySet().iterator();
/*      */             
/* 2560 */             while (iterator1.hasNext()) {
/*      */               
/* 2562 */               Map.Entry entry1 = iterator1.next();
/* 2563 */               Iterator iterator2 = ((Vector)entry1.getValue()).iterator();
/*      */               
/* 2565 */               while (iterator2.hasNext()) {
/*      */                 
/* 2567 */                 OraclePooledConnection oraclePooledConnection = iterator2.next();
/*      */                 
/* 2569 */                 if (paramBoolean1) {
/* 2570 */                   markDownConnectionsForServiceEvent(paramString1, paramString2, oraclePooledConnection); continue;
/*      */                 } 
/* 2572 */                 if (paramBoolean2) {
/* 2573 */                   markDownConnectionsForHostEvent(paramString3, oraclePooledConnection);
/*      */                 }
/*      */               } 
/*      */             } 
/*      */           } 
/*      */         } 
/*      */       } 
/* 2580 */       if (paramString1 == null) {
/* 2581 */         this.isEntireServiceDownProcessed = true;
/*      */       }
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private boolean markDownConnectionsForServiceEvent(String paramString1, String paramString2, OraclePooledConnection paramOraclePooledConnection) {
/* 2593 */     boolean bool = false;
/*      */     
/* 2595 */     if (paramString1 == null || (paramString2 == paramOraclePooledConnection.dataSourceDbUniqNameKey && paramString1 == paramOraclePooledConnection.dataSourceInstanceNameKey)) {
/*      */ 
/*      */ 
/*      */       
/* 2599 */       paramOraclePooledConnection.connectionMarkedDown = true;
/* 2600 */       bool = true;
/*      */     } 
/*      */     
/* 2603 */     return bool;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private boolean markDownConnectionsForHostEvent(String paramString, OraclePooledConnection paramOraclePooledConnection) {
/* 2612 */     boolean bool = false;
/*      */     
/* 2614 */     if (paramString == paramOraclePooledConnection.dataSourceHostNameKey) {
/*      */       
/* 2616 */       paramOraclePooledConnection.connectionMarkedDown = true;
/* 2617 */       paramOraclePooledConnection.needToAbort = true;
/* 2618 */       bool = true;
/*      */     } 
/*      */     
/* 2621 */     return bool;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   synchronized void cleanupFailoverConnections(boolean paramBoolean1, boolean paramBoolean2, String paramString1, String paramString2, String paramString3, String paramString4) {
/* 2643 */     OraclePooledConnection oraclePooledConnection = null;
/* 2644 */     Object[] arrayOfObject = this.checkedOutConnectionList.toArray();
/* 2645 */     int i = this.checkedOutConnectionList.size();
/*      */     
/* 2647 */     OraclePooledConnection[] arrayOfOraclePooledConnection = new OraclePooledConnection[i];
/* 2648 */     byte b1 = 0;
/*      */     byte b2;
/* 2650 */     for (b2 = 0; b2 < i; b2++) {
/*      */ 
/*      */       
/*      */       try {
/* 2654 */         oraclePooledConnection = (OraclePooledConnection)arrayOfObject[b2];
/*      */         
/* 2656 */         if ((paramBoolean1 && (paramString1 == null || paramString1 == oraclePooledConnection.dataSourceInstanceNameKey) && paramString2 == oraclePooledConnection.dataSourceDbUniqNameKey) || (paramBoolean2 && paramString3 == oraclePooledConnection.dataSourceHostNameKey))
/*      */         {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */           
/* 2663 */           if (oraclePooledConnection.isSameUser(this.defaultUser, this.defaultPassword) && oraclePooledConnection.cachedConnectionAttributes != null && oraclePooledConnection.cachedConnectionAttributes.isEmpty())
/*      */           {
/*      */             
/* 2666 */             this.defaultUserPreFailureSize++;
/*      */           }
/*      */           
/* 2669 */           this.checkedOutConnectionList.removeElement(oraclePooledConnection);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */           
/* 2676 */           abortConnection(oraclePooledConnection);
/* 2677 */           oraclePooledConnection.needToAbort = true;
/*      */ 
/*      */           
/* 2680 */           arrayOfOraclePooledConnection[b1++] = oraclePooledConnection;
/*      */         }
/*      */       
/* 2683 */       } catch (Exception exception) {}
/*      */     } 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 2691 */     for (b2 = 0; b2 < b1; b2++) {
/*      */ 
/*      */       
/*      */       try {
/* 2695 */         closeCheckedOutConnection(arrayOfOraclePooledConnection[b2], false);
/*      */       }
/* 2697 */       catch (SQLException sQLException) {}
/*      */     } 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 2705 */     if (this.checkedOutConnectionList.size() < i && this.cacheConnectionWaitTimeout > 0)
/*      */     {
/*      */       
/* 2708 */       notifyAll();
/*      */     }
/*      */ 
/*      */ 
/*      */     
/*      */     try {
/* 2714 */       doForEveryCachedConnection(2);
/*      */     }
/* 2716 */     catch (SQLException sQLException) {}
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 2724 */     if (this.databaseInstancesList != null && (i = this.databaseInstancesList.size()) > 0)
/*      */     {
/*      */       
/* 2727 */       synchronized (this.databaseInstancesList) {
/*      */         
/* 2729 */         OracleDatabaseInstance oracleDatabaseInstance = null;
/* 2730 */         arrayOfObject = this.databaseInstancesList.toArray();
/*      */         
/* 2732 */         for (byte b = 0; b < i; b++) {
/*      */           
/* 2734 */           oracleDatabaseInstance = (OracleDatabaseInstance)arrayOfObject[b];
/*      */           
/* 2736 */           if (oracleDatabaseInstance.databaseUniqName == paramString2 && oracleDatabaseInstance.instanceName == paramString1) {
/*      */ 
/*      */ 
/*      */             
/* 2740 */             if (oracleDatabaseInstance.flag <= 3)
/* 2741 */               this.dbInstancePercentTotal -= oracleDatabaseInstance.percent; 
/* 2742 */             this.databaseInstancesList.remove(oracleDatabaseInstance);
/*      */           } 
/*      */         } 
/*      */       } 
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   void zapRLBInfo() {
/* 2754 */     this.databaseInstancesList.clear();
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected synchronized void closeAndRemovePooledConnection(OraclePooledConnection paramOraclePooledConnection) throws SQLException {
/* 2766 */     if (paramOraclePooledConnection != null) {
/*      */       
/* 2768 */       if (paramOraclePooledConnection.needToAbort) {
/* 2769 */         abortConnection(paramOraclePooledConnection);
/*      */       }
/* 2771 */       actualPooledConnectionClose(paramOraclePooledConnection);
/* 2772 */       removeCacheConnection(paramOraclePooledConnection);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private void abortConnection(OraclePooledConnection paramOraclePooledConnection) {
/*      */     try {
/* 2789 */       ((OracleConnection)paramOraclePooledConnection.getPhysicalHandle()).abort();
/*      */     
/*      */     }
/* 2792 */     catch (Exception exception) {}
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private void actualPooledConnectionClose(OraclePooledConnection paramOraclePooledConnection) throws SQLException {
/* 2812 */     int i = 0;
/* 2813 */     if (this.databaseInstancesList != null && (i = this.databaseInstancesList.size()) > 0)
/*      */     {
/*      */       
/* 2816 */       synchronized (this.databaseInstancesList) {
/*      */         
/* 2818 */         OracleDatabaseInstance oracleDatabaseInstance = null;
/*      */         
/* 2820 */         for (byte b = 0; b < i; b++) {
/*      */           
/* 2822 */           oracleDatabaseInstance = this.databaseInstancesList.get(b);
/* 2823 */           if (oracleDatabaseInstance.databaseUniqName == paramOraclePooledConnection.dataSourceDbUniqNameKey && oracleDatabaseInstance.instanceName == paramOraclePooledConnection.dataSourceInstanceNameKey) {
/*      */ 
/*      */             
/* 2826 */             if (oracleDatabaseInstance.numberOfConnectionsCount > 0) {
/* 2827 */               oracleDatabaseInstance.numberOfConnectionsCount--;
/*      */             }
/*      */ 
/*      */ 
/*      */             
/*      */             break;
/*      */           } 
/*      */         } 
/*      */       } 
/*      */     }
/*      */ 
/*      */ 
/*      */     
/*      */     try {
/* 2841 */       this.connectionClosedCount++;
/* 2842 */       paramOraclePooledConnection.close();
/*      */     }
/* 2844 */     catch (SQLException sQLException) {}
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected int getCacheTimeToLiveTimeout() {
/* 2853 */     return this.cacheTimeToLiveTimeout;
/*      */   }
/*      */ 
/*      */   
/*      */   protected int getCacheInactivityTimeout() {
/* 2858 */     return this.cacheInactivityTimeout;
/*      */   }
/*      */ 
/*      */   
/*      */   protected int getCachePropertyCheckInterval() {
/* 2863 */     return this.cachePropertyCheckInterval;
/*      */   }
/*      */ 
/*      */   
/*      */   protected int getCacheAbandonedTimeout() {
/* 2868 */     return this.cacheAbandonedConnectionTimeout;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private synchronized void processConnectionCacheCallback() throws SQLException {
/* 2883 */     float f = this.cacheMaxLimit / 100.0F;
/* 2884 */     int i = (int)(this.cacheLowerThresholdLimit * f);
/*      */ 
/*      */     
/* 2887 */     releaseBasedOnPriority(1024, i);
/*      */ 
/*      */     
/* 2890 */     if (this.cacheSize < i) {
/* 2891 */       releaseBasedOnPriority(512, i);
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private void releaseBasedOnPriority(int paramInt1, int paramInt2) throws SQLException {
/* 2904 */     Object[] arrayOfObject = this.checkedOutConnectionList.toArray();
/*      */     
/* 2906 */     for (byte b = 0; b < arrayOfObject.length && this.cacheSize < paramInt2; b++) {
/*      */       
/* 2908 */       OraclePooledConnection oraclePooledConnection = (OraclePooledConnection)arrayOfObject[b];
/* 2909 */       OracleConnection oracleConnection = null;
/*      */       
/* 2911 */       if (oraclePooledConnection != null) {
/* 2912 */         oracleConnection = (OracleConnection)oraclePooledConnection.getLogicalHandle();
/*      */       }
/* 2914 */       if (oracleConnection != null) {
/*      */         
/* 2916 */         OracleConnectionCacheCallback oracleConnectionCacheCallback = oracleConnection.getConnectionCacheCallbackObj();
/*      */ 
/*      */         
/* 2919 */         if (oracleConnectionCacheCallback != null && (oracleConnection.getConnectionCacheCallbackFlag() == 2 || oracleConnection.getConnectionCacheCallbackFlag() == 4))
/*      */         {
/*      */ 
/*      */ 
/*      */ 
/*      */           
/* 2925 */           if (paramInt1 == oracleConnection.getConnectionReleasePriority()) {
/*      */             
/* 2927 */             Object object = oracleConnection.getConnectionCacheCallbackPrivObj();
/* 2928 */             oracleConnectionCacheCallback.releaseConnection((OracleConnection)oracleConnection, object);
/*      */           } 
/*      */         }
/*      */       } 
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private synchronized void processConnectionWaitTimeout(long paramLong) throws SQLException {
/*      */     try {
/* 2950 */       wait(paramLong);
/*      */     }
/* 2952 */     catch (InterruptedException interruptedException) {}
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private void processInactivityTimeout(OraclePooledConnection paramOraclePooledConnection) throws SQLException {
/* 2974 */     long l1 = paramOraclePooledConnection.getLastAccessedTime();
/* 2975 */     long l2 = System.currentTimeMillis();
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 2983 */     if (getTotalCachedConnections() > this.cacheMinLimit && l2 - l1 > (this.cacheInactivityTimeout * 1000))
/*      */     {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 2990 */       closeAndRemovePooledConnection(paramOraclePooledConnection);
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private void cleanupTimeoutThread() throws SQLException {
/* 3005 */     if (this.timeoutThread != null) {
/*      */       
/* 3007 */       this.timeoutThread.timeToLive = false;
/*      */ 
/*      */ 
/*      */       
/* 3011 */       if (this.timeoutThread.isSleeping) {
/* 3012 */         this.timeoutThread.interrupt();
/*      */       }
/* 3014 */       this.timeoutThread = null;
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void purgeCacheConnections(boolean paramBoolean, int paramInt) {
/*      */     try {
/* 3030 */       if (paramBoolean) {
/* 3031 */         doForEveryCheckedOutConnection(paramInt);
/*      */       }
/*      */ 
/*      */       
/* 3035 */       doForEveryCachedConnection(paramInt);
/*      */     }
/* 3037 */     catch (SQLException sQLException) {}
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void updateDatabaseInstance(String paramString1, String paramString2, int paramInt1, int paramInt2) {
/* 3054 */     if (this.databaseInstancesList == null) {
/* 3055 */       this.databaseInstancesList = new LinkedList();
/*      */     }
/* 3057 */     synchronized (this.databaseInstancesList) {
/*      */       
/* 3059 */       int i = this.databaseInstancesList.size();
/* 3060 */       boolean bool = false;
/*      */       
/* 3062 */       for (byte b = 0; b < i; b++) {
/*      */         
/* 3064 */         OracleDatabaseInstance oracleDatabaseInstance = this.databaseInstancesList.get(b);
/* 3065 */         if (oracleDatabaseInstance.databaseUniqName == paramString1 && oracleDatabaseInstance.instanceName == paramString2) {
/*      */ 
/*      */           
/* 3068 */           oracleDatabaseInstance.percent = paramInt1;
/* 3069 */           oracleDatabaseInstance.flag = paramInt2;
/* 3070 */           bool = true;
/*      */           
/*      */           break;
/*      */         } 
/*      */       } 
/* 3075 */       if (!bool) {
/*      */         
/* 3077 */         OracleDatabaseInstance oracleDatabaseInstance = new OracleDatabaseInstance(paramString1, paramString2);
/*      */ 
/*      */         
/* 3080 */         oracleDatabaseInstance.percent = paramInt1;
/* 3081 */         oracleDatabaseInstance.flag = paramInt2;
/*      */         
/* 3083 */         this.databaseInstancesList.add(oracleDatabaseInstance);
/*      */       } 
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void processDatabaseInstances() throws SQLException {
/* 3099 */     OracleDatabaseInstance oracleDatabaseInstance = null;
/*      */     
/* 3101 */     if (this.databaseInstancesList != null) {
/*      */       
/* 3103 */       synchronized (this.databaseInstancesList) {
/*      */         
/* 3105 */         int i = 0;
/* 3106 */         boolean bool = false;
/*      */ 
/*      */         
/* 3109 */         this.useGoodGroup = false;
/*      */ 
/*      */         
/* 3112 */         int j = this.databaseInstancesList.size();
/*      */         byte b;
/* 3114 */         for (b = 0; b < j; b++) {
/*      */           
/* 3116 */           oracleDatabaseInstance = this.databaseInstancesList.get(b);
/*      */ 
/*      */ 
/*      */           
/* 3120 */           if (oracleDatabaseInstance.flag <= 3) {
/* 3121 */             i += oracleDatabaseInstance.percent;
/*      */           }
/*      */         } 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */         
/* 3129 */         if (i > 0) {
/*      */           
/* 3131 */           this.dbInstancePercentTotal = i;
/* 3132 */           this.useGoodGroup = true;
/*      */         } 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */         
/* 3139 */         if (j > 1) {
/*      */ 
/*      */           
/* 3142 */           for (b = 0; b < j; b++) {
/*      */             
/* 3144 */             oracleDatabaseInstance = this.databaseInstancesList.get(b);
/* 3145 */             this.countTotal += oracleDatabaseInstance.attemptedConnRequestCount;
/*      */           } 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */           
/* 3153 */           if (this.countTotal > j * 1000) {
/*      */             
/* 3155 */             for (b = 0; b < j; b++) {
/*      */               
/* 3157 */               oracleDatabaseInstance = this.databaseInstancesList.get(b);
/*      */ 
/*      */               
/* 3160 */               float f1 = oracleDatabaseInstance.attemptedConnRequestCount / this.countTotal;
/*      */               
/* 3162 */               float f2 = oracleDatabaseInstance.numberOfConnectionsCount / getTotalCachedConnections();
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */               
/* 3176 */               if (f2 > f1 * 2.0F) {
/*      */ 
/*      */ 
/*      */ 
/*      */                 
/* 3181 */                 if ((int)(oracleDatabaseInstance.numberOfConnectionsCount * 0.25D) >= 1) {
/* 3182 */                   this.instancesToRetireQueue.addElement(oracleDatabaseInstance);
/*      */                 }
/* 3184 */                 bool = true;
/*      */               } 
/*      */             } 
/*      */ 
/*      */             
/* 3189 */             if (bool) {
/*      */               
/* 3191 */               for (b = 0; b < j; b++) {
/*      */                 
/* 3193 */                 oracleDatabaseInstance = this.databaseInstancesList.get(b);
/* 3194 */                 oracleDatabaseInstance.attemptedConnRequestCount = 0;
/*      */               } 
/* 3196 */               bool = false;
/*      */             } 
/*      */           } 
/*      */         } 
/*      */       } 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 3213 */       if (this.instancesToRetireQueue.size() > 0) {
/*      */         
/* 3215 */         if (this.gravitateCacheThread != null) {
/*      */ 
/*      */           
/*      */           try {
/* 3219 */             this.gravitateCacheThread.interrupt();
/* 3220 */             this.gravitateCacheThread.join();
/*      */           }
/* 3222 */           catch (InterruptedException interruptedException) {}
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */           
/* 3228 */           this.gravitateCacheThread = null;
/*      */         } 
/*      */ 
/*      */         
/* 3232 */         this.gravitateCacheThread = new OracleGravitateConnectionCacheThread(this);
/*      */ 
/*      */         
/* 3235 */         this.cacheManager.checkAndStartThread(this.gravitateCacheThread);
/*      */       } 
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void gravitateCache() {
/* 3251 */     while (this.instancesToRetireQueue.size() > 0) {
/*      */ 
/*      */       
/* 3254 */       this.instanceToRetire = this.instancesToRetireQueue.remove(0);
/* 3255 */       this.retireConnectionsCount = (int)(this.instanceToRetire.numberOfConnectionsCount * 0.25D);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*      */       try {
/* 3264 */         doForEveryCachedConnection(24);
/*      */       }
/* 3266 */       catch (SQLException sQLException) {}
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 3279 */       if (this.retireConnectionsCount > 0) {
/*      */         
/*      */         try {
/*      */ 
/*      */ 
/*      */ 
/*      */           
/* 3286 */           doForEveryCheckedOutConnection(24);
/*      */         }
/* 3288 */         catch (SQLException sQLException) {}
/*      */       }
/*      */     } 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 3297 */     this.retireConnectionsCount = 0;
/* 3298 */     this.instanceToRetire = null;
/* 3299 */     this.countTotal = 0;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void cleanupRLBThreads() {
/* 3316 */     if (this.gravitateCacheThread != null) {
/*      */ 
/*      */       
/*      */       try {
/* 3320 */         this.gravitateCacheThread.interrupt();
/* 3321 */         this.gravitateCacheThread.join();
/*      */       }
/* 3323 */       catch (InterruptedException interruptedException) {}
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 3329 */       this.gravitateCacheThread = null;
/*      */     } 
/*      */     
/* 3332 */     if (this.runtimeLoadBalancingThread != null) {
/*      */ 
/*      */       
/*      */       try {
/* 3336 */         this.runtimeLoadBalancingThread.interrupt();
/*      */       }
/* 3338 */       catch (Exception exception) {}
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 3344 */       this.runtimeLoadBalancingThread = null;
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   Map getStatistics() throws SQLException {
/* 3354 */     HashMap hashMap = new HashMap(2);
/* 3355 */     hashMap.put("PhysicalConnectionClosedCount", new Integer(this.connectionClosedCount));
/* 3356 */     hashMap.put("PhysicalConnectionCreatedCount", new Integer(this.connectionCreatedCount));
/* 3357 */     return hashMap;
/*      */   }
/*      */ 
/*      */ 
/*      */   
/* 3362 */   private static final String _Copyright_2004_Oracle_All_Rights_Reserved_ = null;
/*      */   public static final boolean TRACE = false;
/*      */   public static final boolean PRIVATE_TRACE = false;
/*      */   public static final String BUILD_DATE = "Sat_Feb__2_11:39:41_PST_2008";
/*      */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\lib\ojdbc14.jar!\oracle\jdbc\pool\OracleImplicitConnectionCache.class
 * Java compiler version: 2 (46.0)
 * JD-Core Version:       1.1.3
 */