/*     */ package swing2swt.layout;
/*     */ 
/*     */ import org.eclipse.swt.graphics.Point;
/*     */ import org.eclipse.swt.graphics.Rectangle;
/*     */ import org.eclipse.swt.widgets.Composite;
/*     */ import org.eclipse.swt.widgets.Control;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class GridLayout
/*     */   extends AWTLayout
/*     */ {
/*     */   private int rows;
/*     */   private int columns;
/*     */   private int hgap;
/*     */   private int vgap;
/*     */   
/*     */   public GridLayout() {
/*  43 */     this(1, 0);
/*     */   }
/*     */   
/*     */   public GridLayout(int rows, int columns) {
/*  47 */     this(rows, columns, 0, 0);
/*     */   }
/*     */   
/*     */   public GridLayout(int rows, int columns, int hgap, int vgap) {
/*  51 */     if (rows == 0 && columns == 0) {
/*  52 */       throw new IllegalArgumentException("rows and cols cannot both be zero");
/*     */     }
/*  54 */     if (rows > 0 && columns > 0) {
/*  55 */       columns = 0;
/*     */     }
/*  57 */     this.rows = rows;
/*  58 */     this.columns = columns;
/*  59 */     this.hgap = hgap;
/*  60 */     this.vgap = vgap;
/*     */   }
/*     */   
/*     */   public int getColumns() {
/*  64 */     return this.columns;
/*     */   }
/*     */   
/*     */   public int getHgap() {
/*  68 */     return this.hgap;
/*     */   }
/*     */   
/*     */   public int getRows() {
/*  72 */     return this.rows;
/*     */   }
/*     */   
/*     */   public int getVgap() {
/*  76 */     return this.vgap;
/*     */   }
/*     */   
/*     */   public void setColumns(int cols) {
/*  80 */     if (this.rows == 0 && this.columns == 0) {
/*  81 */       throw new IllegalArgumentException("rows and cols cannot both be zero");
/*     */     }
/*  83 */     this.columns = cols;
/*     */   }
/*     */   
/*     */   public void setHgap(int hgap) {
/*  87 */     this.hgap = hgap;
/*     */   }
/*     */   
/*     */   public void setRows(int rows) {
/*  91 */     if (rows == 0 && this.columns == 0) {
/*  92 */       throw new IllegalArgumentException("rows and cols cannot both be zero");
/*     */     }
/*  94 */     this.rows = rows;
/*     */   }
/*     */   
/*     */   public void setVgap(int vgap) {
/*  98 */     this.vgap = vgap;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected Point computeSize(Composite composite, int wHint, int hHint, boolean flushCache) {
/* 108 */     Control[] children = composite.getChildren();
/* 109 */     int nbOfVisibleChildren = 0;
/* 110 */     for (int i = 0; i < children.length; i++)
/*     */     {
/* 112 */       nbOfVisibleChildren++;
/*     */     }
/*     */     
/* 115 */     if (nbOfVisibleChildren == 0)
/* 116 */       return new Point(0, 0); 
/* 117 */     int r = this.rows;
/* 118 */     int c = this.columns;
/* 119 */     if (r == 0) {
/* 120 */       r = nbOfVisibleChildren / c + ((nbOfVisibleChildren % c == 0) ? 0 : 1);
/* 121 */     } else if (c == 0) {
/* 122 */       c = nbOfVisibleChildren / r + ((nbOfVisibleChildren % r == 0) ? 0 : 1);
/* 123 */     }  int width = 0;
/* 124 */     int height = 0;
/* 125 */     for (int j = 0; j < children.length; j++) {
/*     */ 
/*     */       
/* 128 */       Point size = 
/* 129 */         getPreferredSize(children[j], -1, -1, flushCache);
/* 130 */       if (size.x > width)
/* 131 */         width = size.x; 
/* 132 */       if (size.y > height)
/* 133 */         height = size.y; 
/*     */     } 
/* 135 */     return new Point(c * width + (c - 1) * this.hgap, r * height + (r - 1) * this.vgap);
/*     */   }
/*     */   
/*     */   protected void layout(Composite composite, boolean flushCache) {
/* 139 */     Rectangle clientArea = composite.getClientArea();
/* 140 */     Control[] children = composite.getChildren();
/* 141 */     int nbOfVisibleChildren = 0;
/* 142 */     for (int i = 0; i < children.length; i++)
/*     */     {
/* 144 */       nbOfVisibleChildren++;
/*     */     }
/* 146 */     if (nbOfVisibleChildren == 0) {
/*     */       return;
/*     */     }
/* 149 */     int r = this.rows;
/* 150 */     int c = this.columns;
/* 151 */     if (r == 0) {
/* 152 */       r = nbOfVisibleChildren / c + ((nbOfVisibleChildren % c == 0) ? 0 : 1);
/* 153 */     } else if (c == 0) {
/* 154 */       c = nbOfVisibleChildren / r + ((nbOfVisibleChildren % r == 0) ? 0 : 1);
/* 155 */     }  int width = (clientArea.width - (c - 1) * this.hgap) / c;
/* 156 */     int height = (clientArea.height - (r - 1) * this.vgap) / r;
/*     */     
/* 158 */     int x = clientArea.x;
/* 159 */     int y = clientArea.y;
/* 160 */     for (int j = 0; j < children.length; j++) {
/*     */ 
/*     */       
/* 163 */       children[j].setBounds(x, y, width, height);
/* 164 */       if ((j + 1) % c == 0) {
/*     */         
/* 166 */         x = clientArea.x;
/* 167 */         y += height + this.vgap;
/*     */       } else {
/* 169 */         x += width + this.hgap;
/*     */       } 
/*     */     } 
/*     */   }
/*     */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\swing2swt\layout\GridLayout.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       1.1.3
 */