package jpdf.gui;

import java.awt.Color;
import java.awt.Component;
import java.awt.Container;
import java.awt.Dimension;
import java.awt.Font;
import java.awt.Window;
import java.awt.event.FocusAdapter;
import java.awt.event.FocusEvent;
import javax.swing.BorderFactory;
import javax.swing.JComponent;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.SwingUtilities;
import javax.swing.border.Border;
import jpdf.gui.dialog.AbstractPrintDialog;
import jpdf.manage.PrintManager;
import jpdf.wrap.printable.PageLabelPrintableWrapper;
import jpdf_common.gui.ability.WaitCursorable;
import jpdf_common.system.c.f;

public abstract class AbstractPrintOptionsPanel extends JPanel implements PrintOptionsController {
  public static final int DEFAULT_HORIZONTAL_GAP = 7;
  
  public static final int DEFAULT_VERTICAL_GAP = 7;
  
  protected static final int DEFAULT_CONTENT_OFFSET = 3;
  
  protected static final int DEFAULT_LABEL_CONTROL_GAP = 4;
  
  protected static final Border EMPTY_BORDER = BorderFactory.createEmptyBorder(7, 7, 7, 7);
  
  public AbstractPrintOptionsPanel(String paramString) {
    setName(paramString);
  }
  
  public static PrintOptionsController buildEmptyControllerPanel(String paramString) {
    return new a(paramString);
  }
  
  public boolean focusOnFirstInputComponent() {
    return focusOnFirstInputComponent(this);
  }
  
  public static boolean focusOnFirstInputComponent(Container paramContainer) {
    Component[] arrayOfComponent = paramContainer.getComponents();
    for (byte b = 0; b < arrayOfComponent.length; b++) {
      if (arrayOfComponent[b].isEnabled())
        if (arrayOfComponent[b] instanceof JPanel || arrayOfComponent[b] instanceof javax.swing.Box) {
          if (arrayOfComponent[b] instanceof jpdf_common.gui.ability.InputFocusable) {
            arrayOfComponent[b].requestFocus();
            return true;
          } 
          if (focusOnFirstInputComponent((Container)arrayOfComponent[b]))
            return true; 
        } else if (arrayOfComponent[b] instanceof JScrollPane || arrayOfComponent[b] instanceof javax.swing.JViewport) {
          if (focusOnFirstInputComponent((Container)arrayOfComponent[b]))
            return true; 
        } else if (!(arrayOfComponent[b] instanceof JLabel) && arrayOfComponent[b].isFocusable()) {
          arrayOfComponent[b].requestFocus();
          return true;
        }  
    } 
    return false;
  }
  
  public JComponent getDisplayComponent() {
    return this;
  }
  
  public int getLabelPreferredWidth() {
    Component[] arrayOfComponent = getComponents();
    int i = -1;
    byte b = 0;
    while (b < arrayOfComponent.length) {
      if (arrayOfComponent[b] instanceof JLabel) {
        i = (((JLabel)arrayOfComponent[b]).getPreferredSize()).width;
        break;
      } 
      if (!(arrayOfComponent[b] instanceof JPanel) || (i = getLabelPreferredWidth((JPanel)arrayOfComponent[b])) < 0)
        b++; 
    } 
    if (i > 0)
      i += 2; 
    return i;
  }
  
  public static int getLabelPreferredWidth(JPanel paramJPanel) {
    Component[] arrayOfComponent = paramJPanel.getComponents();
    int i = -1;
    byte b = 0;
    while (b < arrayOfComponent.length) {
      if (arrayOfComponent[b] instanceof JLabel) {
        i = (((JLabel)arrayOfComponent[b]).getPreferredSize()).width;
        break;
      } 
      if (!(arrayOfComponent[b] instanceof JPanel) || (i = getLabelPreferredWidth((JPanel)arrayOfComponent[b])) < 0)
        b++; 
    } 
    if (i > 0)
      i += 2; 
    return i;
  }
  
  public static void handleInputDataException(InputDataException paramInputDataException) {
    b b = new b(paramInputDataException.INPUT_COMPONENT);
    paramInputDataException.INPUT_COMPONENT.requestFocus();
    jpdf_common.gui.manage.a.a(paramInputDataException.TITLE, paramInputDataException.getMessage(), false);
    paramInputDataException.INPUT_COMPONENT.addFocusListener(b);
  }
  
  public boolean isEmptyControllerPanel() {
    return this instanceof a;
  }
  
  public void setEnabled(boolean paramBoolean) {
    super.setEnabled(paramBoolean);
    setInputEnabled(this, paramBoolean);
  }
  
  public void setLabelPreferredWidth(int paramInt) {
    Component[] arrayOfComponent = getComponents();
    Dimension dimension = null;
    byte b = 0;
    while (b < arrayOfComponent.length) {
      if (arrayOfComponent[b] instanceof JLabel) {
        (dimension = ((JLabel)arrayOfComponent[b]).getPreferredSize()).width = paramInt;
        ((JLabel)arrayOfComponent[b]).setPreferredSize(dimension);
        return;
      } 
      if (!(arrayOfComponent[b] instanceof JPanel) || !setLabelPreferredWidth((JPanel)arrayOfComponent[b], paramInt))
        b++; 
    } 
  }
  
  public static boolean setLabelPreferredWidth(JPanel paramJPanel, int paramInt) {
    Component[] arrayOfComponent = paramJPanel.getComponents();
    Object object = null;
    boolean bool = false;
    byte b = 0;
    while (b < arrayOfComponent.length) {
      if (arrayOfComponent[b] instanceof JLabel) {
        Dimension dimension;
        (dimension = ((JLabel)arrayOfComponent[b]).getPreferredSize()).width = paramInt;
        ((JLabel)arrayOfComponent[b]).setPreferredSize(dimension);
        boolean bool1 = true;
        break;
      } 
      if (!(arrayOfComponent[b] instanceof JPanel) || !(bool = setLabelPreferredWidth((JPanel)arrayOfComponent[b], paramInt)))
        b++; 
    } 
    return bool;
  }
  
  public static void setPreferredHeight(JComponent paramJComponent, int paramInt) {
    Dimension dimension;
    (dimension = paramJComponent.getPreferredSize()).height = paramInt;
    paramJComponent.setPreferredSize(dimension);
  }
  
  public static void setPreferredWidth(JComponent paramJComponent, int paramInt) {
    Dimension dimension;
    (dimension = paramJComponent.getPreferredSize()).width = paramInt;
    paramJComponent.setPreferredSize(dimension);
  }
  
  protected WaitCursorable displayWaitCursor() {
    WaitCursorable waitCursorable = null;
    Container container;
    if (container = getTopLevelAncestor() instanceof WaitCursorable)
      (waitCursorable = (WaitCursorable)container).setWaitCursor(); 
    return waitCursorable;
  }
  
  protected WaitCursorable displayWaitCursor(int paramInt) {
    Thread thread = null;
    Container container;
    if (container = getTopLevelAncestor() instanceof WaitCursorable) {
      WaitCursorable waitCursorable;
      (waitCursorable = (WaitCursorable)container).setWaitCursor();
      a a = new a(this, paramInt, waitCursorable);
      (thread = new Thread(a)).setPriority(1);
      thread.start();
    } else {
      container = null;
    } 
    return (WaitCursorable)container;
  }
  
  protected PrintInfoHolder getPrintInfoHolder() {
    PrintInfoHolder printInfoHolder = null;
    Window window;
    if (window = SwingUtilities.getWindowAncestor(this) instanceof AbstractPrintDialog)
      printInfoHolder = ((AbstractPrintDialog)window).getPrintInfoHolder(); 
    return printInfoHolder;
  }
  
  protected static void setInputEnabled(Container paramContainer, boolean paramBoolean) {
    Component[] arrayOfComponent = paramContainer.getComponents();
    for (byte b = 0; b < arrayOfComponent.length; b++) {
      if (arrayOfComponent[b] instanceof JScrollPane) {
        setInputEnabled(((JScrollPane)arrayOfComponent[b]).getViewport(), paramBoolean);
      } else if (arrayOfComponent[b] instanceof JLabel) {
        if (((JLabel)arrayOfComponent[b]).getLabelFor() != null)
          arrayOfComponent[b].setEnabled(paramBoolean); 
      } else {
        arrayOfComponent[b].setEnabled(paramBoolean);
        if (arrayOfComponent[b] instanceof JPanel || arrayOfComponent[b] instanceof javax.swing.Box)
          setInputEnabled((Container)arrayOfComponent[b], paramBoolean); 
      } 
    } 
  }
  
  static {
    String str = "494f43451f4475606b746073686e6d391f7676762d726e65736571606c64766e716a722d626e6c";
    String str = str;
    StringBuffer stringBuffer = new StringBuffer();
    Object object = null;
    int i = str.length();
    boolean bool = false;
    int j;
    for (j = 0; j < i; j += 2) {
      String str2;
      int k = Integer.parseInt(str2 = str.substring(j, j + 2), 16);
      String str1;
      if ((str1 = Integer.toHexString(++k)).length() == 1)
        stringBuffer.append('0'); 
      stringBuffer.append(str1);
    } 
    str = f.c(str = stringBuffer.toString());
    PageLabelPrintableWrapper.Encloser encloser;
    PrintManager.addPrintableEncloser((PrintManager.PrintableEncloser)(encloser = new PageLabelPrintableWrapper.Encloser(str, new Font("arial", 0, 10), 20, 40, Color.WHITE, Color.BLACK)));
  }
  
  static class a extends AbstractPrintOptionsPanel {
    public a(String param1String) {
      super(param1String);
    }
    
    public final void initializePrintOptions(PrintInfoHolder param1PrintInfoHolder) {}
    
    public final boolean updatePrintOptions(PrintInfoHolder param1PrintInfoHolder) {
      return true;
    }
  }
  
  static class b extends FocusAdapter {
    private final Color a;
    
    private final Color b;
    
    public b(Component param1Component) {
      this.a = param1Component.getBackground();
      this.b = param1Component.getForeground();
      param1Component.setBackground(Color.YELLOW);
      param1Component.setForeground(Color.RED);
    }
    
    public final void focusLost(FocusEvent param1FocusEvent) {
      Component component;
      (component = (Component)param1FocusEvent.getSource()).setBackground(this.a);
      component.setForeground(this.b);
      component.removeFocusListener(this);
    }
  }
}


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\lib\jpdf_demo.jar!\jpdf\gui\AbstractPrintOptionsPanel.class
 * Java compiler version: 5 (49.0)
 * JD-Core Version:       1.1.3
 */