package jpdf.printer;

import java.awt.Color;
import java.awt.Component;
import java.awt.Container;
import java.awt.Dialog;
import java.awt.Dimension;
import java.awt.Font;
import java.awt.FontMetrics;
import java.awt.Frame;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.Rectangle;
import java.awt.font.LineMetrics;
import java.awt.geom.AffineTransform;
import java.awt.print.PageFormat;
import java.io.FileOutputStream;
import java.io.PrintStream;
import javax.print.attribute.AttributeSet;
import javax.print.attribute.PrintRequestAttributeSet;
import javax.swing.DebugGraphics;
import javax.swing.JComponent;
import javax.swing.border.Border;
import jpdf.ability.FitScalabilityCoded;
import jpdf.attribute.BackgroundColorOnPage;
import jpdf.attribute.ContentBorder;
import jpdf.attribute.FitToPages;
import jpdf.attribute.FitToPagesSelected;
import jpdf.attribute.OffsetLeft;
import jpdf.attribute.OffsetRight;
import jpdf.attribute.ScaleFactor;
import jpdf.attribute.ScaleFactorMax;
import jpdf.attribute.ScaleFactorMin;
import jpdf.attribute.UseBackgroundColor;
import jpdf.manage.PrintManager;
import jpdf.manage.PrintParameterHolder;
import jpdf.printable.FullyNavigableAttributeSetPrintable;
import jpdf.printable.PageGridPrintable;
import jpdf.printable.ResetablePrintable;
import jpdf.printer.observer.PrinterEventType;
import jpdf.printer.swing.SwingPropertyCopier;
import jpdf.printer.text.PrintTextUtility;
import jpdf.utility.PageDecorationUtility;
import jpdf.utility.PrintUtility;
import jpdf.wrap.graphics.NoDrawGraphics2DWrapper;
import jpdf_common.gui.a.c;
import jpdf_common.system.c.f;
import jpdf_common.system.c.g;

public abstract class AbstractComponentPrinter extends AbstractPrinter implements FitScalabilityCoded, FullyNavigableAttributeSetPrintable, PageGridPrintable, ResetablePrintable {
  public static final String PRINT_CLONE_PROPERTY_KEY = "JpdfPrintClone";
  
  protected final Component TARGET_COMPONENT;
  
  protected final Dimension PAGE_GRID_SIZE = new Dimension(-1, -1);
  
  protected final Dimension EXTRA_SPACE = new Dimension();
  
  protected final ScaleFactorInfoHolder SCALE_FACTOR_INFO_HOLDER = new ScaleFactorInfoHolder();
  
  private a a = null;
  
  private Border b = null;
  
  private Color c = null;
  
  private Color d = null;
  
  private boolean e = false;
  
  private int f = -1;
  
  private int g = -1;
  
  private int h = 0;
  
  private int i = -1;
  
  private int j = 0;
  
  private int k = 60;
  
  private int l = 0;
  
  private final b m = new b();
  
  public AbstractComponentPrinter(Component paramComponent, String paramString, boolean paramBoolean) {
    this(paramComponent, paramString, PrintManager.getDefaultPrintAttributes(), paramBoolean);
  }
  
  public AbstractComponentPrinter(Component paramComponent, String paramString, AttributeSet paramAttributeSet, boolean paramBoolean) {
    super(paramString, paramAttributeSet);
    this.TARGET_COMPONENT = paramComponent;
    setTargetComponentBackgroundColor(this.TARGET_COMPONENT.getBackground());
    if (this.TARGET_COMPONENT instanceof JComponent) {
      setTargetComponentBorder(((JComponent)this.TARGET_COMPONENT).getBorder());
      if (paramBoolean)
        ((JComponent)this.TARGET_COMPONENT).putClientProperty("JpdfPrintClone", Boolean.TRUE); 
    } 
    Dimension dimension;
    if ((dimension = (paramComponent = paramComponent).getSize()).width <= 0 || dimension.height <= 0)
      paramComponent.setSize(paramComponent.getPreferredSize()); 
    if (this.TARGET_COMPONENT instanceof jpdf.ability.PrintImageUsable)
      setToPrintWithImage(1); 
  }
  
  public int computePageCount() {
    PageFormat pageFormat = PrintUtility.createPageFormat(getAttributeSet());
    return computePageCount(pageFormat);
  }
  
  public int computePageCount(PageFormat paramPageFormat) {
    resetState();
    computePageGridSize(paramPageFormat);
    return getPageCount();
  }
  
  public Dimension computePageGridSize(PageFormat paramPageFormat) {
    PrintRequestAttributeSet printRequestAttributeSet = getAttributeSet();
    this.DECORATION_OPTIONS.pageIndex = -99;
    prepareForPrinting(paramPageFormat, printRequestAttributeSet);
    float f = computeScaleFactor(paramPageFormat, printRequestAttributeSet, this.SCALE_FACTOR_INFO_HOLDER);
    computePageGridSize(paramPageFormat, printRequestAttributeSet, f, this.PAGE_GRID_SIZE);
    int i = this.PAGE_GRID_SIZE.width * this.PAGE_GRID_SIZE.height;
    AbstractComponentPrinter abstractComponentPrinter;
    (abstractComponentPrinter = this).f = i;
    return this.PAGE_GRID_SIZE;
  }
  
  public float computeScaleFactor(PageFormat paramPageFormat) {
    return computeScaleFactor(paramPageFormat, getAttributeSet(), this.SCALE_FACTOR_INFO_HOLDER);
  }
  
  public int getEmptySpaceAtLastPageBottom() {
    return this.l;
  }
  
  public int getFitScalingSupportCode() {
    return 0;
  }
  
  public Color getPageBackgroundColor() {
    return (this.d != null) ? this.d : getTargetComponentBackgroundColor();
  }
  
  public int getPageCount() {
    return this.f;
  }
  
  public int getPrintedPageIndex() {
    return this.g;
  }
  
  public Component getTargetComponent() {
    return this.TARGET_COMPONENT;
  }
  
  public Color getTargetComponentBackgroundColor() {
    return this.c;
  }
  
  public Border getTargetComponentBorder() {
    return this.b;
  }
  
  public Dimension getTargetComponentPrintSize() {
    return this.TARGET_COMPONENT.getSize();
  }
  
  public float getScaleFactor() {
    return this.SCALE_FACTOR_INFO_HOLDER.scaleFactor;
  }
  
  public boolean isBackgroundColorSupported() {
    return true;
  }
  
  public boolean isBorderControlAllowed() {
    return (isBorderSupported() && getTargetComponentBorder() != null);
  }
  
  public boolean isDoubleBuffered() {
    return this.TARGET_COMPONENT.isDoubleBuffered();
  }
  
  public boolean isInListPrinter() {
    return this.e;
  }
  
  public int print(Graphics paramGraphics, PageFormat paramPageFormat, int paramInt) {
    Rectangle rectangle;
    PrintCustomizer printCustomizer = getPrintCustomizer();
    PrintRequestAttributeSet printRequestAttributeSet = getAttributeSet();
    Graphics2D graphics2D = (Graphics2D)paramGraphics;
    float f = this.SCALE_FACTOR_INFO_HOLDER.scaleFactor;
    if (isToDebugPrinting()) {
      String str = getClass().getName() + " printing " + this.TARGET_COMPONENT.getClass().getName();
      updatePrintJobStatus(str);
    } 
    if (PrintManager.isPrintJobCancelled())
      return 1; 
    broadcastEventToObservers(PrinterEventType.START_PAGE_PRINT, graphics2D, paramPageFormat, paramInt, f);
    if (a(paramGraphics, paramInt)) {
      AbstractComponentPrinter abstractComponentPrinter1;
      g.b((abstractComponentPrinter1 = this).k);
      computePageGridSize(paramPageFormat);
      f = this.SCALE_FACTOR_INFO_HOLDER.scaleFactor;
    } 
    int i = this.PAGE_GRID_SIZE.width * this.PAGE_GRID_SIZE.height;
    AbstractComponentPrinter abstractComponentPrinter;
    int j;
    if ((j = paramInt + (abstractComponentPrinter = this).j) >= i)
      return 1; 
    if (printCustomizer != null)
      graphics2D = printCustomizer.customizePrint(graphics2D, paramPageFormat, j, this, printRequestAttributeSet, this.PRINT_PARAM_HOLDER); 
    if (isInListPrinter()) {
      graphics2D.clip(this.DECORATION_OPTIONS.pageContentRectangle);
    } else {
      printPageDecorations(graphics2D, printRequestAttributeSet, paramPageFormat, j, getDisplayPageCount(), f);
    } 
    AffineTransform affineTransform = null;
    printCustomizer = null;
    boolean bool;
    if (bool = (isToPrintPageDecorations() && !isTransparentImageGraphics(graphics2D)) ? true : false) {
      rectangle = graphics2D.getClipBounds();
      affineTransform = graphics2D.getTransform();
    } 
    i = a(graphics2D, paramPageFormat, j, printRequestAttributeSet, graphics2D.getClipBounds(), f, true);
    if (bool)
      a(graphics2D, affineTransform, rectangle); 
    return i;
  }
  
  public void reset() {
    resetState();
  }
  
  public static void setComponentCloneProperties(JComponent paramJComponent1, JComponent paramJComponent2, boolean paramBoolean) {
    Container container = null;
    SwingPropertyCopier.copyComponentVisibleProperties(paramJComponent1, paramJComponent2);
    if (paramJComponent1.isOpaque() || paramBoolean) {
      paramJComponent2.setBackground(paramJComponent1.getBackground());
    } else {
      Container container1 = (paramJComponent1 = paramJComponent1).getParent();
      Container container2 = null;
      while (container1 != null) {
        if (container1.isOpaque()) {
          container2 = container1;
          break;
        } 
        container1 = container1.getParent();
      } 
      if ((container = container2) != null) {
        paramJComponent2.setBackground(container.getBackground());
      } else {
        paramJComponent2.setBackground(Color.WHITE);
      } 
    } 
    paramJComponent2.setOpaque(true);
  }
  
  public void setContinuationText(String paramString, Color paramColor) {
    Font font = (font = getTargetComponent().getFont()).deriveFont(2, (font.getSize() + 1));
    a a1 = new a(paramString, font, paramColor, null, this);
    AbstractComponentPrinter abstractComponentPrinter;
    (abstractComponentPrinter = this).a = a1;
  }
  
  public void setContinuationText(String paramString, Color paramColor, int paramInt) {
    Font font = (font = getTargetComponent().getFont()).deriveFont(2, paramInt);
    a a1 = new a(paramString, font, paramColor, null, this);
    AbstractComponentPrinter abstractComponentPrinter;
    (abstractComponentPrinter = this).a = a1;
  }
  
  public void setContinuationText(String paramString, Color paramColor, Font paramFont) {
    a a1 = new a(paramString, paramFont, paramColor, null, this);
    AbstractComponentPrinter abstractComponentPrinter;
    (abstractComponentPrinter = this).a = a1;
  }
  
  public void setContinuationText(String paramString, Color paramColor1, Color paramColor2) {
    Font font = (font = getTargetComponent().getFont()).deriveFont(2, (font.getSize() + 1));
    setContinuationText(paramString, paramColor1, paramColor2, font);
  }
  
  public void setContinuationText(String paramString, Color paramColor1, Color paramColor2, Font paramFont) {
    a a1 = new a(paramString, paramFont, paramColor1, paramColor2, this);
    a a2 = a1;
    AbstractComponentPrinter abstractComponentPrinter;
    (abstractComponentPrinter = this).a = a2;
  }
  
  public boolean setDoubleBuffered(boolean paramBoolean) {
    boolean bool = false;
    if (this.TARGET_COMPONENT instanceof JComponent && this.TARGET_COMPONENT.isDoubleBuffered() != paramBoolean) {
      ((JComponent)this.TARGET_COMPONENT).setDoubleBuffered(paramBoolean);
      bool = true;
    } 
    return bool;
  }
  
  public void setPageBackgroundColor(Color paramColor) {
    this.d = paramColor;
  }
  
  public void setPrintJobDelayMilliseconds(int paramInt) {
    int i = paramInt;
    AbstractComponentPrinter abstractComponentPrinter;
    (abstractComponentPrinter = this).k = i;
  }
  
  public void setTargetComponentBackgroundColor(Color paramColor) {
    this.c = paramColor;
  }
  
  public void setTargetComponentBorder(Border paramBorder) {
    this.b = paramBorder;
  }
  
  protected abstract void computePageGridSize(PageFormat paramPageFormat, AttributeSet paramAttributeSet, float paramFloat, Dimension paramDimension);
  
  protected float computeScaleFactor(PageFormat paramPageFormat, AttributeSet paramAttributeSet, ScaleFactorInfoHolder paramScaleFactorInfoHolder) {
    Object object = null;
    object = null;
    Dimension dimension = getTargetComponentPrintSize();
    boolean bool = false;
    float f2 = 1.0F;
    float f1 = 0.0F;
    float f3 = 0.0F;
    float f4 = 0.01F;
    float f5 = 99.0F;
    int k = 1;
    int m = 1;
    int i = 0;
    int j = 0;
    i = ((j = getFitScalingSupportCode()) != 0) ? 1 : 0;
    paramScaleFactorInfoHolder.setToFixedScaleFactor(1.0F);
    if (paramAttributeSet != null) {
      if (i)
        bool = FitToPagesSelected.isFitSelected(paramAttributeSet); 
      if (bool) {
        if (j == 2) {
          k = 1;
          m = 99999;
        } else {
          FitToPages fitToPages;
          if ((fitToPages = (FitToPages)paramAttributeSet.get(FitToPages.class)) != null) {
            k = fitToPages.getWidth();
            m = fitToPages.getHeight();
          } 
          if (j == 3) {
            m = 99999;
          } else if (j == 4) {
            k = 99999;
          } 
        } 
        i = (i = PageDecorationUtility.computeAvailablePageWidth(paramPageFormat, paramAttributeSet, this.DECORATION_OPTIONS, 1)) * k - 2;
        if (m / k > 10) {
          j = 999999;
        } else {
          j = computeTotalAvailableHeight(paramPageFormat, paramAttributeSet, 1, m);
          j -= 2;
        } 
        float f6 = i / dimension.width;
        float f7 = j / dimension.height;
        if (f6 < f7) {
          f2 = f6;
          paramScaleFactorInfoHolder.fitsPagesWide = k;
          paramScaleFactorInfoHolder.fitsPagesHigh = 0;
        } else {
          f2 = f7;
          paramScaleFactorInfoHolder.fitsPagesWide = 0;
          paramScaleFactorInfoHolder.fitsPagesHigh = m;
        } 
      } else {
        ScaleFactor scaleFactor;
        if ((scaleFactor = (ScaleFactor)paramAttributeSet.get(ScaleFactor.class)) != null)
          f2 = scaleFactor.getValue(); 
      } 
      ScaleFactorMin scaleFactorMin;
      if ((scaleFactorMin = (ScaleFactorMin)paramAttributeSet.get(ScaleFactorMin.class)) != null)
        f4 = scaleFactorMin.getValue(); 
      ScaleFactorMax scaleFactorMax;
      if ((scaleFactorMax = (ScaleFactorMax)paramAttributeSet.get(ScaleFactorMax.class)) != null)
        f5 = scaleFactorMax.getValue(); 
      if (f2 < f4) {
        f2 = f4;
        paramScaleFactorInfoHolder.fitsPagesWide = 0;
        paramScaleFactorInfoHolder.fitsPagesHigh = 0;
      } else if (f2 > f5) {
        f2 = f5;
        paramScaleFactorInfoHolder.fitsPagesWide = 0;
        paramScaleFactorInfoHolder.fitsPagesHigh = 0;
      } 
    } 
    paramScaleFactorInfoHolder.scaleFactor = f2;
    return f2;
  }
  
  protected void drawContentFrame(Graphics2D paramGraphics2D, Color paramColor) {
    drawContentFrame(paramGraphics2D, paramColor, paramGraphics2D.getClipBounds(), true);
  }
  
  protected void drawContentFrame(Graphics2D paramGraphics2D, Color paramColor, Rectangle paramRectangle, boolean paramBoolean) {
    Dimension dimension = getTargetComponentPrintSize();
    Rectangle rectangle = null;
    if (dimension.width > 0 && dimension.height > 0) {
      if (paramBoolean)
        rectangle = paramGraphics2D.getClipBounds(); 
      paramGraphics2D.setClip(paramRectangle.x - 2, paramRectangle.y - 2, paramRectangle.width + 3, paramRectangle.height + 4);
      paramGraphics2D.setColor(paramColor);
      paramGraphics2D.drawRect(-1, -1, dimension.width + 1, dimension.height + 1);
      if (paramBoolean)
        paramGraphics2D.setClip(rectangle); 
    } 
  }
  
  protected void drawPageContentFrame(Graphics2D paramGraphics2D, Color paramColor) {
    drawPageContentFrame(paramGraphics2D, paramColor, paramGraphics2D.getClipBounds(), true);
  }
  
  protected void drawPageContentFrame(Graphics2D paramGraphics2D, Color paramColor, Rectangle paramRectangle, boolean paramBoolean) {
    Rectangle rectangle1 = null;
    Dimension dimension = getTargetComponentPrintSize();
    if (paramBoolean)
      rectangle1 = paramGraphics2D.getClipBounds(); 
    Rectangle rectangle2;
    int i = (rectangle2 = new Rectangle(paramRectangle)).x + rectangle2.width;
    if (dimension.width < i)
      rectangle2.width -= i - dimension.width; 
    i = rectangle2.y + rectangle2.height;
    if (dimension.height < i)
      rectangle2.height -= i - dimension.height; 
    paramGraphics2D.setClip(paramRectangle.x - 2, paramRectangle.y - 2, paramRectangle.width + 4, paramRectangle.height + 4);
    paramGraphics2D.setColor(paramColor);
    paramGraphics2D.draw(rectangle2);
    if (paramBoolean)
      paramGraphics2D.setClip(rectangle1); 
  }
  
  protected abstract int getComponentHeightOnPage(int paramInt);
  
  protected int getEmptySpaceAtFirstPageTop() {
    return this.h;
  }
  
  protected int getLastPageHeightUsed() {
    int j;
    AbstractComponentPrinter abstractComponentPrinter;
    a a1 = (abstractComponentPrinter = this).a;
    int i;
    if ((i = this.PAGE_GRID_SIZE.height - 1) < 0)
      return 0; 
    if (i == 0) {
      if ((j = getEmptySpaceAtFirstPageTop()) == 0)
        j += this.DECORATION_OPTIONS.minimumOffsets.top; 
    } else {
      j = this.DECORATION_OPTIONS.minimumOffsets.top;
    } 
    j += getComponentHeightOnPage(i);
    if (i > 0 && a1 != null)
      j += a1.a(); 
    return j;
  }
  
  protected static String getTitleForComponent(Component paramComponent) {
    String str;
    if (paramComponent instanceof java.awt.Window) {
      if (paramComponent instanceof Dialog) {
        if ((str = ((Dialog)paramComponent).getTitle()).equals(""))
          str = paramComponent.getClass().getName(); 
      } else if (paramComponent instanceof Frame) {
        if ((str = ((Frame)paramComponent).getTitle()).equals(""))
          str = paramComponent.getClass().getName(); 
      } else {
        str = paramComponent.getClass().getName();
      } 
    } else {
      str = paramComponent.getName();
    } 
    return str;
  }
  
  protected boolean isBorderSupported() {
    return true;
  }
  
  protected void paintTargetComponent(Graphics2D paramGraphics2D) {
    printTargetComponent(paramGraphics2D, false);
  }
  
  protected void prepareForPrinting(PageFormat paramPageFormat, AttributeSet paramAttributeSet) {
    Border border = null;
    border = null;
    Color color = null;
    super.prepareForPrinting(paramPageFormat, paramAttributeSet);
    if (isBackgroundColorSupported()) {
      if (UseBackgroundColor.isToUseBackgroundColor(paramAttributeSet)) {
        color = getTargetComponentBackgroundColor();
      } else {
        color = Color.WHITE;
      } 
      this.TARGET_COMPONENT.setBackground(color);
    } 
    if (isBorderSupported()) {
      if (ContentBorder.isToPrintBorder(paramAttributeSet))
        border = getTargetComponentBorder(); 
      ((JComponent)this.TARGET_COMPONENT).setBorder(border);
      Container container;
      if ((container = this.TARGET_COMPONENT.getParent()) != null) {
        this.TARGET_COMPONENT.invalidate();
        container.validate();
      } 
    } 
  }
  
  protected void printPageDecorations(Graphics2D paramGraphics2D, AttributeSet paramAttributeSet, PageFormat paramPageFormat, int paramInt1, int paramInt2, float paramFloat) {
    NoDrawGraphics2DWrapper noDrawGraphics2DWrapper;
    Color color = getPageBackgroundColor();
    boolean bool;
    if ((bool = isToPrintPageDecorations()) && isBackgroundColorSupported() && !color.equals(Color.WHITE) && BackgroundColorOnPage.isBackgroundColorOnPage(paramAttributeSet))
      PageDecorationUtility.fillBackground(paramGraphics2D, paramPageFormat, color); 
    if (!bool)
      noDrawGraphics2DWrapper = new NoDrawGraphics2DWrapper(paramGraphics2D); 
    this.PRINT_PARAM_HOLDER.pageNo = paramInt1 + 1 + getDisplayPageNumberOffset();
    this.PRINT_PARAM_HOLDER.pageCount = paramInt2;
    this.PRINT_PARAM_HOLDER.scaleFactor = paramFloat;
    this.PRINT_PARAM_HOLDER.pageGridWidth = this.PAGE_GRID_SIZE.width;
    PageDecorationUtility.printStandardPageDecorations(this, (Graphics2D)noDrawGraphics2DWrapper, paramPageFormat, this.DECORATION_OPTIONS, this.PRINT_PARAM_HOLDER, true);
  }
  
  protected void printTargetComponent(Graphics2D paramGraphics2D, boolean paramBoolean) {
    AffineTransform affineTransform = paramGraphics2D.getTransform();
    if (paramBoolean) {
      this.TARGET_COMPONENT.paint(paramGraphics2D);
    } else {
      this.TARGET_COMPONENT.print(paramGraphics2D);
    } 
    paramGraphics2D.setTransform(affineTransform);
  }
  
  protected abstract void printTargetComponent(Graphics2D paramGraphics2D, int paramInt1, int paramInt2, AttributeSet paramAttributeSet, float paramFloat);
  
  protected void resetState() {
    this.PAGE_GRID_SIZE.width = -1;
    this.PAGE_GRID_SIZE.height = -1;
    byte b1 = -1;
    AbstractComponentPrinter abstractComponentPrinter;
    (abstractComponentPrinter = this).f = b1;
    b1 = -1;
    (abstractComponentPrinter = this).g = b1;
  }
  
  protected void setEmptySpaceAtFirstPageTop(int paramInt) {
    this.h = paramInt;
  }
  
  protected void useDebugGraphicsForTargetComponent() {
    String str;
    int i = (str = getClass().getName()).lastIndexOf('.');
    if (isDoubleBuffered()) {
      str = "Debug Graphics cannot be used with a Double Buffered component.";
      PrintManager.handleException(new IllegalStateException(str));
      return;
    } 
    if (i > 0)
      str = str.substring(i + 1); 
    str = str + ".DebugGraphics.log";
    try {
      DebugGraphics.setLogStream(new PrintStream(new FileOutputStream(str)));
      ((JComponent)this.TARGET_COMPONENT).setDebugGraphicsOptions(1);
      return;
    } catch (Exception exception) {
      PrintManager.handleException((Throwable)(str = null));
      return;
    } 
  }
  
  protected void useNormalGraphicsForTargetComponent() {
    PrintStream printStream = null;
    try {
      if ((printStream = DebugGraphics.logStream()) != null)
        printStream.close(); 
      return;
    } catch (Exception exception) {
      PrintManager.handleException((Throwable)(printStream = null));
      return;
    } 
  }
  
  final int a(int paramInt) {
    return paramInt / this.PAGE_GRID_SIZE.width;
  }
  
  final void a(Graphics2D paramGraphics2D, int paramInt1, int paramInt2, float paramFloat, Rectangle paramRectangle, boolean paramBoolean) {
    if (isToPrintPageContentFrame() || isToPrintContentFrame()) {
      paramRectangle = new Rectangle(paramRectangle);
      undoShiftAndScale(paramInt1, paramInt2, paramFloat, paramRectangle);
      if (isToPrintPageContentFrame())
        drawPageContentFrame(paramGraphics2D, Color.BLACK, paramRectangle, false); 
      if (isToPrintContentFrame())
        drawContentFrame(paramGraphics2D, Color.BLACK, paramRectangle, false); 
    } 
  }
  
  final void a(Graphics2D paramGraphics2D, PageFormat paramPageFormat) {
    PrintRequestAttributeSet printRequestAttributeSet = null;
    Color color = null;
    if (isBackgroundColorSupported() && !(color = getPageBackgroundColor()).equals(Color.WHITE) && BackgroundColorOnPage.isBackgroundColorOnPage(printRequestAttributeSet = getAttributeSet()))
      PageDecorationUtility.fillBackground(paramGraphics2D, paramPageFormat, color); 
  }
  
  final a a() {
    return this.a;
  }
  
  final int b() {
    AbstractComponentPrinter abstractComponentPrinter;
    a a1 = (abstractComponentPrinter = this).a;
    int i = 0;
    if (a1 != null)
      i = a1.a(); 
    return i;
  }
  
  final int c() {
    return this.i;
  }
  
  final int a(Graphics2D paramGraphics2D, Rectangle paramRectangle) {
    AbstractComponentPrinter abstractComponentPrinter;
    a a1 = (abstractComponentPrinter = this).a;
    int i = 0;
    if (a1 != null) {
      i = a1.a(paramGraphics2D, paramRectangle);
      paramGraphics2D.translate(0, i);
    } 
    return i;
  }
  
  final void b(int paramInt) {
    this.l = paramInt;
  }
  
  final void c(int paramInt) {
    this.i = 1;
  }
  
  final void a(boolean paramBoolean) {
    this.e = true;
  }
  
  final void a(Rectangle paramRectangle) {
    PrintRequestAttributeSet printRequestAttributeSet;
    int j = OffsetLeft.getOffsetPixelsRounded(printRequestAttributeSet = getAttributeSet(), 0);
    int i = OffsetRight.getOffsetPixelsRounded(printRequestAttributeSet, 0);
    int k = paramRectangle.x + j;
    i = paramRectangle.width - j + i;
    this.DECORATION_OPTIONS.pageContentRectangle.setBounds(k, paramRectangle.y, i, paramRectangle.height);
  }
  
  final void d(int paramInt) {
    this.k = paramInt;
  }
  
  final void e(int paramInt) {
    this.j = paramInt;
    setDisplayPageNumberOffset(-paramInt);
  }
  
  static int a(int[] paramArrayOfint, int paramInt1, int paramInt2, int paramInt3, int paramInt4) {
    int i;
    if ((i = paramInt3 - paramInt2) > 0) {
      paramArrayOfint[paramInt1] = paramArrayOfint[paramInt1] + paramInt3 - i + 1;
      if (++paramInt1 >= paramArrayOfint.length)
        paramArrayOfint = a(paramArrayOfint, 1); 
      paramArrayOfint[paramInt1] = paramArrayOfint[paramInt1 - 1] + i + 1;
    } else {
      if (paramInt2 < 0)
        paramInt4 = paramInt2; 
      paramArrayOfint[paramInt1] = paramArrayOfint[paramInt1] + paramInt3 + paramInt4;
    } 
    return paramInt1;
  }
  
  static void a(Graphics2D paramGraphics2D, AffineTransform paramAffineTransform, Rectangle paramRectangle) {
    if (paramGraphics2D.getClass().getName().endsWith("2.text.TextRenderGraphics2D"))
      return; 
    Font font = c.a.deriveFont(1, 16.0F);
    paramGraphics2D.setFont(font);
    String str = f.c("4A504446204576616C756174696F6E3A207777772E736F66746672616D65776F726B732E636F6D");
    FontMetrics fontMetrics;
    int i = (fontMetrics = paramGraphics2D.getFontMetrics()).stringWidth(str);
    int j = paramRectangle.y + paramRectangle.height - 52;
    int k = paramRectangle.x + paramRectangle.width - i + 5;
    paramGraphics2D.setTransform(paramAffineTransform);
    paramGraphics2D.setClip(paramRectangle);
    paramGraphics2D.setColor(new Color(32, 240, 176));
    paramGraphics2D.fillRect(k, j, i + 2, 18);
    paramGraphics2D.setColor(Color.BLACK);
    paramGraphics2D.drawString(str, k, j + fontMetrics.getAscent() - 2);
  }
  
  private boolean a(Graphics paramGraphics, int paramInt) {
    return (this.PAGE_GRID_SIZE.width < 0) ? true : ((paramInt == 0 && paramGraphics instanceof sun.print.PeekGraphics));
  }
  
  private int a(Graphics2D paramGraphics2D, PageFormat paramPageFormat, int paramInt, AttributeSet paramAttributeSet, Rectangle paramRectangle, float paramFloat, boolean paramBoolean) {
    int j = 0;
    int k = 0;
    if (this.SCALE_FACTOR_INFO_HOLDER.fitsPagesWide != 0) {
      paramRectangle.x += this.SCALE_FACTOR_INFO_HOLDER.fitSpaceReduction / 2;
      paramGraphics2D.setClip(paramRectangle);
    } else if (this.SCALE_FACTOR_INFO_HOLDER.fitsPagesHigh != 0) {
      paramRectangle.y += this.SCALE_FACTOR_INFO_HOLDER.fitSpaceReduction / 2;
      paramGraphics2D.setClip(paramRectangle);
    } 
    if (paramBoolean)
      broadcastEventToObservers(PrinterEventType.START_PAGE_CONTENT_PRINT, paramGraphics2D, paramPageFormat, paramInt, paramFloat); 
    if (paramInt > 0) {
      j = a(paramInt);
      int m = paramInt;
      AbstractComponentPrinter abstractComponentPrinter1 = this;
      k = m % abstractComponentPrinter1.PAGE_GRID_SIZE.width;
    } 
    printTargetComponent(paramGraphics2D, j, k, paramAttributeSet, paramFloat);
    int i = paramInt;
    AbstractComponentPrinter abstractComponentPrinter;
    (abstractComponentPrinter = this).g = i;
    return PrintManager.isPrintJobCancelled() ? 1 : 0;
  }
  
  public int printPreview(Graphics paramGraphics, PageFormat paramPageFormat, int paramInt, Rectangle paramRectangle, float paramFloat) {
    PrintCustomizer printCustomizer = getPrintCustomizer();
    PrintRequestAttributeSet printRequestAttributeSet = getAttributeSet();
    Graphics2D graphics2D = (Graphics2D)paramGraphics;
    float f = this.SCALE_FACTOR_INFO_HOLDER.scaleFactor;
    if (a(paramGraphics, paramInt)) {
      computePageGridSize(paramPageFormat);
      f = this.SCALE_FACTOR_INFO_HOLDER.scaleFactor;
    } 
    int i = this.PAGE_GRID_SIZE.width * this.PAGE_GRID_SIZE.height;
    AbstractComponentPrinter abstractComponentPrinter;
    int k;
    if ((k = paramInt + (abstractComponentPrinter = this).j) >= i)
      return 1; 
    if (printCustomizer != null)
      graphics2D = printCustomizer.customizePrint(graphics2D, paramPageFormat, k, this, printRequestAttributeSet, this.PRINT_PARAM_HOLDER); 
    Rectangle rectangle1;
    if ((rectangle1 = this.m.a(k, paramRectangle, paramFloat, this.DECORATION_OPTIONS)) == null) {
      printPageDecorations(graphics2D, printRequestAttributeSet, paramPageFormat, k, getDisplayPageCount(), f);
      rectangle1 = graphics2D.getClipBounds();
      this.m.a(this.DECORATION_OPTIONS);
    } else {
      a(graphics2D, paramPageFormat);
      if (this.DECORATION_OPTIONS.framePrinted)
        PageDecorationUtility.printStandardPageFrame(graphics2D, paramPageFormat); 
    } 
    AffineTransform affineTransform = graphics2D.getTransform();
    Rectangle rectangle2 = b.a(this.m);
    if (b.a(paramRectangle, paramFloat)) {
      Rectangle rectangle = rectangle1;
      paramFloat = paramFloat;
      int n = (int)((paramRectangle = paramRectangle).y / paramFloat) - 2;
      int m = (int)(paramRectangle.height / paramFloat) + 4;
      if (n < rectangle.y) {
        int i1 = rectangle.y - n;
        n = rectangle.y;
        m -= i1;
      } else {
        int i1 = n + m;
        int i2 = rectangle.y + rectangle.height;
        if (i1 > i2)
          m -= i1 - i2; 
      } 
      rectangle.y = n;
      rectangle.height = m;
      if (rectangle1.height <= 0)
        return 0; 
      graphics2D.clip(rectangle1);
    } 
    int j;
    if ((j = a(graphics2D, paramPageFormat, k, printRequestAttributeSet, rectangle1, f, false)) == 0) {
      k = rectangle2.y + rectangle2.height - 144;
      boolean bool;
      if (bool = (rectangle1.y >= k || rectangle1.y + rectangle1.height >= k) ? true : false) {
        AffineTransform affineTransform1 = graphics2D.getTransform();
        Rectangle rectangle = graphics2D.getClipBounds();
        a(graphics2D, affineTransform, rectangle2);
        graphics2D.setTransform(affineTransform1);
        graphics2D.setClip(rectangle);
      } 
    } 
    return j;
  }
  
  static class b {
    private Rectangle a = new Rectangle();
    
    private int b = -1543;
    
    static boolean a(Rectangle param1Rectangle, float param1Float) {
      return (param1Rectangle.height / param1Float < 72.0F);
    }
    
    final void a(PageDecorationUtility.DecorationOptions param1DecorationOptions) {
      this.a.setBounds(param1DecorationOptions.pageContentRectangle);
      this.b = param1DecorationOptions.pageIndex;
    }
    
    final Rectangle a(int param1Int, Rectangle param1Rectangle, float param1Float, PageDecorationUtility.DecorationOptions param1DecorationOptions) {
      Rectangle rectangle;
      if (!a(param1Rectangle, param1Float))
        return null; 
      if (param1DecorationOptions.pageIndex == param1Int) {
        rectangle = param1DecorationOptions.pageContentRectangle;
      } else if (this.b == rectangle) {
        rectangle = this.a;
      } else {
        return null;
      } 
      int j = param1Rectangle.y;
      int i = param1Rectangle.y + param1Rectangle.height - 1;
      j = (int)(j / param1Float);
      i = (int)(i / param1Float);
      return ((i = (j < rectangle.y || i > rectangle.y + rectangle.height) ? 1 : 0) != 0) ? null : new Rectangle(rectangle);
    }
  }
  
  static class a {
    private final LineMetrics a;
    
    private final Color b;
    
    private final Color c;
    
    private final String d;
    
    private final Font e;
    
    private final int f;
    
    private final int g;
    
    public a(String param1String, Font param1Font, Color param1Color1, Color param1Color2, AbstractComponentPrinter param1AbstractComponentPrinter) {
      if (param1Font == null)
        throw new NullPointerException("Continuation String font cannot be NULL."); 
      if (param1Color1 == null)
        throw new NullPointerException("Continuation String color cannot be NULL."); 
      String str1 = param1String;
      AbstractComponentPrinter abstractComponentPrinter;
      String str2 = (abstractComponentPrinter = param1AbstractComponentPrinter).getTargetComponent().getName();
      PrintParameterHolder.replaceAll(str1, "[-T-]", abstractComponentPrinter.getTitle());
      this.d = AbstractPrinter.replaceNameMarker(str1, str2);
      this.b = param1Color1;
      this.c = param1Color2;
      this.e = param1Font;
      this.a = PrintTextUtility.getLineMetrics(this.e, this.d, true);
      this.f = (int)(this.a.getHeight() + 1.0F);
      if (this.c != null) {
        this.g = PrintTextUtility.computeWidth(this.e, this.d, true);
        return;
      } 
      this.g = -1;
    }
    
    public final int a() {
      return this.f;
    }
    
    public final int a(Graphics2D param1Graphics2D, Rectangle param1Rectangle) {
      int j = (int)this.a.getDescent();
      int i = param1Rectangle.x + 2;
      j = param1Rectangle.y + this.f - j + 1;
      if (this.c != null) {
        param1Graphics2D.setColor(this.c);
        param1Graphics2D.fillRect(i - 1, param1Rectangle.y - 1, this.g + 2, this.f + 2);
      } 
      param1Graphics2D.setFont(this.e);
      param1Graphics2D.setColor(this.b);
      param1Graphics2D.drawString(this.d, i, j);
      return this.f;
    }
  }
  
  public static class ScaleFactorInfoHolder {
    public float scaleFactor = 1.0F;
    
    public int fitSpaceReduction = 2;
    
    public int fitsPagesWide = 0;
    
    public int fitsPagesHigh = 0;
    
    protected void resetDefaults() {
      this.scaleFactor = 1.0F;
      this.fitsPagesWide = 0;
      this.fitsPagesHigh = 0;
      this.fitSpaceReduction = 2;
    }
    
    protected void setToFixedScaleFactor(float param1Float) {
      this.scaleFactor = param1Float;
      this.fitsPagesWide = 0;
      this.fitsPagesHigh = 0;
      this.fitSpaceReduction = 2;
    }
  }
}


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\lib\jpdf_demo.jar!\jpdf\printer\AbstractComponentPrinter.class
 * Java compiler version: 5 (49.0)
 * JD-Core Version:       1.1.3
 */