/*     */ package oracle.jdbc.driver;
/*     */ 
/*     */ import java.sql.Date;
/*     */ import java.sql.SQLException;
/*     */ import java.sql.Time;
/*     */ import java.sql.Timestamp;
/*     */ import java.util.Calendar;
/*     */ import java.util.TimeZone;
/*     */ import oracle.sql.DATE;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ abstract class DateTimeCommonAccessor
/*     */   extends Accessor
/*     */ {
/*     */   static final int GREGORIAN_CUTOVER_YEAR = 1582;
/*     */   static final long GREGORIAN_CUTOVER = -12219292800000L;
/*     */   static final int JAN_1_1_JULIAN_DAY = 1721426;
/*     */   static final int EPOCH_JULIAN_DAY = 2440588;
/*     */   static final int ONE_SECOND = 1000;
/*     */   static final int ONE_MINUTE = 60000;
/*     */   static final int ONE_HOUR = 3600000;
/*     */   static final long ONE_DAY = 86400000L;
/*  41 */   static final int[] NUM_DAYS = new int[] { 0, 31, 59, 90, 120, 151, 181, 212, 243, 273, 304, 334 };
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  46 */   static final int[] LEAP_NUM_DAYS = new int[] { 0, 31, 60, 91, 121, 152, 182, 213, 244, 274, 305, 335 };
/*     */   
/*     */   static final int ORACLE_CENTURY = 0;
/*     */   
/*     */   static final int ORACLE_YEAR = 1;
/*     */   
/*     */   static final int ORACLE_MONTH = 2;
/*     */   
/*     */   static final int ORACLE_DAY = 3;
/*     */   
/*     */   static final int ORACLE_HOUR = 4;
/*     */   
/*     */   static final int ORACLE_MIN = 5;
/*     */   
/*     */   static final int ORACLE_SEC = 6;
/*     */   
/*     */   static final int ORACLE_NANO1 = 7;
/*     */   
/*     */   static final int ORACLE_NANO2 = 8;
/*     */   static final int ORACLE_NANO3 = 9;
/*     */   static final int ORACLE_NANO4 = 10;
/*     */   static final int ORACLE_TZ1 = 11;
/*     */   static final int ORACLE_TZ2 = 12;
/*     */   static final int SIZE_DATE = 7;
/*     */   static final int MAX_TIMESTAMP_LENGTH = 11;
/*     */   static TimeZone epochTimeZone;
/*     */   static long epochTimeZoneOffset;
/*     */   
/*     */   Time getTime(int paramInt) throws SQLException {
/*  75 */     Time time = null;
/*     */     
/*  77 */     if (this.rowSpaceIndicator == null)
/*     */     {
/*     */ 
/*     */ 
/*     */       
/*  82 */       DatabaseError.throwSqlException(21);
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*  89 */     if (this.rowSpaceIndicator[this.indicatorIndex + paramInt] != -1) {
/*     */       
/*  91 */       int i = this.columnIndex + this.byteLength * paramInt;
/*     */ 
/*     */ 
/*     */       
/*  95 */       TimeZone timeZone = this.statement.getDefaultTimeZone();
/*     */       
/*  97 */       if (timeZone != epochTimeZone) {
/*     */         
/*  99 */         epochTimeZoneOffset = calculateEpochOffset(timeZone);
/* 100 */         epochTimeZone = timeZone;
/*     */       } 
/*     */       
/* 103 */       time = new Time(oracleTime(i) - epochTimeZoneOffset);
/*     */     } 
/*     */     
/* 106 */     return time;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   Date getDate(int paramInt) throws SQLException {
/* 113 */     return getDate(paramInt, this.statement.getDefaultCalendar());
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   Date getDate(int paramInt, Calendar paramCalendar) throws SQLException {
/* 120 */     if (paramCalendar == null) {
/* 121 */       return getDate(paramInt);
/*     */     }
/* 123 */     Date date = null;
/*     */     
/* 125 */     if (this.rowSpaceIndicator == null)
/*     */     {
/*     */ 
/*     */ 
/*     */       
/* 130 */       DatabaseError.throwSqlException(21);
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 137 */     if (this.rowSpaceIndicator[this.indicatorIndex + paramInt] != -1) {
/*     */       
/* 139 */       int i = this.columnIndex + this.byteLength * paramInt;
/* 140 */       int j = ((this.rowSpaceByte[0 + i] & 0xFF) - 100) * 100 + (this.rowSpaceByte[1 + i] & 0xFF) - 100;
/*     */ 
/*     */       
/* 143 */       paramCalendar.set(j, oracleMonth(i), oracleDay(i), 0, 0, 0);
/* 144 */       paramCalendar.set(14, 0);
/*     */ 
/*     */       
/* 147 */       if (j > 0 && paramCalendar.isSet(0)) {
/* 148 */         paramCalendar.set(0, 1);
/*     */       }
/*     */ 
/*     */ 
/*     */ 
/*     */       
/* 154 */       date = new Date(paramCalendar.getTimeInMillis());
/*     */     } 
/*     */ 
/*     */ 
/*     */     
/* 159 */     return date;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   Time getTime(int paramInt, Calendar paramCalendar) throws SQLException {
/* 166 */     if (paramCalendar == null) {
/* 167 */       return getTime(paramInt);
/*     */     }
/* 169 */     Time time = null;
/*     */     
/* 171 */     if (this.rowSpaceIndicator == null)
/*     */     {
/*     */ 
/*     */ 
/*     */       
/* 176 */       DatabaseError.throwSqlException(21);
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 183 */     if (this.rowSpaceIndicator[this.indicatorIndex + paramInt] != -1) {
/*     */       
/* 185 */       int i = this.columnIndex + this.byteLength * paramInt;
/* 186 */       int j = ((this.rowSpaceByte[0 + i] & 0xFF) - 100) * 100 + (this.rowSpaceByte[1 + i] & 0xFF) - 100;
/*     */ 
/*     */       
/* 189 */       paramCalendar.set(1970, 0, 1, oracleHour(i), oracleMin(i), oracleSec(i));
/* 190 */       paramCalendar.set(14, 0);
/*     */ 
/*     */ 
/*     */       
/* 194 */       if (j > 0 && paramCalendar.isSet(0)) {
/* 195 */         paramCalendar.set(0, 1);
/*     */       }
/*     */ 
/*     */ 
/*     */ 
/*     */       
/* 201 */       time = new Time(paramCalendar.getTimeInMillis());
/*     */     } 
/*     */ 
/*     */ 
/*     */     
/* 206 */     return time;
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   Timestamp getTimestamp(int paramInt) throws SQLException {
/* 212 */     return getTimestamp(paramInt, this.statement.getDefaultCalendar());
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   Timestamp getTimestamp(int paramInt, Calendar paramCalendar) throws SQLException {
/* 219 */     if (paramCalendar == null) {
/* 220 */       return getTimestamp(paramInt);
/*     */     }
/* 222 */     Timestamp timestamp = null;
/*     */     
/* 224 */     if (this.rowSpaceIndicator == null)
/*     */     {
/*     */ 
/*     */ 
/*     */       
/* 229 */       DatabaseError.throwSqlException(21);
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 236 */     if (this.rowSpaceIndicator[this.indicatorIndex + paramInt] != -1) {
/*     */       
/* 238 */       int i = this.columnIndex + this.byteLength * paramInt;
/* 239 */       int j = ((this.rowSpaceByte[0 + i] & 0xFF) - 100) * 100 + (this.rowSpaceByte[1 + i] & 0xFF) - 100;
/*     */ 
/*     */ 
/*     */ 
/*     */       
/* 244 */       paramCalendar.set(j, oracleMonth(i), oracleDay(i), oracleHour(i), oracleMin(i), oracleSec(i));
/*     */       
/* 246 */       paramCalendar.set(14, 0);
/*     */ 
/*     */       
/* 249 */       if (j > 0 && paramCalendar.isSet(0)) {
/* 250 */         paramCalendar.set(0, 1);
/*     */       }
/*     */ 
/*     */ 
/*     */ 
/*     */       
/* 256 */       timestamp = new Timestamp(paramCalendar.getTimeInMillis());
/*     */ 
/*     */ 
/*     */       
/* 260 */       short s = this.rowSpaceIndicator[this.lengthIndex + paramInt];
/* 261 */       if (s >= 11)
/*     */       {
/* 263 */         timestamp.setNanos(oracleNanos(i));
/*     */       }
/*     */     } 
/*     */ 
/*     */     
/* 268 */     return timestamp;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   DATE getDATE(int paramInt) throws SQLException {
/* 276 */     DATE dATE = null;
/*     */     
/* 278 */     if (this.rowSpaceIndicator == null)
/*     */     {
/*     */ 
/*     */ 
/*     */       
/* 283 */       DatabaseError.throwSqlException(21);
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 290 */     if (this.rowSpaceIndicator[this.indicatorIndex + paramInt] != -1) {
/*     */       
/* 292 */       int i = this.columnIndex + this.byteLength * paramInt;
/* 293 */       byte[] arrayOfByte = new byte[7];
/*     */       
/* 295 */       System.arraycopy(this.rowSpaceByte, i, arrayOfByte, 0, 7);
/*     */       
/* 297 */       dATE = new DATE(arrayOfByte);
/*     */     } 
/*     */     
/* 300 */     return dATE;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   final int oracleYear(int paramInt) {
/* 307 */     int i = ((this.rowSpaceByte[0 + paramInt] & 0xFF) - 100) * 100 + (this.rowSpaceByte[1 + paramInt] & 0xFF) - 100;
/*     */ 
/*     */ 
/*     */     
/* 311 */     return (i <= 0) ? (i + 1) : i;
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   final int oracleMonth(int paramInt) {
/* 317 */     return this.rowSpaceByte[2 + paramInt] - 1;
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   final int oracleDay(int paramInt) {
/* 323 */     return this.rowSpaceByte[3 + paramInt];
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   final int oracleHour(int paramInt) {
/* 329 */     return this.rowSpaceByte[4 + paramInt] - 1;
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   final int oracleMin(int paramInt) {
/* 335 */     return this.rowSpaceByte[5 + paramInt] - 1;
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   final int oracleSec(int paramInt) {
/* 341 */     return this.rowSpaceByte[6 + paramInt] - 1;
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   final int oracleTZ1(int paramInt) {
/* 347 */     return this.rowSpaceByte[11 + paramInt];
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   final int oracleTZ2(int paramInt) {
/* 353 */     return this.rowSpaceByte[12 + paramInt];
/*     */   }
/*     */ 
/*     */   
/*     */   final int oracleTime(int paramInt) {
/* 358 */     int i = oracleHour(paramInt);
/*     */     
/* 360 */     i *= 60;
/* 361 */     i += oracleMin(paramInt);
/* 362 */     i *= 60;
/* 363 */     i += oracleSec(paramInt);
/* 364 */     i *= 1000;
/*     */     
/* 366 */     return i;
/*     */   }
/*     */ 
/*     */   
/*     */   final int oracleNanos(int paramInt) {
/* 371 */     int i = (this.rowSpaceByte[7 + paramInt] & 0xFF) << 24;
/*     */     
/* 373 */     i |= (this.rowSpaceByte[8 + paramInt] & 0xFF) << 16;
/* 374 */     i |= (this.rowSpaceByte[9 + paramInt] & 0xFF) << 8;
/* 375 */     i |= this.rowSpaceByte[10 + paramInt] & 0xFF & 0xFF;
/*     */     
/* 377 */     return i;
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   static final long computeJulianDay(boolean paramBoolean, int paramInt1, int paramInt2, int paramInt3) {
/* 383 */     boolean bool = (paramInt1 % 4 == 0) ? true : false;
/* 384 */     int i = paramInt1 - 1;
/* 385 */     long l = 365L * i + floorDivide(i, 4L) + 1721423L;
/*     */     
/* 387 */     if (paramBoolean) {
/*     */       
/* 389 */       bool = (bool && (paramInt1 % 100 != 0 || paramInt1 % 400 == 0)) ? true : false;
/*     */ 
/*     */       
/* 392 */       l += floorDivide(i, 400L) - floorDivide(i, 100L) + 2L;
/*     */     } 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 399 */     return l + paramInt3 + (bool ? LEAP_NUM_DAYS[paramInt2] : NUM_DAYS[paramInt2]);
/*     */   }
/*     */ 
/*     */   
/*     */   static final long floorDivide(long paramLong1, long paramLong2) {
/* 404 */     return (paramLong1 >= 0L) ? (paramLong1 / paramLong2) : ((paramLong1 + 1L) / paramLong2 - 1L);
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   static final long julianDayToMillis(long paramLong) {
/* 410 */     return (paramLong - 2440588L) * 86400000L;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   static final long zoneOffset(TimeZone paramTimeZone, int paramInt1, int paramInt2, int paramInt3, int paramInt4, int paramInt5) {
/* 418 */     return paramTimeZone.getOffset((paramInt1 < 0) ? 0 : 1, paramInt1, paramInt2, paramInt3, paramInt4, paramInt5);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   static long getMillis(int paramInt1, int paramInt2, int paramInt3, int paramInt4, TimeZone paramTimeZone) {
/* 437 */     boolean bool = (paramInt1 >= 1582) ? true : false;
/* 438 */     long l1 = computeJulianDay(bool, paramInt1, paramInt2, paramInt3);
/* 439 */     long l2 = (l1 - 2440588L) * 86400000L;
/*     */ 
/*     */ 
/*     */     
/* 443 */     if (bool != ((l2 >= -12219292800000L) ? true : false)) {
/*     */       
/* 445 */       l1 = computeJulianDay(!bool, paramInt1, paramInt2, paramInt3);
/* 446 */       l2 = (l1 - 2440588L) * 86400000L;
/*     */     } 
/*     */ 
/*     */ 
/*     */     
/* 451 */     l2 += paramInt4;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 456 */     return l2 - zoneOffset(paramTimeZone, paramInt1, paramInt2, paramInt3, julianDayToDayOfWeek(l1), paramInt4);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   static final int julianDayToDayOfWeek(long paramLong) {
/* 472 */     int i = (int)((paramLong + 1L) % 7L);
/*     */     
/* 474 */     return i + ((i < 0) ? 8 : 1);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   static long calculateEpochOffset(TimeZone paramTimeZone) {
/* 491 */     return zoneOffset(paramTimeZone, 1970, 0, 1, 5, 0);
/*     */   }
/*     */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\lib\ojdbc14.jar!\oracle\jdbc\driver\DateTimeCommonAccessor.class
 * Java compiler version: 2 (46.0)
 * JD-Core Version:       1.1.3
 */