/*     */ package oracle.jdbc.driver;
/*     */ 
/*     */ import java.sql.SQLException;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class LRUStatementCache
/*     */ {
/*     */   private int cacheSize;
/*     */   private int numElements;
/*     */   private OracleStatementCacheEntry applicationCacheStart;
/*     */   private OracleStatementCacheEntry applicationCacheEnd;
/*     */   private OracleStatementCacheEntry implicitCacheStart;
/*     */   private OracleStatementCacheEntry explicitCacheStart;
/*     */   boolean implicitCacheEnabled;
/*     */   boolean explicitCacheEnabled;
/*     */   private boolean debug = false;
/*     */   
/*     */   protected LRUStatementCache(int paramInt) throws SQLException {
/*  69 */     if (paramInt < 0) {
/*  70 */       DatabaseError.throwSqlException(123);
/*     */     }
/*  72 */     this.cacheSize = paramInt;
/*  73 */     this.numElements = 0;
/*     */     
/*  75 */     this.implicitCacheStart = null;
/*  76 */     this.explicitCacheStart = null;
/*     */     
/*  78 */     this.implicitCacheEnabled = false;
/*  79 */     this.explicitCacheEnabled = false;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void resize(int paramInt) throws SQLException {
/*  99 */     if (paramInt < 0) {
/* 100 */       DatabaseError.throwSqlException(123);
/*     */     }
/* 102 */     if (paramInt >= this.cacheSize || paramInt >= this.numElements) {
/*     */ 
/*     */       
/* 105 */       this.cacheSize = paramInt;
/*     */     
/*     */     }
/*     */     else {
/*     */ 
/*     */       
/* 111 */       OracleStatementCacheEntry oracleStatementCacheEntry = this.applicationCacheEnd;
/* 112 */       for (; this.numElements > paramInt; oracleStatementCacheEntry = oracleStatementCacheEntry.applicationPrev) {
/* 113 */         purgeCacheEntry(oracleStatementCacheEntry);
/*     */       }
/* 115 */       this.cacheSize = paramInt;
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void setImplicitCachingEnabled(boolean paramBoolean) throws SQLException {
/* 138 */     if (!paramBoolean) {
/* 139 */       purgeImplicitCache();
/*     */     }
/* 141 */     this.implicitCacheEnabled = paramBoolean;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public boolean getImplicitCachingEnabled() throws SQLException {
/*     */     boolean bool;
/* 156 */     if (this.cacheSize == 0) {
/* 157 */       bool = false;
/*     */     } else {
/* 159 */       bool = this.implicitCacheEnabled;
/*     */     } 
/*     */ 
/*     */ 
/*     */     
/* 164 */     return bool;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void setExplicitCachingEnabled(boolean paramBoolean) throws SQLException {
/* 183 */     if (!paramBoolean) {
/* 184 */       purgeExplicitCache();
/*     */     }
/* 186 */     this.explicitCacheEnabled = paramBoolean;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public boolean getExplicitCachingEnabled() throws SQLException {
/*     */     boolean bool;
/* 201 */     if (this.cacheSize == 0) {
/* 202 */       bool = false;
/*     */     } else {
/* 204 */       bool = this.explicitCacheEnabled;
/*     */     } 
/*     */ 
/*     */ 
/*     */     
/* 209 */     return bool;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void addToImplicitCache(OraclePreparedStatement paramOraclePreparedStatement, String paramString, int paramInt1, int paramInt2) throws SQLException {
/* 233 */     if (!this.implicitCacheEnabled || this.cacheSize == 0 || paramOraclePreparedStatement.cacheState == 2) {
/*     */       return;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 245 */     if (this.numElements == this.cacheSize) {
/* 246 */       purgeCacheEntry(this.applicationCacheEnd);
/*     */     }
/*     */ 
/*     */     
/* 250 */     paramOraclePreparedStatement.enterImplicitCache();
/*     */ 
/*     */     
/* 253 */     OracleStatementCacheEntry oracleStatementCacheEntry = new OracleStatementCacheEntry();
/*     */     
/* 255 */     oracleStatementCacheEntry.statement = paramOraclePreparedStatement;
/* 256 */     oracleStatementCacheEntry.onImplicit = true;
/*     */     
/* 258 */     oracleStatementCacheEntry.sql = paramString;
/* 259 */     oracleStatementCacheEntry.statementType = paramInt1;
/* 260 */     oracleStatementCacheEntry.scrollType = paramInt2;
/*     */ 
/*     */     
/* 263 */     oracleStatementCacheEntry.applicationNext = this.applicationCacheStart;
/* 264 */     oracleStatementCacheEntry.applicationPrev = null;
/*     */     
/* 266 */     if (this.applicationCacheStart != null) {
/* 267 */       this.applicationCacheStart.applicationPrev = oracleStatementCacheEntry;
/*     */     }
/* 269 */     this.applicationCacheStart = oracleStatementCacheEntry;
/*     */     
/* 271 */     oracleStatementCacheEntry.implicitNext = this.implicitCacheStart;
/* 272 */     oracleStatementCacheEntry.implicitPrev = null;
/*     */     
/* 274 */     if (this.implicitCacheStart != null) {
/* 275 */       this.implicitCacheStart.implicitPrev = oracleStatementCacheEntry;
/*     */     }
/* 277 */     this.implicitCacheStart = oracleStatementCacheEntry;
/*     */ 
/*     */     
/* 280 */     if (this.applicationCacheEnd == null) {
/* 281 */       this.applicationCacheEnd = oracleStatementCacheEntry;
/*     */     }
/*     */ 
/*     */     
/* 285 */     this.numElements++;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void addToExplicitCache(OraclePreparedStatement paramOraclePreparedStatement, String paramString) throws SQLException {
/* 306 */     if (!this.explicitCacheEnabled || this.cacheSize == 0 || paramOraclePreparedStatement.cacheState == 2) {
/*     */       return;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 318 */     if (this.numElements == this.cacheSize) {
/* 319 */       purgeCacheEntry(this.applicationCacheEnd);
/*     */     }
/*     */ 
/*     */     
/* 323 */     paramOraclePreparedStatement.enterExplicitCache();
/*     */ 
/*     */     
/* 326 */     OracleStatementCacheEntry oracleStatementCacheEntry = new OracleStatementCacheEntry();
/*     */     
/* 328 */     oracleStatementCacheEntry.statement = paramOraclePreparedStatement;
/* 329 */     oracleStatementCacheEntry.sql = paramString;
/* 330 */     oracleStatementCacheEntry.onImplicit = false;
/*     */ 
/*     */     
/* 333 */     oracleStatementCacheEntry.applicationNext = this.applicationCacheStart;
/* 334 */     oracleStatementCacheEntry.applicationPrev = null;
/*     */     
/* 336 */     if (this.applicationCacheStart != null) {
/* 337 */       this.applicationCacheStart.applicationPrev = oracleStatementCacheEntry;
/*     */     }
/* 339 */     this.applicationCacheStart = oracleStatementCacheEntry;
/*     */     
/* 341 */     oracleStatementCacheEntry.explicitNext = this.explicitCacheStart;
/* 342 */     oracleStatementCacheEntry.explicitPrev = null;
/*     */     
/* 344 */     if (this.explicitCacheStart != null) {
/* 345 */       this.explicitCacheStart.explicitPrev = oracleStatementCacheEntry;
/*     */     }
/* 347 */     this.explicitCacheStart = oracleStatementCacheEntry;
/*     */ 
/*     */     
/* 350 */     if (this.applicationCacheEnd == null) {
/* 351 */       this.applicationCacheEnd = oracleStatementCacheEntry;
/*     */     }
/*     */ 
/*     */     
/* 355 */     this.numElements++;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected OracleStatement searchImplicitCache(String paramString, int paramInt1, int paramInt2) throws SQLException {
/* 381 */     if (!this.implicitCacheEnabled)
/*     */     {
/*     */ 
/*     */ 
/*     */ 
/*     */       
/* 387 */       return null;
/*     */     }
/*     */ 
/*     */     
/* 391 */     OracleStatementCacheEntry oracleStatementCacheEntry = null;
/*     */     
/* 393 */     for (oracleStatementCacheEntry = this.implicitCacheStart; oracleStatementCacheEntry != null; oracleStatementCacheEntry = oracleStatementCacheEntry.implicitNext) {
/*     */       
/* 395 */       if (oracleStatementCacheEntry.statementType == paramInt1 && oracleStatementCacheEntry.scrollType == paramInt2 && oracleStatementCacheEntry.sql.equals(paramString)) {
/*     */         break;
/*     */       }
/*     */     } 
/*     */     
/* 400 */     if (oracleStatementCacheEntry != null) {
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */       
/* 411 */       if (oracleStatementCacheEntry.applicationPrev != null) {
/* 412 */         oracleStatementCacheEntry.applicationPrev.applicationNext = oracleStatementCacheEntry.applicationNext;
/*     */       }
/* 414 */       if (oracleStatementCacheEntry.applicationNext != null) {
/* 415 */         oracleStatementCacheEntry.applicationNext.applicationPrev = oracleStatementCacheEntry.applicationPrev;
/*     */       }
/* 417 */       if (this.applicationCacheStart == oracleStatementCacheEntry) {
/* 418 */         this.applicationCacheStart = oracleStatementCacheEntry.applicationNext;
/*     */       }
/* 420 */       if (this.applicationCacheEnd == oracleStatementCacheEntry) {
/* 421 */         this.applicationCacheEnd = oracleStatementCacheEntry.applicationPrev;
/*     */       }
/* 423 */       if (oracleStatementCacheEntry.implicitPrev != null) {
/* 424 */         oracleStatementCacheEntry.implicitPrev.implicitNext = oracleStatementCacheEntry.implicitNext;
/*     */       }
/* 426 */       if (oracleStatementCacheEntry.implicitNext != null) {
/* 427 */         oracleStatementCacheEntry.implicitNext.implicitPrev = oracleStatementCacheEntry.implicitPrev;
/*     */       }
/* 429 */       if (this.implicitCacheStart == oracleStatementCacheEntry) {
/* 430 */         this.implicitCacheStart = oracleStatementCacheEntry.implicitNext;
/*     */       }
/*     */ 
/*     */       
/* 434 */       this.numElements--;
/*     */ 
/*     */       
/* 437 */       oracleStatementCacheEntry.statement.exitImplicitCacheToActive();
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */       
/* 444 */       return oracleStatementCacheEntry.statement;
/*     */     } 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 457 */     return null;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected OracleStatement searchExplicitCache(String paramString) throws SQLException {
/* 477 */     if (!this.explicitCacheEnabled)
/*     */     {
/*     */ 
/*     */ 
/*     */ 
/*     */       
/* 483 */       return null;
/*     */     }
/*     */ 
/*     */     
/* 487 */     OracleStatementCacheEntry oracleStatementCacheEntry = null;
/*     */     
/* 489 */     for (oracleStatementCacheEntry = this.explicitCacheStart; oracleStatementCacheEntry != null; oracleStatementCacheEntry = oracleStatementCacheEntry.explicitNext) {
/*     */       
/* 491 */       if (oracleStatementCacheEntry.sql.equals(paramString)) {
/*     */         break;
/*     */       }
/*     */     } 
/* 495 */     if (oracleStatementCacheEntry != null) {
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */       
/* 506 */       if (oracleStatementCacheEntry.applicationPrev != null) {
/* 507 */         oracleStatementCacheEntry.applicationPrev.applicationNext = oracleStatementCacheEntry.applicationNext;
/*     */       }
/* 509 */       if (oracleStatementCacheEntry.applicationNext != null) {
/* 510 */         oracleStatementCacheEntry.applicationNext.applicationPrev = oracleStatementCacheEntry.applicationPrev;
/*     */       }
/* 512 */       if (this.applicationCacheStart == oracleStatementCacheEntry) {
/* 513 */         this.applicationCacheStart = oracleStatementCacheEntry.applicationNext;
/*     */       }
/* 515 */       if (this.applicationCacheEnd == oracleStatementCacheEntry) {
/* 516 */         this.applicationCacheEnd = oracleStatementCacheEntry.applicationPrev;
/*     */       }
/* 518 */       if (oracleStatementCacheEntry.explicitPrev != null) {
/* 519 */         oracleStatementCacheEntry.explicitPrev.explicitNext = oracleStatementCacheEntry.explicitNext;
/*     */       }
/* 521 */       if (oracleStatementCacheEntry.explicitNext != null) {
/* 522 */         oracleStatementCacheEntry.explicitNext.explicitPrev = oracleStatementCacheEntry.explicitPrev;
/*     */       }
/* 524 */       if (this.explicitCacheStart == oracleStatementCacheEntry) {
/* 525 */         this.explicitCacheStart = oracleStatementCacheEntry.explicitNext;
/*     */       }
/*     */ 
/*     */       
/* 529 */       this.numElements--;
/*     */ 
/*     */       
/* 532 */       oracleStatementCacheEntry.statement.exitExplicitCacheToActive();
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */       
/* 538 */       return oracleStatementCacheEntry.statement;
/*     */     } 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 549 */     return null;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void purgeImplicitCache() throws SQLException {
/* 566 */     for (OracleStatementCacheEntry oracleStatementCacheEntry = this.implicitCacheStart; oracleStatementCacheEntry != null; 
/* 567 */       oracleStatementCacheEntry = oracleStatementCacheEntry.implicitNext) {
/* 568 */       purgeCacheEntry(oracleStatementCacheEntry);
/*     */     }
/* 570 */     this.implicitCacheStart = null;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void purgeExplicitCache() throws SQLException {
/* 587 */     for (OracleStatementCacheEntry oracleStatementCacheEntry = this.explicitCacheStart; oracleStatementCacheEntry != null; 
/* 588 */       oracleStatementCacheEntry = oracleStatementCacheEntry.explicitNext) {
/* 589 */       purgeCacheEntry(oracleStatementCacheEntry);
/*     */     }
/* 591 */     this.explicitCacheStart = null;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private void purgeCacheEntry(OracleStatementCacheEntry paramOracleStatementCacheEntry) throws SQLException {
/* 610 */     if (paramOracleStatementCacheEntry.applicationNext != null) {
/* 611 */       paramOracleStatementCacheEntry.applicationNext.applicationPrev = paramOracleStatementCacheEntry.applicationPrev;
/*     */     }
/* 613 */     if (paramOracleStatementCacheEntry.applicationPrev != null) {
/* 614 */       paramOracleStatementCacheEntry.applicationPrev.applicationNext = paramOracleStatementCacheEntry.applicationNext;
/*     */     }
/* 616 */     if (this.applicationCacheStart == paramOracleStatementCacheEntry) {
/* 617 */       this.applicationCacheStart = paramOracleStatementCacheEntry.applicationNext;
/*     */     }
/* 619 */     if (this.applicationCacheEnd == paramOracleStatementCacheEntry) {
/* 620 */       this.applicationCacheEnd = paramOracleStatementCacheEntry.applicationPrev;
/*     */     }
/* 622 */     if (paramOracleStatementCacheEntry.onImplicit) {
/*     */       
/* 624 */       if (paramOracleStatementCacheEntry.implicitNext != null) {
/* 625 */         paramOracleStatementCacheEntry.implicitNext.implicitPrev = paramOracleStatementCacheEntry.implicitPrev;
/*     */       }
/* 627 */       if (paramOracleStatementCacheEntry.implicitPrev != null) {
/* 628 */         paramOracleStatementCacheEntry.implicitPrev.implicitNext = paramOracleStatementCacheEntry.implicitNext;
/*     */       }
/* 630 */       if (this.implicitCacheStart == paramOracleStatementCacheEntry) {
/* 631 */         this.implicitCacheStart = paramOracleStatementCacheEntry.implicitNext;
/*     */       }
/*     */     } else {
/*     */       
/* 635 */       if (paramOracleStatementCacheEntry.explicitNext != null) {
/* 636 */         paramOracleStatementCacheEntry.explicitNext.explicitPrev = paramOracleStatementCacheEntry.explicitPrev;
/*     */       }
/* 638 */       if (paramOracleStatementCacheEntry.explicitPrev != null) {
/* 639 */         paramOracleStatementCacheEntry.explicitPrev.explicitNext = paramOracleStatementCacheEntry.explicitNext;
/*     */       }
/* 641 */       if (this.explicitCacheStart == paramOracleStatementCacheEntry) {
/* 642 */         this.explicitCacheStart = paramOracleStatementCacheEntry.explicitNext;
/*     */       }
/*     */     } 
/*     */     
/* 646 */     this.numElements--;
/*     */ 
/*     */     
/* 649 */     if (paramOracleStatementCacheEntry.onImplicit) {
/* 650 */       paramOracleStatementCacheEntry.statement.exitImplicitCacheToClose();
/*     */     } else {
/* 652 */       paramOracleStatementCacheEntry.statement.exitExplicitCacheToClose();
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public int getCacheSize() {
/* 665 */     return this.cacheSize;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void printCache(String paramString) throws SQLException {
/* 681 */     System.out.println("*** Start of Statement Cache Dump (" + paramString + ") ***");
/* 682 */     System.out.println("cache size: " + this.cacheSize + " num elements: " + this.numElements + " implicit enabled: " + this.implicitCacheEnabled + " explicit enabled: " + this.explicitCacheEnabled);
/*     */ 
/*     */ 
/*     */     
/* 686 */     System.out.println("applicationStart: " + this.applicationCacheStart + "  applicationEnd: " + this.applicationCacheEnd);
/*     */     
/*     */     OracleStatementCacheEntry oracleStatementCacheEntry;
/* 689 */     for (oracleStatementCacheEntry = this.applicationCacheStart; oracleStatementCacheEntry != null; oracleStatementCacheEntry = oracleStatementCacheEntry.applicationNext) {
/* 690 */       oracleStatementCacheEntry.print();
/*     */     }
/* 692 */     System.out.println("implicitStart: " + this.implicitCacheStart);
/*     */     
/* 694 */     for (oracleStatementCacheEntry = this.implicitCacheStart; oracleStatementCacheEntry != null; oracleStatementCacheEntry = oracleStatementCacheEntry.implicitNext) {
/* 695 */       oracleStatementCacheEntry.print();
/*     */     }
/* 697 */     System.out.println("explicitStart: " + this.explicitCacheStart);
/*     */     
/* 699 */     for (oracleStatementCacheEntry = this.explicitCacheStart; oracleStatementCacheEntry != null; oracleStatementCacheEntry = oracleStatementCacheEntry.explicitNext) {
/* 700 */       oracleStatementCacheEntry.print();
/*     */     }
/* 702 */     System.out.println("*** End of Statement Cache Dump (" + paramString + ") ***");
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void close() throws SQLException {
/* 718 */     OracleStatementCacheEntry oracleStatementCacheEntry = this.applicationCacheStart;
/* 719 */     for (; oracleStatementCacheEntry != null; oracleStatementCacheEntry = oracleStatementCacheEntry.applicationNext) {
/*     */ 
/*     */ 
/*     */       
/* 723 */       if (oracleStatementCacheEntry.onImplicit) {
/* 724 */         oracleStatementCacheEntry.statement.exitImplicitCacheToClose();
/*     */       } else {
/* 726 */         oracleStatementCacheEntry.statement.exitExplicitCacheToClose();
/*     */       } 
/*     */     } 
/*     */ 
/*     */ 
/*     */     
/* 732 */     this.applicationCacheStart = null;
/* 733 */     this.applicationCacheEnd = null;
/* 734 */     this.implicitCacheStart = null;
/* 735 */     this.explicitCacheStart = null;
/* 736 */     this.numElements = 0;
/*     */   }
/*     */ 
/*     */ 
/*     */   
/* 741 */   private static final String _Copyright_2004_Oracle_All_Rights_Reserved_ = null;
/*     */   public static final boolean TRACE = false;
/*     */   public static final boolean PRIVATE_TRACE = false;
/*     */   public static final String BUILD_DATE = "Sat_Feb__2_11:39:35_PST_2008";
/*     */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\lib\ojdbc14.jar!\oracle\jdbc\driver\LRUStatementCache.class
 * Java compiler version: 2 (46.0)
 * JD-Core Version:       1.1.3
 */