/*     */ package oracle.jdbc.driver;
/*     */ 
/*     */ import java.io.IOException;
/*     */ import java.io.Reader;
/*     */ import java.sql.SQLException;
/*     */ import oracle.sql.CLOB;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class OracleClobReader
/*     */   extends Reader
/*     */ {
/*     */   CLOB clob;
/*     */   DBConversion dbConversion;
/*     */   long lobOffset;
/*     */   long markedChar;
/*     */   char[] buf;
/*     */   int pos;
/*     */   int count;
/*     */   int chunkSize;
/*     */   boolean isClosed;
/*     */   boolean endOfStream;
/*     */   
/*     */   public OracleClobReader(CLOB paramCLOB) throws SQLException {
/*  49 */     this(paramCLOB, ((PhysicalConnection)paramCLOB.getInternalConnection()).getDefaultStreamChunkSize() / 3);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public OracleClobReader(CLOB paramCLOB, int paramInt) throws SQLException {
/*  66 */     this(paramCLOB, paramInt, 1L);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public OracleClobReader(CLOB paramCLOB, int paramInt, long paramLong) throws SQLException {
/*  87 */     if (paramCLOB == null || paramInt <= 0 || paramCLOB.getInternalConnection() == null || paramLong < 1L)
/*     */     {
/*     */       
/*  90 */       throw new IllegalArgumentException("Illegal Arguments");
/*     */     }
/*     */     
/*  93 */     this.dbConversion = ((PhysicalConnection)paramCLOB.getInternalConnection()).conversion;
/*     */ 
/*     */     
/*  96 */     this.clob = paramCLOB;
/*  97 */     this.lobOffset = paramLong;
/*  98 */     this.markedChar = -1L;
/*     */     
/* 100 */     this.buf = new char[paramInt];
/* 101 */     this.pos = this.count = 0;
/* 102 */     this.chunkSize = paramInt;
/*     */     
/* 104 */     this.isClosed = false;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public int read(char[] paramArrayOfchar, int paramInt1, int paramInt2) throws IOException {
/* 127 */     ensureOpen();
/*     */     
/* 129 */     if (!needChars()) {
/* 130 */       return -1;
/*     */     }
/* 132 */     int i = paramInt1;
/* 133 */     int j = i + Math.min(paramInt2, paramArrayOfchar.length - paramInt1);
/*     */     
/* 135 */     i += writeChars(paramArrayOfchar, i, j - i);
/*     */     
/* 137 */     while (i < j && needChars())
/*     */     {
/* 139 */       i += writeChars(paramArrayOfchar, i, j - i);
/*     */     }
/*     */     
/* 142 */     return i - paramInt1;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected boolean needChars() throws IOException {
/* 157 */     ensureOpen();
/*     */     
/* 159 */     if (this.pos >= this.count) {
/*     */       
/* 161 */       if (!this.endOfStream) {
/*     */         
/*     */         try {
/*     */ 
/*     */ 
/*     */           
/* 167 */           this.count = this.clob.getChars(this.lobOffset, this.chunkSize, this.buf);
/*     */ 
/*     */           
/* 170 */           if (this.count < this.chunkSize) {
/* 171 */             this.endOfStream = true;
/*     */           }
/* 173 */           if (this.count > 0)
/*     */           {
/* 175 */             this.pos = 0;
/* 176 */             this.lobOffset += this.count;
/*     */             
/* 178 */             return true;
/*     */           }
/*     */         
/* 181 */         } catch (SQLException sQLException) {
/*     */           
/* 183 */           DatabaseError.SQLToIOException(sQLException);
/*     */         } 
/*     */       }
/*     */       
/* 187 */       return false;
/*     */     } 
/*     */     
/* 190 */     return true;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected int writeChars(char[] paramArrayOfchar, int paramInt1, int paramInt2) {
/* 206 */     int i = Math.min(paramInt2, this.count - this.pos);
/*     */     
/* 208 */     System.arraycopy(this.buf, this.pos, paramArrayOfchar, paramInt1, i);
/*     */     
/* 210 */     this.pos += i;
/*     */     
/* 212 */     return i;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public boolean ready() throws IOException {
/* 230 */     ensureOpen();
/*     */     
/* 232 */     return (this.pos < this.count);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void close() throws IOException {
/* 248 */     this.isClosed = true;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   void ensureOpen() throws IOException {
/*     */     try {
/* 264 */       if (this.isClosed) {
/* 265 */         DatabaseError.throwSqlException(57, null);
/*     */       }
/* 267 */     } catch (SQLException sQLException) {
/*     */       
/* 269 */       DatabaseError.SQLToIOException(sQLException);
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public boolean markSupported() {
/* 282 */     return true;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void mark(int paramInt) throws IOException {
/* 304 */     if (paramInt < 0) {
/* 305 */       throw new IllegalArgumentException("Read-ahead limit < 0");
/*     */     }
/* 307 */     this.markedChar = this.lobOffset - this.count + this.pos;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void reset() throws IOException {
/* 329 */     ensureOpen();
/*     */     
/* 331 */     if (this.markedChar < 0L) {
/* 332 */       throw new IOException("Mark invalid or stream not marked.");
/*     */     }
/* 334 */     this.lobOffset = this.markedChar;
/* 335 */     this.pos = this.count;
/* 336 */     this.endOfStream = false;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public long skip(long paramLong) throws IOException {
/* 355 */     ensureOpen();
/*     */     
/* 357 */     long l = 0L;
/*     */     
/* 359 */     if ((this.count - this.pos) >= paramLong) {
/*     */       
/* 361 */       this.pos = (int)(this.pos + paramLong);
/* 362 */       l += paramLong;
/*     */     }
/*     */     else {
/*     */       
/* 366 */       l += (this.count - this.pos);
/* 367 */       this.pos = this.count;
/*     */ 
/*     */       
/*     */       try {
/* 371 */         long l1 = this.clob.length() - this.lobOffset + 1L;
/*     */         
/* 373 */         if (l1 >= paramLong - l)
/*     */         {
/* 375 */           this.lobOffset += paramLong - l;
/* 376 */           l += paramLong - l;
/*     */         }
/*     */         else
/*     */         {
/* 380 */           this.lobOffset += l1;
/* 381 */           l += l1;
/*     */         }
/*     */       
/* 384 */       } catch (SQLException sQLException) {
/*     */         
/* 386 */         DatabaseError.SQLToIOException(sQLException);
/*     */       } 
/*     */     } 
/*     */     
/* 390 */     return l;
/*     */   }
/*     */ 
/*     */ 
/*     */   
/* 395 */   private static final String _Copyright_2004_Oracle_All_Rights_Reserved_ = null;
/*     */   public static final boolean TRACE = false;
/*     */   public static final boolean PRIVATE_TRACE = false;
/*     */   public static final String BUILD_DATE = "Sat_Feb__2_11:39:36_PST_2008";
/*     */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\lib\ojdbc14.jar!\oracle\jdbc\driver\OracleClobReader.class
 * Java compiler version: 2 (46.0)
 * JD-Core Version:       1.1.3
 */