/*      */ package oracle.jdbc.driver;
/*      */ 
/*      */ import java.io.ByteArrayInputStream;
/*      */ import java.io.IOException;
/*      */ import java.io.InputStream;
/*      */ import java.io.Reader;
/*      */ import java.math.BigDecimal;
/*      */ import java.net.MalformedURLException;
/*      */ import java.net.URL;
/*      */ import java.sql.Array;
/*      */ import java.sql.Blob;
/*      */ import java.sql.Clob;
/*      */ import java.sql.Connection;
/*      */ import java.sql.Date;
/*      */ import java.sql.Ref;
/*      */ import java.sql.ResultSet;
/*      */ import java.sql.ResultSetMetaData;
/*      */ import java.sql.SQLException;
/*      */ import java.sql.Statement;
/*      */ import java.sql.Time;
/*      */ import java.sql.Timestamp;
/*      */ import java.util.Calendar;
/*      */ import java.util.Map;
/*      */ import java.util.Vector;
/*      */ import oracle.sql.ARRAY;
/*      */ import oracle.sql.BFILE;
/*      */ import oracle.sql.BLOB;
/*      */ import oracle.sql.CHAR;
/*      */ import oracle.sql.CLOB;
/*      */ import oracle.sql.CustomDatum;
/*      */ import oracle.sql.CustomDatumFactory;
/*      */ import oracle.sql.DATE;
/*      */ import oracle.sql.Datum;
/*      */ import oracle.sql.INTERVALDS;
/*      */ import oracle.sql.INTERVALYM;
/*      */ import oracle.sql.NUMBER;
/*      */ import oracle.sql.OPAQUE;
/*      */ import oracle.sql.ORAData;
/*      */ import oracle.sql.ORADataFactory;
/*      */ import oracle.sql.RAW;
/*      */ import oracle.sql.REF;
/*      */ import oracle.sql.ROWID;
/*      */ import oracle.sql.STRUCT;
/*      */ import oracle.sql.TIMESTAMP;
/*      */ import oracle.sql.TIMESTAMPLTZ;
/*      */ import oracle.sql.TIMESTAMPTZ;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ class ScrollableResultSet
/*      */   extends BaseResultSet
/*      */ {
/*      */   PhysicalConnection connection;
/*      */   OracleResultSetImpl resultSet;
/*      */   ScrollRsetStatement scrollStmt;
/*      */   ResultSetMetaData metadata;
/*      */   private int rsetType;
/*      */   private int rsetConcurency;
/*      */   private int beginColumnIndex;
/*      */   private int columnCount;
/*      */   private int wasNull;
/*      */   OracleResultSetCache rsetCache;
/*      */   int currentRow;
/*      */   private int numRowsCached;
/*      */   private boolean allRowsCached;
/*      */   private int lastRefetchSz;
/*      */   private Vector refetchRowids;
/*      */   private OraclePreparedStatement refetchStmt;
/*      */   private int usrFetchDirection;
/*      */   
/*      */   ScrollableResultSet(ScrollRsetStatement paramScrollRsetStatement, OracleResultSetImpl paramOracleResultSetImpl, int paramInt1, int paramInt2) throws SQLException {
/*   75 */     this.connection = ((OracleStatement)paramScrollRsetStatement).connection;
/*   76 */     this.resultSet = paramOracleResultSetImpl;
/*   77 */     this.metadata = null;
/*   78 */     this.scrollStmt = paramScrollRsetStatement;
/*   79 */     this.rsetType = paramInt1;
/*   80 */     this.rsetConcurency = paramInt2;
/*   81 */     this.autoRefetch = paramScrollRsetStatement.getAutoRefetch();
/*   82 */     this.beginColumnIndex = needIdentifier(paramInt1, paramInt2) ? 1 : 0;
/*   83 */     this.columnCount = 0;
/*   84 */     this.wasNull = -1;
/*   85 */     this.rsetCache = paramScrollRsetStatement.getResultSetCache();
/*      */     
/*   87 */     if (this.rsetCache == null) {
/*      */       
/*   89 */       this.rsetCache = new OracleResultSetCacheImpl();
/*      */     } else {
/*      */ 
/*      */       
/*      */       try {
/*      */         
/*   95 */         this.rsetCache.clear();
/*      */       }
/*   97 */       catch (IOException iOException) {
/*      */         
/*   99 */         DatabaseError.throwSqlException(iOException);
/*      */       } 
/*      */     } 
/*      */     
/*  103 */     this.currentRow = 0;
/*  104 */     this.numRowsCached = 0;
/*  105 */     this.allRowsCached = false;
/*  106 */     this.lastRefetchSz = 0;
/*  107 */     this.refetchRowids = null;
/*  108 */     this.refetchStmt = null;
/*  109 */     this.usrFetchDirection = 1000;
/*  110 */     getInternalMetadata();
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void close() throws SQLException {
/*  122 */     synchronized (this.connection) {
/*      */       
/*  124 */       synchronized (this) {
/*      */ 
/*      */ 
/*      */ 
/*      */         
/*  129 */         if (this.resultSet != null) {
/*  130 */           this.resultSet.close();
/*      */         }
/*  132 */         if (this.refetchStmt != null) {
/*  133 */           this.refetchStmt.close();
/*      */         }
/*  135 */         if (this.scrollStmt != null) {
/*  136 */           this.scrollStmt.notifyCloseRset();
/*      */         }
/*  138 */         if (this.refetchRowids != null) {
/*  139 */           this.refetchRowids.removeAllElements();
/*      */         }
/*  141 */         this.resultSet = null;
/*  142 */         this.scrollStmt = null;
/*  143 */         this.refetchStmt = null;
/*  144 */         this.refetchRowids = null;
/*  145 */         this.metadata = null;
/*      */ 
/*      */         
/*      */         try {
/*  149 */           if (this.rsetCache != null)
/*      */           {
/*  151 */             this.rsetCache.clear();
/*  152 */             this.rsetCache.close();
/*      */           }
/*      */         
/*  155 */         } catch (IOException iOException) {
/*      */           
/*  157 */           DatabaseError.throwSqlException(iOException);
/*      */         } 
/*      */         
/*  160 */         this.rsetCache = null;
/*      */       } 
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized boolean wasNull() throws SQLException {
/*  171 */     if (this.wasNull == -1) {
/*  172 */       DatabaseError.throwSqlException(24);
/*      */     }
/*  174 */     return (this.wasNull == 1);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized Statement getStatement() throws SQLException {
/*  184 */     return (Statement)this.scrollStmt;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   synchronized void resetBeginColumnIndex() {
/*  196 */     this.beginColumnIndex = 0;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   synchronized ResultSet getResultSet() {
/*  208 */     return (ResultSet)this.resultSet;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   synchronized int removeRowInCache(int paramInt) throws SQLException {
/*  217 */     if (!isEmptyResultSet() && isValidRow(paramInt)) {
/*      */       
/*  219 */       removeCachedRowAt(paramInt);
/*      */       
/*  221 */       this.numRowsCached--;
/*      */       
/*  223 */       if (paramInt >= this.currentRow) {
/*  224 */         this.currentRow--;
/*      */       }
/*  226 */       return 1;
/*      */     } 
/*      */     
/*  229 */     return 0;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   int refreshRowsInCache(int paramInt1, int paramInt2, int paramInt3) throws SQLException {
/*  242 */     synchronized (this.connection) {
/*      */       
/*  244 */       synchronized (this) {
/*      */         
/*  246 */         OracleResultSet oracleResultSet = null;
/*  247 */         int i = 0;
/*      */ 
/*      */         
/*  250 */         i = get_refetch_size(paramInt1, paramInt2, paramInt3);
/*      */ 
/*      */         
/*      */         try {
/*  254 */           if (i > 0)
/*      */           {
/*      */ 
/*      */             
/*  258 */             if (i != this.lastRefetchSz) {
/*      */               
/*  260 */               if (this.refetchStmt != null) {
/*  261 */                 this.refetchStmt.close();
/*      */               }
/*  263 */               this.refetchStmt = prepare_refetch_statement(i);
/*  264 */               this.refetchStmt.setQueryTimeout(((OracleStatement)this.scrollStmt).getQueryTimeout());
/*  265 */               this.lastRefetchSz = i;
/*      */             } 
/*      */ 
/*      */             
/*  269 */             prepare_refetch_binds(this.refetchStmt, i);
/*      */ 
/*      */             
/*  272 */             oracleResultSet = (OracleResultSet)this.refetchStmt.executeQuery();
/*      */ 
/*      */             
/*  275 */             save_refetch_results(oracleResultSet, paramInt1, i, paramInt3);
/*      */           }
/*      */         
/*      */         }
/*      */         finally {
/*      */           
/*  281 */           if (oracleResultSet != null) {
/*  282 */             oracleResultSet.close();
/*      */           }
/*      */         } 
/*  285 */         return i;
/*      */       } 
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized boolean next() throws SQLException {
/*  300 */     if (isEmptyResultSet())
/*      */     {
/*  302 */       return false;
/*      */     }
/*      */ 
/*      */     
/*  306 */     if (this.currentRow < 1) {
/*      */       
/*  308 */       this.currentRow = 1;
/*      */     }
/*      */     else {
/*      */       
/*  312 */       this.currentRow++;
/*      */     } 
/*      */     
/*  315 */     return isValidRow(this.currentRow);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized boolean isBeforeFirst() throws SQLException {
/*  325 */     return (!isEmptyResultSet() && this.currentRow < 1);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized boolean isAfterLast() throws SQLException {
/*  334 */     return (!isEmptyResultSet() && this.currentRow > 0 && !isValidRow(this.currentRow));
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized boolean isFirst() throws SQLException {
/*  343 */     return (this.currentRow == 1);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized boolean isLast() throws SQLException {
/*  352 */     return (!isEmptyResultSet() && isValidRow(this.currentRow) && !isValidRow(this.currentRow + 1));
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void beforeFirst() throws SQLException {
/*  362 */     if (!isEmptyResultSet()) {
/*  363 */       this.currentRow = 0;
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void afterLast() throws SQLException {
/*  372 */     if (!isEmptyResultSet()) {
/*  373 */       this.currentRow = getLastRow() + 1;
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized boolean first() throws SQLException {
/*  382 */     if (isEmptyResultSet())
/*      */     {
/*  384 */       return false;
/*      */     }
/*      */ 
/*      */     
/*  388 */     this.currentRow = 1;
/*      */     
/*  390 */     return isValidRow(this.currentRow);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized boolean last() throws SQLException {
/*  400 */     if (isEmptyResultSet())
/*      */     {
/*  402 */       return false;
/*      */     }
/*      */ 
/*      */     
/*  406 */     this.currentRow = getLastRow();
/*      */     
/*  408 */     return isValidRow(this.currentRow);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized int getRow() throws SQLException {
/*  418 */     if (isValidRow(this.currentRow)) {
/*  419 */       return this.currentRow;
/*      */     }
/*  421 */     return 0;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized boolean absolute(int paramInt) throws SQLException {
/*  430 */     if (paramInt == 0) {
/*  431 */       DatabaseError.throwSqlException(68, "absolute (0)");
/*      */     }
/*      */     
/*  434 */     if (isEmptyResultSet())
/*      */     {
/*  436 */       return false;
/*      */     }
/*  438 */     if (paramInt > 0) {
/*      */       
/*  440 */       this.currentRow = paramInt;
/*      */     }
/*  442 */     else if (paramInt < 0) {
/*      */       
/*  444 */       this.currentRow = getLastRow() + 1 + paramInt;
/*      */     } 
/*      */     
/*  447 */     return isValidRow(this.currentRow);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized boolean relative(int paramInt) throws SQLException {
/*  456 */     if (isEmptyResultSet())
/*      */     {
/*  458 */       return false;
/*      */     }
/*  460 */     if (isValidRow(this.currentRow)) {
/*      */       
/*  462 */       this.currentRow += paramInt;
/*      */       
/*  464 */       return isValidRow(this.currentRow);
/*      */     } 
/*      */ 
/*      */     
/*  468 */     DatabaseError.throwSqlException(82, "relative");
/*      */ 
/*      */     
/*  471 */     return false;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized boolean previous() throws SQLException {
/*  481 */     if (isEmptyResultSet())
/*      */     {
/*  483 */       return false;
/*      */     }
/*  485 */     if (isAfterLast()) {
/*      */       
/*  487 */       this.currentRow = getLastRow();
/*      */     }
/*      */     else {
/*      */       
/*  491 */       this.currentRow--;
/*      */     } 
/*      */     
/*  494 */     return isValidRow(this.currentRow);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized Datum getOracleObject(int paramInt) throws SQLException {
/*  507 */     this.wasNull = -1;
/*      */     
/*  509 */     if (!isValidRow(this.currentRow)) {
/*  510 */       DatabaseError.throwSqlException(11);
/*      */     }
/*  512 */     if (paramInt < 1 || paramInt > getColumnCount()) {
/*  513 */       DatabaseError.throwSqlException(3);
/*      */     }
/*  515 */     Datum datum = getCachedDatumValueAt(this.currentRow, paramInt + this.beginColumnIndex);
/*      */ 
/*      */     
/*  518 */     this.wasNull = (datum == null) ? 1 : 0;
/*      */     
/*  520 */     return datum;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized String getString(int paramInt) throws SQLException {
/*  529 */     Datum datum = getOracleObject(paramInt);
/*      */     
/*  531 */     if (datum != null) {
/*      */       CLOB cLOB;
/*  533 */       switch (getInternalMetadata().getColumnType(paramInt + this.beginColumnIndex)) {
/*      */ 
/*      */         
/*      */         case 2005:
/*  537 */           cLOB = (CLOB)datum;
/*  538 */           return cLOB.getSubString(1L, (int)cLOB.length());
/*      */       } 
/*      */ 
/*      */ 
/*      */       
/*  543 */       return datum.stringValue();
/*      */     } 
/*      */ 
/*      */ 
/*      */     
/*  548 */     return null;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized boolean getBoolean(int paramInt) throws SQLException {
/*  557 */     Datum datum = getOracleObject(paramInt);
/*      */     
/*  559 */     if (datum != null)
/*      */     {
/*  561 */       return datum.booleanValue();
/*      */     }
/*      */     
/*  564 */     return false;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized byte getByte(int paramInt) throws SQLException {
/*  573 */     Datum datum = getOracleObject(paramInt);
/*      */     
/*  575 */     if (datum != null) {
/*  576 */       return datum.byteValue();
/*      */     }
/*  578 */     return 0;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized short getShort(int paramInt) throws SQLException {
/*  587 */     long l = getLong(paramInt);
/*      */     
/*  589 */     if (l > 65537L || l < -65538L) {
/*  590 */       DatabaseError.throwSqlException(26, "getShort");
/*      */     }
/*      */     
/*  593 */     return (short)(int)l;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized int getInt(int paramInt) throws SQLException {
/*  602 */     Datum datum = getOracleObject(paramInt);
/*      */     
/*  604 */     if (datum != null)
/*      */     {
/*  606 */       return datum.intValue();
/*      */     }
/*      */     
/*  609 */     return 0;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized long getLong(int paramInt) throws SQLException {
/*  618 */     Datum datum = getOracleObject(paramInt);
/*      */     
/*  620 */     if (datum != null)
/*      */     {
/*  622 */       return datum.longValue();
/*      */     }
/*      */     
/*  625 */     return 0L;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized float getFloat(int paramInt) throws SQLException {
/*  634 */     Datum datum = getOracleObject(paramInt);
/*      */     
/*  636 */     if (datum != null)
/*      */     {
/*  638 */       return datum.floatValue();
/*      */     }
/*      */     
/*  641 */     return 0.0F;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized double getDouble(int paramInt) throws SQLException {
/*  650 */     Datum datum = getOracleObject(paramInt);
/*      */     
/*  652 */     if (datum != null)
/*      */     {
/*  654 */       return datum.doubleValue();
/*      */     }
/*      */     
/*  657 */     return 0.0D;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized BigDecimal getBigDecimal(int paramInt1, int paramInt2) throws SQLException {
/*  667 */     Datum datum = getOracleObject(paramInt1);
/*      */     
/*  669 */     if (datum != null)
/*      */     {
/*  671 */       return datum.bigDecimalValue();
/*      */     }
/*      */     
/*  674 */     return null;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized byte[] getBytes(int paramInt) throws SQLException {
/*  683 */     Datum datum = getOracleObject(paramInt);
/*      */     
/*  685 */     if (datum != null) {
/*      */       
/*  687 */       if (datum instanceof RAW) {
/*  688 */         return ((RAW)datum).shareBytes();
/*      */       }
/*  690 */       DatabaseError.throwSqlException(4, "getBytes");
/*      */     } 
/*      */ 
/*      */     
/*  694 */     return null;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized Date getDate(int paramInt) throws SQLException {
/*  703 */     Datum datum = getOracleObject(paramInt);
/*  704 */     Date date = null;
/*      */     
/*  706 */     if (datum != null)
/*      */     
/*  708 */     { ResultSetMetaData resultSetMetaData = getInternalMetadata();
/*  709 */       switch (resultSetMetaData.getColumnType(paramInt + this.beginColumnIndex))
/*      */       
/*      */       { case 93:
/*  712 */           date = ((TIMESTAMP)datum).dateValue();
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */           
/*  729 */           return date;case -101: date = ((TIMESTAMPTZ)datum).dateValue((Connection)this.connection); return date;case -102: date = ((TIMESTAMPLTZ)datum).dateValue((Connection)this.connection); return date; }  date = datum.dateValue(); }  return date;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized Time getTime(int paramInt) throws SQLException {
/*  738 */     Datum datum = getOracleObject(paramInt);
/*  739 */     Time time = null;
/*      */     
/*  741 */     if (datum != null)
/*      */     
/*  743 */     { ResultSetMetaData resultSetMetaData = getInternalMetadata();
/*  744 */       switch (resultSetMetaData.getColumnType(paramInt + this.beginColumnIndex))
/*      */       
/*      */       { case 93:
/*  747 */           time = ((TIMESTAMP)datum).timeValue();
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */           
/*  764 */           return time;case -101: time = ((TIMESTAMPTZ)datum).timeValue((Connection)this.connection); return time;case -102: time = ((TIMESTAMPLTZ)datum).timeValue((Connection)this.connection); return time; }  time = datum.timeValue(); }  return time;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized Timestamp getTimestamp(int paramInt) throws SQLException {
/*  774 */     Datum datum = getOracleObject(paramInt);
/*  775 */     Timestamp timestamp = null;
/*      */     
/*  777 */     if (datum != null)
/*      */     
/*  779 */     { ResultSetMetaData resultSetMetaData = getInternalMetadata();
/*  780 */       switch (resultSetMetaData.getColumnType(paramInt + this.beginColumnIndex))
/*      */       
/*      */       { case 93:
/*  783 */           timestamp = ((TIMESTAMP)datum).timestampValue();
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */           
/*  801 */           return timestamp;case -101: timestamp = ((TIMESTAMPTZ)datum).timestampValue((Connection)this.connection); return timestamp;case -102: timestamp = ((TIMESTAMPLTZ)datum).timestampValue((Connection)this.connection, ((OracleStatement)this.scrollStmt).getDefaultCalendar()); return timestamp; }  timestamp = datum.timestampValue(); }  return timestamp;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized InputStream getAsciiStream(int paramInt) throws SQLException {
/*  811 */     Datum datum = getOracleObject(paramInt);
/*      */     
/*  813 */     if (datum != null)
/*      */     {
/*  815 */       return datum.asciiStreamValue();
/*      */     }
/*      */     
/*  818 */     return null;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized InputStream getUnicodeStream(int paramInt) throws SQLException {
/*  828 */     Datum datum = getOracleObject(paramInt);
/*      */     
/*  830 */     if (datum != null) {
/*      */       
/*  832 */       DBConversion dBConversion = this.connection.conversion;
/*  833 */       byte[] arrayOfByte = datum.shareBytes();
/*      */       
/*  835 */       if (datum instanceof RAW)
/*      */       {
/*  837 */         return dBConversion.ConvertStream(new ByteArrayInputStream(arrayOfByte), 3);
/*      */       }
/*      */       
/*  840 */       if (datum instanceof CHAR)
/*      */       {
/*  842 */         return dBConversion.ConvertStream(new ByteArrayInputStream(arrayOfByte), 1);
/*      */       }
/*      */ 
/*      */       
/*  846 */       DatabaseError.throwSqlException(4, "getUnicodeStream");
/*      */     } 
/*      */ 
/*      */     
/*  850 */     return null;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized InputStream getBinaryStream(int paramInt) throws SQLException {
/*  860 */     Datum datum = getOracleObject(paramInt);
/*      */     
/*  862 */     if (datum != null)
/*      */     {
/*  864 */       return datum.binaryStreamValue();
/*      */     }
/*      */     
/*  867 */     return null;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Object getObject(int paramInt) throws SQLException {
/*  877 */     return getObject(paramInt, this.connection.getTypeMap());
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized Reader getCharacterStream(int paramInt) throws SQLException {
/*  888 */     Datum datum = getOracleObject(paramInt);
/*      */     
/*  890 */     if (datum != null)
/*      */     {
/*  892 */       return datum.characterStreamValue();
/*      */     }
/*      */     
/*  895 */     return null;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public BigDecimal getBigDecimal(int paramInt) throws SQLException {
/*  905 */     return getBigDecimal(paramInt, 0);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized Object getObject(int paramInt, Map paramMap) throws SQLException {
/*  916 */     Datum datum = getOracleObject(paramInt);
/*      */     
/*  918 */     if (datum != null) {
/*      */       
/*  920 */       if (datum instanceof STRUCT) {
/*  921 */         return ((STRUCT)datum).toJdbc(paramMap);
/*      */       }
/*  923 */       return datum.toJdbc();
/*      */     } 
/*      */     
/*  926 */     return null;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized Ref getRef(int paramInt) throws SQLException {
/*  936 */     return (Ref)getREF(paramInt);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized Blob getBlob(int paramInt) throws SQLException {
/*  946 */     return (Blob)getBLOB(paramInt);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized Clob getClob(int paramInt) throws SQLException {
/*  956 */     return (Clob)getCLOB(paramInt);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized Array getArray(int paramInt) throws SQLException {
/*  967 */     return (Array)getARRAY(paramInt);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized Date getDate(int paramInt, Calendar paramCalendar) throws SQLException {
/*  977 */     Datum datum = getOracleObject(paramInt);
/*  978 */     Date date = null;
/*      */     
/*  980 */     if (datum != null)
/*      */     
/*  982 */     { ResultSetMetaData resultSetMetaData = getInternalMetadata();
/*  983 */       switch (resultSetMetaData.getColumnType(paramInt + this.beginColumnIndex))
/*      */       
/*      */       { case 93:
/*  986 */           date = new Date(((TIMESTAMP)datum).timestampValue().getTime());
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */           
/* 1009 */           return date;case -101: date = new Date(((TIMESTAMPTZ)datum).timestampValue((Connection)this.connection).getTime()); return date;case -102: date = new Date(((TIMESTAMPLTZ)datum).timestampValue((Connection)this.connection, paramCalendar).getTime()); return date;case 91: date = ((DATE)datum).dateValue(paramCalendar); return date; }  DatabaseError.throwSqlException(4, "getDate"); }  return date;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized Time getTime(int paramInt, Calendar paramCalendar) throws SQLException {
/* 1019 */     Datum datum = getOracleObject(paramInt);
/* 1020 */     Time time = null;
/*      */     
/* 1022 */     if (datum != null)
/*      */     
/* 1024 */     { ResultSetMetaData resultSetMetaData = getInternalMetadata();
/* 1025 */       switch (resultSetMetaData.getColumnType(paramInt + this.beginColumnIndex))
/*      */       
/*      */       { case 93:
/* 1028 */           time = new Time(((TIMESTAMP)datum).timestampValue().getTime());
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */           
/* 1049 */           return time;case -101: time = new Time(((TIMESTAMPTZ)datum).timestampValue((Connection)this.connection).getTime()); return time;case -102: time = new Time(((TIMESTAMPLTZ)datum).timestampValue((Connection)this.connection, paramCalendar).getTime()); return time;case 91: time = ((DATE)datum).timeValue(paramCalendar); return time; }  DatabaseError.throwSqlException(4, "getTime"); }  return time;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized Timestamp getTimestamp(int paramInt, Calendar paramCalendar) throws SQLException {
/* 1059 */     Datum datum = getOracleObject(paramInt);
/* 1060 */     Timestamp timestamp = null;
/*      */     
/* 1062 */     if (datum != null)
/*      */     
/* 1064 */     { ResultSetMetaData resultSetMetaData = getInternalMetadata();
/* 1065 */       switch (resultSetMetaData.getColumnType(paramInt + this.beginColumnIndex))
/*      */       
/*      */       { case 93:
/* 1068 */           timestamp = ((TIMESTAMP)datum).timestampValue();
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */           
/* 1089 */           return timestamp;case -101: timestamp = ((TIMESTAMPTZ)datum).timestampValue((Connection)this.connection); return timestamp;case -102: timestamp = ((TIMESTAMPLTZ)datum).timestampValue((Connection)this.connection, paramCalendar); return timestamp;case 91: timestamp = ((DATE)datum).timestampValue(paramCalendar); return timestamp; }  DatabaseError.throwSqlException(4, "getTimestamp"); }  return timestamp;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized URL getURL(int paramInt) throws SQLException {
/* 1099 */     URL uRL = null;
/*      */     
/* 1101 */     int i = getInternalMetadata().getColumnType(paramInt);
/* 1102 */     int j = SQLUtil.getInternalType(i);
/*      */ 
/*      */     
/* 1105 */     if (j == 96 || j == 1 || j == 8) {
/*      */       
/*      */       try
/*      */       {
/*      */         
/* 1110 */         uRL = new URL(getString(paramInt));
/*      */       }
/* 1112 */       catch (MalformedURLException malformedURLException)
/*      */       {
/* 1114 */         DatabaseError.throwSqlException(136);
/*      */       }
/*      */     
/*      */     } else {
/*      */       
/* 1119 */       throw new SQLException("Conversion to java.net.URL not supported.");
/*      */     } 
/*      */     
/* 1122 */     return uRL;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized ResultSet getCursor(int paramInt) throws SQLException {
/* 1132 */     DatabaseError.throwSqlException(4, "getCursor");
/*      */ 
/*      */     
/* 1135 */     return null;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized ROWID getROWID(int paramInt) throws SQLException {
/* 1145 */     Datum datum = getOracleObject(paramInt);
/*      */     
/* 1147 */     if (datum != null) {
/*      */       
/* 1149 */       if (datum instanceof ROWID) {
/* 1150 */         return (ROWID)datum;
/*      */       }
/* 1152 */       DatabaseError.throwSqlException(4, "getROWID");
/*      */     } 
/*      */ 
/*      */     
/* 1156 */     return null;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized NUMBER getNUMBER(int paramInt) throws SQLException {
/* 1166 */     Datum datum = getOracleObject(paramInt);
/*      */     
/* 1168 */     if (datum != null) {
/*      */       
/* 1170 */       if (datum instanceof NUMBER) {
/* 1171 */         return (NUMBER)datum;
/*      */       }
/* 1173 */       DatabaseError.throwSqlException(4, "getNUMBER");
/*      */     } 
/*      */ 
/*      */     
/* 1177 */     return null;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized DATE getDATE(int paramInt) throws SQLException {
/* 1187 */     Datum datum = getOracleObject(paramInt);
/*      */     
/* 1189 */     if (datum != null) {
/*      */       
/* 1191 */       if (datum instanceof DATE) {
/* 1192 */         return (DATE)datum;
/*      */       }
/* 1194 */       DatabaseError.throwSqlException(4, "getDATE");
/*      */     } 
/*      */ 
/*      */     
/* 1198 */     return null;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized TIMESTAMP getTIMESTAMP(int paramInt) throws SQLException {
/* 1208 */     Datum datum = getOracleObject(paramInt);
/*      */     
/* 1210 */     if (datum != null) {
/*      */       
/* 1212 */       if (datum instanceof TIMESTAMP) {
/* 1213 */         return (TIMESTAMP)datum;
/*      */       }
/* 1215 */       DatabaseError.throwSqlException(4, "getTIMESTAMP");
/*      */     } 
/*      */ 
/*      */     
/* 1219 */     return null;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized TIMESTAMPTZ getTIMESTAMPTZ(int paramInt) throws SQLException {
/* 1229 */     Datum datum = getOracleObject(paramInt);
/*      */     
/* 1231 */     if (datum != null) {
/*      */       
/* 1233 */       if (datum instanceof TIMESTAMPTZ) {
/* 1234 */         return (TIMESTAMPTZ)datum;
/*      */       }
/* 1236 */       DatabaseError.throwSqlException(4, "getTIMESTAMPTZ");
/*      */     } 
/*      */ 
/*      */     
/* 1240 */     return null;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized TIMESTAMPLTZ getTIMESTAMPLTZ(int paramInt) throws SQLException {
/* 1250 */     Datum datum = getOracleObject(paramInt);
/*      */     
/* 1252 */     if (datum != null) {
/*      */       
/* 1254 */       if (datum instanceof TIMESTAMPLTZ) {
/* 1255 */         return (TIMESTAMPLTZ)datum;
/*      */       }
/* 1257 */       DatabaseError.throwSqlException(4, "getTIMESTAMPLTZ");
/*      */     } 
/*      */ 
/*      */     
/* 1261 */     return null;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized INTERVALDS getINTERVALDS(int paramInt) throws SQLException {
/* 1271 */     Datum datum = getOracleObject(paramInt);
/*      */     
/* 1273 */     if (datum != null) {
/*      */       
/* 1275 */       if (datum instanceof INTERVALDS) {
/* 1276 */         return (INTERVALDS)datum;
/*      */       }
/* 1278 */       DatabaseError.throwSqlException(4, "getINTERVALDS");
/*      */     } 
/*      */ 
/*      */     
/* 1282 */     return null;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized INTERVALYM getINTERVALYM(int paramInt) throws SQLException {
/* 1292 */     Datum datum = getOracleObject(paramInt);
/*      */     
/* 1294 */     if (datum != null) {
/*      */       
/* 1296 */       if (datum instanceof INTERVALYM) {
/* 1297 */         return (INTERVALYM)datum;
/*      */       }
/* 1299 */       DatabaseError.throwSqlException(4, "getINTERVALYM");
/*      */     } 
/*      */ 
/*      */     
/* 1303 */     return null;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized ARRAY getARRAY(int paramInt) throws SQLException {
/* 1313 */     Datum datum = getOracleObject(paramInt);
/*      */     
/* 1315 */     if (datum != null) {
/*      */       
/* 1317 */       if (datum instanceof ARRAY) {
/* 1318 */         return (ARRAY)datum;
/*      */       }
/* 1320 */       DatabaseError.throwSqlException(4, "getARRAY");
/*      */     } 
/*      */ 
/*      */     
/* 1324 */     return null;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized STRUCT getSTRUCT(int paramInt) throws SQLException {
/* 1334 */     Datum datum = getOracleObject(paramInt);
/*      */     
/* 1336 */     if (datum != null) {
/*      */       
/* 1338 */       if (datum instanceof STRUCT) {
/* 1339 */         return (STRUCT)datum;
/*      */       }
/* 1341 */       DatabaseError.throwSqlException(4, "getSTRUCT");
/*      */     } 
/*      */ 
/*      */     
/* 1345 */     return null;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized OPAQUE getOPAQUE(int paramInt) throws SQLException {
/* 1355 */     Datum datum = getOracleObject(paramInt);
/*      */     
/* 1357 */     if (datum != null) {
/*      */       
/* 1359 */       if (datum instanceof OPAQUE) {
/* 1360 */         return (OPAQUE)datum;
/*      */       }
/* 1362 */       DatabaseError.throwSqlException(4, "getOPAQUE");
/*      */     } 
/*      */ 
/*      */     
/* 1366 */     return null;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized REF getREF(int paramInt) throws SQLException {
/* 1376 */     Datum datum = getOracleObject(paramInt);
/*      */     
/* 1378 */     if (datum != null) {
/*      */       
/* 1380 */       if (datum instanceof REF) {
/* 1381 */         return (REF)datum;
/*      */       }
/* 1383 */       DatabaseError.throwSqlException(4, "getREF");
/*      */     } 
/*      */ 
/*      */     
/* 1387 */     return null;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized CHAR getCHAR(int paramInt) throws SQLException {
/* 1397 */     Datum datum = getOracleObject(paramInt);
/*      */     
/* 1399 */     if (datum != null) {
/*      */       
/* 1401 */       if (datum instanceof CHAR) {
/* 1402 */         return (CHAR)datum;
/*      */       }
/* 1404 */       DatabaseError.throwSqlException(4, "getCHAR");
/*      */     } 
/*      */ 
/*      */     
/* 1408 */     return null;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized RAW getRAW(int paramInt) throws SQLException {
/* 1418 */     Datum datum = getOracleObject(paramInt);
/*      */     
/* 1420 */     if (datum != null) {
/*      */       
/* 1422 */       if (datum instanceof RAW) {
/* 1423 */         return (RAW)datum;
/*      */       }
/* 1425 */       DatabaseError.throwSqlException(4, "getRAW");
/*      */     } 
/*      */ 
/*      */     
/* 1429 */     return null;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized BLOB getBLOB(int paramInt) throws SQLException {
/* 1439 */     Datum datum = getOracleObject(paramInt);
/*      */     
/* 1441 */     if (datum != null) {
/*      */       
/* 1443 */       if (datum instanceof BLOB) {
/* 1444 */         return (BLOB)datum;
/*      */       }
/* 1446 */       DatabaseError.throwSqlException(4, "getBLOB");
/*      */     } 
/*      */ 
/*      */     
/* 1450 */     return null;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized CLOB getCLOB(int paramInt) throws SQLException {
/* 1460 */     Datum datum = getOracleObject(paramInt);
/*      */     
/* 1462 */     if (datum != null) {
/*      */       
/* 1464 */       if (datum instanceof CLOB) {
/* 1465 */         return (CLOB)datum;
/*      */       }
/* 1467 */       DatabaseError.throwSqlException(4, "getCLOB");
/*      */     } 
/*      */ 
/*      */     
/* 1471 */     return null;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized BFILE getBFILE(int paramInt) throws SQLException {
/* 1481 */     Datum datum = getOracleObject(paramInt);
/*      */     
/* 1483 */     if (datum != null) {
/*      */       
/* 1485 */       if (datum instanceof BFILE) {
/* 1486 */         return (BFILE)datum;
/*      */       }
/* 1488 */       DatabaseError.throwSqlException(4, "getBFILE");
/*      */     } 
/*      */ 
/*      */     
/* 1492 */     return null;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized BFILE getBfile(int paramInt) throws SQLException {
/* 1503 */     return getBFILE(paramInt);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized CustomDatum getCustomDatum(int paramInt, CustomDatumFactory paramCustomDatumFactory) throws SQLException {
/* 1514 */     Datum datum = getOracleObject(paramInt);
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1519 */     return paramCustomDatumFactory.create(datum, 0);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized ORAData getORAData(int paramInt, ORADataFactory paramORADataFactory) throws SQLException {
/* 1530 */     Datum datum = getOracleObject(paramInt);
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1535 */     return paramORADataFactory.create(datum, 0);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public ResultSetMetaData getMetaData() throws SQLException {
/* 1548 */     synchronized (this.connection) {
/*      */       
/* 1550 */       synchronized (this) {
/*      */         
/* 1552 */         return (ResultSetMetaData)new OracleResultSetMetaData(this.connection, (OracleStatement)this.scrollStmt, this.beginColumnIndex);
/*      */       } 
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized int findColumn(String paramString) throws SQLException {
/* 1565 */     return this.resultSet.findColumn(paramString) - this.beginColumnIndex;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void setFetchDirection(int paramInt) throws SQLException {
/* 1578 */     if (paramInt == 1000) {
/*      */       
/* 1580 */       this.usrFetchDirection = paramInt;
/*      */     }
/* 1582 */     else if (paramInt == 1001 || paramInt == 1002) {
/*      */ 
/*      */       
/* 1585 */       this.usrFetchDirection = paramInt;
/*      */       
/* 1587 */       this.sqlWarning = DatabaseError.addSqlWarning(this.sqlWarning, 87);
/*      */     
/*      */     }
/*      */     else {
/*      */ 
/*      */       
/* 1593 */       DatabaseError.throwSqlException(68, "setFetchDirection");
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized int getFetchDirection() throws SQLException {
/* 1605 */     return 1000;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void setFetchSize(int paramInt) throws SQLException {
/* 1614 */     this.resultSet.setFetchSize(paramInt);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized int getFetchSize() throws SQLException {
/* 1623 */     return this.resultSet.getFetchSize();
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public int getType() throws SQLException {
/* 1632 */     return this.rsetType;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public int getConcurrency() throws SQLException {
/* 1641 */     return this.rsetConcurency;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void refreshRow() throws SQLException {
/* 1657 */     if (!needIdentifier(this.rsetType, this.rsetConcurency)) {
/* 1658 */       DatabaseError.throwSqlException(23, "refreshRow");
/*      */     }
/*      */     
/* 1661 */     if (isValidRow(this.currentRow)) {
/*      */       
/* 1663 */       int i = getFetchDirection();
/*      */ 
/*      */       
/*      */       try {
/* 1667 */         refreshRowsInCache(this.currentRow, getFetchSize(), i);
/*      */       }
/* 1669 */       catch (SQLException sQLException) {
/*      */         
/* 1671 */         DatabaseError.throwSqlException(sQLException, 90, "Unsupported syntax for refreshRow()");
/*      */       }
/*      */     
/*      */     } else {
/*      */       
/* 1676 */       DatabaseError.throwSqlException(82, "refreshRow");
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void setCurrentRowValueAt(Object paramObject1, int paramInt, Object paramObject2) throws SQLException {
/* 1691 */     if (paramObject1 instanceof UpdatableResultSet) {
/* 1692 */       putCachedValueAt(this.currentRow, paramInt, paramObject2);
/*      */     } else {
/* 1694 */       DatabaseError.throwSqlException(1);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private boolean isEmptyResultSet() throws SQLException {
/* 1706 */     if (this.numRowsCached != 0)
/*      */     {
/* 1708 */       return false;
/*      */     }
/* 1710 */     if (this.numRowsCached == 0 && this.allRowsCached)
/*      */     {
/* 1712 */       return true;
/*      */     }
/*      */ 
/*      */     
/* 1716 */     return !isValidRow(1);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   boolean isValidRow(int paramInt) throws SQLException {
/* 1730 */     if (paramInt > 0 && paramInt <= this.numRowsCached)
/*      */     {
/* 1732 */       return true;
/*      */     }
/* 1734 */     if (paramInt <= 0)
/*      */     {
/* 1736 */       return false;
/*      */     }
/*      */ 
/*      */     
/* 1740 */     return cacheRowAt(paramInt);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private boolean cacheRowAt(int paramInt) throws SQLException {
/* 1757 */     while (this.numRowsCached < paramInt && this.resultSet.next()) {
/*      */       
/* 1759 */       for (byte b = 0; b < getColumnCount(); b++) {
/*      */ 
/*      */         
/* 1762 */         byte[] arrayOfByte = this.resultSet.privateGetBytes(b + 1);
/*      */         
/* 1764 */         putCachedValueAt(this.numRowsCached + 1, b + 1, arrayOfByte);
/*      */       } 
/*      */       
/* 1767 */       this.numRowsCached++;
/*      */     } 
/*      */     
/* 1770 */     if (this.numRowsCached < paramInt) {
/*      */       
/* 1772 */       this.allRowsCached = true;
/*      */       
/* 1774 */       return false;
/*      */     } 
/*      */ 
/*      */     
/* 1778 */     return true;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private int cacheAllRows() throws SQLException {
/* 1791 */     while (this.resultSet.next()) {
/*      */       
/* 1793 */       for (byte b = 0; b < getColumnCount(); b++) {
/* 1794 */         putCachedValueAt(this.numRowsCached + 1, b + 1, this.resultSet.privateGetBytes(b + 1));
/*      */       }
/* 1796 */       this.numRowsCached++;
/*      */     } 
/*      */     
/* 1799 */     this.allRowsCached = true;
/*      */     
/* 1801 */     return this.numRowsCached;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   int getColumnCount() throws SQLException {
/* 1813 */     if (this.columnCount == 0) {
/*      */ 
/*      */ 
/*      */       
/* 1817 */       int i = this.resultSet.statement.numberOfDefinePositions;
/*      */       
/* 1819 */       if (this.resultSet.statement.accessors != null && i > 0) {
/* 1820 */         this.columnCount = i;
/*      */       } else {
/* 1822 */         this.columnCount = getInternalMetadata().getColumnCount();
/*      */       } 
/*      */     } 
/* 1825 */     return this.columnCount;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private ResultSetMetaData getInternalMetadata() throws SQLException {
/* 1837 */     if (this.metadata == null) {
/* 1838 */       this.metadata = this.resultSet.getMetaData();
/*      */     }
/* 1840 */     return this.metadata;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private int getLastRow() throws SQLException {
/* 1852 */     if (!this.allRowsCached) {
/* 1853 */       cacheAllRows();
/*      */     }
/* 1855 */     return this.numRowsCached;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private int get_refetch_size(int paramInt1, int paramInt2, int paramInt3) throws SQLException {
/* 1869 */     byte b1 = (paramInt3 == 1001) ? -1 : 1;
/*      */ 
/*      */     
/* 1872 */     byte b2 = 0;
/*      */     
/* 1874 */     if (this.refetchRowids == null) {
/* 1875 */       this.refetchRowids = new Vector(10);
/*      */     } else {
/* 1877 */       this.refetchRowids.removeAllElements();
/*      */     } 
/*      */     
/* 1880 */     while (b2 < paramInt2 && isValidRow(paramInt1 + b2 * b1)) {
/*      */       
/* 1882 */       this.refetchRowids.addElement(getCachedDatumValueAt(paramInt1 + b2 * b1, 1));
/*      */ 
/*      */       
/* 1885 */       b2++;
/*      */     } 
/*      */     
/* 1888 */     return b2;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private OraclePreparedStatement prepare_refetch_statement(int paramInt) throws SQLException {
/* 1906 */     if (paramInt < 1) {
/* 1907 */       DatabaseError.throwSqlException(68);
/*      */     }
/*      */ 
/*      */ 
/*      */     
/* 1912 */     return (OraclePreparedStatement)this.connection.prepareStatement(((OracleStatement)this.scrollStmt).sqlObject.getRefetchSqlForScrollableResultSet(this, paramInt));
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private void prepare_refetch_binds(OraclePreparedStatement paramOraclePreparedStatement, int paramInt) throws SQLException {
/* 1929 */     int i = this.scrollStmt.copyBinds((Statement)paramOraclePreparedStatement, 0);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1950 */     for (byte b = 0; b < paramInt; b++)
/*      */     {
/* 1952 */       paramOraclePreparedStatement.setROWID(i + b + 1, this.refetchRowids.elementAt(b));
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private void save_refetch_results(OracleResultSet paramOracleResultSet, int paramInt1, int paramInt2, int paramInt3) throws SQLException {
/* 1968 */     byte b = (paramInt3 == 1001) ? -1 : 1;
/*      */     
/* 1970 */     while (paramOracleResultSet.next()) {
/*      */       
/* 1972 */       ROWID rOWID = paramOracleResultSet.getROWID(1);
/*      */       
/* 1974 */       boolean bool = false;
/* 1975 */       int i = paramInt1;
/*      */       
/* 1977 */       while (!bool && i < paramInt1 + paramInt2 * b) {
/*      */         
/* 1979 */         if (((ROWID)getCachedDatumValueAt(i, 1)).stringValue().equals(rOWID.stringValue())) {
/*      */           
/* 1981 */           bool = true; continue;
/*      */         } 
/* 1983 */         i += b;
/*      */       } 
/*      */       
/* 1986 */       if (bool)
/*      */       {
/* 1988 */         for (byte b1 = 0; b1 < getColumnCount(); b1++)
/*      */         {
/* 1990 */           putCachedValueAt(i, b1 + 1, paramOracleResultSet.getOracleObject(b1 + 1));
/*      */         }
/*      */       }
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private Object getCachedValueAt(int paramInt1, int paramInt2) throws SQLException {
/*      */     try {
/* 2005 */       return this.rsetCache.get(paramInt1, paramInt2);
/*      */     }
/* 2007 */     catch (IOException iOException) {
/*      */       
/* 2009 */       DatabaseError.throwSqlException(iOException);
/*      */ 
/*      */       
/* 2012 */       return null;
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private Datum getCachedDatumValueAt(int paramInt1, int paramInt2) throws SQLException {
/* 2021 */     Object object = null;
/*      */ 
/*      */     
/*      */     try {
/* 2025 */       object = this.rsetCache.get(paramInt1, paramInt2);
/*      */     }
/* 2027 */     catch (IOException iOException) {
/*      */       
/* 2029 */       DatabaseError.throwSqlException(iOException);
/*      */     } 
/*      */     
/* 2032 */     Datum datum = null;
/*      */     
/* 2034 */     if (object != null)
/*      */     {
/* 2036 */       if (object instanceof Datum) {
/*      */         
/* 2038 */         datum = (Datum)object;
/*      */       }
/* 2040 */       else if (((byte[])object).length > 0) {
/*      */         
/* 2042 */         int i = getInternalMetadata().getColumnType(paramInt2);
/* 2043 */         int j = getInternalMetadata().getColumnDisplaySize(paramInt2);
/*      */ 
/*      */ 
/*      */         
/* 2047 */         int k = this.scrollStmt.getMaxFieldSize();
/*      */         
/* 2049 */         if (k > 0 && k < j) {
/* 2050 */           j = k;
/*      */         }
/* 2052 */         String str = null;
/*      */         
/* 2054 */         if (i == 2006 || i == 2002 || i == 2008 || i == 2007 || i == 2003)
/*      */         {
/*      */           
/* 2057 */           str = getInternalMetadata().getColumnTypeName(paramInt2);
/*      */         }
/* 2059 */         int m = SQLUtil.getInternalType(i);
/*      */ 
/*      */         
/* 2062 */         short s = (this.resultSet.statement.accessors[paramInt2 - 1]).formOfUse;
/*      */         
/* 2064 */         if (s == 2 && (m == 96 || m == 1 || m == 8 || m == 112)) {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */           
/* 2073 */           datum = SQLUtil.makeNDatum(this.connection, (byte[])object, m, str, s, j);
/*      */         
/*      */         }
/*      */         else {
/*      */ 
/*      */           
/* 2079 */           datum = SQLUtil.makeDatum(this.connection, (byte[])object, m, str, j);
/*      */         } 
/*      */ 
/*      */ 
/*      */         
/*      */         try {
/* 2085 */           this.rsetCache.put(paramInt1, paramInt2, datum);
/*      */         }
/* 2087 */         catch (IOException iOException) {
/*      */           
/* 2089 */           DatabaseError.throwSqlException(iOException);
/*      */         } 
/*      */       } else {
/*      */ 
/*      */         
/*      */         try {
/*      */           
/* 2096 */           this.rsetCache.put(paramInt1, paramInt2, null);
/*      */         }
/* 2098 */         catch (IOException iOException) {
/*      */           
/* 2100 */           DatabaseError.throwSqlException(iOException);
/*      */         } 
/*      */       } 
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 2108 */     return datum;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private void putCachedValueAt(int paramInt1, int paramInt2, Object paramObject) throws SQLException {
/*      */     try {
/* 2120 */       this.rsetCache.put(paramInt1, paramInt2, paramObject);
/*      */     }
/* 2122 */     catch (IOException iOException) {
/*      */       
/* 2124 */       DatabaseError.throwSqlException(iOException);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private void removeCachedRowAt(int paramInt) throws SQLException {
/*      */     try {
/* 2136 */       this.rsetCache.remove(paramInt);
/*      */     }
/* 2138 */     catch (IOException iOException) {
/*      */       
/* 2140 */       DatabaseError.throwSqlException(iOException);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public static boolean needIdentifier(int paramInt1, int paramInt2) {
/* 2153 */     if ((paramInt1 == 1003 && paramInt2 == 1007) || (paramInt1 == 1004 && paramInt2 == 1007))
/*      */     {
/*      */       
/* 2156 */       return false;
/*      */     }
/* 2158 */     return true;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public static boolean needCache(int paramInt1, int paramInt2) {
/* 2168 */     if (paramInt1 == 1003 || (paramInt1 == 1004 && paramInt2 == 1007))
/*      */     {
/*      */       
/* 2171 */       return false;
/*      */     }
/* 2173 */     return true;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public static boolean supportRefreshRow(int paramInt1, int paramInt2) {
/* 2183 */     if (paramInt1 == 1003 || (paramInt1 == 1004 && paramInt2 == 1007))
/*      */     {
/*      */       
/* 2186 */       return false;
/*      */     }
/* 2188 */     return true;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   int getFirstUserColumnIndex() {
/* 2208 */     return this.beginColumnIndex;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 2214 */   private static final String _Copyright_2004_Oracle_All_Rights_Reserved_ = null;
/*      */   public static final boolean TRACE = false;
/*      */   public static final boolean PRIVATE_TRACE = false;
/*      */   public static final String BUILD_DATE = "Sat_Feb__2_11:39:37_PST_2008";
/*      */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\lib\ojdbc14.jar!\oracle\jdbc\driver\ScrollableResultSet.class
 * Java compiler version: 2 (46.0)
 * JD-Core Version:       1.1.3
 */