/*      */ package oracle.jdbc.driver;
/*      */ 
/*      */ import java.io.ByteArrayInputStream;
/*      */ import java.io.IOException;
/*      */ import java.io.InputStream;
/*      */ import java.io.Reader;
/*      */ import java.math.BigDecimal;
/*      */ import java.net.MalformedURLException;
/*      */ import java.net.URL;
/*      */ import java.sql.Array;
/*      */ import java.sql.Blob;
/*      */ import java.sql.Clob;
/*      */ import java.sql.Connection;
/*      */ import java.sql.Date;
/*      */ import java.sql.Ref;
/*      */ import java.sql.ResultSet;
/*      */ import java.sql.ResultSetMetaData;
/*      */ import java.sql.SQLException;
/*      */ import java.sql.SQLWarning;
/*      */ import java.sql.Statement;
/*      */ import java.sql.Time;
/*      */ import java.sql.Timestamp;
/*      */ import java.util.Calendar;
/*      */ import java.util.Map;
/*      */ import oracle.sql.ARRAY;
/*      */ import oracle.sql.BFILE;
/*      */ import oracle.sql.BLOB;
/*      */ import oracle.sql.CHAR;
/*      */ import oracle.sql.CLOB;
/*      */ import oracle.sql.CustomDatum;
/*      */ import oracle.sql.CustomDatumFactory;
/*      */ import oracle.sql.DATE;
/*      */ import oracle.sql.Datum;
/*      */ import oracle.sql.INTERVALDS;
/*      */ import oracle.sql.INTERVALYM;
/*      */ import oracle.sql.NUMBER;
/*      */ import oracle.sql.OPAQUE;
/*      */ import oracle.sql.ORAData;
/*      */ import oracle.sql.ORADataFactory;
/*      */ import oracle.sql.RAW;
/*      */ import oracle.sql.REF;
/*      */ import oracle.sql.ROWID;
/*      */ import oracle.sql.STRUCT;
/*      */ import oracle.sql.TIMESTAMP;
/*      */ import oracle.sql.TIMESTAMPLTZ;
/*      */ import oracle.sql.TIMESTAMPTZ;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ class UpdatableResultSet
/*      */   extends BaseResultSet
/*      */ {
/*      */   static final int concurrencyType = 1008;
/*      */   static final int beginColumnIndex = 1;
/*      */   PhysicalConnection connection;
/*      */   OracleResultSet resultSet;
/*      */   boolean isCachedRset;
/*      */   ScrollRsetStatement scrollStmt;
/*      */   ResultSetMetaData rsetMetaData;
/*      */   private int rsetType;
/*      */   private int columnCount;
/*      */   private OraclePreparedStatement deleteStmt;
/*      */   private OraclePreparedStatement insertStmt;
/*      */   private OraclePreparedStatement updateStmt;
/*      */   private int[] indexColsChanged;
/*      */   private Object[] rowBuffer;
/*      */   private boolean[] m_nullIndicator;
/*      */   private int[][] typeInfo;
/*      */   private boolean isInserting;
/*      */   private boolean isUpdating;
/*      */   private int wasNull;
/*      */   private static final int VALUE_NULL = 1;
/*      */   private static final int VALUE_NOT_NULL = 2;
/*      */   private static final int VALUE_UNKNOWN = 3;
/*      */   private static final int VALUE_IN_RSET = 4;
/*      */   private static final int ASCII_STREAM = 1;
/*      */   private static final int BINARY_STREAM = 2;
/*      */   private static final int UNICODE_STREAM = 3;
/*   80 */   private static int _MIN_STREAM_SIZE = 4000;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   UpdatableResultSet(ScrollRsetStatement paramScrollRsetStatement, ScrollableResultSet paramScrollableResultSet, int paramInt1, int paramInt2) throws SQLException {
/*   92 */     init(paramScrollRsetStatement, paramScrollableResultSet, paramInt1, paramInt2);
/*      */ 
/*      */     
/*   95 */     paramScrollableResultSet.resetBeginColumnIndex();
/*      */     
/*   97 */     getInternalMetadata();
/*   98 */     this.isCachedRset = true;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   UpdatableResultSet(ScrollRsetStatement paramScrollRsetStatement, OracleResultSetImpl paramOracleResultSetImpl, int paramInt1, int paramInt2) throws SQLException {
/*  107 */     init(paramScrollRsetStatement, paramOracleResultSetImpl, paramInt1, paramInt2);
/*      */     
/*  109 */     getInternalMetadata();
/*  110 */     this.isCachedRset = false;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private void init(ScrollRsetStatement paramScrollRsetStatement, OracleResultSet paramOracleResultSet, int paramInt1, int paramInt2) throws SQLException {
/*  123 */     if (paramScrollRsetStatement == null || paramOracleResultSet == null || paramInt2 != 1008) {
/*  124 */       DatabaseError.throwSqlException(68);
/*      */     }
/*  126 */     this.connection = ((OracleStatement)paramScrollRsetStatement).connection;
/*  127 */     this.resultSet = paramOracleResultSet;
/*  128 */     this.scrollStmt = paramScrollRsetStatement;
/*  129 */     this.rsetType = paramInt1;
/*  130 */     this.autoRefetch = paramScrollRsetStatement.getAutoRefetch();
/*  131 */     this.deleteStmt = null;
/*  132 */     this.insertStmt = null;
/*  133 */     this.updateStmt = null;
/*  134 */     this.indexColsChanged = null;
/*  135 */     this.rowBuffer = null;
/*  136 */     this.m_nullIndicator = null;
/*  137 */     this.typeInfo = (int[][])null;
/*  138 */     this.isInserting = false;
/*  139 */     this.isUpdating = false;
/*  140 */     this.wasNull = -1;
/*  141 */     this.rsetMetaData = null;
/*  142 */     this.columnCount = 0;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void close() throws SQLException {
/*  157 */     if (this.resultSet != null) {
/*  158 */       this.resultSet.close();
/*      */     }
/*  160 */     if (this.insertStmt != null) {
/*  161 */       this.insertStmt.close();
/*      */     }
/*  163 */     if (this.updateStmt != null) {
/*  164 */       this.updateStmt.close();
/*      */     }
/*  166 */     if (this.deleteStmt != null) {
/*  167 */       this.deleteStmt.close();
/*      */     }
/*  169 */     if (this.scrollStmt != null) {
/*  170 */       this.scrollStmt.notifyCloseRset();
/*      */     }
/*  172 */     cancelRowInserts();
/*      */     
/*  174 */     this.connection = null;
/*  175 */     this.resultSet = null;
/*  176 */     this.scrollStmt = null;
/*  177 */     this.rsetMetaData = null;
/*  178 */     this.scrollStmt = null;
/*  179 */     this.deleteStmt = null;
/*  180 */     this.insertStmt = null;
/*  181 */     this.updateStmt = null;
/*  182 */     this.indexColsChanged = null;
/*  183 */     this.rowBuffer = null;
/*  184 */     this.m_nullIndicator = null;
/*  185 */     this.typeInfo = (int[][])null;
/*      */   }
/*      */ 
/*      */   
/*      */   public synchronized boolean wasNull() throws SQLException {
/*  190 */     switch (this.wasNull) {
/*      */ 
/*      */       
/*      */       case 1:
/*  194 */         return true;
/*      */       
/*      */       case 2:
/*  197 */         return false;
/*      */       
/*      */       case 4:
/*  200 */         return this.resultSet.wasNull();
/*      */     } 
/*      */ 
/*      */ 
/*      */     
/*  205 */     DatabaseError.throwSqlException(24);
/*      */ 
/*      */     
/*  208 */     return false;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   int getFirstUserColumnIndex() {
/*  221 */     return 1;
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized Statement getStatement() throws SQLException {
/*  227 */     return (Statement)this.scrollStmt;
/*      */   }
/*      */ 
/*      */   
/*      */   public SQLWarning getWarnings() throws SQLException {
/*  232 */     SQLWarning sQLWarning1 = this.resultSet.getWarnings();
/*      */     
/*  234 */     if (this.sqlWarning == null) {
/*  235 */       return sQLWarning1;
/*      */     }
/*      */     
/*  238 */     SQLWarning sQLWarning2 = this.sqlWarning;
/*      */     
/*  240 */     while (sQLWarning2.getNextWarning() != null) {
/*  241 */       sQLWarning2 = sQLWarning2.getNextWarning();
/*      */     }
/*  243 */     sQLWarning2.setNextWarning(sQLWarning1);
/*      */ 
/*      */     
/*  246 */     return this.sqlWarning;
/*      */   }
/*      */ 
/*      */   
/*      */   public void clearWarnings() throws SQLException {
/*  251 */     this.sqlWarning = null;
/*      */     
/*  253 */     this.resultSet.clearWarnings();
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized boolean next() throws SQLException {
/*  262 */     cancelRowChanges();
/*      */     
/*  264 */     return this.resultSet.next();
/*      */   }
/*      */ 
/*      */   
/*      */   public synchronized boolean isBeforeFirst() throws SQLException {
/*  269 */     return this.resultSet.isBeforeFirst();
/*      */   }
/*      */ 
/*      */   
/*      */   public synchronized boolean isAfterLast() throws SQLException {
/*  274 */     return this.resultSet.isAfterLast();
/*      */   }
/*      */ 
/*      */   
/*      */   public synchronized boolean isFirst() throws SQLException {
/*  279 */     return this.resultSet.isFirst();
/*      */   }
/*      */ 
/*      */   
/*      */   public synchronized boolean isLast() throws SQLException {
/*  284 */     return this.resultSet.isLast();
/*      */   }
/*      */ 
/*      */   
/*      */   public synchronized void beforeFirst() throws SQLException {
/*  289 */     cancelRowChanges();
/*  290 */     this.resultSet.beforeFirst();
/*      */   }
/*      */ 
/*      */   
/*      */   public synchronized void afterLast() throws SQLException {
/*  295 */     cancelRowChanges();
/*  296 */     this.resultSet.afterLast();
/*      */   }
/*      */ 
/*      */   
/*      */   public synchronized boolean first() throws SQLException {
/*  301 */     cancelRowChanges();
/*      */     
/*  303 */     return this.resultSet.first();
/*      */   }
/*      */ 
/*      */   
/*      */   public synchronized boolean last() throws SQLException {
/*  308 */     cancelRowChanges();
/*      */     
/*  310 */     return this.resultSet.last();
/*      */   }
/*      */ 
/*      */   
/*      */   public synchronized int getRow() throws SQLException {
/*  315 */     return this.resultSet.getRow();
/*      */   }
/*      */ 
/*      */   
/*      */   public boolean absolute(int paramInt) throws SQLException {
/*  320 */     synchronized (this.connection) {
/*      */       
/*  322 */       synchronized (this) {
/*      */         
/*  324 */         cancelRowChanges();
/*      */         
/*  326 */         return this.resultSet.absolute(paramInt);
/*      */       } 
/*      */     } 
/*      */   }
/*      */ 
/*      */   
/*      */   public synchronized boolean relative(int paramInt) throws SQLException {
/*  333 */     cancelRowChanges();
/*      */     
/*  335 */     return this.resultSet.relative(paramInt);
/*      */   }
/*      */ 
/*      */   
/*      */   public synchronized boolean previous() throws SQLException {
/*  340 */     cancelRowChanges();
/*      */     
/*  342 */     return this.resultSet.previous();
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized Datum getOracleObject(int paramInt) throws SQLException {
/*  351 */     Datum datum = null;
/*      */     
/*  353 */     setIsNull(3);
/*      */     
/*  355 */     if (isOnInsertRow() || (isUpdatingRow() && isRowBufferUpdatedAt(paramInt))) {
/*      */ 
/*      */       
/*  358 */       setIsNull((datum == null));
/*      */       
/*  360 */       datum = getRowBufferDatumAt(paramInt);
/*      */     }
/*      */     else {
/*      */       
/*  364 */       setIsNull(4);
/*      */       
/*  366 */       datum = this.resultSet.getOracleObject(paramInt + 1);
/*      */     } 
/*      */     
/*  369 */     return datum;
/*      */   }
/*      */ 
/*      */   
/*      */   public synchronized String getString(int paramInt) throws SQLException {
/*  374 */     String str = null;
/*      */     
/*  376 */     setIsNull(3);
/*      */     
/*  378 */     if (isOnInsertRow() || (isUpdatingRow() && isRowBufferUpdatedAt(paramInt))) {
/*      */ 
/*      */       
/*  381 */       Datum datum = getRowBufferDatumAt(paramInt);
/*      */       
/*  383 */       setIsNull((datum == null));
/*      */       
/*  385 */       if (datum != null) {
/*  386 */         str = datum.stringValue();
/*      */       }
/*      */     } else {
/*      */       
/*  390 */       setIsNull(4);
/*      */       
/*  392 */       str = this.resultSet.getString(paramInt + 1);
/*      */     } 
/*      */     
/*  395 */     return str;
/*      */   }
/*      */ 
/*      */   
/*      */   public synchronized boolean getBoolean(int paramInt) throws SQLException {
/*  400 */     boolean bool = false;
/*      */     
/*  402 */     setIsNull(3);
/*      */     
/*  404 */     if (isOnInsertRow() || (isUpdatingRow() && isRowBufferUpdatedAt(paramInt))) {
/*      */ 
/*      */       
/*  407 */       Datum datum = getRowBufferDatumAt(paramInt);
/*      */       
/*  409 */       setIsNull((datum == null));
/*      */       
/*  411 */       if (datum != null) {
/*  412 */         bool = datum.booleanValue();
/*      */       }
/*      */     } else {
/*      */       
/*  416 */       setIsNull(4);
/*      */       
/*  418 */       bool = this.resultSet.getBoolean(paramInt + 1);
/*      */     } 
/*      */     
/*  421 */     return bool;
/*      */   }
/*      */ 
/*      */   
/*      */   public synchronized byte getByte(int paramInt) throws SQLException {
/*  426 */     byte b = 0;
/*      */     
/*  428 */     setIsNull(3);
/*      */     
/*  430 */     if (isOnInsertRow() || (isUpdatingRow() && isRowBufferUpdatedAt(paramInt))) {
/*      */ 
/*      */       
/*  433 */       Datum datum = getRowBufferDatumAt(paramInt);
/*      */       
/*  435 */       setIsNull((datum == null));
/*      */       
/*  437 */       if (datum != null) {
/*  438 */         b = datum.byteValue();
/*      */       }
/*      */     } else {
/*      */       
/*  442 */       setIsNull(4);
/*      */       
/*  444 */       b = this.resultSet.getByte(paramInt + 1);
/*      */     } 
/*      */     
/*  447 */     return b;
/*      */   }
/*      */ 
/*      */   
/*      */   public synchronized short getShort(int paramInt) throws SQLException {
/*  452 */     short s = 0;
/*      */     
/*  454 */     setIsNull(3);
/*      */     
/*  456 */     if (isOnInsertRow() || (isUpdatingRow() && isRowBufferUpdatedAt(paramInt))) {
/*      */ 
/*      */       
/*  459 */       long l = getLong(paramInt);
/*      */       
/*  461 */       if (l > 65537L || l < -65538L) {
/*  462 */         DatabaseError.throwSqlException(26, "getShort");
/*      */       }
/*      */       
/*  465 */       s = (short)(int)l;
/*      */     }
/*      */     else {
/*      */       
/*  469 */       setIsNull(4);
/*      */       
/*  471 */       s = this.resultSet.getShort(paramInt + 1);
/*      */     } 
/*      */     
/*  474 */     return s;
/*      */   }
/*      */ 
/*      */   
/*      */   public synchronized int getInt(int paramInt) throws SQLException {
/*  479 */     int i = 0;
/*      */     
/*  481 */     setIsNull(3);
/*      */     
/*  483 */     if (isOnInsertRow() || (isUpdatingRow() && isRowBufferUpdatedAt(paramInt))) {
/*      */ 
/*      */       
/*  486 */       Datum datum = getRowBufferDatumAt(paramInt);
/*      */       
/*  488 */       setIsNull((datum == null));
/*      */       
/*  490 */       if (datum != null) {
/*  491 */         i = datum.intValue();
/*      */       }
/*      */     } else {
/*      */       
/*  495 */       setIsNull(4);
/*      */       
/*  497 */       i = this.resultSet.getInt(paramInt + 1);
/*      */     } 
/*      */     
/*  500 */     return i;
/*      */   }
/*      */ 
/*      */   
/*      */   public synchronized long getLong(int paramInt) throws SQLException {
/*  505 */     long l = 0L;
/*      */     
/*  507 */     setIsNull(3);
/*      */     
/*  509 */     if (isOnInsertRow() || (isUpdatingRow() && isRowBufferUpdatedAt(paramInt))) {
/*      */ 
/*      */       
/*  512 */       Datum datum = getRowBufferDatumAt(paramInt);
/*      */       
/*  514 */       setIsNull((datum == null));
/*      */       
/*  516 */       if (datum != null) {
/*  517 */         l = datum.longValue();
/*      */       }
/*      */     } else {
/*      */       
/*  521 */       setIsNull(4);
/*      */       
/*  523 */       l = this.resultSet.getLong(paramInt + 1);
/*      */     } 
/*      */     
/*  526 */     return l;
/*      */   }
/*      */ 
/*      */   
/*      */   public synchronized float getFloat(int paramInt) throws SQLException {
/*  531 */     float f = 0.0F;
/*      */     
/*  533 */     setIsNull(3);
/*      */     
/*  535 */     if (isOnInsertRow() || (isUpdatingRow() && isRowBufferUpdatedAt(paramInt))) {
/*      */ 
/*      */       
/*  538 */       Datum datum = getRowBufferDatumAt(paramInt);
/*      */       
/*  540 */       setIsNull((datum == null));
/*      */       
/*  542 */       if (datum != null) {
/*  543 */         f = datum.floatValue();
/*      */       }
/*      */     } else {
/*      */       
/*  547 */       setIsNull(4);
/*      */       
/*  549 */       f = this.resultSet.getFloat(paramInt + 1);
/*      */     } 
/*      */     
/*  552 */     return f;
/*      */   }
/*      */ 
/*      */   
/*      */   public synchronized double getDouble(int paramInt) throws SQLException {
/*  557 */     double d = 0.0D;
/*      */     
/*  559 */     setIsNull(3);
/*      */     
/*  561 */     if (isOnInsertRow() || (isUpdatingRow() && isRowBufferUpdatedAt(paramInt))) {
/*      */ 
/*      */       
/*  564 */       Datum datum = getRowBufferDatumAt(paramInt);
/*      */       
/*  566 */       setIsNull((datum == null));
/*      */       
/*  568 */       if (datum != null) {
/*  569 */         d = datum.doubleValue();
/*      */       }
/*      */     } else {
/*      */       
/*  573 */       setIsNull(4);
/*      */       
/*  575 */       d = this.resultSet.getDouble(paramInt + 1);
/*      */     } 
/*      */     
/*  578 */     return d;
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized BigDecimal getBigDecimal(int paramInt1, int paramInt2) throws SQLException {
/*  584 */     BigDecimal bigDecimal = null;
/*      */     
/*  586 */     setIsNull(3);
/*      */     
/*  588 */     if (isOnInsertRow() || (isUpdatingRow() && isRowBufferUpdatedAt(paramInt1))) {
/*      */ 
/*      */       
/*  591 */       Datum datum = getRowBufferDatumAt(paramInt1);
/*      */       
/*  593 */       setIsNull((datum == null));
/*      */       
/*  595 */       if (datum != null) {
/*  596 */         bigDecimal = datum.bigDecimalValue();
/*      */       }
/*      */     } else {
/*      */       
/*  600 */       setIsNull(4);
/*      */       
/*  602 */       bigDecimal = this.resultSet.getBigDecimal(paramInt1 + 1);
/*      */     } 
/*      */     
/*  605 */     return bigDecimal;
/*      */   }
/*      */ 
/*      */   
/*      */   public synchronized byte[] getBytes(int paramInt) throws SQLException {
/*  610 */     byte[] arrayOfByte = null;
/*      */     
/*  612 */     setIsNull(3);
/*      */     
/*  614 */     if (isOnInsertRow() || (isUpdatingRow() && isRowBufferUpdatedAt(paramInt))) {
/*      */ 
/*      */       
/*  617 */       Datum datum = getRowBufferDatumAt(paramInt);
/*      */       
/*  619 */       setIsNull((datum == null));
/*      */       
/*  621 */       if (datum != null) {
/*  622 */         arrayOfByte = datum.getBytes();
/*      */       }
/*      */     } else {
/*      */       
/*  626 */       setIsNull(4);
/*      */       
/*  628 */       arrayOfByte = this.resultSet.getBytes(paramInt + 1);
/*      */     } 
/*      */     
/*  631 */     return arrayOfByte;
/*      */   }
/*      */ 
/*      */   
/*      */   public synchronized Date getDate(int paramInt) throws SQLException {
/*  636 */     Date date = null;
/*      */     
/*  638 */     setIsNull(3);
/*      */     
/*  640 */     if (isOnInsertRow() || (isUpdatingRow() && isRowBufferUpdatedAt(paramInt))) {
/*      */ 
/*      */       
/*  643 */       Datum datum = getRowBufferDatumAt(paramInt);
/*      */       
/*  645 */       setIsNull((datum == null));
/*      */       
/*  647 */       if (datum != null) {
/*  648 */         date = datum.dateValue();
/*      */       }
/*      */     } else {
/*      */       
/*  652 */       setIsNull(4);
/*      */       
/*  654 */       date = this.resultSet.getDate(paramInt + 1);
/*      */     } 
/*      */     
/*  657 */     return date;
/*      */   }
/*      */ 
/*      */   
/*      */   public synchronized Time getTime(int paramInt) throws SQLException {
/*  662 */     Time time = null;
/*      */     
/*  664 */     setIsNull(3);
/*      */     
/*  666 */     if (isOnInsertRow() || (isUpdatingRow() && isRowBufferUpdatedAt(paramInt))) {
/*      */ 
/*      */       
/*  669 */       Datum datum = getRowBufferDatumAt(paramInt);
/*      */       
/*  671 */       setIsNull((datum == null));
/*      */       
/*  673 */       if (datum != null) {
/*  674 */         time = datum.timeValue();
/*      */       }
/*      */     } else {
/*      */       
/*  678 */       setIsNull(4);
/*      */       
/*  680 */       time = this.resultSet.getTime(paramInt + 1);
/*      */     } 
/*      */     
/*  683 */     return time;
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized Timestamp getTimestamp(int paramInt) throws SQLException {
/*  689 */     Timestamp timestamp = null;
/*      */     
/*  691 */     setIsNull(3);
/*      */     
/*  693 */     if (isOnInsertRow() || (isUpdatingRow() && isRowBufferUpdatedAt(paramInt))) {
/*      */ 
/*      */       
/*  696 */       Datum datum = getRowBufferDatumAt(paramInt);
/*      */       
/*  698 */       setIsNull((datum == null));
/*      */       
/*  700 */       if (datum != null) {
/*  701 */         timestamp = datum.timestampValue();
/*      */       }
/*      */     } else {
/*      */       
/*  705 */       setIsNull(4);
/*      */       
/*  707 */       timestamp = this.resultSet.getTimestamp(paramInt + 1);
/*      */     } 
/*      */     
/*  710 */     return timestamp;
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized InputStream getAsciiStream(int paramInt) throws SQLException {
/*  716 */     InputStream inputStream = null;
/*      */     
/*  718 */     setIsNull(3);
/*      */     
/*  720 */     if (isOnInsertRow() || (isUpdatingRow() && isRowBufferUpdatedAt(paramInt))) {
/*      */ 
/*      */       
/*  723 */       Object object = getRowBufferAt(paramInt);
/*      */       
/*  725 */       setIsNull((object == null));
/*      */       
/*  727 */       if (object != null)
/*      */       {
/*  729 */         if (object instanceof InputStream)
/*      */         {
/*  731 */           inputStream = (InputStream)object;
/*      */         }
/*      */         else
/*      */         {
/*  735 */           Datum datum = getRowBufferDatumAt(paramInt);
/*      */           
/*  737 */           inputStream = datum.asciiStreamValue();
/*      */         }
/*      */       
/*      */       }
/*      */     } else {
/*      */       
/*  743 */       setIsNull(4);
/*      */       
/*  745 */       inputStream = this.resultSet.getAsciiStream(paramInt + 1);
/*      */     } 
/*      */     
/*  748 */     return inputStream;
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized InputStream getUnicodeStream(int paramInt) throws SQLException {
/*  754 */     InputStream inputStream = null;
/*      */     
/*  756 */     setIsNull(3);
/*      */     
/*  758 */     if (isOnInsertRow() || (isUpdatingRow() && isRowBufferUpdatedAt(paramInt))) {
/*      */ 
/*      */       
/*  761 */       Object object = getRowBufferAt(paramInt);
/*      */       
/*  763 */       setIsNull((object == null));
/*      */       
/*  765 */       if (object != null)
/*      */       {
/*  767 */         if (object instanceof InputStream) {
/*      */           
/*  769 */           inputStream = (InputStream)object;
/*      */         }
/*      */         else {
/*      */           
/*  773 */           Datum datum = getRowBufferDatumAt(paramInt);
/*  774 */           DBConversion dBConversion = this.connection.conversion;
/*  775 */           byte[] arrayOfByte = datum.shareBytes();
/*      */           
/*  777 */           if (datum instanceof RAW)
/*      */           {
/*  779 */             inputStream = dBConversion.ConvertStream(new ByteArrayInputStream(arrayOfByte), 3);
/*      */           
/*      */           }
/*  782 */           else if (datum instanceof CHAR)
/*      */           {
/*  784 */             inputStream = dBConversion.ConvertStream(new ByteArrayInputStream(arrayOfByte), 1);
/*      */           }
/*      */           else
/*      */           {
/*  788 */             DatabaseError.throwSqlException(4, "getUnicodeStream");
/*      */           }
/*      */         
/*      */         } 
/*      */       }
/*      */     } else {
/*      */       
/*  795 */       setIsNull(4);
/*      */       
/*  797 */       inputStream = this.resultSet.getUnicodeStream(paramInt + 1);
/*      */     } 
/*      */     
/*  800 */     return inputStream;
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized InputStream getBinaryStream(int paramInt) throws SQLException {
/*  806 */     InputStream inputStream = null;
/*      */     
/*  808 */     setIsNull(3);
/*      */     
/*  810 */     if (isOnInsertRow() || (isUpdatingRow() && isRowBufferUpdatedAt(paramInt))) {
/*      */ 
/*      */       
/*  813 */       Object object = getRowBufferAt(paramInt);
/*      */       
/*  815 */       setIsNull((object == null));
/*      */       
/*  817 */       if (object != null)
/*      */       {
/*  819 */         if (object instanceof InputStream)
/*      */         {
/*  821 */           inputStream = (InputStream)object;
/*      */         }
/*      */         else
/*      */         {
/*  825 */           Datum datum = getRowBufferDatumAt(paramInt);
/*      */           
/*  827 */           inputStream = datum.binaryStreamValue();
/*      */         }
/*      */       
/*      */       }
/*      */     } else {
/*      */       
/*  833 */       setIsNull(4);
/*      */       
/*  835 */       inputStream = this.resultSet.getBinaryStream(paramInt + 1);
/*      */     } 
/*      */     
/*  838 */     return inputStream;
/*      */   }
/*      */ 
/*      */   
/*      */   public synchronized Object getObject(int paramInt) throws SQLException {
/*  843 */     Object object = null;
/*      */     
/*  845 */     setIsNull(3);
/*      */     
/*  847 */     if (isOnInsertRow() || (isUpdatingRow() && isRowBufferUpdatedAt(paramInt))) {
/*      */ 
/*      */       
/*  850 */       Datum datum = getOracleObject(paramInt);
/*      */       
/*  852 */       setIsNull((datum == null));
/*      */       
/*  854 */       if (datum != null) {
/*  855 */         object = datum.toJdbc();
/*      */       }
/*      */     } else {
/*      */       
/*  859 */       setIsNull(4);
/*      */       
/*  861 */       object = this.resultSet.getObject(paramInt + 1);
/*      */     } 
/*      */     
/*  864 */     return object;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized Reader getCharacterStream(int paramInt) throws SQLException {
/*  871 */     Reader reader = null;
/*      */     
/*  873 */     setIsNull(3);
/*      */     
/*  875 */     if (isOnInsertRow() || (isUpdatingRow() && isRowBufferUpdatedAt(paramInt))) {
/*      */ 
/*      */       
/*  878 */       Object object = getRowBufferAt(paramInt);
/*      */       
/*  880 */       setIsNull((object == null));
/*      */       
/*  882 */       if (object != null)
/*      */       {
/*  884 */         if (object instanceof Reader)
/*      */         {
/*  886 */           reader = (Reader)object;
/*      */         }
/*      */         else
/*      */         {
/*  890 */           Datum datum = getRowBufferDatumAt(paramInt);
/*      */           
/*  892 */           reader = datum.characterStreamValue();
/*      */         }
/*      */       
/*      */       }
/*      */     } else {
/*      */       
/*  898 */       setIsNull(4);
/*      */       
/*  900 */       reader = this.resultSet.getCharacterStream(paramInt + 1);
/*      */     } 
/*      */     
/*  903 */     return reader;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized BigDecimal getBigDecimal(int paramInt) throws SQLException {
/*  910 */     BigDecimal bigDecimal = null;
/*      */     
/*  912 */     setIsNull(3);
/*      */     
/*  914 */     if (isOnInsertRow() || (isUpdatingRow() && isRowBufferUpdatedAt(paramInt))) {
/*      */ 
/*      */       
/*  917 */       Datum datum = getRowBufferDatumAt(paramInt);
/*      */       
/*  919 */       setIsNull((datum == null));
/*      */       
/*  921 */       if (datum != null) {
/*  922 */         bigDecimal = datum.bigDecimalValue();
/*      */       }
/*      */     } else {
/*      */       
/*  926 */       setIsNull(4);
/*      */       
/*  928 */       bigDecimal = this.resultSet.getBigDecimal(paramInt + 1);
/*      */     } 
/*      */     
/*  931 */     return bigDecimal;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized Object getObject(int paramInt, Map paramMap) throws SQLException {
/*  938 */     Object object = null;
/*      */     
/*  940 */     setIsNull(3);
/*      */     
/*  942 */     if (isOnInsertRow() || (isUpdatingRow() && isRowBufferUpdatedAt(paramInt))) {
/*      */ 
/*      */       
/*  945 */       Datum datum = getOracleObject(paramInt);
/*      */       
/*  947 */       setIsNull((datum == null));
/*      */       
/*  949 */       if (datum != null)
/*      */       {
/*  951 */         if (datum instanceof STRUCT) {
/*  952 */           object = ((STRUCT)datum).toJdbc(paramMap);
/*      */         } else {
/*  954 */           object = datum.toJdbc();
/*      */         } 
/*      */       }
/*      */     } else {
/*      */       
/*  959 */       setIsNull(4);
/*      */       
/*  961 */       object = this.resultSet.getObject(paramInt + 1, paramMap);
/*      */     } 
/*      */     
/*  964 */     return object;
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized Ref getRef(int paramInt) throws SQLException {
/*  970 */     return (Ref)getREF(paramInt);
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized Blob getBlob(int paramInt) throws SQLException {
/*  976 */     return (Blob)getBLOB(paramInt);
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized Clob getClob(int paramInt) throws SQLException {
/*  982 */     return (Clob)getCLOB(paramInt);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized Array getArray(int paramInt) throws SQLException {
/*  989 */     return (Array)getARRAY(paramInt);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized Date getDate(int paramInt, Calendar paramCalendar) throws SQLException {
/*  996 */     Date date = null;
/*      */     
/*  998 */     setIsNull(3);
/*      */     
/* 1000 */     if (isOnInsertRow() || (isUpdatingRow() && isRowBufferUpdatedAt(paramInt))) {
/*      */ 
/*      */       
/* 1003 */       Datum datum = getOracleObject(paramInt);
/*      */       
/* 1005 */       setIsNull((datum == null));
/*      */       
/* 1007 */       if (datum != null)
/*      */       {
/* 1009 */         if (datum instanceof DATE) {
/* 1010 */           date = ((DATE)datum).dateValue(paramCalendar);
/*      */         } else {
/*      */           
/* 1013 */           DATE dATE = new DATE(datum.stringValue());
/*      */           
/* 1015 */           if (dATE != null) {
/* 1016 */             date = dATE.dateValue(paramCalendar);
/*      */           }
/*      */         } 
/*      */       }
/*      */     } else {
/*      */       
/* 1022 */       setIsNull(4);
/*      */       
/* 1024 */       date = this.resultSet.getDate(paramInt + 1, paramCalendar);
/*      */     } 
/*      */     
/* 1027 */     return date;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized Time getTime(int paramInt, Calendar paramCalendar) throws SQLException {
/* 1034 */     Time time = null;
/*      */     
/* 1036 */     setIsNull(3);
/*      */     
/* 1038 */     if (isOnInsertRow() || (isUpdatingRow() && isRowBufferUpdatedAt(paramInt))) {
/*      */ 
/*      */       
/* 1041 */       Datum datum = getOracleObject(paramInt);
/*      */       
/* 1043 */       setIsNull((datum == null));
/*      */       
/* 1045 */       if (datum != null)
/*      */       {
/* 1047 */         if (datum instanceof DATE) {
/* 1048 */           time = ((DATE)datum).timeValue(paramCalendar);
/*      */         } else {
/*      */           
/* 1051 */           DATE dATE = new DATE(datum.stringValue());
/*      */           
/* 1053 */           if (dATE != null) {
/* 1054 */             time = dATE.timeValue(paramCalendar);
/*      */           }
/*      */         } 
/*      */       }
/*      */     } else {
/*      */       
/* 1060 */       setIsNull(4);
/*      */       
/* 1062 */       time = this.resultSet.getTime(paramInt + 1, paramCalendar);
/*      */     } 
/*      */     
/* 1065 */     return time;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized Timestamp getTimestamp(int paramInt, Calendar paramCalendar) throws SQLException {
/* 1072 */     Timestamp timestamp = null;
/*      */     
/* 1074 */     setIsNull(3);
/*      */     
/* 1076 */     if (isOnInsertRow() || (isUpdatingRow() && isRowBufferUpdatedAt(paramInt))) {
/*      */ 
/*      */       
/* 1079 */       Datum datum = getOracleObject(paramInt);
/*      */       
/* 1081 */       setIsNull((datum == null));
/*      */       
/* 1083 */       if (datum != null)
/*      */       {
/* 1085 */         if (datum instanceof DATE) {
/* 1086 */           timestamp = ((DATE)datum).timestampValue(paramCalendar);
/*      */         } else {
/*      */           
/* 1089 */           DATE dATE = new DATE(datum.stringValue());
/*      */           
/* 1091 */           if (dATE != null) {
/* 1092 */             timestamp = dATE.timestampValue(paramCalendar);
/*      */           }
/*      */         } 
/*      */       }
/*      */     } else {
/*      */       
/* 1098 */       setIsNull(4);
/*      */       
/* 1100 */       timestamp = this.resultSet.getTimestamp(paramInt + 1, paramCalendar);
/*      */     } 
/*      */     
/* 1103 */     return timestamp;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized URL getURL(int paramInt) throws SQLException {
/* 1113 */     URL uRL = null;
/*      */     
/* 1115 */     int i = getInternalMetadata().getColumnType(paramInt);
/* 1116 */     int j = SQLUtil.getInternalType(i);
/*      */ 
/*      */     
/* 1119 */     if (j == 96 || j == 1 || j == 8) {
/*      */       
/*      */       try
/*      */       {
/*      */         
/* 1124 */         uRL = new URL(getString(paramInt));
/*      */       }
/* 1126 */       catch (MalformedURLException malformedURLException)
/*      */       {
/* 1128 */         DatabaseError.throwSqlException(136);
/*      */       }
/*      */     
/*      */     } else {
/*      */       
/* 1133 */       throw new SQLException("Conversion to java.net.URL not supported.");
/*      */     } 
/*      */     
/* 1136 */     return uRL;
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized ResultSet getCursor(int paramInt) throws SQLException {
/* 1142 */     ResultSet resultSet = null;
/*      */     
/* 1144 */     setIsNull(3);
/*      */     
/* 1146 */     if (isOnInsertRow() || (isUpdatingRow() && isRowBufferUpdatedAt(paramInt))) {
/*      */ 
/*      */       
/* 1149 */       Datum datum = getOracleObject(paramInt);
/*      */       
/* 1151 */       setIsNull((datum == null));
/* 1152 */       DatabaseError.throwSqlException(4, "getCursor");
/*      */     
/*      */     }
/*      */     else {
/*      */       
/* 1157 */       setIsNull(4);
/*      */       
/* 1159 */       resultSet = this.resultSet.getCursor(paramInt + 1);
/*      */     } 
/*      */     
/* 1162 */     return resultSet;
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized ROWID getROWID(int paramInt) throws SQLException {
/* 1168 */     ROWID rOWID = null;
/*      */     
/* 1170 */     setIsNull(3);
/*      */     
/* 1172 */     if (isOnInsertRow() || (isUpdatingRow() && isRowBufferUpdatedAt(paramInt))) {
/*      */ 
/*      */       
/* 1175 */       Datum datum = getRowBufferDatumAt(paramInt);
/*      */       
/* 1177 */       setIsNull((datum == null));
/*      */       
/* 1179 */       if (datum != null && !(datum instanceof ROWID)) {
/* 1180 */         DatabaseError.throwSqlException(4, "getROWID");
/*      */       }
/*      */       
/* 1183 */       rOWID = (ROWID)datum;
/*      */     }
/*      */     else {
/*      */       
/* 1187 */       setIsNull(4);
/*      */       
/* 1189 */       rOWID = this.resultSet.getROWID(paramInt + 1);
/*      */     } 
/*      */     
/* 1192 */     return rOWID;
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized NUMBER getNUMBER(int paramInt) throws SQLException {
/* 1198 */     NUMBER nUMBER = null;
/*      */     
/* 1200 */     setIsNull(3);
/*      */     
/* 1202 */     if (isOnInsertRow() || (isUpdatingRow() && isRowBufferUpdatedAt(paramInt))) {
/*      */ 
/*      */       
/* 1205 */       Datum datum = getRowBufferDatumAt(paramInt);
/*      */       
/* 1207 */       setIsNull((datum == null));
/*      */       
/* 1209 */       if (datum != null && !(datum instanceof NUMBER)) {
/* 1210 */         DatabaseError.throwSqlException(4, "getNUMBER");
/*      */       }
/*      */       
/* 1213 */       nUMBER = (NUMBER)datum;
/*      */     }
/*      */     else {
/*      */       
/* 1217 */       setIsNull(4);
/*      */       
/* 1219 */       nUMBER = this.resultSet.getNUMBER(paramInt + 1);
/*      */     } 
/*      */     
/* 1222 */     return nUMBER;
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized DATE getDATE(int paramInt) throws SQLException {
/* 1228 */     DATE dATE = null;
/*      */     
/* 1230 */     setIsNull(3);
/*      */     
/* 1232 */     if (isOnInsertRow() || (isUpdatingRow() && isRowBufferUpdatedAt(paramInt))) {
/*      */ 
/*      */       
/* 1235 */       Datum datum = getRowBufferDatumAt(paramInt);
/*      */       
/* 1237 */       setIsNull((datum == null));
/*      */       
/* 1239 */       if (datum != null && !(datum instanceof DATE)) {
/* 1240 */         DatabaseError.throwSqlException(4, "getDATE");
/*      */       }
/*      */       
/* 1243 */       dATE = (DATE)datum;
/*      */     }
/*      */     else {
/*      */       
/* 1247 */       setIsNull(4);
/*      */       
/* 1249 */       dATE = this.resultSet.getDATE(paramInt + 1);
/*      */     } 
/*      */     
/* 1252 */     return dATE;
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized TIMESTAMP getTIMESTAMP(int paramInt) throws SQLException {
/* 1258 */     TIMESTAMP tIMESTAMP = null;
/*      */     
/* 1260 */     setIsNull(3);
/*      */     
/* 1262 */     if (isOnInsertRow() || (isUpdatingRow() && isRowBufferUpdatedAt(paramInt))) {
/*      */ 
/*      */       
/* 1265 */       Datum datum = getRowBufferDatumAt(paramInt);
/*      */       
/* 1267 */       setIsNull((datum == null));
/*      */       
/* 1269 */       if (datum != null && !(datum instanceof TIMESTAMP)) {
/* 1270 */         DatabaseError.throwSqlException(4, "getTIMESTAMP");
/*      */       }
/*      */       
/* 1273 */       tIMESTAMP = (TIMESTAMP)datum;
/*      */     }
/*      */     else {
/*      */       
/* 1277 */       setIsNull(4);
/*      */       
/* 1279 */       tIMESTAMP = this.resultSet.getTIMESTAMP(paramInt + 1);
/*      */     } 
/*      */     
/* 1282 */     return tIMESTAMP;
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized TIMESTAMPTZ getTIMESTAMPTZ(int paramInt) throws SQLException {
/* 1288 */     TIMESTAMPTZ tIMESTAMPTZ = null;
/*      */     
/* 1290 */     setIsNull(3);
/*      */     
/* 1292 */     if (isOnInsertRow() || (isUpdatingRow() && isRowBufferUpdatedAt(paramInt))) {
/*      */ 
/*      */       
/* 1295 */       Datum datum = getRowBufferDatumAt(paramInt);
/*      */       
/* 1297 */       setIsNull((datum == null));
/*      */       
/* 1299 */       if (datum != null && !(datum instanceof TIMESTAMPTZ)) {
/* 1300 */         DatabaseError.throwSqlException(4, "getTIMESTAMPTZ");
/*      */       }
/*      */       
/* 1303 */       tIMESTAMPTZ = (TIMESTAMPTZ)datum;
/*      */     }
/*      */     else {
/*      */       
/* 1307 */       setIsNull(4);
/*      */       
/* 1309 */       tIMESTAMPTZ = this.resultSet.getTIMESTAMPTZ(paramInt + 1);
/*      */     } 
/*      */     
/* 1312 */     return tIMESTAMPTZ;
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized TIMESTAMPLTZ getTIMESTAMPLTZ(int paramInt) throws SQLException {
/* 1318 */     TIMESTAMPLTZ tIMESTAMPLTZ = null;
/*      */     
/* 1320 */     setIsNull(3);
/*      */     
/* 1322 */     if (isOnInsertRow() || (isUpdatingRow() && isRowBufferUpdatedAt(paramInt))) {
/*      */ 
/*      */       
/* 1325 */       Datum datum = getRowBufferDatumAt(paramInt);
/*      */       
/* 1327 */       setIsNull((datum == null));
/*      */       
/* 1329 */       if (datum != null && !(datum instanceof TIMESTAMPLTZ)) {
/* 1330 */         DatabaseError.throwSqlException(4, "getTIMESTAMPLTZ");
/*      */       }
/*      */       
/* 1333 */       tIMESTAMPLTZ = (TIMESTAMPLTZ)datum;
/*      */     }
/*      */     else {
/*      */       
/* 1337 */       setIsNull(4);
/*      */       
/* 1339 */       tIMESTAMPLTZ = this.resultSet.getTIMESTAMPLTZ(paramInt + 1);
/*      */     } 
/*      */     
/* 1342 */     return tIMESTAMPLTZ;
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized INTERVALDS getINTERVALDS(int paramInt) throws SQLException {
/* 1348 */     INTERVALDS iNTERVALDS = null;
/*      */     
/* 1350 */     setIsNull(3);
/*      */     
/* 1352 */     if (isOnInsertRow() || (isUpdatingRow() && isRowBufferUpdatedAt(paramInt))) {
/*      */ 
/*      */       
/* 1355 */       Datum datum = getRowBufferDatumAt(paramInt);
/*      */       
/* 1357 */       setIsNull((datum == null));
/*      */       
/* 1359 */       if (datum != null && !(datum instanceof INTERVALDS)) {
/* 1360 */         DatabaseError.throwSqlException(4, "getINTERVALDS");
/*      */       }
/*      */       
/* 1363 */       iNTERVALDS = (INTERVALDS)datum;
/*      */     }
/*      */     else {
/*      */       
/* 1367 */       setIsNull(4);
/*      */       
/* 1369 */       iNTERVALDS = this.resultSet.getINTERVALDS(paramInt + 1);
/*      */     } 
/*      */     
/* 1372 */     return iNTERVALDS;
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized INTERVALYM getINTERVALYM(int paramInt) throws SQLException {
/* 1378 */     INTERVALYM iNTERVALYM = null;
/*      */     
/* 1380 */     setIsNull(3);
/*      */     
/* 1382 */     if (isOnInsertRow() || (isUpdatingRow() && isRowBufferUpdatedAt(paramInt))) {
/*      */ 
/*      */       
/* 1385 */       Datum datum = getRowBufferDatumAt(paramInt);
/*      */       
/* 1387 */       setIsNull((datum == null));
/*      */       
/* 1389 */       if (datum != null && !(datum instanceof INTERVALYM)) {
/* 1390 */         DatabaseError.throwSqlException(4, "getINTERVALYM");
/*      */       }
/*      */       
/* 1393 */       iNTERVALYM = (INTERVALYM)datum;
/*      */     }
/*      */     else {
/*      */       
/* 1397 */       setIsNull(4);
/*      */       
/* 1399 */       iNTERVALYM = this.resultSet.getINTERVALYM(paramInt + 1);
/*      */     } 
/*      */     
/* 1402 */     return iNTERVALYM;
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized ARRAY getARRAY(int paramInt) throws SQLException {
/* 1408 */     ARRAY aRRAY = null;
/*      */     
/* 1410 */     setIsNull(3);
/*      */     
/* 1412 */     if (isOnInsertRow() || (isUpdatingRow() && isRowBufferUpdatedAt(paramInt))) {
/*      */ 
/*      */       
/* 1415 */       Datum datum = getRowBufferDatumAt(paramInt);
/*      */       
/* 1417 */       setIsNull((datum == null));
/*      */       
/* 1419 */       if (datum != null && !(datum instanceof ARRAY)) {
/* 1420 */         DatabaseError.throwSqlException(4, "getARRAY");
/*      */       }
/*      */       
/* 1423 */       aRRAY = (ARRAY)datum;
/*      */     }
/*      */     else {
/*      */       
/* 1427 */       setIsNull(4);
/*      */       
/* 1429 */       aRRAY = this.resultSet.getARRAY(paramInt + 1);
/*      */     } 
/*      */     
/* 1432 */     return aRRAY;
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized STRUCT getSTRUCT(int paramInt) throws SQLException {
/* 1438 */     STRUCT sTRUCT = null;
/*      */     
/* 1440 */     setIsNull(3);
/*      */     
/* 1442 */     if (isOnInsertRow() || (isUpdatingRow() && isRowBufferUpdatedAt(paramInt))) {
/*      */ 
/*      */       
/* 1445 */       Datum datum = getRowBufferDatumAt(paramInt);
/*      */       
/* 1447 */       setIsNull((datum == null));
/*      */       
/* 1449 */       if (datum != null && !(datum instanceof STRUCT)) {
/* 1450 */         DatabaseError.throwSqlException(4, "getSTRUCT");
/*      */       }
/*      */       
/* 1453 */       sTRUCT = (STRUCT)datum;
/*      */     }
/*      */     else {
/*      */       
/* 1457 */       setIsNull(4);
/*      */       
/* 1459 */       sTRUCT = this.resultSet.getSTRUCT(paramInt + 1);
/*      */     } 
/*      */     
/* 1462 */     return sTRUCT;
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized OPAQUE getOPAQUE(int paramInt) throws SQLException {
/* 1468 */     OPAQUE oPAQUE = null;
/*      */     
/* 1470 */     setIsNull(3);
/*      */     
/* 1472 */     if (isOnInsertRow() || (isUpdatingRow() && isRowBufferUpdatedAt(paramInt))) {
/*      */ 
/*      */       
/* 1475 */       Datum datum = getRowBufferDatumAt(paramInt);
/*      */       
/* 1477 */       setIsNull((datum == null));
/*      */       
/* 1479 */       if (datum != null && !(datum instanceof OPAQUE)) {
/* 1480 */         DatabaseError.throwSqlException(4, "getOPAQUE");
/*      */       }
/*      */       
/* 1483 */       oPAQUE = (OPAQUE)datum;
/*      */     }
/*      */     else {
/*      */       
/* 1487 */       setIsNull(4);
/*      */       
/* 1489 */       oPAQUE = this.resultSet.getOPAQUE(paramInt + 1);
/*      */     } 
/*      */     
/* 1492 */     return oPAQUE;
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized REF getREF(int paramInt) throws SQLException {
/* 1498 */     REF rEF = null;
/*      */     
/* 1500 */     setIsNull(3);
/*      */     
/* 1502 */     if (isOnInsertRow() || (isUpdatingRow() && isRowBufferUpdatedAt(paramInt))) {
/*      */ 
/*      */       
/* 1505 */       Datum datum = getRowBufferDatumAt(paramInt);
/*      */       
/* 1507 */       setIsNull((datum == null));
/*      */       
/* 1509 */       if (datum != null && !(datum instanceof REF)) {
/* 1510 */         DatabaseError.throwSqlException(4, "getREF");
/*      */       }
/*      */       
/* 1513 */       rEF = (REF)datum;
/*      */     }
/*      */     else {
/*      */       
/* 1517 */       setIsNull(4);
/*      */       
/* 1519 */       rEF = this.resultSet.getREF(paramInt + 1);
/*      */     } 
/*      */     
/* 1522 */     return rEF;
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized CHAR getCHAR(int paramInt) throws SQLException {
/* 1528 */     CHAR cHAR = null;
/*      */     
/* 1530 */     setIsNull(3);
/*      */     
/* 1532 */     if (isOnInsertRow() || (isUpdatingRow() && isRowBufferUpdatedAt(paramInt))) {
/*      */ 
/*      */       
/* 1535 */       Datum datum = getRowBufferDatumAt(paramInt);
/*      */       
/* 1537 */       setIsNull((datum == null));
/*      */       
/* 1539 */       if (datum != null && !(datum instanceof CHAR)) {
/* 1540 */         DatabaseError.throwSqlException(4, "getCHAR");
/*      */       }
/*      */       
/* 1543 */       cHAR = (CHAR)datum;
/*      */     }
/*      */     else {
/*      */       
/* 1547 */       setIsNull(4);
/*      */       
/* 1549 */       cHAR = this.resultSet.getCHAR(paramInt + 1);
/*      */     } 
/*      */     
/* 1552 */     return cHAR;
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized RAW getRAW(int paramInt) throws SQLException {
/* 1558 */     RAW rAW = null;
/*      */     
/* 1560 */     setIsNull(3);
/*      */     
/* 1562 */     if (isOnInsertRow() || (isUpdatingRow() && isRowBufferUpdatedAt(paramInt))) {
/*      */ 
/*      */       
/* 1565 */       Datum datum = getRowBufferDatumAt(paramInt);
/*      */       
/* 1567 */       setIsNull((datum == null));
/*      */       
/* 1569 */       if (datum != null && !(datum instanceof RAW)) {
/* 1570 */         DatabaseError.throwSqlException(4, "getRAW");
/*      */       }
/*      */       
/* 1573 */       rAW = (RAW)datum;
/*      */     }
/*      */     else {
/*      */       
/* 1577 */       setIsNull(4);
/*      */       
/* 1579 */       rAW = this.resultSet.getRAW(paramInt + 1);
/*      */     } 
/*      */     
/* 1582 */     return rAW;
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized BLOB getBLOB(int paramInt) throws SQLException {
/* 1588 */     BLOB bLOB = null;
/*      */     
/* 1590 */     setIsNull(3);
/*      */     
/* 1592 */     if (isOnInsertRow() || (isUpdatingRow() && isRowBufferUpdatedAt(paramInt))) {
/*      */ 
/*      */       
/* 1595 */       Datum datum = getRowBufferDatumAt(paramInt);
/*      */       
/* 1597 */       setIsNull((datum == null));
/*      */       
/* 1599 */       if (datum != null && !(datum instanceof BLOB)) {
/* 1600 */         DatabaseError.throwSqlException(4, "getBLOB");
/*      */       }
/*      */       
/* 1603 */       bLOB = (BLOB)datum;
/*      */     }
/*      */     else {
/*      */       
/* 1607 */       setIsNull(4);
/*      */       
/* 1609 */       bLOB = this.resultSet.getBLOB(paramInt + 1);
/*      */     } 
/*      */     
/* 1612 */     return bLOB;
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized CLOB getCLOB(int paramInt) throws SQLException {
/* 1618 */     CLOB cLOB = null;
/*      */     
/* 1620 */     setIsNull(3);
/*      */     
/* 1622 */     if (isOnInsertRow() || (isUpdatingRow() && isRowBufferUpdatedAt(paramInt))) {
/*      */ 
/*      */       
/* 1625 */       Datum datum = getRowBufferDatumAt(paramInt);
/*      */       
/* 1627 */       setIsNull((datum == null));
/*      */       
/* 1629 */       if (datum != null && !(datum instanceof CLOB)) {
/* 1630 */         DatabaseError.throwSqlException(4, "getCLOB");
/*      */       }
/*      */       
/* 1633 */       cLOB = (CLOB)datum;
/*      */     }
/*      */     else {
/*      */       
/* 1637 */       setIsNull(4);
/*      */       
/* 1639 */       cLOB = this.resultSet.getCLOB(paramInt + 1);
/*      */     } 
/*      */     
/* 1642 */     return cLOB;
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized BFILE getBFILE(int paramInt) throws SQLException {
/* 1648 */     BFILE bFILE = null;
/*      */     
/* 1650 */     setIsNull(3);
/*      */     
/* 1652 */     if (isOnInsertRow() || (isUpdatingRow() && isRowBufferUpdatedAt(paramInt))) {
/*      */ 
/*      */       
/* 1655 */       Datum datum = getRowBufferDatumAt(paramInt);
/*      */       
/* 1657 */       setIsNull((datum == null));
/*      */       
/* 1659 */       if (datum != null && !(datum instanceof BFILE)) {
/* 1660 */         DatabaseError.throwSqlException(4, "getBFILE");
/*      */       }
/*      */       
/* 1663 */       bFILE = (BFILE)datum;
/*      */     }
/*      */     else {
/*      */       
/* 1667 */       setIsNull(4);
/*      */       
/* 1669 */       bFILE = this.resultSet.getBFILE(paramInt + 1);
/*      */     } 
/*      */     
/* 1672 */     return bFILE;
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized BFILE getBfile(int paramInt) throws SQLException {
/* 1678 */     return getBFILE(paramInt);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized CustomDatum getCustomDatum(int paramInt, CustomDatumFactory paramCustomDatumFactory) throws SQLException {
/* 1685 */     if (paramCustomDatumFactory == null) {
/* 1686 */       DatabaseError.throwSqlException(68);
/*      */     }
/* 1688 */     CustomDatum customDatum = null;
/*      */     
/* 1690 */     setIsNull(3);
/*      */     
/* 1692 */     if (isOnInsertRow() || (isUpdatingRow() && isRowBufferUpdatedAt(paramInt))) {
/*      */ 
/*      */       
/* 1695 */       Datum datum = getRowBufferDatumAt(paramInt);
/*      */       
/* 1697 */       setIsNull((datum == null));
/*      */       
/* 1699 */       customDatum = paramCustomDatumFactory.create(datum, 0);
/*      */     }
/*      */     else {
/*      */       
/* 1703 */       setIsNull(4);
/*      */       
/* 1705 */       customDatum = this.resultSet.getCustomDatum(paramInt + 1, paramCustomDatumFactory);
/*      */     } 
/*      */     
/* 1708 */     return customDatum;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized ORAData getORAData(int paramInt, ORADataFactory paramORADataFactory) throws SQLException {
/* 1715 */     if (paramORADataFactory == null) {
/* 1716 */       DatabaseError.throwSqlException(68);
/*      */     }
/* 1718 */     ORAData oRAData = null;
/*      */     
/* 1720 */     setIsNull(3);
/*      */     
/* 1722 */     if (isOnInsertRow() || (isUpdatingRow() && isRowBufferUpdatedAt(paramInt))) {
/*      */ 
/*      */       
/* 1725 */       Datum datum = getRowBufferDatumAt(paramInt);
/*      */       
/* 1727 */       setIsNull((datum == null));
/*      */       
/* 1729 */       oRAData = paramORADataFactory.create(datum, 0);
/*      */     }
/*      */     else {
/*      */       
/* 1733 */       setIsNull(4);
/*      */       
/* 1735 */       oRAData = this.resultSet.getORAData(paramInt + 1, paramORADataFactory);
/*      */     } 
/*      */     
/* 1738 */     return oRAData;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public ResultSetMetaData getMetaData() throws SQLException {
/* 1747 */     if (((OracleStatement)this.scrollStmt).closed) {
/* 1748 */       DatabaseError.throwSqlException(9, "getMetaData");
/*      */     }
/*      */     
/* 1751 */     synchronized (this.connection) {
/*      */       
/* 1753 */       synchronized (this) {
/*      */         
/* 1755 */         return (ResultSetMetaData)new OracleResultSetMetaData(this.connection, (OracleStatement)this.scrollStmt, 1);
/*      */       } 
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized int findColumn(String paramString) throws SQLException {
/* 1764 */     return this.resultSet.findColumn(paramString) - 1;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void setFetchDirection(int paramInt) throws SQLException {
/* 1773 */     this.resultSet.setFetchDirection(paramInt);
/*      */   }
/*      */ 
/*      */   
/*      */   public synchronized int getFetchDirection() throws SQLException {
/* 1778 */     return this.resultSet.getFetchDirection();
/*      */   }
/*      */ 
/*      */   
/*      */   public synchronized void setFetchSize(int paramInt) throws SQLException {
/* 1783 */     this.resultSet.setFetchSize(paramInt);
/*      */   }
/*      */ 
/*      */   
/*      */   public synchronized int getFetchSize() throws SQLException {
/* 1788 */     return this.resultSet.getFetchSize();
/*      */   }
/*      */ 
/*      */   
/*      */   public int getType() throws SQLException {
/* 1793 */     return this.rsetType;
/*      */   }
/*      */ 
/*      */   
/*      */   public int getConcurrency() throws SQLException {
/* 1798 */     return 1008;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public boolean rowUpdated() throws SQLException {
/* 1807 */     return false;
/*      */   }
/*      */ 
/*      */   
/*      */   public boolean rowInserted() throws SQLException {
/* 1812 */     return false;
/*      */   }
/*      */ 
/*      */   
/*      */   public boolean rowDeleted() throws SQLException {
/* 1817 */     return false;
/*      */   }
/*      */ 
/*      */   
/*      */   public synchronized void insertRow() throws SQLException {
/* 1822 */     if (!isOnInsertRow()) {
/* 1823 */       DatabaseError.throwSqlException(83);
/*      */     }
/* 1825 */     prepareInsertRowStatement();
/* 1826 */     prepareInsertRowBinds();
/* 1827 */     executeInsertRow();
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public void updateRow() throws SQLException {
/* 1833 */     synchronized (this.connection) {
/*      */       
/* 1835 */       synchronized (this) {
/*      */ 
/*      */         
/* 1838 */         if (isOnInsertRow()) {
/* 1839 */           DatabaseError.throwSqlException(84);
/*      */         }
/* 1841 */         int i = getNumColumnsChanged();
/*      */         
/* 1843 */         if (i > 0) {
/*      */           
/* 1845 */           prepareUpdateRowStatement(i);
/* 1846 */           prepareUpdateRowBinds(i);
/* 1847 */           executeUpdateRow();
/*      */         } 
/*      */       } 
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void deleteRow() throws SQLException {
/* 1857 */     if (isOnInsertRow()) {
/* 1858 */       DatabaseError.throwSqlException(84);
/*      */     }
/* 1860 */     prepareDeleteRowStatement();
/* 1861 */     prepareDeleteRowBinds();
/* 1862 */     executeDeleteRow();
/*      */   }
/*      */ 
/*      */   
/*      */   public void refreshRow() throws SQLException {
/* 1867 */     synchronized (this.connection) {
/*      */       
/* 1869 */       synchronized (this) {
/*      */ 
/*      */ 
/*      */         
/* 1873 */         if (isOnInsertRow()) {
/* 1874 */           DatabaseError.throwSqlException(84);
/*      */         }
/* 1876 */         this.resultSet.refreshRow();
/*      */       } 
/*      */     } 
/*      */   }
/*      */ 
/*      */   
/*      */   public synchronized void cancelRowUpdates() throws SQLException {
/* 1883 */     if (this.isUpdating) {
/*      */       
/* 1885 */       this.isUpdating = false;
/*      */       
/* 1887 */       clearRowBuffer();
/*      */     } 
/*      */   }
/*      */ 
/*      */   
/*      */   public synchronized void moveToInsertRow() throws SQLException {
/* 1893 */     if (isOnInsertRow()) {
/*      */       return;
/*      */     }
/* 1896 */     this.isInserting = true;
/*      */ 
/*      */     
/* 1899 */     if (this.rowBuffer == null) {
/* 1900 */       this.rowBuffer = new Object[getColumnCount()];
/*      */     }
/* 1902 */     if (this.m_nullIndicator == null) {
/* 1903 */       this.m_nullIndicator = new boolean[getColumnCount()];
/*      */     }
/* 1905 */     clearRowBuffer();
/*      */   }
/*      */ 
/*      */   
/*      */   public synchronized void moveToCurrentRow() throws SQLException {
/* 1910 */     cancelRowInserts();
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void updateString(int paramInt, String paramString) throws SQLException {
/* 1916 */     updateObject(paramInt, paramString);
/*      */   }
/*      */ 
/*      */   
/*      */   public synchronized void updateNull(int paramInt) throws SQLException {
/* 1921 */     setRowBufferAt(paramInt, (Datum)null);
/*      */   }
/*      */ 
/*      */   
/*      */   public void updateBoolean(int paramInt, boolean paramBoolean) throws SQLException {
/* 1926 */     updateObject(paramInt, new Boolean(paramBoolean));
/*      */   }
/*      */ 
/*      */   
/*      */   public void updateByte(int paramInt, byte paramByte) throws SQLException {
/* 1931 */     updateObject(paramInt, new Integer(paramByte));
/*      */   }
/*      */ 
/*      */   
/*      */   public void updateShort(int paramInt, short paramShort) throws SQLException {
/* 1936 */     updateObject(paramInt, new Integer(paramShort));
/*      */   }
/*      */ 
/*      */   
/*      */   public void updateInt(int paramInt1, int paramInt2) throws SQLException {
/* 1941 */     updateObject(paramInt1, new Integer(paramInt2));
/*      */   }
/*      */ 
/*      */   
/*      */   public void updateLong(int paramInt, long paramLong) throws SQLException {
/* 1946 */     updateObject(paramInt, new Long(paramLong));
/*      */   }
/*      */ 
/*      */   
/*      */   public void updateFloat(int paramInt, float paramFloat) throws SQLException {
/* 1951 */     updateObject(paramInt, new Float(paramFloat));
/*      */   }
/*      */ 
/*      */   
/*      */   public void updateDouble(int paramInt, double paramDouble) throws SQLException {
/* 1956 */     updateObject(paramInt, new Double(paramDouble));
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public void updateBigDecimal(int paramInt, BigDecimal paramBigDecimal) throws SQLException {
/* 1962 */     updateObject(paramInt, paramBigDecimal);
/*      */   }
/*      */ 
/*      */   
/*      */   public void updateBytes(int paramInt, byte[] paramArrayOfbyte) throws SQLException {
/* 1967 */     updateObject(paramInt, paramArrayOfbyte);
/*      */   }
/*      */ 
/*      */   
/*      */   public void updateDate(int paramInt, Date paramDate) throws SQLException {
/* 1972 */     updateObject(paramInt, paramDate);
/*      */   }
/*      */ 
/*      */   
/*      */   public void updateTime(int paramInt, Time paramTime) throws SQLException {
/* 1977 */     updateObject(paramInt, paramTime);
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public void updateTimestamp(int paramInt, Timestamp paramTimestamp) throws SQLException {
/* 1983 */     updateObject(paramInt, paramTimestamp);
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public void updateAsciiStream(int paramInt1, InputStream paramInputStream, int paramInt2) throws SQLException {
/* 1989 */     int i = getInternalMetadata().getColumnType(1 + paramInt1);
/*      */     
/* 1991 */     if (paramInputStream != null && paramInt2 > 0) {
/*      */       
/* 1993 */       if (!isStreamType(i)) {
/*      */         
/* 1995 */         byte[] arrayOfByte = new byte[paramInt2];
/*      */ 
/*      */         
/*      */         try {
/* 1999 */           int j = paramInputStream.read(arrayOfByte);
/*      */           
/* 2001 */           paramInputStream.close();
/* 2002 */           if (j <= 0) {
/*      */             
/* 2004 */             updateNull(paramInt1);
/*      */             return;
/*      */           } 
/* 2007 */           String str = new String(arrayOfByte, 0, j);
/*      */           
/* 2009 */           updateString(paramInt1, str);
/*      */         }
/* 2011 */         catch (IOException iOException) {
/*      */           
/* 2013 */           DatabaseError.throwSqlException(iOException);
/*      */         }
/*      */       
/*      */       } else {
/*      */         
/* 2018 */         int[] arrayOfInt = { paramInt2, 1 };
/*      */ 
/*      */ 
/*      */ 
/*      */         
/* 2023 */         setRowBufferAt(paramInt1, paramInputStream, arrayOfInt);
/*      */       }
/*      */     
/*      */     } else {
/*      */       
/* 2028 */       setRowBufferAt(paramInt1, (Datum)null);
/*      */     } 
/*      */   }
/*      */ 
/*      */   
/*      */   final boolean isStreamType(int paramInt) {
/* 2034 */     return (paramInt == 2004 || paramInt == 2005 || paramInt == -4 || paramInt == -1);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void updateBinaryStream(int paramInt1, InputStream paramInputStream, int paramInt2) throws SQLException {
/* 2043 */     int i = getInternalMetadata().getColumnType(1 + paramInt1);
/*      */     
/* 2045 */     if (paramInputStream != null && paramInt2 > 0) {
/*      */       
/* 2047 */       if (!isStreamType(i)) {
/*      */         
/* 2049 */         byte[] arrayOfByte = new byte[paramInt2];
/*      */ 
/*      */         
/*      */         try {
/* 2053 */           int j = paramInputStream.read(arrayOfByte);
/*      */           
/* 2055 */           paramInputStream.close();
/* 2056 */           if (j < paramInt2) {
/*      */             
/* 2058 */             byte[] arrayOfByte1 = new byte[j];
/* 2059 */             System.arraycopy(arrayOfByte, 0, arrayOfByte1, 0, j);
/* 2060 */             arrayOfByte = arrayOfByte1;
/* 2061 */           } else if (j <= 0) {
/*      */             
/* 2063 */             updateNull(paramInt1);
/*      */             
/*      */             return;
/*      */           } 
/* 2067 */           updateBytes(paramInt1, arrayOfByte);
/*      */         }
/* 2069 */         catch (IOException iOException) {
/*      */           
/* 2071 */           DatabaseError.throwSqlException(iOException);
/*      */         }
/*      */       
/*      */       } else {
/*      */         
/* 2076 */         int[] arrayOfInt = { paramInt2, 2 };
/*      */ 
/*      */ 
/*      */ 
/*      */         
/* 2081 */         setRowBufferAt(paramInt1, paramInputStream, arrayOfInt);
/*      */       }
/*      */     
/*      */     } else {
/*      */       
/* 2086 */       setRowBufferAt(paramInt1, (Datum)null);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public void updateCharacterStream(int paramInt1, Reader paramReader, int paramInt2) throws SQLException {
/* 2093 */     int i = getInternalMetadata().getColumnType(1 + paramInt1);
/*      */     
/* 2095 */     if (paramReader != null && paramInt2 > 0) {
/*      */       
/* 2097 */       if (!isStreamType(i)) {
/*      */         
/* 2099 */         char[] arrayOfChar = new char[paramInt2];
/*      */ 
/*      */         
/*      */         try {
/* 2103 */           int j = paramReader.read(arrayOfChar);
/*      */           
/* 2105 */           paramReader.close();
/* 2106 */           if (j <= 0) {
/*      */             
/* 2108 */             updateNull(paramInt1);
/*      */             
/*      */             return;
/*      */           } 
/* 2112 */           String str = new String(arrayOfChar, 0, j);
/* 2113 */           updateString(paramInt1, str);
/*      */         }
/* 2115 */         catch (IOException iOException) {
/*      */           
/* 2117 */           DatabaseError.throwSqlException(iOException);
/*      */         }
/*      */       
/*      */       } else {
/*      */         
/* 2122 */         int[] arrayOfInt = { paramInt2 };
/*      */ 
/*      */ 
/*      */ 
/*      */         
/* 2127 */         setRowBufferAt(paramInt1, paramReader, arrayOfInt);
/*      */       }
/*      */     
/*      */     } else {
/*      */       
/* 2132 */       setRowBufferAt(paramInt1, (Datum)null);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public void updateObject(int paramInt1, Object paramObject, int paramInt2) throws SQLException {
/* 2139 */     updateObject(paramInt1, paramObject);
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void updateObject(int paramInt, Object paramObject) throws SQLException {
/* 2145 */     Datum datum = null;
/*      */     
/* 2147 */     if (paramObject != null)
/*      */     {
/* 2149 */       if (paramObject instanceof Datum) {
/* 2150 */         datum = (Datum)paramObject;
/*      */       } else {
/*      */         
/* 2153 */         OracleResultSetMetaData oracleResultSetMetaData = (OracleResultSetMetaData)getInternalMetadata();
/* 2154 */         int i = paramInt + 1;
/* 2155 */         datum = SQLUtil.makeOracleDatum(this.connection, paramObject, oracleResultSetMetaData.getColumnType(i), null, oracleResultSetMetaData.isNCHAR(i));
/*      */       } 
/*      */     }
/*      */ 
/*      */     
/* 2160 */     setRowBufferAt(paramInt, datum);
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public synchronized void updateOracleObject(int paramInt, Datum paramDatum) throws SQLException {
/* 2166 */     setRowBufferAt(paramInt, paramDatum);
/*      */   }
/*      */ 
/*      */   
/*      */   public void updateROWID(int paramInt, ROWID paramROWID) throws SQLException {
/* 2171 */     updateOracleObject(paramInt, (Datum)paramROWID);
/*      */   }
/*      */ 
/*      */   
/*      */   public void updateNUMBER(int paramInt, NUMBER paramNUMBER) throws SQLException {
/* 2176 */     updateOracleObject(paramInt, (Datum)paramNUMBER);
/*      */   }
/*      */ 
/*      */   
/*      */   public void updateDATE(int paramInt, DATE paramDATE) throws SQLException {
/* 2181 */     updateOracleObject(paramInt, (Datum)paramDATE);
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public void updateINTERVALYM(int paramInt, INTERVALYM paramINTERVALYM) throws SQLException {
/* 2187 */     updateOracleObject(paramInt, (Datum)paramINTERVALYM);
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public void updateINTERVALDS(int paramInt, INTERVALDS paramINTERVALDS) throws SQLException {
/* 2193 */     updateOracleObject(paramInt, (Datum)paramINTERVALDS);
/*      */   }
/*      */ 
/*      */   
/*      */   public void updateTIMESTAMP(int paramInt, TIMESTAMP paramTIMESTAMP) throws SQLException {
/* 2198 */     updateOracleObject(paramInt, (Datum)paramTIMESTAMP);
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public void updateTIMESTAMPTZ(int paramInt, TIMESTAMPTZ paramTIMESTAMPTZ) throws SQLException {
/* 2204 */     updateOracleObject(paramInt, (Datum)paramTIMESTAMPTZ);
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public void updateTIMESTAMPLTZ(int paramInt, TIMESTAMPLTZ paramTIMESTAMPLTZ) throws SQLException {
/* 2210 */     updateOracleObject(paramInt, (Datum)paramTIMESTAMPLTZ);
/*      */   }
/*      */ 
/*      */   
/*      */   public void updateARRAY(int paramInt, ARRAY paramARRAY) throws SQLException {
/* 2215 */     updateOracleObject(paramInt, (Datum)paramARRAY);
/*      */   }
/*      */ 
/*      */   
/*      */   public void updateSTRUCT(int paramInt, STRUCT paramSTRUCT) throws SQLException {
/* 2220 */     updateOracleObject(paramInt, (Datum)paramSTRUCT);
/*      */   }
/*      */ 
/*      */   
/*      */   public void updateOPAQUE(int paramInt, OPAQUE paramOPAQUE) throws SQLException {
/* 2225 */     updateOracleObject(paramInt, (Datum)paramOPAQUE);
/*      */   }
/*      */ 
/*      */   
/*      */   public void updateREF(int paramInt, REF paramREF) throws SQLException {
/* 2230 */     updateOracleObject(paramInt, (Datum)paramREF);
/*      */   }
/*      */ 
/*      */   
/*      */   public void updateCHAR(int paramInt, CHAR paramCHAR) throws SQLException {
/* 2235 */     updateOracleObject(paramInt, (Datum)paramCHAR);
/*      */   }
/*      */ 
/*      */   
/*      */   public void updateRAW(int paramInt, RAW paramRAW) throws SQLException {
/* 2240 */     updateOracleObject(paramInt, (Datum)paramRAW);
/*      */   }
/*      */ 
/*      */   
/*      */   public void updateBLOB(int paramInt, BLOB paramBLOB) throws SQLException {
/* 2245 */     updateOracleObject(paramInt, (Datum)paramBLOB);
/*      */   }
/*      */ 
/*      */   
/*      */   public void updateCLOB(int paramInt, CLOB paramCLOB) throws SQLException {
/* 2250 */     updateOracleObject(paramInt, (Datum)paramCLOB);
/*      */   }
/*      */ 
/*      */   
/*      */   public void updateBFILE(int paramInt, BFILE paramBFILE) throws SQLException {
/* 2255 */     updateOracleObject(paramInt, (Datum)paramBFILE);
/*      */   }
/*      */ 
/*      */   
/*      */   public void updateBfile(int paramInt, BFILE paramBFILE) throws SQLException {
/* 2260 */     updateOracleObject(paramInt, (Datum)paramBFILE);
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public void updateCustomDatum(int paramInt, CustomDatum paramCustomDatum) throws SQLException {
/* 2266 */     throw new Error("wanna do datum = ((CustomDatum) x).toDatum(m_comm)");
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void updateORAData(int paramInt, ORAData paramORAData) throws SQLException {
/* 2274 */     Datum datum = paramORAData.toDatum((Connection)this.connection);
/*      */     
/* 2276 */     updateOracleObject(paramInt, datum);
/*      */   }
/*      */ 
/*      */   
/*      */   public void updateRef(int paramInt, Ref paramRef) throws SQLException {
/* 2281 */     updateREF(paramInt, (REF)paramRef);
/*      */   }
/*      */ 
/*      */   
/*      */   public void updateBlob(int paramInt, Blob paramBlob) throws SQLException {
/* 2286 */     updateBLOB(paramInt, (BLOB)paramBlob);
/*      */   }
/*      */ 
/*      */   
/*      */   public void updateClob(int paramInt, Clob paramClob) throws SQLException {
/* 2291 */     updateCLOB(paramInt, (CLOB)paramClob);
/*      */   }
/*      */ 
/*      */   
/*      */   public void updateArray(int paramInt, Array paramArray) throws SQLException {
/* 2296 */     updateARRAY(paramInt, (ARRAY)paramArray);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   int getColumnCount() throws SQLException {
/* 2308 */     if (this.columnCount == 0)
/*      */     {
/* 2310 */       if (this.resultSet instanceof OracleResultSetImpl) {
/*      */         
/* 2312 */         if (((OracleResultSetImpl)this.resultSet).statement.accessors != null) {
/* 2313 */           this.columnCount = ((OracleResultSetImpl)this.resultSet).statement.numberOfDefinePositions;
/*      */         } else {
/*      */           
/* 2316 */           this.columnCount = getInternalMetadata().getColumnCount();
/*      */         } 
/*      */       } else {
/* 2319 */         this.columnCount = ((ScrollableResultSet)this.resultSet).getColumnCount();
/*      */       } 
/*      */     }
/* 2322 */     return this.columnCount;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   ResultSetMetaData getInternalMetadata() throws SQLException {
/* 2330 */     if (this.rsetMetaData == null) {
/* 2331 */       this.rsetMetaData = this.resultSet.getMetaData();
/*      */     }
/* 2333 */     return this.rsetMetaData;
/*      */   }
/*      */ 
/*      */   
/*      */   private synchronized void cancelRowChanges() throws SQLException {
/* 2338 */     synchronized (this.connection) {
/*      */       
/* 2340 */       synchronized (this) {
/*      */         
/* 2342 */         if (this.isInserting) {
/* 2343 */           cancelRowInserts();
/*      */         }
/* 2345 */         if (this.isUpdating) {
/* 2346 */           cancelRowUpdates();
/*      */         }
/*      */       } 
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   boolean isOnInsertRow() {
/* 2356 */     return this.isInserting;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private void cancelRowInserts() {
/* 2364 */     if (this.isInserting) {
/*      */       
/* 2366 */       this.isInserting = false;
/*      */       
/* 2368 */       clearRowBuffer();
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   boolean isUpdatingRow() {
/* 2377 */     return this.isUpdating;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private void clearRowBuffer() {
/* 2385 */     if (this.rowBuffer != null)
/*      */     {
/* 2387 */       for (byte b = 0; b < this.rowBuffer.length; b++) {
/* 2388 */         this.rowBuffer[b] = null;
/*      */       }
/*      */     }
/* 2391 */     if (this.m_nullIndicator != null)
/*      */     {
/* 2393 */       for (byte b = 0; b < this.m_nullIndicator.length; b++) {
/* 2394 */         this.m_nullIndicator[b] = false;
/*      */       }
/*      */     }
/* 2397 */     if (this.typeInfo != null)
/*      */     {
/* 2399 */       for (byte b = 0; b < this.typeInfo.length; b++) {
/* 2400 */         if (this.typeInfo[b] != null) {
/* 2401 */           for (byte b1 = 0; b1 < (this.typeInfo[b]).length; b1++) {
/* 2402 */             this.typeInfo[b][b1] = 0;
/*      */           }
/*      */         }
/*      */       } 
/*      */     }
/*      */   }
/*      */ 
/*      */   
/*      */   private void setRowBufferAt(int paramInt, Datum paramDatum) throws SQLException {
/* 2411 */     setRowBufferAt(paramInt, paramDatum, (int[])null);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private void setRowBufferAt(int paramInt, Object paramObject, int[] paramArrayOfint) throws SQLException {
/* 2420 */     if (!this.isInserting)
/*      */     {
/* 2422 */       if (isBeforeFirst() || isAfterLast() || getRow() == 0) {
/* 2423 */         DatabaseError.throwSqlException(82);
/*      */       } else {
/* 2425 */         this.isUpdating = true;
/*      */       } 
/*      */     }
/* 2428 */     if (paramInt < 1 || paramInt > getColumnCount() - 1) {
/* 2429 */       DatabaseError.throwSqlException(68, "setRowBufferAt");
/*      */     }
/*      */     
/* 2432 */     if (this.rowBuffer == null) {
/* 2433 */       this.rowBuffer = new Object[getColumnCount()];
/*      */     }
/* 2435 */     if (this.m_nullIndicator == null) {
/*      */       
/* 2437 */       this.m_nullIndicator = new boolean[getColumnCount()];
/*      */       
/* 2439 */       for (byte b = 0; b < getColumnCount(); b++) {
/* 2440 */         this.m_nullIndicator[b] = false;
/*      */       }
/*      */     } 
/* 2443 */     if (paramArrayOfint != null) {
/*      */       
/* 2445 */       if (this.typeInfo == null)
/*      */       {
/* 2447 */         this.typeInfo = new int[getColumnCount()][];
/*      */       }
/*      */       
/* 2450 */       this.typeInfo[paramInt] = paramArrayOfint;
/*      */     } 
/*      */     
/* 2453 */     this.rowBuffer[paramInt] = paramObject;
/* 2454 */     this.m_nullIndicator[paramInt] = (paramObject == null);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private Datum getRowBufferDatumAt(int paramInt) throws SQLException {
/* 2462 */     if (paramInt < 1 || paramInt > getColumnCount() - 1) {
/* 2463 */       DatabaseError.throwSqlException(68, "getRowBufferDatumAt");
/*      */     }
/*      */     
/* 2466 */     Datum datum = null;
/*      */     
/* 2468 */     if (this.rowBuffer != null) {
/*      */       
/* 2470 */       Object object = this.rowBuffer[paramInt];
/*      */       
/* 2472 */       if (object != null)
/*      */       {
/* 2474 */         if (object instanceof Datum) {
/*      */           
/* 2476 */           datum = (Datum)object;
/*      */         }
/*      */         else {
/*      */           
/* 2480 */           OracleResultSetMetaData oracleResultSetMetaData = (OracleResultSetMetaData)getInternalMetadata();
/* 2481 */           int i = paramInt + 1;
/* 2482 */           datum = SQLUtil.makeOracleDatum(this.connection, object, oracleResultSetMetaData.getColumnType(i), null, oracleResultSetMetaData.isNCHAR(i));
/*      */ 
/*      */ 
/*      */           
/* 2486 */           this.rowBuffer[paramInt] = datum;
/*      */         } 
/*      */       }
/*      */     } 
/*      */     
/* 2491 */     return datum;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private Object getRowBufferAt(int paramInt) throws SQLException {
/* 2499 */     if (paramInt < 1 || paramInt > getColumnCount() - 1) {
/* 2500 */       DatabaseError.throwSqlException(68, "getRowBufferDatumAt");
/*      */     }
/*      */     
/* 2503 */     if (this.rowBuffer != null)
/*      */     {
/* 2505 */       return this.rowBuffer[paramInt];
/*      */     }
/*      */     
/* 2508 */     return null;
/*      */   }
/*      */ 
/*      */   
/*      */   private boolean isRowBufferUpdatedAt(int paramInt) {
/* 2513 */     if (this.rowBuffer == null) {
/* 2514 */       return false;
/*      */     }
/* 2516 */     return (this.rowBuffer[paramInt] != null || this.m_nullIndicator[paramInt]);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private void prepareInsertRowStatement() throws SQLException {
/* 2524 */     if (this.insertStmt == null) {
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 2529 */       this.insertStmt = (OraclePreparedStatement)this.connection.prepareStatement(((OracleStatement)this.scrollStmt).sqlObject.getInsertSqlForUpdatableResultSet(this));
/*      */ 
/*      */       
/* 2532 */       this.insertStmt.setQueryTimeout(((Statement)this.scrollStmt).getQueryTimeout());
/* 2533 */       if (((OracleStatement)this.scrollStmt).sqlObject.generatedSqlNeedEscapeProcessing()) {
/* 2534 */         this.insertStmt.setEscapeProcessing(true);
/*      */       }
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private void prepareInsertRowBinds() throws SQLException {
/* 2544 */     int i = 1;
/*      */ 
/*      */     
/* 2547 */     i = prepareSubqueryBinds(this.insertStmt, i);
/*      */     
/* 2549 */     OracleResultSetMetaData oracleResultSetMetaData = (OracleResultSetMetaData)getInternalMetadata();
/*      */     
/* 2551 */     for (byte b = 1; b < getColumnCount(); b++) {
/*      */       
/* 2553 */       Object object = getRowBufferAt(b);
/*      */       
/* 2555 */       if (object != null) {
/*      */         
/* 2557 */         if (object instanceof Reader)
/*      */         {
/* 2559 */           this.insertStmt.setCharacterStream(i + b - 1, (Reader)object, this.typeInfo[b][0]);
/*      */         
/*      */         }
/* 2562 */         else if (object instanceof InputStream)
/*      */         {
/* 2564 */           if (this.typeInfo[b][1] == 2) {
/* 2565 */             this.insertStmt.setBinaryStream(i + b - 1, (InputStream)object, this.typeInfo[b][0]);
/*      */           
/*      */           }
/* 2568 */           else if (this.typeInfo[b][1] == 1) {
/* 2569 */             this.insertStmt.setAsciiStream(i + b - 1, (InputStream)object, this.typeInfo[b][0]);
/*      */           }
/*      */         
/*      */         }
/*      */         else
/*      */         {
/* 2575 */           Datum datum = getRowBufferDatumAt(b);
/*      */           
/* 2577 */           if (oracleResultSetMetaData.isNCHAR(b + 1))
/* 2578 */             this.insertStmt.setFormOfUse(i + b - 1, (short)2); 
/* 2579 */           this.insertStmt.setOracleObject(i + b - 1, datum);
/*      */         
/*      */         }
/*      */ 
/*      */       
/*      */       }
/*      */       else {
/*      */ 
/*      */         
/* 2588 */         int j = getInternalMetadata().getColumnType(b + 1);
/*      */         
/* 2590 */         if (j == 2006 || j == 2002 || j == 2008 || j == 2007 || j == 2003) {
/*      */ 
/*      */ 
/*      */           
/* 2594 */           this.insertStmt.setNull(i + b - 1, j, getInternalMetadata().getColumnTypeName(b + 1));
/*      */         
/*      */         }
/*      */         else {
/*      */           
/* 2599 */           this.insertStmt.setNull(i + b - 1, j);
/*      */         } 
/*      */       } 
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private void executeInsertRow() throws SQLException {
/* 2610 */     if (this.insertStmt.executeUpdate() != 1) {
/* 2611 */       DatabaseError.throwSqlException(85);
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private int getNumColumnsChanged() throws SQLException {
/* 2621 */     byte b = 0;
/*      */     
/* 2623 */     if (this.indexColsChanged == null) {
/* 2624 */       this.indexColsChanged = new int[getColumnCount()];
/*      */     }
/* 2626 */     if (this.rowBuffer != null)
/*      */     {
/* 2628 */       for (byte b1 = 1; b1 < getColumnCount(); b1++) {
/*      */         
/* 2630 */         if (this.rowBuffer[b1] != null || (this.rowBuffer[b1] == null && this.m_nullIndicator[b1]))
/*      */         {
/*      */           
/* 2633 */           this.indexColsChanged[b++] = b1;
/*      */         }
/*      */       } 
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 2641 */     return b;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private void prepareUpdateRowStatement(int paramInt) throws SQLException {
/* 2653 */     if (this.updateStmt != null) {
/* 2654 */       this.updateStmt.close();
/*      */     }
/*      */ 
/*      */ 
/*      */     
/* 2659 */     this.updateStmt = (OraclePreparedStatement)this.connection.prepareStatement(((OracleStatement)this.scrollStmt).sqlObject.getUpdateSqlForUpdatableResultSet(this, paramInt, this.rowBuffer, this.indexColsChanged));
/*      */ 
/*      */ 
/*      */     
/* 2663 */     this.updateStmt.setQueryTimeout(((Statement)this.scrollStmt).getQueryTimeout());
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private void prepareUpdateRowBinds(int paramInt) throws SQLException {
/* 2671 */     int i = 1;
/*      */ 
/*      */     
/* 2674 */     i = prepareSubqueryBinds(this.updateStmt, i);
/*      */     
/* 2676 */     OracleResultSetMetaData oracleResultSetMetaData = (OracleResultSetMetaData)getInternalMetadata();
/*      */     
/* 2678 */     for (byte b = 0; b < paramInt; b++) {
/*      */       
/* 2680 */       int j = this.indexColsChanged[b];
/* 2681 */       Object object = getRowBufferAt(j);
/*      */       
/* 2683 */       if (object != null) {
/*      */         
/* 2685 */         if (object instanceof Reader) {
/*      */           
/* 2687 */           this.updateStmt.setCharacterStream(i++, (Reader)object, this.typeInfo[j][0]);
/*      */         
/*      */         }
/* 2690 */         else if (object instanceof InputStream) {
/*      */           
/* 2692 */           if (this.typeInfo[j][1] == 2) {
/*      */ 
/*      */             
/* 2695 */             this.updateStmt.setBinaryStream(i++, (InputStream)object, this.typeInfo[j][0]);
/*      */           }
/* 2697 */           else if (this.typeInfo[j][1] == 1) {
/* 2698 */             this.updateStmt.setAsciiStream(i++, (InputStream)object, this.typeInfo[j][0]);
/*      */           }
/*      */         
/*      */         } else {
/*      */           
/* 2703 */           Datum datum = getRowBufferDatumAt(j);
/*      */           
/* 2705 */           if (oracleResultSetMetaData.isNCHAR(j + 1))
/* 2706 */             this.updateStmt.setFormOfUse(i, (short)2); 
/* 2707 */           this.updateStmt.setOracleObject(i++, datum);
/*      */         }
/*      */       
/*      */       }
/*      */       else {
/*      */         
/* 2713 */         int k = getInternalMetadata().getColumnType(j + 1);
/*      */         
/* 2715 */         if (k == 2006 || k == 2002 || k == 2008 || k == 2007 || k == 2003) {
/*      */ 
/*      */ 
/*      */           
/* 2719 */           this.updateStmt.setNull(i++, k, getInternalMetadata().getColumnTypeName(j + 1));
/*      */         
/*      */         }
/*      */         else {
/*      */           
/* 2724 */           this.updateStmt.setNull(i++, k);
/*      */         } 
/*      */       } 
/*      */     } 
/*      */ 
/*      */     
/* 2730 */     prepareCompareSelfBinds(this.updateStmt, i);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private void executeUpdateRow() throws SQLException {
/*      */     try {
/* 2740 */       if (this.updateStmt.executeUpdate() == 0) {
/* 2741 */         DatabaseError.throwSqlException(85);
/*      */       }
/*      */ 
/*      */       
/* 2745 */       if (this.isCachedRset)
/*      */       {
/* 2747 */         if (this.autoRefetch)
/*      */         {
/* 2749 */           ((ScrollableResultSet)this.resultSet).refreshRowsInCache(getRow(), 1, 1000);
/*      */           
/* 2751 */           cancelRowUpdates();
/*      */         }
/*      */         else
/*      */         {
/* 2755 */           if (this.rowBuffer != null)
/*      */           {
/* 2757 */             for (byte b = 1; b < getColumnCount(); b++) {
/*      */               
/* 2759 */               if (this.rowBuffer[b] != null || (this.rowBuffer[b] == null && this.m_nullIndicator[b]))
/*      */               {
/*      */                 
/* 2762 */                 ((ScrollableResultSet)this.resultSet).setCurrentRowValueAt(this, b + 1, this.rowBuffer[b]);
/*      */               }
/*      */             } 
/*      */           }
/*      */ 
/*      */           
/* 2768 */           cancelRowUpdates();
/*      */         
/*      */         }
/*      */ 
/*      */       
/*      */       }
/*      */     
/*      */     }
/*      */     finally {
/*      */ 
/*      */       
/* 2779 */       if (this.updateStmt != null) {
/*      */         
/* 2781 */         this.updateStmt.close();
/*      */         
/* 2783 */         this.updateStmt = null;
/*      */       } 
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private void prepareDeleteRowStatement() throws SQLException {
/* 2793 */     if (this.deleteStmt == null) {
/*      */       
/* 2795 */       StringBuffer stringBuffer = new StringBuffer();
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 2800 */       this.deleteStmt = (OraclePreparedStatement)this.connection.prepareStatement(((OracleStatement)this.scrollStmt).sqlObject.getDeleteSqlForUpdatableResultSet(this));
/*      */ 
/*      */       
/* 2803 */       this.deleteStmt.setQueryTimeout(((Statement)this.scrollStmt).getQueryTimeout());
/* 2804 */       if (((OracleStatement)this.scrollStmt).sqlObject.generatedSqlNeedEscapeProcessing()) {
/* 2805 */         this.deleteStmt.setEscapeProcessing(true);
/*      */       }
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private void prepareDeleteRowBinds() throws SQLException {
/* 2814 */     int i = 1;
/*      */ 
/*      */     
/* 2817 */     i = prepareSubqueryBinds(this.deleteStmt, i);
/*      */ 
/*      */     
/* 2820 */     prepareCompareSelfBinds(this.deleteStmt, i);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private void executeDeleteRow() throws SQLException {
/* 2830 */     if (this.deleteStmt.executeUpdate() == 0) {
/* 2831 */       DatabaseError.throwSqlException(85);
/*      */     }
/*      */ 
/*      */     
/* 2835 */     if (this.isCachedRset) {
/* 2836 */       ((ScrollableResultSet)this.resultSet).removeRowInCache(getRow());
/*      */     }
/*      */   }
/*      */ 
/*      */   
/*      */   private int prepareCompareSelfBinds(OraclePreparedStatement paramOraclePreparedStatement, int paramInt) throws SQLException {
/* 2842 */     Datum datum = this.resultSet.getOracleObject(1);
/*      */     
/* 2844 */     paramOraclePreparedStatement.setOracleObject(paramInt, this.resultSet.getOracleObject(1));
/*      */     
/* 2846 */     return paramInt + 1;
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   private int prepareSubqueryBinds(OraclePreparedStatement paramOraclePreparedStatement, int paramInt) throws SQLException {
/* 2852 */     int i = this.scrollStmt.copyBinds((Statement)paramOraclePreparedStatement, paramInt - 1);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 2870 */     return i + 1;
/*      */   }
/*      */ 
/*      */   
/*      */   private void setIsNull(int paramInt) {
/* 2875 */     this.wasNull = paramInt;
/*      */   }
/*      */ 
/*      */   
/*      */   private void setIsNull(boolean paramBoolean) {
/* 2880 */     if (paramBoolean) {
/* 2881 */       this.wasNull = 1;
/*      */     } else {
/* 2883 */       this.wasNull = 2;
/*      */     } 
/*      */   }
/*      */ 
/*      */   
/* 2888 */   private static final String _Copyright_2004_Oracle_All_Rights_Reserved_ = null;
/*      */   public static final boolean TRACE = false;
/*      */   public static final boolean PRIVATE_TRACE = false;
/*      */   public static final String BUILD_DATE = "Sat_Feb__2_11:39:40_PST_2008";
/*      */ }


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\lib\ojdbc14.jar!\oracle\jdbc\driver\UpdatableResultSet.class
 * Java compiler version: 2 (46.0)
 * JD-Core Version:       1.1.3
 */