package oracle.jdbc.internal;

import java.sql.Connection;
import java.sql.ResultSet;
import java.sql.ResultSetMetaData;
import java.sql.SQLException;
import java.util.Enumeration;
import java.util.Map;
import java.util.Properties;
import javax.transaction.xa.XAResource;
import oracle.jdbc.OracleConnection;
import oracle.jdbc.oracore.OracleTypeADT;
import oracle.jdbc.oracore.OracleTypeCLOB;
import oracle.jdbc.pool.OracleConnectionCacheCallback;
import oracle.jdbc.pool.OraclePooledConnection;
import oracle.sql.ARRAY;
import oracle.sql.ArrayDescriptor;
import oracle.sql.BFILE;
import oracle.sql.BLOB;
import oracle.sql.BfileDBAccess;
import oracle.sql.BlobDBAccess;
import oracle.sql.CLOB;
import oracle.sql.ClobDBAccess;
import oracle.sql.CustomDatum;
import oracle.sql.Datum;
import oracle.sql.StructDescriptor;

public interface OracleConnection extends OracleConnection {
  public static final int CHAR_TO_ASCII = 0;
  
  public static final int CHAR_TO_UNICODE = 1;
  
  public static final int RAW_TO_ASCII = 2;
  
  public static final int RAW_TO_UNICODE = 3;
  
  public static final int UNICODE_TO_CHAR = 4;
  
  public static final int ASCII_TO_CHAR = 5;
  
  public static final int NONE = 6;
  
  public static final int JAVACHAR_TO_CHAR = 7;
  
  public static final int RAW_TO_JAVACHAR = 8;
  
  public static final int CHAR_TO_JAVACHAR = 9;
  
  public static final int GLOBAL_TXN = 1;
  
  public static final int NO_GLOBAL_TXN = 0;
  
  short getStructAttrNCsId() throws SQLException;
  
  Map getTypeMap() throws SQLException;
  
  Properties getDBAccessProperties() throws SQLException;
  
  Properties getOCIHandles() throws SQLException;
  
  String getDatabaseProductVersion() throws SQLException;
  
  void cancel() throws SQLException;
  
  String getURL() throws SQLException;
  
  short getVersionNumber() throws SQLException;
  
  Map getJavaObjectTypeMap();
  
  void setJavaObjectTypeMap(Map paramMap);
  
  BfileDBAccess createBfileDBAccess() throws SQLException;
  
  BlobDBAccess createBlobDBAccess() throws SQLException;
  
  ClobDBAccess createClobDBAccess() throws SQLException;
  
  void setDefaultFixedString(boolean paramBoolean);
  
  boolean getDefaultFixedString();
  
  OracleConnection getWrapper();
  
  Class classForNameAndSchema(String paramString1, String paramString2) throws ClassNotFoundException;
  
  void setFDO(byte[] paramArrayOfbyte) throws SQLException;
  
  byte[] getFDO(boolean paramBoolean) throws SQLException;
  
  boolean getBigEndian() throws SQLException;
  
  Object getDescriptor(byte[] paramArrayOfbyte);
  
  void putDescriptor(byte[] paramArrayOfbyte, Object paramObject) throws SQLException;
  
  OracleConnection getPhysicalConnection();
  
  void removeDescriptor(String paramString);
  
  void removeAllDescriptor();
  
  int numberOfDescriptorCacheEntries();
  
  Enumeration descriptorCacheKeys();
  
  long getTdoCState(String paramString1, String paramString2) throws SQLException;
  
  Datum toDatum(CustomDatum paramCustomDatum) throws SQLException;
  
  short getDbCsId() throws SQLException;
  
  short getJdbcCsId() throws SQLException;
  
  short getNCharSet();
  
  ResultSet newArrayDataResultSet(Datum[] paramArrayOfDatum, long paramLong, int paramInt, Map paramMap) throws SQLException;
  
  ResultSet newArrayDataResultSet(ARRAY paramARRAY, long paramLong, int paramInt, Map paramMap) throws SQLException;
  
  ResultSet newArrayLocatorResultSet(ArrayDescriptor paramArrayDescriptor, byte[] paramArrayOfbyte, long paramLong, int paramInt, Map paramMap) throws SQLException;
  
  ResultSetMetaData newStructMetaData(StructDescriptor paramStructDescriptor) throws SQLException;
  
  void getForm(OracleTypeADT paramOracleTypeADT, OracleTypeCLOB paramOracleTypeCLOB, int paramInt) throws SQLException;
  
  int CHARBytesToJavaChars(byte[] paramArrayOfbyte, int paramInt, char[] paramArrayOfchar) throws SQLException;
  
  int NCHARBytesToJavaChars(byte[] paramArrayOfbyte, int paramInt, char[] paramArrayOfchar) throws SQLException;
  
  boolean IsNCharFixedWith();
  
  short getDriverCharSet();
  
  int getC2SNlsRatio();
  
  int getMaxCharSize() throws SQLException;
  
  int getMaxCharbyteSize();
  
  int getMaxNCharbyteSize();
  
  boolean isCharSetMultibyte(short paramShort);
  
  int javaCharsToCHARBytes(char[] paramArrayOfchar, int paramInt, byte[] paramArrayOfbyte) throws SQLException;
  
  int javaCharsToNCHARBytes(char[] paramArrayOfchar, int paramInt, byte[] paramArrayOfbyte) throws SQLException;
  
  void setStartTime(long paramLong) throws SQLException;
  
  long getStartTime() throws SQLException;
  
  boolean isStatementCacheInitialized();
  
  void getPropertyForPooledConnection(OraclePooledConnection paramOraclePooledConnection) throws SQLException;
  
  void setTypeMap(Map paramMap) throws SQLException;
  
  String getProtocolType();
  
  Connection getLogicalConnection(OraclePooledConnection paramOraclePooledConnection, boolean paramBoolean) throws SQLException;
  
  void setTxnMode(int paramInt);
  
  int getTxnMode();
  
  int getHeapAllocSize() throws SQLException;
  
  int getOCIEnvHeapAllocSize() throws SQLException;
  
  void setAbandonedTimeoutEnabled(boolean paramBoolean) throws SQLException;
  
  int getHeartbeatNoChangeCount() throws SQLException;
  
  void closeInternal(boolean paramBoolean) throws SQLException;
  
  void cleanupAndClose(boolean paramBoolean) throws SQLException;
  
  OracleConnectionCacheCallback getConnectionCacheCallbackObj() throws SQLException;
  
  Object getConnectionCacheCallbackPrivObj() throws SQLException;
  
  int getConnectionCacheCallbackFlag() throws SQLException;
  
  Properties getServerSessionInfo() throws SQLException;
  
  CLOB createClob(byte[] paramArrayOfbyte) throws SQLException;
  
  CLOB createClob(byte[] paramArrayOfbyte, short paramShort) throws SQLException;
  
  BLOB createBlob(byte[] paramArrayOfbyte) throws SQLException;
  
  BFILE createBfile(byte[] paramArrayOfbyte) throws SQLException;
  
  boolean isDescriptorSharable(OracleConnection paramOracleConnection) throws SQLException;
  
  OracleStatement refCursorCursorToStatement(int paramInt) throws SQLException;
  
  XAResource getXAResource() throws SQLException;
  
  void abort() throws SQLException;
  
  void setApplicationContext(String paramString1, String paramString2, String paramString3) throws SQLException;
  
  void clearAllApplicationContext(String paramString) throws SQLException;
  
  boolean isV8Compatible() throws SQLException;
  
  String getDefaultSchemaNameForNamedTypes() throws SQLException;
}


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\lib\ojdbc14.jar!\oracle\jdbc\internal\OracleConnection.class
 * Java compiler version: 2 (46.0)
 * JD-Core Version:       1.1.3
 */