package oracle.net.jndi;

import java.util.Properties;
import java.util.Vector;
import javax.naming.NamingEnumeration;
import javax.naming.NamingException;
import javax.naming.directory.Attribute;
import javax.naming.directory.Attributes;
import javax.naming.directory.DirContext;
import javax.naming.directory.InitialDirContext;
import oracle.net.ns.NetException;

public class JndiAttrs {
  private Properties env;
  
  private static final String nFactory = "java.naming.factory.initial";
  
  private static final String nProvider = "java.naming.provider.url";
  
  private static final String nProfile = "ora-net-profile";
  
  private static final String default_nFactory = "com.sun.jndi.ldap.LdapCtxFactory";
  
  DirContext ctx;
  
  public JndiAttrs(Properties paramProperties) throws NetException {
    String str = null;
    this.env = new Properties();
    if (paramProperties.containsKey("java.naming.factory.initial")) {
      this.env.put("java.naming.factory.initial", paramProperties.getProperty("java.naming.factory.initial"));
    } else {
      this.env.put("java.naming.factory.initial", "com.sun.jndi.ldap.LdapCtxFactory");
    } 
    if (paramProperties.containsKey("java.naming.provider.url")) {
      str = paramProperties.getProperty("java.naming.provider.url");
      if (str.startsWith("ldaps")) {
        this.env.put("java.naming.ldap.factory.socket", "oracle.net.jndi.CustomSSLSocketFactory");
        this.env.put("java.naming.security.protocol", "ssl");
        str = "ldap:" + str.substring(6);
      } 
      this.env.put("java.naming.provider.url", str);
    } 
    if (paramProperties.containsKey("oracle.net.profile"))
      this.env.put("ora-net-profile", paramProperties.getProperty("oracle.net.profile")); 
    try {
      Class clazz = Class.forName("javax.naming.directory.InitialDirContext");
      if (this.env.get("java.naming.factory.initial") == null)
        this.env.put("java.naming.factory.initial", "com.sun.jndi.ldap.LdapCtxFactory"); 
      if (this.env.get("java.naming.provider.url") == null)
        this.env.put("java.naming.provider.url", str); 
    } catch (Exception exception) {
      throw new NetException(110, exception.toString());
    } 
    Object object;
    if ((object = paramProperties.get("java.naming.security.authentication")) != null)
      this.env.put("java.naming.security.authentication", object); 
    if ((object = paramProperties.get("java.naming.security.principal")) != null)
      this.env.put("java.naming.security.principal", object); 
    if ((object = paramProperties.get("java.naming.security.credentials")) != null)
      this.env.put("java.naming.security.credentials", object); 
    byte b = 0;
    while (b < 3) {
      try {
        this.ctx = new InitialDirContext(this.env);
      } catch (NamingException namingException) {
        Class clazz = null;
        try {
          clazz = Class.forName("javax.net.ssl.SSLException");
        } catch (Exception exception) {
          throw new NetException(108, namingException.toString());
        } 
        if (clazz.isInstance(namingException.getRootCause()) && b < 3) {
          b++;
          continue;
        } 
        throw new NetException(108, namingException.toString());
      } 
    } 
  }
  
  public Vector getProfileAttrs(String paramString) throws NetException {
    String str = "cn=";
    Attributes attributes = null;
    try {
      str = str.concat(paramString);
      attributes = this.ctx.getAttributes(str);
    } catch (NamingException namingException) {
      throw new NetException(108, namingException.toString());
    } 
    return setAttrs(attributes);
  }
  
  public Vector getAttrs(String paramString, String[] paramArrayOfString) throws NetException {
    String str = "cn=";
    Attributes attributes = null;
    try {
      str = str.concat(paramString);
      attributes = this.ctx.getAttributes(str, paramArrayOfString);
    } catch (NamingException namingException) {
      throw new NetException(108, namingException.toString());
    } 
    return setAttrs(attributes);
  }
  
  private Vector setAttrs(Attributes paramAttributes) throws NetException {
    Vector vector = new Vector(1, 1);
    if (paramAttributes == null) {
      System.out.println("No attributes");
    } else {
      try {
        NamingEnumeration namingEnumeration = paramAttributes.getAll();
        while (namingEnumeration != null && namingEnumeration.hasMoreElements()) {
          Attribute attribute = namingEnumeration.next();
          NamingEnumeration namingEnumeration1 = attribute.getAll();
          while (namingEnumeration1.hasMoreElements())
            vector.addElement(namingEnumeration1.nextElement()); 
        } 
      } catch (NamingException namingException) {
        throw new NetException(108, namingException.toString());
      } 
    } 
    return vector;
  }
  
  public void setEnv(String paramString1, String paramString2) {
    this.env.put(paramString1, paramString2);
  }
  
  public void close() throws NetException {
    try {
      if (null != this.ctx)
        this.ctx.close(); 
    } catch (NamingException namingException) {
      throw new NetException(108, namingException.toString());
    } 
  }
  
  public final String getLdapUrlUsed() throws NetException {
    String str = null;
    try {
      str = (String)this.ctx.getEnvironment().get("java.naming.provider.url");
    } catch (NamingException namingException) {
      throw new NetException(108, namingException.toString());
    } 
    return str;
  }
}


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\lib\ojdbc14.jar!\oracle\net\jndi\JndiAttrs.class
 * Java compiler version: 2 (46.0)
 * JD-Core Version:       1.1.3
 */