package oracle.net.nl;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;
import java.io.Reader;
import java.io.Writer;
import java.util.Enumeration;
import java.util.Hashtable;
import java.util.StringTokenizer;
import java.util.Vector;

public class NLParamParser {
  private String filename;
  
  private Hashtable ht;
  
  private Vector linebuffer;
  
  private int filePermissions = 0;
  
  private int Commentcnt = 0;
  
  private int nvStringcnt = 0;
  
  private int Groupcnt = 0;
  
  private boolean hasComments = false;
  
  private boolean hasGroups = false;
  
  private String[] errstr;
  
  private int errstrcnt;
  
  public static final byte IGNORE_NONE = 0;
  
  public static final byte IGNORE_NL_EXCEPTION = 1;
  
  public static final byte IGNORE_FILE_EXCEPTION = 2;
  
  public static final byte NLPASUCC = 1;
  
  public static final byte NLPAOVWR = 2;
  
  public static final byte NLPAFAIL = -1;
  
  private static boolean DEBUG = false;
  
  public static NLParamParser createEmptyParamParser() {
    return new NLParamParser();
  }
  
  private NLParamParser() {
    this.filename = null;
    this.ht = new Hashtable(128);
  }
  
  public NLParamParser(String paramString) throws IOException, NLException {
    this(paramString, (byte)2);
  }
  
  public NLParamParser(String paramString, byte paramByte) throws NLException, IOException {
    this.filename = paramString;
    this.ht = new Hashtable(128);
    FileReader fileReader = null;
    BufferedReader bufferedReader = null;
    try {
      fileReader = new FileReader(paramString);
      bufferedReader = new BufferedReader(fileReader);
      initializeNlpa(bufferedReader, paramByte);
    } catch (FileNotFoundException fileNotFoundException) {
      if ((paramByte & 0x2) == 0)
        throw new FileNotFoundException(paramString); 
    } finally {
      if (fileReader != null)
        fileReader.close(); 
      if (bufferedReader != null)
        bufferedReader.close(); 
    } 
  }
  
  public NLParamParser(Reader paramReader) throws IOException, NLException {
    this(paramReader, (byte)0);
  }
  
  public NLParamParser(Reader paramReader, byte paramByte) throws IOException, NLException {
    BufferedReader bufferedReader = new BufferedReader(paramReader);
    this.filename = null;
    this.ht = new Hashtable(128);
    initializeNlpa(bufferedReader, paramByte);
  }
  
  private void initializeNlpa(BufferedReader paramBufferedReader, byte paramByte) throws IOException, NLException {
    this.linebuffer = new Vector(100, 50);
    this.errstr = new String[50];
    try {
      while (true) {
        String str = paramBufferedReader.readLine();
        if (str == null)
          break; 
        this.linebuffer.addElement(str);
      } 
    } catch (IOException iOException) {
      if ((paramByte & 0x2) == 0)
        throw new IOException("Unable to read a line from : " + this.filename); 
    } 
    String str1 = "";
    String str2 = System.getProperty("line.separator");
    String str3 = "";
    String str4 = "";
    for (byte b = 0; b < this.linebuffer.size(); b++) {
      String str = this.linebuffer.elementAt(b);
      if (str.length() != 0)
        if (str.charAt(0) == '#') {
          if (str.indexOf(".ORA Configuration ") != -1 || str.indexOf(" Network Configuration File: ") != -1 || str.indexOf("Generated by") != -1) {
            if (DEBUG)
              System.out.println(str + ": this comment ignored"); 
          } else if (str3.length() != 0) {
            str4 = str4 + str + str2;
          } else {
            str3 = "COMMENT#" + this.Commentcnt;
            str4 = str + str2;
            if (!this.hasComments)
              this.hasComments = true; 
          } 
        } else if (str.charAt(0) == ' ' || str.charAt(0) == '\t' || str.charAt(0) == ')') {
          if (str4.length() == 0) {
            if (str1.length() == 0)
              str = eatNLPWS(str); 
            str = checkNLPforComments(str);
            if (str.length() != 0)
              str1 = str1 + str + str2; 
          } else if (str1.length() == 0 && str4.length() != 0) {
            str = eatNLPWS(str);
            str = checkNLPforComments(str);
            if (str.length() != 0 && (paramByte & 0x1) == 0)
              throw new NLException("InvalidChar-04611", ""); 
          } else if (str1.length() != 0 && str4.length() != 0) {
            str3 = "";
            str4 = "";
            str = checkNLPforComments(str);
            str1 = str1 + str + str2;
          } 
        } else if (str1.length() == 0 && str4.length() == 0) {
          str = checkNLPforComments(str);
          str1 = str1 + str + str2;
        } else if (str1.length() == 0 && str4.length() != 0) {
          str4 = modifyCommentString(str4);
          try {
            addNLPListElement(str3 + "=" + str4);
          } catch (NLException nLException) {
            this.errstr[this.errstrcnt++] = str1;
            if ((paramByte & 0x1) == 0)
              throw nLException; 
          } 
          str3 = "";
          str4 = "";
          this.Commentcnt++;
          str = checkNLPforComments(str);
          str1 = str1 + str + str2;
        } else if (str1.length() != 0 && str4.length() == 0) {
          try {
            addNLPListElement(str1);
          } catch (NLException nLException) {
            this.errstr[this.errstrcnt++] = str1;
            if ((paramByte & 0x1) == 0)
              throw nLException; 
          } 
          str1 = "";
          str = checkNLPforComments(str);
          str1 = str1 + str + str2;
        } else if (str1.length() != 0 && str4.length() != 0) {
          try {
            addNLPListElement(str1);
          } catch (NLException nLException) {
            this.errstr[this.errstrcnt++] = str1;
            if ((paramByte & 0x1) == 0)
              throw nLException; 
          } 
          str1 = "";
          str = checkNLPforComments(str);
          str1 = str1 + str + str2;
          str4 = modifyCommentString(str4);
          try {
            addNLPListElement(str3 + "=" + str4);
          } catch (NLException nLException) {
            this.errstr[this.errstrcnt++] = str1;
            if ((paramByte & 0x1) == 0)
              throw nLException; 
          } 
          str3 = "";
          str4 = "";
          this.Commentcnt++;
        }  
    } 
    if (str1.length() != 0) {
      try {
        addNLPListElement(str1);
      } catch (NLException nLException) {
        this.errstr[this.errstrcnt++] = str1;
        if ((paramByte & 0x1) == 0)
          throw nLException; 
      } 
      str1 = "";
    } 
    if (str4.length() != 0) {
      str4 = modifyCommentString(str4);
      try {
        addNLPListElement(str3 + "=" + str4);
      } catch (NLException nLException) {
        this.errstr[this.errstrcnt++] = str1;
        if ((paramByte & 0x1) == 0)
          throw nLException; 
      } 
      str3 = "";
      str4 = "";
      this.Commentcnt++;
    } 
  }
  
  private String modifyCommentString(String paramString) {
    String str = "";
    boolean bool = false;
    for (byte b = 0; b < paramString.length(); b++) {
      char c = paramString.charAt(b);
      switch (c) {
        case '(':
          str = str + "\\(";
          break;
        case '=':
          str = str + "\\=";
          break;
        case ')':
          str = str + "\\)";
          break;
        case ',':
          str = str + "\\,";
          break;
        case '\\':
          str = str + "\\\\";
          break;
        default:
          str = str + paramString.charAt(b);
          break;
      } 
    } 
    return str;
  }
  
  private String checkNLPforComments(String paramString) {
    StringBuffer stringBuffer = new StringBuffer(paramString.length());
    boolean bool = false;
    for (byte b = 0; b < paramString.length(); b++) {
      char c = paramString.charAt(b);
      if (c == '#') {
        if (b != 0) {
          if (paramString.charAt(b - 1) == '\\') {
            stringBuffer.append(c);
          } else {
            break;
          } 
        } else {
          return "";
        } 
      } else {
        stringBuffer.append(c);
      } 
    } 
    return stringBuffer.toString();
  }
  
  private String eatNLPWS(String paramString) {
    StringBuffer stringBuffer = new StringBuffer(paramString.length());
    byte b = 0;
    boolean bool = false;
    while (!bool) {
      char c = paramString.charAt(b++);
      if (c != ' ' || c != '\t') {
        bool = true;
        for (int i = b - 1; paramString.charAt(i) == '\n'; i++)
          stringBuffer.append(paramString.charAt(i)); 
        continue;
      } 
      if (c == '\n')
        return ""; 
    } 
    return stringBuffer.toString();
  }
  
  public void saveNLParams() throws IOException {
    if (this.filename == null)
      return; 
    FileWriter fileWriter = null;
    try {
      fileWriter = new FileWriter(this.filename);
      String str = "unknown";
      StringTokenizer stringTokenizer = new StringTokenizer(this.filename, File.separator);
      while (stringTokenizer.hasMoreTokens())
        str = stringTokenizer.nextToken(); 
      writeToStream(fileWriter, str, this.filename);
    } finally {
      if (fileWriter != null)
        fileWriter.close(); 
    } 
  }
  
  public void writeToStream(Writer paramWriter, String paramString1, String paramString2) {
    PrintWriter printWriter = null;
    printWriter = new PrintWriter(new BufferedWriter(paramWriter));
    printWriter.println("# " + paramString1 + " Network Configuration File: " + paramString2 + "");
    printWriter.println("# Generated by Oracle configuration tools.");
    printWriter.println("");
    if (this.hasGroups)
      saveNLPGroups(printWriter); 
    Enumeration enumeration = this.ht.elements();
    while (enumeration.hasMoreElements()) {
      NVPair nVPair = enumeration.nextElement();
      String str = nVPair.toString(0, true);
      if (DEBUG)
        System.out.println("The initial stringified NVPair is:\n" + str); 
      if (!str.equals("")) {
        char[] arrayOfChar = new char[str.length() - 2];
        str.getChars(1, str.length() - 1, arrayOfChar, 0);
        String str1 = new String(arrayOfChar);
        if (DEBUG)
          System.out.println("The modified NV String is:\n" + str1); 
        printWriter.println(str1);
        printWriter.println("");
        arrayOfChar = null;
      } 
    } 
    printWriter.close();
  }
  
  public void saveNLParams(String paramString) throws FileNotFoundException, IOException {
    String str = this.filename;
    this.filename = paramString;
    saveNLParams();
    this.filename = str;
  }
  
  public String getFilename() {
    return this.filename;
  }
  
  public boolean configuredInFile() {
    return !(this.filename == null);
  }
  
  public int getNLPListSize() {
    this.nvStringcnt = 0;
    Enumeration enumeration = this.ht.keys();
    while (enumeration.hasMoreElements()) {
      String str = enumeration.nextElement();
      if (str.indexOf("COMMENT") == -1)
        this.nvStringcnt++; 
    } 
    return this.nvStringcnt;
  }
  
  public boolean inErrorList(String paramString) {
    boolean bool = false;
    if (DEBUG)
      System.out.println("Entering inErrorList():"); 
    for (byte b = 0; (!bool || b < this.errstrcnt) && this.errstrcnt != 0; b++) {
      if (this.errstr[b].indexOf(paramString) != -1)
        bool = true; 
    } 
    return bool;
  }
  
  public NVPair getNLPListElement(String paramString) {
    String str = paramString.toUpperCase();
    return (NVPair)this.ht.get(str);
  }
  
  public String[] getNLPAllNames() {
    int i = getNLPListSize();
    String[] arrayOfString = new String[i];
    byte b = 0;
    Enumeration enumeration = this.ht.keys();
    while (enumeration.hasMoreElements()) {
      String str = enumeration.nextElement();
      if (str.indexOf("COMMENT") == -1)
        arrayOfString[b++] = str; 
    } 
    return arrayOfString;
  }
  
  public String[] getNLPAllElements() {
    int i = getNLPListSize();
    String[] arrayOfString = new String[i];
    byte b = 0;
    Enumeration enumeration = this.ht.elements();
    while (enumeration.hasMoreElements()) {
      NVPair nVPair = enumeration.nextElement();
      if (nVPair.getName().indexOf("COMMENT") == -1) {
        String str = nVPair.toString();
        arrayOfString[b++] = str;
      } 
    } 
    return arrayOfString;
  }
  
  public byte addNLPListElement(String paramString, Object paramObject) {
    try {
      Object object = this.ht.put(paramString, paramObject);
      return (object != null) ? 2 : 1;
    } catch (NullPointerException nullPointerException) {
      if (DEBUG)
        System.out.println(nullPointerException.getMessage()); 
      return -1;
    } 
  }
  
  public void addNLPGroupProfile(String[] paramArrayOfString) {
    String str = new String("GROUP#" + this.Groupcnt++);
    String[] arrayOfString = paramArrayOfString;
    if (!this.hasGroups)
      this.hasGroups = true; 
    addNLPListElement(str, arrayOfString);
  }
  
  private String[] getNLPGroupProfile(String paramString) {
    String str = paramString.toUpperCase();
    return (String[])this.ht.get(str);
  }
  
  private void saveNLPGroups(PrintWriter paramPrintWriter) {
    for (byte b = 0; b < this.Groupcnt; b++) {
      String str = new String("GROUP#" + b);
      String[] arrayOfString = getNLPGroupProfile(str);
      for (byte b1 = 0; b1 < arrayOfString.length; b1++) {
        String str1 = null;
        String str2 = null;
        NVPair nVPair = null;
        if (DEBUG)
          System.out.println("Current Value in Group Profile: " + arrayOfString[b1]); 
        if (arrayOfString[b1] != null) {
          nVPair = getNLPListElement(arrayOfString[b1]);
          if (nVPair != null) {
            str1 = nVPair.toString(0, true);
            if (DEBUG)
              System.out.println("Parameter Value = " + str1); 
            char[] arrayOfChar = new char[str1.length() - 2];
            str1.getChars(1, str1.length() - 1, arrayOfChar, 0);
            str2 = new String(arrayOfChar);
            paramPrintWriter.println(str2);
            paramPrintWriter.println("");
            NVPair nVPair1 = removeNLPListElement(arrayOfString[b1]);
            if (nVPair1 == null && DEBUG)
              System.out.println("saveNLPGroups(): Could notremove param from Hashtable"); 
            arrayOfChar = null;
            str2 = null;
          } else if (DEBUG) {
            System.out.println("No such Parameter in the Table");
          } 
        } 
      } 
      removeNLPGroupProfile(str);
    } 
  }
  
  public void addNLPListElement(String paramString) throws NLException {
    char[] arrayOfChar = new char[paramString.length() + 2];
    String str1 = "";
    if (DEBUG) {
      System.out.println("Entering Method addNLPListElement\n");
      System.out.println("String to add is: " + paramString + "");
    } 
    paramString.getChars(0, paramString.length(), arrayOfChar, 1);
    if (arrayOfChar[1] == '(') {
      str1 = paramString;
    } else {
      arrayOfChar[0] = '(';
      String str = System.getProperty("os.name");
      if (str.equals("Windows NT") || str.equals("Windows 95")) {
        if (arrayOfChar[arrayOfChar.length - 2] == '/' || arrayOfChar[arrayOfChar.length - 2] == '\\') {
          arrayOfChar[arrayOfChar.length - 2] = ')';
        } else {
          arrayOfChar[arrayOfChar.length - 1] = ')';
        } 
      } else if (arrayOfChar[arrayOfChar.length - 2] == '\\') {
        arrayOfChar[arrayOfChar.length - 2] = ')';
      } else {
        arrayOfChar[arrayOfChar.length - 1] = ')';
      } 
      str1 = new String(arrayOfChar);
      if (DEBUG)
        System.out.println("The modified NV String is: " + str1 + ""); 
    } 
    NVFactory nVFactory = new NVFactory();
    NVPair nVPair = nVFactory.createNVPair(str1);
    if (nVPair.getRHSType() == NVPair.RHS_NONE)
      throw new NLException("NullRHS-04612", nVPair.getName()); 
    String str2 = nVPair.getName();
    String str3 = str2.toUpperCase();
    nVPair.setName(str3);
    if (DEBUG)
      System.out.println("The final NV String is: " + nVPair.toString() + ""); 
    byte b = addNLPListElement(str3, nVPair);
    switch (b) {
      case 2:
        if (DEBUG)
          System.out.println("The value for the Name: " + str2 + " was overwritten\n"); 
        break;
      case -1:
        if (DEBUG)
          System.out.println("The value for the Name: " + str2 + " could not be inserted\n"); 
        break;
    } 
  }
  
  public NVPair removeNLPListElement(String paramString) {
    String str = paramString.toUpperCase();
    if (DEBUG)
      System.out.println("Trying to remove: " + str + " from Table"); 
    Object object = this.ht.remove(str);
    return (object != null) ? (NVPair)object : null;
  }
  
  public void removeNLPGroupProfile(String paramString) {
    String str = paramString.toUpperCase();
    if (DEBUG)
      System.out.println("Trying to remove: " + str + " GroupName from Table"); 
    Object object = this.ht.remove(str);
  }
  
  public void removeNLPAllElements() {
    this.ht.clear();
  }
  
  public String toString() {
    String str = "";
    Enumeration enumeration = this.ht.elements();
    while (enumeration.hasMoreElements()) {
      NVPair nVPair = enumeration.nextElement();
      String str1 = nVPair.toString();
      str = str + str1 + "\n";
    } 
    return str;
  }
  
  public boolean fileHasComments() {
    return this.hasComments;
  }
  
  public void println() {
    System.out.println(toString());
  }
  
  public void setFilePermissions(int paramInt) {
    this.filePermissions = paramInt;
  }
}


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\lib\ojdbc14.jar!\oracle\net\nl\NLParamParser.class
 * Java compiler version: 2 (46.0)
 * JD-Core Version:       1.1.3
 */