package oracle.net.ns;

import java.util.Enumeration;
import java.util.Properties;
import java.util.StringTokenizer;

public class ClientProfile extends Properties {
  private static final String profile_name = "ora-net-profile";
  
  private static final String shared_profile_name = "ora-shared-profile";
  
  public ClientProfile() {}
  
  public ClientProfile(Properties paramProperties) {
    if (paramProperties.containsKey("oracle.net.profile"))
      put("oracle.net.profile", paramProperties.getProperty("oracle.net.profile")); 
    put("oracle.net.authentication_services", paramProperties.getProperty("oracle.net.authentication_services", "()"));
    put("oracle.net.encryption_client", paramProperties.getProperty("oracle.net.encryption_client", "ACCEPTED"));
    put("oracle.net.encryption_types_client", paramProperties.getProperty("oracle.net.encryption_types_client", "()"));
    put("oracle.net.crypto_checksum_client", paramProperties.getProperty("oracle.net.crypto_checksum_client", "ACCEPTED"));
    put("oracle.net.crypto_checksum_types_client", paramProperties.getProperty("oracle.net.crypto_checksum_types_client", "()"));
    put("oracle.net.crypto_seed", paramProperties.getProperty("oracle.net.crypto_seed", ""));
  }
  
  public String[] getAuthenticationServices() {
    return getServices((String)get("oracle.net.authentication_services"));
  }
  
  public String[] getEncryptionServices() {
    return getServices((String)get("oracle.net.encryption_types_client"));
  }
  
  public String[] getDataIntegrityServices() {
    return getServices((String)get("oracle.net.crypto_checksum_types_client"));
  }
  
  public String getEncryptionLevel() {
    return (String)get("oracle.net.encryption_client");
  }
  
  public int getEncryptionLevelNum() {
    return translateAnoValue(getEncryptionLevel());
  }
  
  public String getDataIntegrityLevel() {
    return (String)get("oracle.net.crypto_checksum_client");
  }
  
  public int getDataIntegrityLevelNum() {
    return translateAnoValue(getDataIntegrityLevel());
  }
  
  public void print() {
    System.out.println(" ----------------------------------------");
    System.out.println(" Displaying the content of ClientProfile ");
    System.out.println(" List:");
    list(System.out);
    Enumeration enumeration = propertyNames();
    System.out.println("Enumeration has elements ? " + enumeration.hasMoreElements());
    for (byte b = 0; enumeration.hasMoreElements(); b++) {
      String str = (String)enumeration.nextElement();
      System.out.println("Key " + b + " = " + str);
      System.out.println("Value = " + getProperty(str));
    } 
    System.out.println(" ----------------------------------------");
  }
  
  private String[] getServices(String paramString) {
    String str = removeParenths(paramString);
    StringTokenizer stringTokenizer = new StringTokenizer(str, ",");
    int i = stringTokenizer.countTokens();
    String[] arrayOfString = new String[i];
    for (byte b = 0; b < i; b++)
      arrayOfString[b] = stringTokenizer.nextToken().trim(); 
    return arrayOfString;
  }
  
  private String removeParenths(String paramString) {
    int i = paramString.indexOf('(');
    boolean bool = (i == -1) ? false : (i + 1);
    int j = paramString.lastIndexOf(')');
    int k = (j == -1) ? paramString.length() : j;
    String str = paramString.substring(bool, k);
    return str.trim();
  }
  
  private int translateAnoValue(String paramString) {
    byte b = 0;
    if (paramString.equalsIgnoreCase("ACCEPTED")) {
      b = 0;
    } else if (paramString.equalsIgnoreCase("REQUESTED")) {
      b = 2;
    } else if (paramString.equalsIgnoreCase("REQUIRED")) {
      b = 3;
    } else if (paramString.equalsIgnoreCase("REJECTED")) {
      b = 1;
    } 
    return b;
  }
}


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\lib\ojdbc14.jar!\oracle\net\ns\ClientProfile.class
 * Java compiler version: 2 (46.0)
 * JD-Core Version:       1.1.3
 */