package oracle.net.nt;

import java.io.IOException;
import java.net.InetSocketAddress;
import java.security.cert.X509Certificate;
import java.util.Properties;
import javax.net.ssl.SSLSocket;
import javax.net.ssl.SSLSocketFactory;
import oracle.net.nl.NLException;
import oracle.net.ns.NetException;

public class TcpsNTAdapter extends TcpNTAdapter {
  String matchSSLServerCertDNWith;
  
  boolean fullDNMatch;
  
  public TcpsNTAdapter(String paramString, Properties paramProperties) throws NLException {
    super(paramString, paramProperties);
  }
  
  public void connect() throws IOException {
    SSLSocketFactory sSLSocketFactory = CustomSSLSocketFactory.getSSLSocketFactory(this.socketOptions);
    this.socket = sSLSocketFactory.createSocket();
    InetSocketAddress inetSocketAddress = new InetSocketAddress(this.host, this.port);
    String str = (String)this.socketOptions.get(new Integer(2));
    try {
      boolean bool = (str == null) ? false : Integer.parseInt(str);
      this.socket.connect(inetSocketAddress, bool);
      setSSLSocketOptions();
    } catch (NumberFormatException numberFormatException) {
      throw new NetException(505);
    } 
  }
  
  public void setSSLSocketOptions() throws IOException {
    setSocketOptions();
    SSLSocket sSLSocket = (SSLSocket)this.socket;
    sSLSocket.setUseClientMode(true);
    TcpsConfigure.configureVersion(sSLSocket, (String)this.socketOptions.get(new Integer(6)));
    TcpsConfigure.configureCipherSuites(sSLSocket, (String)this.socketOptions.get(new Integer(7)));
  }
  
  public void setOption(int paramInt, Object paramObject) throws IOException, NetException {
    SSLSocket sSLSocket = (SSLSocket)this.socket;
    switch (paramInt) {
      case 8:
        setServerDNMatchValue((String[])paramObject);
        return;
      case 7:
        if (((String)paramObject).equalsIgnoreCase("TRUE")) {
          this.fullDNMatch = true;
        } else {
          this.fullDNMatch = false;
        } 
        return;
    } 
    super.setOption(paramInt, paramObject);
  }
  
  public Object getOption(int paramInt) throws IOException, NetException {
    String str1;
    X509Certificate x509Certificate;
    String str2;
    SSLSocket sSLSocket = (SSLSocket)this.socket;
    switch (paramInt) {
      case 2:
        str1 = sSLSocket.getSession().getCipherSuite();
        return (str1 != null && str1.indexOf("NULL") == -1) ? "TRUE" : "FALSE";
      case 5:
        return sSLSocket.getSession().getCipherSuite();
      case 3:
        x509Certificate = (X509Certificate)sSLSocket.getSession().getPeerCertificates()[0];
        return x509Certificate.getSubjectDN().getName();
      case 4:
        return sSLSocket.getSession().getPeerCertificateChain();
      case 6:
        str2 = (String)this.socketOptions.get(new Integer(4));
        if (str2 == null)
          str2 = System.getProperty("oracle.net.ssl_server_dn_match", "false"); 
        if (str2.equalsIgnoreCase("YES") || str2.equalsIgnoreCase("ON") || str2.equalsIgnoreCase("TRUE")) {
          X509Certificate x509Certificate1 = (X509Certificate)sSLSocket.getSession().getPeerCertificates()[0];
          String str = x509Certificate1.getSubjectDN().getName();
          return TcpsConfigure.matchServerDN(str, this.matchSSLServerCertDNWith, this.fullDNMatch) ? "TRUE" : "FALSE";
        } 
        return "TRUE";
    } 
    return super.getOption(paramInt);
  }
  
  public void setServerDNMatchValue(String[] paramArrayOfString) {
    String str1 = paramArrayOfString[0];
    String str2 = paramArrayOfString[1];
    String str3 = paramArrayOfString[2];
    if (str1 != null) {
      this.matchSSLServerCertDNWith = str1;
      this.fullDNMatch = true;
    } else if (str2 != null) {
      if (str2.indexOf('.') != -1) {
        this.matchSSLServerCertDNWith = "CN=" + str2.substring(0, str2.indexOf('.'));
      } else {
        this.matchSSLServerCertDNWith = "CN=" + str2.trim();
      } 
    } else if (str3 != null) {
      if (str3.indexOf('.') != -1) {
        this.matchSSLServerCertDNWith = "CN=" + str3.substring(0, str3.indexOf('.'));
      } else {
        this.matchSSLServerCertDNWith = "CN=" + str3.trim();
      } 
    } 
  }
}


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\lib\ojdbc14.jar!\oracle\net\nt\TcpsNTAdapter.class
 * Java compiler version: 2 (46.0)
 * JD-Core Version:       1.1.3
 */