package oracle.net.resolver;

import java.io.IOException;
import java.util.Hashtable;
import java.util.Properties;
import java.util.Vector;
import oracle.net.TNSAddress.SOException;
import oracle.net.jndi.JndiAttrs;
import oracle.net.nl.NLException;
import oracle.net.nl.NVFactory;
import oracle.net.nl.NVNavigator;
import oracle.net.nl.NVPair;
import oracle.net.ns.NetException;
import oracle.net.nt.ConnOption;
import oracle.net.nt.ConnStrategy;

public class AddrResolution {
  private ConnStrategy cs;
  
  private Properties up;
  
  private static final String default_proxy_rules = "__jdbc__";
  
  private static final String service_alias_name = "ora-net-service-alias";
  
  private static final String service_attr_name = "orclnetdescstring";
  
  private static final int length_of_alias_prefix = 6;
  
  public static final int DEFAULT_DATABASE_PORT = 1521;
  
  public static final String DEFAULT_CONNECT_PROTOCOL = "TCP";
  
  private boolean newSyntax = true;
  
  public boolean connection_revised = false;
  
  public boolean connection_redirected = false;
  
  private String TNSAddress;
  
  public AddrResolution(String paramString, Properties paramProperties) throws NetException {
    this.up = paramProperties;
    this.TNSAddress = paramString;
    if (this.up.containsKey("java.naming.provider.url") || paramString.startsWith("ldap:") || paramString.startsWith("ldaps:")) {
      boolean bool = false;
      if (paramString.startsWith("ldap:") || paramString.startsWith("ldaps:"))
        if (paramString.indexOf(' ') > 0) {
          bool = true;
        } else {
          int i;
          if ((i = paramString.lastIndexOf('/')) == -1)
            throw new NetException(124); 
          this.up.put("java.naming.provider.url", paramString.substring(0, i));
          this.TNSAddress = paramString.substring(i + 1, paramString.length());
        }  
      if (!bool) {
        String[] arrayOfString = new String[1];
        JndiAttrs jndiAttrs = new JndiAttrs(this.up);
        arrayOfString[0] = "orclnetdescstring";
        Vector vector = null;
        try {
          vector = jndiAttrs.getAttrs(this.TNSAddress, arrayOfString);
        } finally {
          jndiAttrs.close();
        } 
        this.TNSAddress = vector.firstElement();
        this.connection_revised = true;
      } else {
        processLdapFailoverLoadblance(paramString);
      } 
    } 
    if (this.up.getProperty("oracle.net.oldSyntax") == "YES")
      this.newSyntax = false; 
  }
  
  private void processLdapFailoverLoadblance(String paramString) throws NetException {
    int i = 0;
    Vector vector1 = new Vector(10);
    char[] arrayOfChar = paramString.toCharArray();
    int j = arrayOfChar.length;
    while (i < j) {
      int m;
      for (m = i + 1; m < j && arrayOfChar[m] != ' '; m++);
      String str = new String(arrayOfChar, i, m - i);
      if (str.startsWith("ldap")) {
        vector1.addElement(str);
      } else {
        throw new NetException(124);
      } 
      for (i = m + 1; i < j && arrayOfChar[i] == ' '; i++);
    } 
    if (vector1.size() <= 0)
      throw new NetException(124); 
    boolean bool1 = true;
    boolean bool2 = true;
    String str1;
    if ((str1 = this.up.getProperty("oracle.net.ldap_failover")) != null && (str1.equalsIgnoreCase("OFF") || str1.equalsIgnoreCase("FALSE") || str1.equalsIgnoreCase("NO")))
      bool1 = false; 
    if ((str1 = this.up.getProperty("oracle.net.ldap_loadbalance")) != null && (str1.equalsIgnoreCase("OFF") || str1.equalsIgnoreCase("FALSE") || str1.equalsIgnoreCase("NO")))
      bool2 = false; 
    if (vector1.size() > 1)
      vector1 = NavDescriptionList.setActiveChildren(vector1, bool1, bool2); 
    StringBuffer stringBuffer = new StringBuffer();
    int k = vector1.size();
    Hashtable hashtable = new Hashtable(k);
    for (byte b = 0; b < k; b++) {
      String str4 = vector1.elementAt(b);
      int m;
      if ((m = str4.lastIndexOf('/')) == -1)
        throw new NetException(124); 
      String str5 = str4.substring(0, m);
      String str6 = str4.substring(m + 1, str4.length());
      stringBuffer.append(str5);
      if (b < k - 1)
        stringBuffer.append(' '); 
      hashtable.put(str5, str6);
    } 
    String str2 = new String(stringBuffer);
    this.up.put("java.naming.provider.url", str2);
    JndiAttrs jndiAttrs = new JndiAttrs(this.up);
    String str3 = jndiAttrs.getLdapUrlUsed();
    this.TNSAddress = (String)hashtable.get(str3);
    Vector vector2 = null;
    String[] arrayOfString = new String[1];
    arrayOfString[0] = "orclnetdescstring";
    try {
      vector2 = jndiAttrs.getAttrs(this.TNSAddress, arrayOfString);
    } finally {
      jndiAttrs.close();
    } 
    this.TNSAddress = vector2.firstElement();
    this.connection_revised = true;
  }
  
  public String getTNSAddress() {
    return this.TNSAddress.toUpperCase();
  }
  
  public ConnOption resolveAndExecute(String paramString) throws NetException, IOException {
    ConnStrategy connStrategy = this.cs;
    if (paramString != null) {
      this.cs = new ConnStrategy(this.up);
      if (this.connection_redirected) {
        this.cs.sdu = connStrategy.sdu;
        this.cs.tdu = connStrategy.tdu;
        this.cs.socketOptions = connStrategy.socketOptions;
        this.cs.reuseOpt = true;
        this.connection_redirected = false;
      } 
      if (paramString.indexOf(')') == -1) {
        int i;
        if ((i = paramString.indexOf(':')) != -1 && paramString.indexOf(':', i + 1) != -1) {
          resolveSimple(paramString);
        } else {
          String str = System.getProperty("oracle.net.tns_admin");
          NameResolver nameResolver = NameResolverFactory.getNameResolver(str);
          resolveAddrTree(nameResolver.resolveName(paramString));
        } 
      } else if (this.newSyntax) {
        resolveAddrTree(paramString);
      } else {
        resolveAddr(paramString);
      } 
    } else if (this.cs == null || !this.cs.hasMoreOptions()) {
      return null;
    } 
    return this.cs.execute();
  }
  
  private void resolveSimple(String paramString) throws NetException {
    ConnOption connOption = new ConnOption();
    int i = 0;
    int j = 0;
    int k = 0;
    if ((i = paramString.indexOf(':')) == -1 || (j = paramString.indexOf(':', i + 1)) == -1)
      throw new NetException(115); 
    if ((k = paramString.indexOf(':', j + 1)) != -1)
      throw new NetException(115); 
    try {
      connOption.host = paramString.substring(0, i);
      connOption.port = Integer.parseInt(paramString.substring(i + 1, j));
      connOption.addr = "(ADDRESS=(PROTOCOL=tcp)(HOST=" + connOption.host + ")(PORT=" + connOption.port + "))";
      connOption.sid = paramString.substring(j + 1, paramString.length());
      String str = "(DESCRIPTION=(CONNECT_DATA=(SID=" + connOption.sid + ")(CID=(PROGRAM=)(HOST=__jdbc__)(USER=)))" + "(ADDRESS=" + "(PROTOCOL=tcp)(HOST=" + connOption.host + ")(PORT=" + connOption.port + ")))";
      connOption.protocol = "TCP";
      connOption.conn_data = new StringBuffer(str);
      this.cs.addOption(connOption);
    } catch (NumberFormatException numberFormatException) {
      throw new NetException(116);
    } 
  }
  
  private void resolveAddr(String paramString) throws NetException {
    if (paramString.startsWith("alias=")) {
      String str = paramString;
      paramString = str.substring(str.indexOf("alias=") + 6, str.length());
    } 
    ConnOption connOption = new ConnOption();
    NVFactory nVFactory = new NVFactory();
    NVNavigator nVNavigator = new NVNavigator();
    NVPair nVPair1 = null;
    NVPair nVPair2 = null;
    try {
      nVPair1 = nVNavigator.findNVPairRecurse(nVFactory.createNVPair(paramString), "CID");
      nVPair2 = nVNavigator.findNVPairRecurse(nVFactory.createNVPair(paramString), "address");
    } catch (NLException nLException) {
      System.err.println(nLException.getMessage());
    } 
    NVPair nVPair3 = nVNavigator.findNVPair(nVPair2, "protocol");
    if (nVPair3 == null)
      throw new NetException(100); 
    connOption.protocol = nVPair3.getAtom();
    if (!connOption.protocol.equals("TCP") && !connOption.protocol.equals("tcp") && !connOption.protocol.equals("SSL") && !connOption.protocol.equals("ssl") && !connOption.protocol.equals("ANO") && !connOption.protocol.equals("ano"))
      throw new NetException(102); 
    nVPair3 = nVNavigator.findNVPair(nVPair2, "Host");
    if (nVPair3 == null)
      throw new NetException(103); 
    connOption.host = nVPair3.getAtom();
    nVPair3 = nVNavigator.findNVPair(nVPair2, "Port");
    if (nVPair3 == null)
      throw new NetException(104); 
    connOption.port = Integer.parseInt(nVPair3.getAtom());
    nVPair3 = nVNavigator.findNVPair(nVPair2, "sduSize");
    if (nVPair3 != null)
      connOption.sdu = Integer.parseInt(nVPair3.getAtom()); 
    nVPair3 = nVNavigator.findNVPair(nVPair2, "tduSize");
    if (nVPair3 != null)
      connOption.tdu = Integer.parseInt(nVPair3.getAtom()); 
    NVPair nVPair4 = null;
    try {
      nVPair4 = nVNavigator.findNVPairRecurse(nVFactory.createNVPair(paramString), "connect_data");
    } catch (NLException nLException) {
      System.err.println(nLException.getMessage());
    } 
    StringBuffer stringBuffer = new StringBuffer(paramString);
    connOption.conn_data = (nVPair4 != null) ? insertCID(paramString) : stringBuffer;
    connOption.addr = "(ADDRESS=(PROTOCOL=tcp)(HOST=" + connOption.host + ")(PORT=" + connOption.port + "))";
    this.cs.addOption(connOption);
  }
  
  private void resolveAddrTree(String paramString) throws NetException {
    NavSchemaObjectFactory navSchemaObjectFactory = new NavSchemaObjectFactory();
    NavServiceAlias navServiceAlias = (NavServiceAlias)navSchemaObjectFactory.create(4);
    try {
      String str = paramString.startsWith("alias=") ? paramString : ("alias=" + paramString);
      navServiceAlias.initFromString(str);
    } catch (NLException nLException) {
      throw new NetException(501);
    } catch (SOException sOException) {
      throw new NetException(502, sOException.getMessage());
    } 
    navServiceAlias.navigate(this.cs, (StringBuffer)null);
  }
  
  private StringBuffer insertCID(String paramString) throws NetException {
    NVFactory nVFactory = new NVFactory();
    NVNavigator nVNavigator = new NVNavigator();
    StringBuffer stringBuffer = new StringBuffer(2048);
    NVPair nVPair1 = null;
    NVPair nVPair2 = null;
    NVPair nVPair3 = null;
    NVPair nVPair4 = null;
    NVPair nVPair5 = null;
    try {
      nVPair1 = nVNavigator.findNVPairRecurse(nVFactory.createNVPair(paramString), "description");
      nVPair2 = nVNavigator.findNVPairRecurse(nVFactory.createNVPair(paramString), "address_list");
      nVPair3 = nVNavigator.findNVPairRecurse(nVFactory.createNVPair(paramString), "address");
      nVPair4 = nVNavigator.findNVPairRecurse(nVFactory.createNVPair(paramString), "connect_data");
      nVPair5 = nVNavigator.findNVPairRecurse(nVFactory.createNVPair(paramString), "source_route");
    } catch (NLException nLException) {
      System.err.println(nLException.getMessage());
    } 
    NVPair nVPair6 = null;
    NVPair nVPair7 = null;
    NVPair nVPair8 = null;
    if (nVPair4 != null) {
      nVPair6 = nVNavigator.findNVPair(nVPair4, "SID");
      nVPair7 = nVNavigator.findNVPair(nVPair4, "CID");
      nVPair8 = nVNavigator.findNVPair(nVPair4, "SERVICE_NAME");
    } else {
      throw new NetException(105);
    } 
    if (nVPair6 == null && nVPair8 == null)
      throw new NetException(106); 
    stringBuffer.append("(DESCRIPTION=");
    if (nVPair2 != null && nVPair2.getListSize() > 0) {
      for (byte b = 0; b < nVPair2.getListSize(); b++) {
        NVPair nVPair = nVPair2.getListElement(b);
        stringBuffer.append(nVPair.toString());
      } 
    } else if (nVPair3 != null) {
      stringBuffer.append(nVPair3.toString());
    } else {
      throw new NetException(107);
    } 
    if (nVPair8 != null) {
      stringBuffer.append("(CONNECT_DATA=" + nVPair8.toString() + "(CID=(PROGRAM=)(HOST=__jdbc__)(USER=)))");
    } else {
      stringBuffer.append("(CONNECT_DATA=" + nVPair6.toString() + "(CID=(PROGRAM=)(HOST=__jdbc__)(USER=)))");
    } 
    if (nVPair5 != null)
      stringBuffer.append(nVPair5.toString()); 
    stringBuffer.append(")");
    return stringBuffer;
  }
  
  public Properties getUp() {
    return this.up;
  }
}


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\lib\ojdbc14.jar!\oracle\net\resolver\AddrResolution.class
 * Java compiler version: 2 (46.0)
 * JD-Core Version:       1.1.3
 */