package oracle.net.resolver;

import java.util.ArrayList;
import java.util.Hashtable;
import oracle.net.nl.InvalidSyntaxException;
import oracle.net.nl.NLException;
import oracle.net.nl.NVFactory;
import oracle.net.nl.NVPair;
import oracle.net.ns.NetException;

public class NameResolver {
  private String tnsAdmin;
  
  private String[] readPath;
  
  private Hashtable adapterHash;
  
  private static final boolean DEBUG = false;
  
  private static final String[] DEFAULT_SEARCH_PATH = new String[] { "TNSNAMES", "HOSTNAME" };
  
  private static final String TNS_ADMIN_PROPERTY = "oracle.net.tns_admin";
  
  private static final String READ_PATH_PROPERTY = "oracle.net.names.directory_path";
  
  protected NameResolver(String paramString) throws NetException {
    this.tnsAdmin = paramString;
    bootNameResolver();
  }
  
  public String resolveName(String paramString) throws NetException {
    if (paramString == null)
      throw new NetException(120); 
    String str1 = paramString.trim();
    if (str1.length() == 0)
      throw new NetException(120); 
    String str2 = null;
    if (this.tnsAdmin == null) {
      HostnameNamingAdapter hostnameNamingAdapter = new HostnameNamingAdapter();
      return hostnameNamingAdapter.resolve(str1);
    } 
    NamingAdapterInterface namingAdapterInterface = null;
    for (byte b = 0; str2 == null && b < this.readPath.length; b++) {
      namingAdapterInterface = (NamingAdapterInterface)this.adapterHash.get(this.readPath[b]);
      try {
        str2 = namingAdapterInterface.resolve(str1);
      } catch (NetException netException) {}
    } 
    if (str2 == null)
      throw new NetException(122, "\"" + paramString + "\""); 
    return str2;
  }
  
  private void addAdapters() {
    if (this.adapterHash == null)
      this.adapterHash = new Hashtable(); 
    this.adapterHash.put("TNSNAMES", new TNSNamesNamingAdapter(this.tnsAdmin));
    this.adapterHash.put("HOSTNAME", new HostnameNamingAdapter());
  }
  
  private void bootNameResolver() throws NetException {
    if (this.tnsAdmin != null) {
      setReadPath();
      addAdapters();
    } 
  }
  
  private boolean checkForValidAdapter(String paramString) {
    int i = DEFAULT_SEARCH_PATH.length;
    for (byte b = 0; b < i; b++) {
      if (DEFAULT_SEARCH_PATH[b].equalsIgnoreCase(paramString))
        return true; 
    } 
    return false;
  }
  
  private void setDefaultPath() {
    this.readPath = DEFAULT_SEARCH_PATH;
  }
  
  private void setReadPath() throws NetException {
    byte b = 0;
    String[] arrayOfString = getUserReadPath();
    if (arrayOfString == null) {
      setDefaultPath();
      return;
    } 
    ArrayList arrayList = new ArrayList();
    for (b = 0; b < arrayOfString.length; b++) {
      if (checkForValidAdapter(arrayOfString[b]) == true) {
        String str = arrayOfString[b];
        str = str.toUpperCase();
        if (!arrayList.contains(str))
          arrayList.add(arrayOfString[b].toUpperCase()); 
      } 
    } 
    int i = arrayList.size();
    if (i == 0)
      throw new NetException(121, " The Read path did not contain any valid adapters."); 
    this.readPath = new String[i];
    arrayList.toArray(this.readPath);
  }
  
  private String[] getUserReadPath() throws NetException {
    String[] arrayOfString = null;
    String str1 = System.getProperty("oracle.net.names.directory_path");
    if (str1 == null)
      return null; 
    str1 = str1.trim();
    if (str1.length() == 0)
      return null; 
    StringBuffer stringBuffer = new StringBuffer(str1);
    if (stringBuffer.charAt(0) == '(') {
      stringBuffer.insert(0, "(path=").append(')');
    } else {
      stringBuffer.insert(0, "(path=(").append("))");
    } 
    String str2 = stringBuffer.toString();
    NVFactory nVFactory = new NVFactory();
    NVPair nVPair = null;
    try {
      nVPair = nVFactory.createNVPair(str2);
      if (nVPair.getRHSType() != NVPair.RHS_LIST || nVPair.getListType() != NVPair.LIST_COMMASEP)
        throw new NetException(121, " Read path specified is " + str1); 
      int i = nVPair.getListSize();
      String[] arrayOfString1 = new String[i];
      for (byte b = 0; b < i; b++)
        arrayOfString1[b] = nVPair.getListElement(b).getName(); 
      arrayOfString = arrayOfString1;
    } catch (InvalidSyntaxException invalidSyntaxException) {
      throw new NetException(121, " Read path specified is " + str1);
    } catch (NLException nLException) {
      throw new NetException(121, " Read path specified is " + str2);
    } 
    return arrayOfString;
  }
}


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\lib\ojdbc14.jar!\oracle\net\resolver\NameResolver.class
 * Java compiler version: 2 (46.0)
 * JD-Core Version:       1.1.3
 */