package oracle.net.resolver;

import java.io.File;
import java.io.IOException;
import oracle.net.nl.NLException;
import oracle.net.nl.NLParamParser;
import oracle.net.nl.NVPair;
import oracle.net.ns.NetException;

public class TNSNamesNamingAdapter implements NamingAdapterInterface {
  private NLParamParser tnsEntriesHdl;
  
  private String tnsDir;
  
  private long lastModifiedTime;
  
  private long nextPollTime;
  
  private static final String TNSFILE = "tnsnames.ora";
  
  private static final long REFRESH_INTERVAL = 0L;
  
  public TNSNamesNamingAdapter(String paramString) {
    this.tnsDir = paramString;
    resetAttr();
  }
  
  private void resetAttr() {
    this.tnsEntriesHdl = null;
    this.lastModifiedTime = 0L;
    this.nextPollTime = 0L;
  }
  
  public String resolve(String paramString) throws NetException {
    NVPair nVPair = null;
    synchronized (this) {
      checkAndReload();
      nVPair = this.tnsEntriesHdl.getNLPListElement(paramString);
    } 
    if (nVPair == null)
      throw new NetException(122, "\"" + paramString + "\""); 
    return nVPair.valueToString();
  }
  
  private void loadFile() throws NetException {
    File file = new File(this.tnsDir, "tnsnames.ora");
    String str = file.getAbsolutePath();
    if (!file.isFile() || !file.canRead()) {
      resetAttr();
      throw new NetException(123, ": " + str);
    } 
    long l = file.lastModified();
    if (this.lastModifiedTime != l)
      try {
        this.tnsEntriesHdl = new NLParamParser(str, (byte)1);
        this.lastModifiedTime = l;
      } catch (IOException iOException) {
        resetAttr();
        throw new NetException(123, ": " + str);
      } catch (NLException nLException) {} 
  }
  
  private void checkAndReload() throws NetException {
    long l = System.currentTimeMillis();
    if (l > this.nextPollTime) {
      this.nextPollTime = l + 0L;
      loadFile();
    } 
  }
}


/* Location:              C:\Users\WJF\Downloads\W020241206353121127023\sydj\plugins\cs.sydj_3.4.3\!\lib\ojdbc14.jar!\oracle\net\resolver\TNSNamesNamingAdapter.class
 * Java compiler version: 2 (46.0)
 * JD-Core Version:       1.1.3
 */